//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs finite impulse response (FIR) filtering.
//    The filter's sum of products is pipelined with a register after
//    every multiplier and adder.  The adder network is a balanced binary
//    tree to minimize latency.  The sum of products has no numeric loss because the
//    multipliers keep all resulting bits and each adder extends the precision by 1.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
//  
//    Inputs:
//      data_i  : Input data.
//      k0_i    : Coefficient 0 multiplied by in_i(0).
//      k1_i    : Coefficient 1 multiplied by in_i(k-1).
//      k2_i    : Coefficient 2 multiplied by in_i(k-2).
//      ...
//      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
//  
//    Outputs:
//      data_o : Output data.
//  
//  Built In Parameters:
//  
//    Filter Order             = 12
//    Input Precision          = 16
//    Coefficient Precision    = 10
//    Sum of Products Latency  = 5
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:45:51 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fir_12_16_10
//    Clock Domains : clock_c  
//    Vector Input  : reset_i(1)
//    Vector Input  : data_i(16)
//    Vector Input  : k0_i(10)
//    Vector Input  : k1_i(10)
//    Vector Input  : k2_i(10)
//    Vector Input  : k3_i(10)
//    Vector Input  : k4_i(10)
//    Vector Input  : k5_i(10)
//    Vector Input  : k6_i(10)
//    Vector Input  : k7_i(10)
//    Vector Input  : k8_i(10)
//    Vector Input  : k9_i(10)
//    Vector Input  : k10_i(10)
//    Vector Input  : k11_i(10)
//    Vector Input  : k12_i(10)
//    Vector Output : data_o(30)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_fir_12_16_10.h"

static unsigned char *data_o;
static unsigned char n365[1];
static unsigned char n363[1];
static unsigned char n353[1];
static unsigned char n351[1];
static unsigned char n341[1];
static unsigned char n339[1];
static unsigned char n330[1];
static unsigned char n320[1];
static unsigned char n318[1];
static unsigned char n308[1];
static unsigned char n306[1];
static unsigned char n296[1];
static unsigned char n294[1];
static unsigned char n285[1];
static unsigned char n275[1];
static unsigned char n273[1];
static unsigned char n263[1];
static unsigned char n261[1];
static unsigned char n251[1];
static unsigned char n249[1];
static unsigned char n239[1];
static unsigned char n237[1];
static unsigned char n227[1];
static unsigned char n225[1];
static unsigned char n215[1];
static unsigned char n213[1];
static unsigned char *data_i;
static unsigned char *k12_i;
static unsigned char *k11_i;
static unsigned char *k10_i;
static unsigned char *k9_i;
static unsigned char *k8_i;
static unsigned char *k7_i;
static unsigned char *k6_i;
static unsigned char *k5_i;
static unsigned char *k4_i;
static unsigned char *k3_i;
static unsigned char *k2_i;
static unsigned char *k1_i;
static unsigned char *k0_i;
static unsigned char *reset_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char n366[4];
static unsigned char n364[4];
static unsigned char n354[4];
static unsigned char n352[4];
static unsigned char n342[4];
static unsigned char n340[4];
static unsigned char n331[4];
static unsigned char n321[4];
static unsigned char n319[4];
static unsigned char n309[4];
static unsigned char n307[4];
static unsigned char n297[4];
static unsigned char n295[4];
static unsigned char n286[4];
static unsigned char n276[4];
static unsigned char n274[4];
static unsigned char n264[4];
static unsigned char n262[4];
static unsigned char n252[4];
static unsigned char n250[4];
static unsigned char n240[4];
static unsigned char n238[4];
static unsigned char n228[4];
static unsigned char n226[4];
static unsigned char n216[4];
static unsigned char n214[4];
static unsigned char n205[4];
static unsigned char n197[4];
static unsigned char n189[4];
static unsigned char n181[4];
static unsigned char n173[4];
static unsigned char n165[4];
static unsigned char n157[4];
static unsigned char n149[4];
static unsigned char n141[4];
static unsigned char n133[4];
static unsigned char n125[4];
static unsigned char n117[4];
static unsigned char n109[4];
static unsigned char n108[2];
static unsigned char n108r[1];
static unsigned char n108e[1];
static unsigned char n108d[2];
static unsigned char n101[2];
static unsigned char n101r[1];
static unsigned char n101e[1];
static unsigned char n101d[2];
static unsigned char n94[2];
static unsigned char n94r[1];
static unsigned char n94e[1];
static unsigned char n94d[2];
static unsigned char n87[2];
static unsigned char n87r[1];
static unsigned char n87e[1];
static unsigned char n87d[2];
static unsigned char n80[2];
static unsigned char n80r[1];
static unsigned char n80e[1];
static unsigned char n80d[2];
static unsigned char n73[2];
static unsigned char n73r[1];
static unsigned char n73e[1];
static unsigned char n73d[2];
static unsigned char n66[2];
static unsigned char n66r[1];
static unsigned char n66e[1];
static unsigned char n66d[2];
static unsigned char n59[2];
static unsigned char n59r[1];
static unsigned char n59e[1];
static unsigned char n59d[2];
static unsigned char n52[2];
static unsigned char n52r[1];
static unsigned char n52e[1];
static unsigned char n52d[2];
static unsigned char n45[2];
static unsigned char n45r[1];
static unsigned char n45e[1];
static unsigned char n45d[2];
static unsigned char n38[2];
static unsigned char n38r[1];
static unsigned char n38e[1];
static unsigned char n38d[2];
static unsigned char n31[2];
static unsigned char n31r[1];
static unsigned char n31e[1];
static unsigned char n31d[2];
static unsigned char n24[2];
static unsigned char n24r[1];
static unsigned char n24e[1];
static unsigned char n24d[2];
static unsigned char n367[4];
static unsigned char n355[4];
static unsigned char n343[4];
static unsigned char n338[4];
static unsigned char n338r[1];
static unsigned char n338e[1];
static unsigned char n338d[4];
static unsigned char n322[4];
static unsigned char n310[4];
static unsigned char n298[4];
static unsigned char n293[4];
static unsigned char n293r[1];
static unsigned char n293e[1];
static unsigned char n293d[4];
static unsigned char n277[4];
static unsigned char n265[4];
static unsigned char n253[4];
static unsigned char n241[4];
static unsigned char n229[4];
static unsigned char n217[4];
static unsigned char n212[4];
static unsigned char n212r[1];
static unsigned char n212e[1];
static unsigned char n212d[4];
static unsigned char n204[4];
static unsigned char n204r[1];
static unsigned char n204e[1];
static unsigned char n204d[4];
static unsigned char n196[4];
static unsigned char n196r[1];
static unsigned char n196e[1];
static unsigned char n196d[4];
static unsigned char n188[4];
static unsigned char n188r[1];
static unsigned char n188e[1];
static unsigned char n188d[4];
static unsigned char n180[4];
static unsigned char n180r[1];
static unsigned char n180e[1];
static unsigned char n180d[4];
static unsigned char n172[4];
static unsigned char n172r[1];
static unsigned char n172e[1];
static unsigned char n172d[4];
static unsigned char n164[4];
static unsigned char n164r[1];
static unsigned char n164e[1];
static unsigned char n164d[4];
static unsigned char n156[4];
static unsigned char n156r[1];
static unsigned char n156e[1];
static unsigned char n156d[4];
static unsigned char n148[4];
static unsigned char n148r[1];
static unsigned char n148e[1];
static unsigned char n148d[4];
static unsigned char n140[4];
static unsigned char n140r[1];
static unsigned char n140e[1];
static unsigned char n140d[4];
static unsigned char n132[4];
static unsigned char n132r[1];
static unsigned char n132e[1];
static unsigned char n132d[4];
static unsigned char n124[4];
static unsigned char n124r[1];
static unsigned char n124e[1];
static unsigned char n124d[4];
static unsigned char n116[4];
static unsigned char n116r[1];
static unsigned char n116e[1];
static unsigned char n116d[4];
static unsigned char n374[4];
static unsigned char n374r[1];
static unsigned char n374e[1];
static unsigned char n374d[4];
static unsigned char n362[4];
static unsigned char n362r[1];
static unsigned char n362e[1];
static unsigned char n362d[4];
static unsigned char n350[4];
static unsigned char n350r[1];
static unsigned char n350e[1];
static unsigned char n350d[4];
static unsigned char n329[4];
static unsigned char n329r[1];
static unsigned char n329e[1];
static unsigned char n329d[4];
static unsigned char n317[4];
static unsigned char n317r[1];
static unsigned char n317e[1];
static unsigned char n317d[4];
static unsigned char n305[4];
static unsigned char n305r[1];
static unsigned char n305e[1];
static unsigned char n305d[4];
static unsigned char n284[4];
static unsigned char n284r[1];
static unsigned char n284e[1];
static unsigned char n284d[4];
static unsigned char n272[4];
static unsigned char n272r[1];
static unsigned char n272e[1];
static unsigned char n272d[4];
static unsigned char n260[4];
static unsigned char n260r[1];
static unsigned char n260e[1];
static unsigned char n260d[4];
static unsigned char n248[4];
static unsigned char n248r[1];
static unsigned char n248e[1];
static unsigned char n248d[4];
static unsigned char n236[4];
static unsigned char n236r[1];
static unsigned char n236e[1];
static unsigned char n236d[4];
static unsigned char n224[4];
static unsigned char n224r[1];
static unsigned char n224e[1];
static unsigned char n224d[4];

void cf_fir_12_16_10_ports(unsigned char* port_reset_i, unsigned char* port_data_i, unsigned char* port_k0_i, unsigned char* port_k1_i, unsigned char* port_k2_i, unsigned char* port_k3_i, unsigned char* port_k4_i, unsigned char* port_k5_i, unsigned char* port_k6_i, unsigned char* port_k7_i, unsigned char* port_k8_i, unsigned char* port_k9_i, unsigned char* port_k10_i, unsigned char* port_k11_i, unsigned char* port_k12_i, unsigned char* port_data_o) {
  reset_i = port_reset_i;
  data_i = port_data_i;
  k0_i = port_k0_i;
  k1_i = port_k1_i;
  k2_i = port_k2_i;
  k3_i = port_k3_i;
  k4_i = port_k4_i;
  k5_i = port_k5_i;
  k6_i = port_k6_i;
  k7_i = port_k7_i;
  k8_i = port_k8_i;
  k9_i = port_k9_i;
  k10_i = port_k10_i;
  k11_i = port_k11_i;
  k12_i = port_k12_i;
  data_o = port_data_o;
}

void cf_fir_12_16_10_calc() {
  data_o[0] = n374[0];
  data_o[1] = n374[1];
  data_o[2] = n374[2];
  data_o[3] = n374[3];
  n365[0] = (1 & (n362[3] >> 4));
  n363[0] = (1 & (n350[3] >> 4));
  n353[0] = (1 & (n338[3] >> 3));
  n351[0] = (1 & (n329[3] >> 3));
  n341[0] = (1 & (n317[3] >> 3));
  n339[0] = (1 & (n305[3] >> 3));
  n330[0] = (1 & (n293[3] >> 2));
  n320[0] = (1 & (n284[3] >> 2));
  n318[0] = (1 & (n272[3] >> 2));
  n308[0] = (1 & (n260[3] >> 2));
  n306[0] = (1 & (n248[3] >> 2));
  n296[0] = (1 & (n236[3] >> 2));
  n294[0] = (1 & (n224[3] >> 2));
  n285[0] = (1 & (n212[3] >> 1));
  n275[0] = (1 & (n204[3] >> 1));
  n273[0] = (1 & (n196[3] >> 1));
  n263[0] = (1 & (n188[3] >> 1));
  n261[0] = (1 & (n180[3] >> 1));
  n251[0] = (1 & (n172[3] >> 1));
  n249[0] = (1 & (n164[3] >> 1));
  n239[0] = (1 & (n156[3] >> 1));
  n237[0] = (1 & (n148[3] >> 1));
  n227[0] = (1 & (n140[3] >> 1));
  n225[0] = (1 & (n132[3] >> 1));
  n215[0] = (1 & (n124[3] >> 1));
  n213[0] = (1 & (n116[3] >> 1));
  n2[0] = 0;
  n1[0] = 1;
  n366[0] = n362[0];
  n366[1] = n362[1];
  n366[2] = n362[2];
  n366[3] = 255 & (n365[0] << 5 | n362[3]);
  n364[0] = n350[0];
  n364[1] = n350[1];
  n364[2] = n350[2];
  n364[3] = 255 & (n363[0] << 5 | n350[3]);
  n354[0] = n338[0];
  n354[1] = n338[1];
  n354[2] = n338[2];
  n354[3] = 255 & (n353[0] << 4 | n338[3]);
  n352[0] = n329[0];
  n352[1] = n329[1];
  n352[2] = n329[2];
  n352[3] = 255 & (n351[0] << 4 | n329[3]);
  n342[0] = n317[0];
  n342[1] = n317[1];
  n342[2] = n317[2];
  n342[3] = 255 & (n341[0] << 4 | n317[3]);
  n340[0] = n305[0];
  n340[1] = n305[1];
  n340[2] = n305[2];
  n340[3] = 255 & (n339[0] << 4 | n305[3]);
  n331[0] = n293[0];
  n331[1] = n293[1];
  n331[2] = n293[2];
  n331[3] = 255 & (n330[0] << 3 | n293[3]);
  n321[0] = n284[0];
  n321[1] = n284[1];
  n321[2] = n284[2];
  n321[3] = 255 & (n320[0] << 3 | n284[3]);
  n319[0] = n272[0];
  n319[1] = n272[1];
  n319[2] = n272[2];
  n319[3] = 255 & (n318[0] << 3 | n272[3]);
  n309[0] = n260[0];
  n309[1] = n260[1];
  n309[2] = n260[2];
  n309[3] = 255 & (n308[0] << 3 | n260[3]);
  n307[0] = n248[0];
  n307[1] = n248[1];
  n307[2] = n248[2];
  n307[3] = 255 & (n306[0] << 3 | n248[3]);
  n297[0] = n236[0];
  n297[1] = n236[1];
  n297[2] = n236[2];
  n297[3] = 255 & (n296[0] << 3 | n236[3]);
  n295[0] = n224[0];
  n295[1] = n224[1];
  n295[2] = n224[2];
  n295[3] = 255 & (n294[0] << 3 | n224[3]);
  n286[0] = n212[0];
  n286[1] = n212[1];
  n286[2] = n212[2];
  n286[3] = 255 & (n285[0] << 2 | n212[3]);
  n276[0] = n204[0];
  n276[1] = n204[1];
  n276[2] = n204[2];
  n276[3] = 255 & (n275[0] << 2 | n204[3]);
  n274[0] = n196[0];
  n274[1] = n196[1];
  n274[2] = n196[2];
  n274[3] = 255 & (n273[0] << 2 | n196[3]);
  n264[0] = n188[0];
  n264[1] = n188[1];
  n264[2] = n188[2];
  n264[3] = 255 & (n263[0] << 2 | n188[3]);
  n262[0] = n180[0];
  n262[1] = n180[1];
  n262[2] = n180[2];
  n262[3] = 255 & (n261[0] << 2 | n180[3]);
  n252[0] = n172[0];
  n252[1] = n172[1];
  n252[2] = n172[2];
  n252[3] = 255 & (n251[0] << 2 | n172[3]);
  n250[0] = n164[0];
  n250[1] = n164[1];
  n250[2] = n164[2];
  n250[3] = 255 & (n249[0] << 2 | n164[3]);
  n240[0] = n156[0];
  n240[1] = n156[1];
  n240[2] = n156[2];
  n240[3] = 255 & (n239[0] << 2 | n156[3]);
  n238[0] = n148[0];
  n238[1] = n148[1];
  n238[2] = n148[2];
  n238[3] = 255 & (n237[0] << 2 | n148[3]);
  n228[0] = n140[0];
  n228[1] = n140[1];
  n228[2] = n140[2];
  n228[3] = 255 & (n227[0] << 2 | n140[3]);
  n226[0] = n132[0];
  n226[1] = n132[1];
  n226[2] = n132[2];
  n226[3] = 255 & (n225[0] << 2 | n132[3]);
  n216[0] = n124[0];
  n216[1] = n124[1];
  n216[2] = n124[2];
  n216[3] = 255 & (n215[0] << 2 | n124[3]);
  n214[0] = n116[0];
  n214[1] = n116[1];
  n214[2] = n116[2];
  n214[3] = 255 & (n213[0] << 2 | n116[3]);
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k12_i[1];
    a[0] = k12_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n108[1];
    b[0] = n108[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n205[0] = 255 & (unsigned char) tmp, tmp >> 8), n205[1] = 255 & (unsigned char) tmp, tmp >> 8), n205[2] = 255 & (unsigned char) tmp, tmp >> 8), n205[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k11_i[1];
    a[0] = k11_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n101[1];
    b[0] = n101[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n197[0] = 255 & (unsigned char) tmp, tmp >> 8), n197[1] = 255 & (unsigned char) tmp, tmp >> 8), n197[2] = 255 & (unsigned char) tmp, tmp >> 8), n197[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k10_i[1];
    a[0] = k10_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n94[1];
    b[0] = n94[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n189[0] = 255 & (unsigned char) tmp, tmp >> 8), n189[1] = 255 & (unsigned char) tmp, tmp >> 8), n189[2] = 255 & (unsigned char) tmp, tmp >> 8), n189[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k9_i[1];
    a[0] = k9_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n87[1];
    b[0] = n87[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n181[0] = 255 & (unsigned char) tmp, tmp >> 8), n181[1] = 255 & (unsigned char) tmp, tmp >> 8), n181[2] = 255 & (unsigned char) tmp, tmp >> 8), n181[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k8_i[1];
    a[0] = k8_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n80[1];
    b[0] = n80[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n173[0] = 255 & (unsigned char) tmp, tmp >> 8), n173[1] = 255 & (unsigned char) tmp, tmp >> 8), n173[2] = 255 & (unsigned char) tmp, tmp >> 8), n173[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k7_i[1];
    a[0] = k7_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n73[1];
    b[0] = n73[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n165[0] = 255 & (unsigned char) tmp, tmp >> 8), n165[1] = 255 & (unsigned char) tmp, tmp >> 8), n165[2] = 255 & (unsigned char) tmp, tmp >> 8), n165[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k6_i[1];
    a[0] = k6_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n66[1];
    b[0] = n66[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n157[0] = 255 & (unsigned char) tmp, tmp >> 8), n157[1] = 255 & (unsigned char) tmp, tmp >> 8), n157[2] = 255 & (unsigned char) tmp, tmp >> 8), n157[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k5_i[1];
    a[0] = k5_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n59[1];
    b[0] = n59[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n149[0] = 255 & (unsigned char) tmp, tmp >> 8), n149[1] = 255 & (unsigned char) tmp, tmp >> 8), n149[2] = 255 & (unsigned char) tmp, tmp >> 8), n149[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k4_i[1];
    a[0] = k4_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n52[1];
    b[0] = n52[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n141[0] = 255 & (unsigned char) tmp, tmp >> 8), n141[1] = 255 & (unsigned char) tmp, tmp >> 8), n141[2] = 255 & (unsigned char) tmp, tmp >> 8), n141[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k3_i[1];
    a[0] = k3_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n45[1];
    b[0] = n45[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n133[0] = 255 & (unsigned char) tmp, tmp >> 8), n133[1] = 255 & (unsigned char) tmp, tmp >> 8), n133[2] = 255 & (unsigned char) tmp, tmp >> 8), n133[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k2_i[1];
    a[0] = k2_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n38[1];
    b[0] = n38[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n125[0] = 255 & (unsigned char) tmp, tmp >> 8), n125[1] = 255 & (unsigned char) tmp, tmp >> 8), n125[2] = 255 & (unsigned char) tmp, tmp >> 8), n125[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k1_i[1];
    a[0] = k1_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n31[1];
    b[0] = n31[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n117[0] = 255 & (unsigned char) tmp, tmp >> 8), n117[1] = 255 & (unsigned char) tmp, tmp >> 8), n117[2] = 255 & (unsigned char) tmp, tmp >> 8), n117[3] = 3 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k0_i[1];
    a[0] = k0_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n24[1];
    b[0] = n24[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n109[0] = 255 & (unsigned char) tmp, tmp >> 8), n109[1] = 255 & (unsigned char) tmp, tmp >> 8), n109[2] = 255 & (unsigned char) tmp, tmp >> 8), n109[3] = 3 & (unsigned char) tmp);
  }
  n108r[0] = reset_i[0];
  n108e[0] = n1[0];
  n108d[0] = n101[0];
  n108d[1] = n101[1];
  n101r[0] = reset_i[0];
  n101e[0] = n1[0];
  n101d[0] = n94[0];
  n101d[1] = n94[1];
  n94r[0] = reset_i[0];
  n94e[0] = n1[0];
  n94d[0] = n87[0];
  n94d[1] = n87[1];
  n87r[0] = reset_i[0];
  n87e[0] = n1[0];
  n87d[0] = n80[0];
  n87d[1] = n80[1];
  n80r[0] = reset_i[0];
  n80e[0] = n1[0];
  n80d[0] = n73[0];
  n80d[1] = n73[1];
  n73r[0] = reset_i[0];
  n73e[0] = n1[0];
  n73d[0] = n66[0];
  n73d[1] = n66[1];
  n66r[0] = reset_i[0];
  n66e[0] = n1[0];
  n66d[0] = n59[0];
  n66d[1] = n59[1];
  n59r[0] = reset_i[0];
  n59e[0] = n1[0];
  n59d[0] = n52[0];
  n59d[1] = n52[1];
  n52r[0] = reset_i[0];
  n52e[0] = n1[0];
  n52d[0] = n45[0];
  n52d[1] = n45[1];
  n45r[0] = reset_i[0];
  n45e[0] = n1[0];
  n45d[0] = n38[0];
  n45d[1] = n38[1];
  n38r[0] = reset_i[0];
  n38e[0] = n1[0];
  n38d[0] = n31[0];
  n38d[1] = n31[1];
  n31r[0] = reset_i[0];
  n31e[0] = n1[0];
  n31d[0] = n24[0];
  n31d[1] = n24[1];
  n24r[0] = reset_i[0];
  n24e[0] = n1[0];
  n24d[0] = data_i[0];
  n24d[1] = data_i[1];
  { unsigned int tmp; (tmp = (unsigned int) n364[3] + (unsigned int) n366[3] + (tmp = (unsigned int) n364[2] + (unsigned int) n366[2] + (tmp = (unsigned int) n364[1] + (unsigned int) n366[1] + (tmp = (unsigned int) n364[0] + (unsigned int) n366[0], n367[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n367[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n367[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n367[3] = 63 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n352[3] + (unsigned int) n354[3] + (tmp = (unsigned int) n352[2] + (unsigned int) n354[2] + (tmp = (unsigned int) n352[1] + (unsigned int) n354[1] + (tmp = (unsigned int) n352[0] + (unsigned int) n354[0], n355[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n355[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n355[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n355[3] = 31 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n340[3] + (unsigned int) n342[3] + (tmp = (unsigned int) n340[2] + (unsigned int) n342[2] + (tmp = (unsigned int) n340[1] + (unsigned int) n342[1] + (tmp = (unsigned int) n340[0] + (unsigned int) n342[0], n343[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n343[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n343[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n343[3] = 31 & (unsigned char) tmp); }
  n338r[0] = n2[0];
  n338e[0] = n1[0];
  n338d[0] = n331[0];
  n338d[1] = n331[1];
  n338d[2] = n331[2];
  n338d[3] = n331[3];
  { unsigned int tmp; (tmp = (unsigned int) n319[3] + (unsigned int) n321[3] + (tmp = (unsigned int) n319[2] + (unsigned int) n321[2] + (tmp = (unsigned int) n319[1] + (unsigned int) n321[1] + (tmp = (unsigned int) n319[0] + (unsigned int) n321[0], n322[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n322[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n322[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n322[3] = 15 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n307[3] + (unsigned int) n309[3] + (tmp = (unsigned int) n307[2] + (unsigned int) n309[2] + (tmp = (unsigned int) n307[1] + (unsigned int) n309[1] + (tmp = (unsigned int) n307[0] + (unsigned int) n309[0], n310[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n310[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n310[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n310[3] = 15 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n295[3] + (unsigned int) n297[3] + (tmp = (unsigned int) n295[2] + (unsigned int) n297[2] + (tmp = (unsigned int) n295[1] + (unsigned int) n297[1] + (tmp = (unsigned int) n295[0] + (unsigned int) n297[0], n298[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n298[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n298[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n298[3] = 15 & (unsigned char) tmp); }
  n293r[0] = n2[0];
  n293e[0] = n1[0];
  n293d[0] = n286[0];
  n293d[1] = n286[1];
  n293d[2] = n286[2];
  n293d[3] = n286[3];
  { unsigned int tmp; (tmp = (unsigned int) n274[3] + (unsigned int) n276[3] + (tmp = (unsigned int) n274[2] + (unsigned int) n276[2] + (tmp = (unsigned int) n274[1] + (unsigned int) n276[1] + (tmp = (unsigned int) n274[0] + (unsigned int) n276[0], n277[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n277[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n277[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n277[3] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n262[3] + (unsigned int) n264[3] + (tmp = (unsigned int) n262[2] + (unsigned int) n264[2] + (tmp = (unsigned int) n262[1] + (unsigned int) n264[1] + (tmp = (unsigned int) n262[0] + (unsigned int) n264[0], n265[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n265[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n265[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n265[3] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n250[3] + (unsigned int) n252[3] + (tmp = (unsigned int) n250[2] + (unsigned int) n252[2] + (tmp = (unsigned int) n250[1] + (unsigned int) n252[1] + (tmp = (unsigned int) n250[0] + (unsigned int) n252[0], n253[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n253[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n253[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n253[3] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n238[3] + (unsigned int) n240[3] + (tmp = (unsigned int) n238[2] + (unsigned int) n240[2] + (tmp = (unsigned int) n238[1] + (unsigned int) n240[1] + (tmp = (unsigned int) n238[0] + (unsigned int) n240[0], n241[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n241[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n241[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n241[3] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n226[3] + (unsigned int) n228[3] + (tmp = (unsigned int) n226[2] + (unsigned int) n228[2] + (tmp = (unsigned int) n226[1] + (unsigned int) n228[1] + (tmp = (unsigned int) n226[0] + (unsigned int) n228[0], n229[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n229[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n229[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n229[3] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n214[3] + (unsigned int) n216[3] + (tmp = (unsigned int) n214[2] + (unsigned int) n216[2] + (tmp = (unsigned int) n214[1] + (unsigned int) n216[1] + (tmp = (unsigned int) n214[0] + (unsigned int) n216[0], n217[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n217[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n217[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n217[3] = 7 & (unsigned char) tmp); }
  n212r[0] = n2[0];
  n212e[0] = n1[0];
  n212d[0] = n205[0];
  n212d[1] = n205[1];
  n212d[2] = n205[2];
  n212d[3] = n205[3];
  n204r[0] = n2[0];
  n204e[0] = n1[0];
  n204d[0] = n197[0];
  n204d[1] = n197[1];
  n204d[2] = n197[2];
  n204d[3] = n197[3];
  n196r[0] = n2[0];
  n196e[0] = n1[0];
  n196d[0] = n189[0];
  n196d[1] = n189[1];
  n196d[2] = n189[2];
  n196d[3] = n189[3];
  n188r[0] = n2[0];
  n188e[0] = n1[0];
  n188d[0] = n181[0];
  n188d[1] = n181[1];
  n188d[2] = n181[2];
  n188d[3] = n181[3];
  n180r[0] = n2[0];
  n180e[0] = n1[0];
  n180d[0] = n173[0];
  n180d[1] = n173[1];
  n180d[2] = n173[2];
  n180d[3] = n173[3];
  n172r[0] = n2[0];
  n172e[0] = n1[0];
  n172d[0] = n165[0];
  n172d[1] = n165[1];
  n172d[2] = n165[2];
  n172d[3] = n165[3];
  n164r[0] = n2[0];
  n164e[0] = n1[0];
  n164d[0] = n157[0];
  n164d[1] = n157[1];
  n164d[2] = n157[2];
  n164d[3] = n157[3];
  n156r[0] = n2[0];
  n156e[0] = n1[0];
  n156d[0] = n149[0];
  n156d[1] = n149[1];
  n156d[2] = n149[2];
  n156d[3] = n149[3];
  n148r[0] = n2[0];
  n148e[0] = n1[0];
  n148d[0] = n141[0];
  n148d[1] = n141[1];
  n148d[2] = n141[2];
  n148d[3] = n141[3];
  n140r[0] = n2[0];
  n140e[0] = n1[0];
  n140d[0] = n133[0];
  n140d[1] = n133[1];
  n140d[2] = n133[2];
  n140d[3] = n133[3];
  n132r[0] = n2[0];
  n132e[0] = n1[0];
  n132d[0] = n125[0];
  n132d[1] = n125[1];
  n132d[2] = n125[2];
  n132d[3] = n125[3];
  n124r[0] = n2[0];
  n124e[0] = n1[0];
  n124d[0] = n117[0];
  n124d[1] = n117[1];
  n124d[2] = n117[2];
  n124d[3] = n117[3];
  n116r[0] = n2[0];
  n116e[0] = n1[0];
  n116d[0] = n109[0];
  n116d[1] = n109[1];
  n116d[2] = n109[2];
  n116d[3] = n109[3];
  n374r[0] = n2[0];
  n374e[0] = n1[0];
  n374d[0] = n367[0];
  n374d[1] = n367[1];
  n374d[2] = n367[2];
  n374d[3] = n367[3];
  n362r[0] = n2[0];
  n362e[0] = n1[0];
  n362d[0] = n355[0];
  n362d[1] = n355[1];
  n362d[2] = n355[2];
  n362d[3] = n355[3];
  n350r[0] = n2[0];
  n350e[0] = n1[0];
  n350d[0] = n343[0];
  n350d[1] = n343[1];
  n350d[2] = n343[2];
  n350d[3] = n343[3];
  n329r[0] = n2[0];
  n329e[0] = n1[0];
  n329d[0] = n322[0];
  n329d[1] = n322[1];
  n329d[2] = n322[2];
  n329d[3] = n322[3];
  n317r[0] = n2[0];
  n317e[0] = n1[0];
  n317d[0] = n310[0];
  n317d[1] = n310[1];
  n317d[2] = n310[2];
  n317d[3] = n310[3];
  n305r[0] = n2[0];
  n305e[0] = n1[0];
  n305d[0] = n298[0];
  n305d[1] = n298[1];
  n305d[2] = n298[2];
  n305d[3] = n298[3];
  n284r[0] = n2[0];
  n284e[0] = n1[0];
  n284d[0] = n277[0];
  n284d[1] = n277[1];
  n284d[2] = n277[2];
  n284d[3] = n277[3];
  n272r[0] = n2[0];
  n272e[0] = n1[0];
  n272d[0] = n265[0];
  n272d[1] = n265[1];
  n272d[2] = n265[2];
  n272d[3] = n265[3];
  n260r[0] = n2[0];
  n260e[0] = n1[0];
  n260d[0] = n253[0];
  n260d[1] = n253[1];
  n260d[2] = n253[2];
  n260d[3] = n253[3];
  n248r[0] = n2[0];
  n248e[0] = n1[0];
  n248d[0] = n241[0];
  n248d[1] = n241[1];
  n248d[2] = n241[2];
  n248d[3] = n241[3];
  n236r[0] = n2[0];
  n236e[0] = n1[0];
  n236d[0] = n229[0];
  n236d[1] = n229[1];
  n236d[2] = n229[2];
  n236d[3] = n229[3];
  n224r[0] = n2[0];
  n224e[0] = n1[0];
  n224d[0] = n217[0];
  n224d[1] = n217[1];
  n224d[2] = n217[2];
  n224d[3] = n217[3];
}

void cf_fir_12_16_10_init() {
  n365[0] = 0;
  n363[0] = 0;
  n353[0] = 0;
  n351[0] = 0;
  n341[0] = 0;
  n339[0] = 0;
  n330[0] = 0;
  n320[0] = 0;
  n318[0] = 0;
  n308[0] = 0;
  n306[0] = 0;
  n296[0] = 0;
  n294[0] = 0;
  n285[0] = 0;
  n275[0] = 0;
  n273[0] = 0;
  n263[0] = 0;
  n261[0] = 0;
  n251[0] = 0;
  n249[0] = 0;
  n239[0] = 0;
  n237[0] = 0;
  n227[0] = 0;
  n225[0] = 0;
  n215[0] = 0;
  n213[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  { int index; for (index = 4; index > 0;) n366[--index] = 0; }
  { int index; for (index = 4; index > 0;) n364[--index] = 0; }
  { int index; for (index = 4; index > 0;) n354[--index] = 0; }
  { int index; for (index = 4; index > 0;) n352[--index] = 0; }
  { int index; for (index = 4; index > 0;) n342[--index] = 0; }
  { int index; for (index = 4; index > 0;) n340[--index] = 0; }
  { int index; for (index = 4; index > 0;) n331[--index] = 0; }
  { int index; for (index = 4; index > 0;) n321[--index] = 0; }
  { int index; for (index = 4; index > 0;) n319[--index] = 0; }
  { int index; for (index = 4; index > 0;) n309[--index] = 0; }
  { int index; for (index = 4; index > 0;) n307[--index] = 0; }
  { int index; for (index = 4; index > 0;) n297[--index] = 0; }
  { int index; for (index = 4; index > 0;) n295[--index] = 0; }
  { int index; for (index = 4; index > 0;) n286[--index] = 0; }
  { int index; for (index = 4; index > 0;) n276[--index] = 0; }
  { int index; for (index = 4; index > 0;) n274[--index] = 0; }
  { int index; for (index = 4; index > 0;) n264[--index] = 0; }
  { int index; for (index = 4; index > 0;) n262[--index] = 0; }
  { int index; for (index = 4; index > 0;) n252[--index] = 0; }
  { int index; for (index = 4; index > 0;) n250[--index] = 0; }
  { int index; for (index = 4; index > 0;) n240[--index] = 0; }
  { int index; for (index = 4; index > 0;) n238[--index] = 0; }
  { int index; for (index = 4; index > 0;) n228[--index] = 0; }
  { int index; for (index = 4; index > 0;) n226[--index] = 0; }
  { int index; for (index = 4; index > 0;) n216[--index] = 0; }
  { int index; for (index = 4; index > 0;) n214[--index] = 0; }
  { int index; for (index = 4; index > 0;) n205[--index] = 0; }
  { int index; for (index = 4; index > 0;) n197[--index] = 0; }
  { int index; for (index = 4; index > 0;) n189[--index] = 0; }
  { int index; for (index = 4; index > 0;) n181[--index] = 0; }
  { int index; for (index = 4; index > 0;) n173[--index] = 0; }
  { int index; for (index = 4; index > 0;) n165[--index] = 0; }
  { int index; for (index = 4; index > 0;) n157[--index] = 0; }
  { int index; for (index = 4; index > 0;) n149[--index] = 0; }
  { int index; for (index = 4; index > 0;) n141[--index] = 0; }
  { int index; for (index = 4; index > 0;) n133[--index] = 0; }
  { int index; for (index = 4; index > 0;) n125[--index] = 0; }
  { int index; for (index = 4; index > 0;) n117[--index] = 0; }
  { int index; for (index = 4; index > 0;) n109[--index] = 0; }
  { int index; for (index = 2; index > 0;) n108[--index] = 0; }
  n108r[0] = 0;
  n108e[0] = 0;
  { int index; for (index = 2; index > 0;) n108d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n101[--index] = 0; }
  n101r[0] = 0;
  n101e[0] = 0;
  { int index; for (index = 2; index > 0;) n101d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n94[--index] = 0; }
  n94r[0] = 0;
  n94e[0] = 0;
  { int index; for (index = 2; index > 0;) n94d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n87[--index] = 0; }
  n87r[0] = 0;
  n87e[0] = 0;
  { int index; for (index = 2; index > 0;) n87d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n80[--index] = 0; }
  n80r[0] = 0;
  n80e[0] = 0;
  { int index; for (index = 2; index > 0;) n80d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n73[--index] = 0; }
  n73r[0] = 0;
  n73e[0] = 0;
  { int index; for (index = 2; index > 0;) n73d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n66[--index] = 0; }
  n66r[0] = 0;
  n66e[0] = 0;
  { int index; for (index = 2; index > 0;) n66d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n59[--index] = 0; }
  n59r[0] = 0;
  n59e[0] = 0;
  { int index; for (index = 2; index > 0;) n59d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n52[--index] = 0; }
  n52r[0] = 0;
  n52e[0] = 0;
  { int index; for (index = 2; index > 0;) n52d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n45[--index] = 0; }
  n45r[0] = 0;
  n45e[0] = 0;
  { int index; for (index = 2; index > 0;) n45d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n38[--index] = 0; }
  n38r[0] = 0;
  n38e[0] = 0;
  { int index; for (index = 2; index > 0;) n38d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n31[--index] = 0; }
  n31r[0] = 0;
  n31e[0] = 0;
  { int index; for (index = 2; index > 0;) n31d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n24[--index] = 0; }
  n24r[0] = 0;
  n24e[0] = 0;
  { int index; for (index = 2; index > 0;) n24d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n367[--index] = 0; }
  { int index; for (index = 4; index > 0;) n355[--index] = 0; }
  { int index; for (index = 4; index > 0;) n343[--index] = 0; }
  { int index; for (index = 4; index > 0;) n338[--index] = 0; }
  n338r[0] = 0;
  n338e[0] = 0;
  { int index; for (index = 4; index > 0;) n338d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n322[--index] = 0; }
  { int index; for (index = 4; index > 0;) n310[--index] = 0; }
  { int index; for (index = 4; index > 0;) n298[--index] = 0; }
  { int index; for (index = 4; index > 0;) n293[--index] = 0; }
  n293r[0] = 0;
  n293e[0] = 0;
  { int index; for (index = 4; index > 0;) n293d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n277[--index] = 0; }
  { int index; for (index = 4; index > 0;) n265[--index] = 0; }
  { int index; for (index = 4; index > 0;) n253[--index] = 0; }
  { int index; for (index = 4; index > 0;) n241[--index] = 0; }
  { int index; for (index = 4; index > 0;) n229[--index] = 0; }
  { int index; for (index = 4; index > 0;) n217[--index] = 0; }
  { int index; for (index = 4; index > 0;) n212[--index] = 0; }
  n212r[0] = 0;
  n212e[0] = 0;
  { int index; for (index = 4; index > 0;) n212d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n204[--index] = 0; }
  n204r[0] = 0;
  n204e[0] = 0;
  { int index; for (index = 4; index > 0;) n204d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n196[--index] = 0; }
  n196r[0] = 0;
  n196e[0] = 0;
  { int index; for (index = 4; index > 0;) n196d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n188[--index] = 0; }
  n188r[0] = 0;
  n188e[0] = 0;
  { int index; for (index = 4; index > 0;) n188d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n180[--index] = 0; }
  n180r[0] = 0;
  n180e[0] = 0;
  { int index; for (index = 4; index > 0;) n180d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n172[--index] = 0; }
  n172r[0] = 0;
  n172e[0] = 0;
  { int index; for (index = 4; index > 0;) n172d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n164[--index] = 0; }
  n164r[0] = 0;
  n164e[0] = 0;
  { int index; for (index = 4; index > 0;) n164d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n156[--index] = 0; }
  n156r[0] = 0;
  n156e[0] = 0;
  { int index; for (index = 4; index > 0;) n156d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n148[--index] = 0; }
  n148r[0] = 0;
  n148e[0] = 0;
  { int index; for (index = 4; index > 0;) n148d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n140[--index] = 0; }
  n140r[0] = 0;
  n140e[0] = 0;
  { int index; for (index = 4; index > 0;) n140d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n132[--index] = 0; }
  n132r[0] = 0;
  n132e[0] = 0;
  { int index; for (index = 4; index > 0;) n132d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n124[--index] = 0; }
  n124r[0] = 0;
  n124e[0] = 0;
  { int index; for (index = 4; index > 0;) n124d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n116[--index] = 0; }
  n116r[0] = 0;
  n116e[0] = 0;
  { int index; for (index = 4; index > 0;) n116d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n374[--index] = 0; }
  n374r[0] = 0;
  n374e[0] = 0;
  { int index; for (index = 4; index > 0;) n374d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n362[--index] = 0; }
  n362r[0] = 0;
  n362e[0] = 0;
  { int index; for (index = 4; index > 0;) n362d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n350[--index] = 0; }
  n350r[0] = 0;
  n350e[0] = 0;
  { int index; for (index = 4; index > 0;) n350d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n329[--index] = 0; }
  n329r[0] = 0;
  n329e[0] = 0;
  { int index; for (index = 4; index > 0;) n329d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n317[--index] = 0; }
  n317r[0] = 0;
  n317e[0] = 0;
  { int index; for (index = 4; index > 0;) n317d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n305[--index] = 0; }
  n305r[0] = 0;
  n305e[0] = 0;
  { int index; for (index = 4; index > 0;) n305d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n284[--index] = 0; }
  n284r[0] = 0;
  n284e[0] = 0;
  { int index; for (index = 4; index > 0;) n284d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n272[--index] = 0; }
  n272r[0] = 0;
  n272e[0] = 0;
  { int index; for (index = 4; index > 0;) n272d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n260[--index] = 0; }
  n260r[0] = 0;
  n260e[0] = 0;
  { int index; for (index = 4; index > 0;) n260d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n248[--index] = 0; }
  n248r[0] = 0;
  n248e[0] = 0;
  { int index; for (index = 4; index > 0;) n248d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n236[--index] = 0; }
  n236r[0] = 0;
  n236e[0] = 0;
  { int index; for (index = 4; index > 0;) n236d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n224[--index] = 0; }
  n224r[0] = 0;
  n224e[0] = 0;
  { int index; for (index = 4; index > 0;) n224d[--index] = 0; }
  cf_fir_12_16_10_calc();
}

void cf_fir_12_16_10_cycle_clock()
{
  if (n24r[0]) {
    n24[0] = 0;
    n24[1] = 0;
  }
  else if (n24e[0]) {
    n24[0] = n24d[0];
    n24[1] = n24d[1];
  }
  if (n31r[0]) {
    n31[0] = 0;
    n31[1] = 0;
  }
  else if (n31e[0]) {
    n31[0] = n31d[0];
    n31[1] = n31d[1];
  }
  if (n38r[0]) {
    n38[0] = 0;
    n38[1] = 0;
  }
  else if (n38e[0]) {
    n38[0] = n38d[0];
    n38[1] = n38d[1];
  }
  if (n45r[0]) {
    n45[0] = 0;
    n45[1] = 0;
  }
  else if (n45e[0]) {
    n45[0] = n45d[0];
    n45[1] = n45d[1];
  }
  if (n52r[0]) {
    n52[0] = 0;
    n52[1] = 0;
  }
  else if (n52e[0]) {
    n52[0] = n52d[0];
    n52[1] = n52d[1];
  }
  if (n59r[0]) {
    n59[0] = 0;
    n59[1] = 0;
  }
  else if (n59e[0]) {
    n59[0] = n59d[0];
    n59[1] = n59d[1];
  }
  if (n66r[0]) {
    n66[0] = 0;
    n66[1] = 0;
  }
  else if (n66e[0]) {
    n66[0] = n66d[0];
    n66[1] = n66d[1];
  }
  if (n73r[0]) {
    n73[0] = 0;
    n73[1] = 0;
  }
  else if (n73e[0]) {
    n73[0] = n73d[0];
    n73[1] = n73d[1];
  }
  if (n80r[0]) {
    n80[0] = 0;
    n80[1] = 0;
  }
  else if (n80e[0]) {
    n80[0] = n80d[0];
    n80[1] = n80d[1];
  }
  if (n87r[0]) {
    n87[0] = 0;
    n87[1] = 0;
  }
  else if (n87e[0]) {
    n87[0] = n87d[0];
    n87[1] = n87d[1];
  }
  if (n94r[0]) {
    n94[0] = 0;
    n94[1] = 0;
  }
  else if (n94e[0]) {
    n94[0] = n94d[0];
    n94[1] = n94d[1];
  }
  if (n101r[0]) {
    n101[0] = 0;
    n101[1] = 0;
  }
  else if (n101e[0]) {
    n101[0] = n101d[0];
    n101[1] = n101d[1];
  }
  if (n108r[0]) {
    n108[0] = 0;
    n108[1] = 0;
  }
  else if (n108e[0]) {
    n108[0] = n108d[0];
    n108[1] = n108d[1];
  }
  if (n116r[0]) {
    n116[0] = 0;
    n116[1] = 0;
    n116[2] = 0;
    n116[3] = 0;
  }
  else if (n116e[0]) {
    n116[0] = n116d[0];
    n116[1] = n116d[1];
    n116[2] = n116d[2];
    n116[3] = n116d[3];
  }
  if (n124r[0]) {
    n124[0] = 0;
    n124[1] = 0;
    n124[2] = 0;
    n124[3] = 0;
  }
  else if (n124e[0]) {
    n124[0] = n124d[0];
    n124[1] = n124d[1];
    n124[2] = n124d[2];
    n124[3] = n124d[3];
  }
  if (n132r[0]) {
    n132[0] = 0;
    n132[1] = 0;
    n132[2] = 0;
    n132[3] = 0;
  }
  else if (n132e[0]) {
    n132[0] = n132d[0];
    n132[1] = n132d[1];
    n132[2] = n132d[2];
    n132[3] = n132d[3];
  }
  if (n140r[0]) {
    n140[0] = 0;
    n140[1] = 0;
    n140[2] = 0;
    n140[3] = 0;
  }
  else if (n140e[0]) {
    n140[0] = n140d[0];
    n140[1] = n140d[1];
    n140[2] = n140d[2];
    n140[3] = n140d[3];
  }
  if (n148r[0]) {
    n148[0] = 0;
    n148[1] = 0;
    n148[2] = 0;
    n148[3] = 0;
  }
  else if (n148e[0]) {
    n148[0] = n148d[0];
    n148[1] = n148d[1];
    n148[2] = n148d[2];
    n148[3] = n148d[3];
  }
  if (n156r[0]) {
    n156[0] = 0;
    n156[1] = 0;
    n156[2] = 0;
    n156[3] = 0;
  }
  else if (n156e[0]) {
    n156[0] = n156d[0];
    n156[1] = n156d[1];
    n156[2] = n156d[2];
    n156[3] = n156d[3];
  }
  if (n164r[0]) {
    n164[0] = 0;
    n164[1] = 0;
    n164[2] = 0;
    n164[3] = 0;
  }
  else if (n164e[0]) {
    n164[0] = n164d[0];
    n164[1] = n164d[1];
    n164[2] = n164d[2];
    n164[3] = n164d[3];
  }
  if (n172r[0]) {
    n172[0] = 0;
    n172[1] = 0;
    n172[2] = 0;
    n172[3] = 0;
  }
  else if (n172e[0]) {
    n172[0] = n172d[0];
    n172[1] = n172d[1];
    n172[2] = n172d[2];
    n172[3] = n172d[3];
  }
  if (n180r[0]) {
    n180[0] = 0;
    n180[1] = 0;
    n180[2] = 0;
    n180[3] = 0;
  }
  else if (n180e[0]) {
    n180[0] = n180d[0];
    n180[1] = n180d[1];
    n180[2] = n180d[2];
    n180[3] = n180d[3];
  }
  if (n188r[0]) {
    n188[0] = 0;
    n188[1] = 0;
    n188[2] = 0;
    n188[3] = 0;
  }
  else if (n188e[0]) {
    n188[0] = n188d[0];
    n188[1] = n188d[1];
    n188[2] = n188d[2];
    n188[3] = n188d[3];
  }
  if (n196r[0]) {
    n196[0] = 0;
    n196[1] = 0;
    n196[2] = 0;
    n196[3] = 0;
  }
  else if (n196e[0]) {
    n196[0] = n196d[0];
    n196[1] = n196d[1];
    n196[2] = n196d[2];
    n196[3] = n196d[3];
  }
  if (n204r[0]) {
    n204[0] = 0;
    n204[1] = 0;
    n204[2] = 0;
    n204[3] = 0;
  }
  else if (n204e[0]) {
    n204[0] = n204d[0];
    n204[1] = n204d[1];
    n204[2] = n204d[2];
    n204[3] = n204d[3];
  }
  if (n212r[0]) {
    n212[0] = 0;
    n212[1] = 0;
    n212[2] = 0;
    n212[3] = 0;
  }
  else if (n212e[0]) {
    n212[0] = n212d[0];
    n212[1] = n212d[1];
    n212[2] = n212d[2];
    n212[3] = n212d[3];
  }
  if (n224r[0]) {
    n224[0] = 0;
    n224[1] = 0;
    n224[2] = 0;
    n224[3] = 0;
  }
  else if (n224e[0]) {
    n224[0] = n224d[0];
    n224[1] = n224d[1];
    n224[2] = n224d[2];
    n224[3] = n224d[3];
  }
  if (n236r[0]) {
    n236[0] = 0;
    n236[1] = 0;
    n236[2] = 0;
    n236[3] = 0;
  }
  else if (n236e[0]) {
    n236[0] = n236d[0];
    n236[1] = n236d[1];
    n236[2] = n236d[2];
    n236[3] = n236d[3];
  }
  if (n248r[0]) {
    n248[0] = 0;
    n248[1] = 0;
    n248[2] = 0;
    n248[3] = 0;
  }
  else if (n248e[0]) {
    n248[0] = n248d[0];
    n248[1] = n248d[1];
    n248[2] = n248d[2];
    n248[3] = n248d[3];
  }
  if (n260r[0]) {
    n260[0] = 0;
    n260[1] = 0;
    n260[2] = 0;
    n260[3] = 0;
  }
  else if (n260e[0]) {
    n260[0] = n260d[0];
    n260[1] = n260d[1];
    n260[2] = n260d[2];
    n260[3] = n260d[3];
  }
  if (n272r[0]) {
    n272[0] = 0;
    n272[1] = 0;
    n272[2] = 0;
    n272[3] = 0;
  }
  else if (n272e[0]) {
    n272[0] = n272d[0];
    n272[1] = n272d[1];
    n272[2] = n272d[2];
    n272[3] = n272d[3];
  }
  if (n284r[0]) {
    n284[0] = 0;
    n284[1] = 0;
    n284[2] = 0;
    n284[3] = 0;
  }
  else if (n284e[0]) {
    n284[0] = n284d[0];
    n284[1] = n284d[1];
    n284[2] = n284d[2];
    n284[3] = n284d[3];
  }
  if (n293r[0]) {
    n293[0] = 0;
    n293[1] = 0;
    n293[2] = 0;
    n293[3] = 0;
  }
  else if (n293e[0]) {
    n293[0] = n293d[0];
    n293[1] = n293d[1];
    n293[2] = n293d[2];
    n293[3] = n293d[3];
  }
  if (n305r[0]) {
    n305[0] = 0;
    n305[1] = 0;
    n305[2] = 0;
    n305[3] = 0;
  }
  else if (n305e[0]) {
    n305[0] = n305d[0];
    n305[1] = n305d[1];
    n305[2] = n305d[2];
    n305[3] = n305d[3];
  }
  if (n317r[0]) {
    n317[0] = 0;
    n317[1] = 0;
    n317[2] = 0;
    n317[3] = 0;
  }
  else if (n317e[0]) {
    n317[0] = n317d[0];
    n317[1] = n317d[1];
    n317[2] = n317d[2];
    n317[3] = n317d[3];
  }
  if (n329r[0]) {
    n329[0] = 0;
    n329[1] = 0;
    n329[2] = 0;
    n329[3] = 0;
  }
  else if (n329e[0]) {
    n329[0] = n329d[0];
    n329[1] = n329d[1];
    n329[2] = n329d[2];
    n329[3] = n329d[3];
  }
  if (n338r[0]) {
    n338[0] = 0;
    n338[1] = 0;
    n338[2] = 0;
    n338[3] = 0;
  }
  else if (n338e[0]) {
    n338[0] = n338d[0];
    n338[1] = n338d[1];
    n338[2] = n338d[2];
    n338[3] = n338d[3];
  }
  if (n350r[0]) {
    n350[0] = 0;
    n350[1] = 0;
    n350[2] = 0;
    n350[3] = 0;
  }
  else if (n350e[0]) {
    n350[0] = n350d[0];
    n350[1] = n350d[1];
    n350[2] = n350d[2];
    n350[3] = n350d[3];
  }
  if (n362r[0]) {
    n362[0] = 0;
    n362[1] = 0;
    n362[2] = 0;
    n362[3] = 0;
  }
  else if (n362e[0]) {
    n362[0] = n362d[0];
    n362[1] = n362d[1];
    n362[2] = n362d[2];
    n362[3] = n362d[3];
  }
  if (n374r[0]) {
    n374[0] = 0;
    n374[1] = 0;
    n374[2] = 0;
    n374[3] = 0;
  }
  else if (n374e[0]) {
    n374[0] = n374d[0];
    n374[1] = n374d[1];
    n374[2] = n374d[2];
    n374[3] = n374d[3];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_i[1];
static unsigned char sim_data_i[2];
static unsigned char sim_k0_i[2];
static unsigned char sim_k1_i[2];
static unsigned char sim_k2_i[2];
static unsigned char sim_k3_i[2];
static unsigned char sim_k4_i[2];
static unsigned char sim_k5_i[2];
static unsigned char sim_k6_i[2];
static unsigned char sim_k7_i[2];
static unsigned char sim_k8_i[2];
static unsigned char sim_k9_i[2];
static unsigned char sim_k10_i[2];
static unsigned char sim_k11_i[2];
static unsigned char sim_k12_i[2];
static unsigned char sim_data_o[4];

void cf_fir_12_16_10_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_fir_12_16_10_init();
  sim_reset_i[0] = reset_i[0];
  sim_data_i[0] = data_i[0];
  sim_data_i[1] = data_i[1];
  sim_k0_i[0] = k0_i[0];
  sim_k0_i[1] = k0_i[1];
  sim_k1_i[0] = k1_i[0];
  sim_k1_i[1] = k1_i[1];
  sim_k2_i[0] = k2_i[0];
  sim_k2_i[1] = k2_i[1];
  sim_k3_i[0] = k3_i[0];
  sim_k3_i[1] = k3_i[1];
  sim_k4_i[0] = k4_i[0];
  sim_k4_i[1] = k4_i[1];
  sim_k5_i[0] = k5_i[0];
  sim_k5_i[1] = k5_i[1];
  sim_k6_i[0] = k6_i[0];
  sim_k6_i[1] = k6_i[1];
  sim_k7_i[0] = k7_i[0];
  sim_k7_i[1] = k7_i[1];
  sim_k8_i[0] = k8_i[0];
  sim_k8_i[1] = k8_i[1];
  sim_k9_i[0] = k9_i[0];
  sim_k9_i[1] = k9_i[1];
  sim_k10_i[0] = k10_i[0];
  sim_k10_i[1] = k10_i[1];
  sim_k11_i[0] = k11_i[0];
  sim_k11_i[1] = k11_i[1];
  sim_k12_i[0] = k12_i[0];
  sim_k12_i[1] = k12_i[1];
  sim_data_o[0] = data_o[0];
  sim_data_o[1] = data_o[1];
  sim_data_o[2] = data_o[2];
  sim_data_o[3] = data_o[3];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_fir_12_16_10 $end\n"
    "$var wire 1 ! reset_i $end\n"
    "$var wire 16 \" data_i $end\n"
    "$var wire 10 # k0_i $end\n"
    "$var wire 10 $ k1_i $end\n"
    "$var wire 10 %% k2_i $end\n"
    "$var wire 10 & k3_i $end\n"
    "$var wire 10 ' k4_i $end\n"
    "$var wire 10 ( k5_i $end\n"
    "$var wire 10 ) k6_i $end\n"
    "$var wire 10 * k7_i $end\n"
    "$var wire 10 + k8_i $end\n"
    "$var wire 10 , k9_i $end\n"
    "$var wire 10 - k10_i $end\n"
    "$var wire 10 . k11_i $end\n"
    "$var wire 10 / k12_i $end\n"
    "$var wire 30 0 data_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
        else if (bit & data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " \"\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
        else if (bit & k0_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
        else if (bit & k1_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
        else if (bit & k2_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
        else if (bit & k3_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
        else if (bit & k4_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
        else if (bit & k5_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
        else if (bit & k6_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
        else if (bit & k7_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
        else if (bit & k8_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
        else if (bit & k9_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
        else if (bit & k10_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
        else if (bit & k11_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
        else if (bit & k12_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 3; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
        else if (bit & data_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_fir_12_16_10_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_fir_12_16_10_sim_sample() {
  int changed = 0;
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_data_i[1] != data_i[1] || sim_data_i[0] != data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
          else if (bit & data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " \"\n");
    }
    sim_data_i[0] = data_i[0];
    sim_data_i[1] = data_i[1];
  }
  if (sim_k0_i[1] != k0_i[1] || sim_k0_i[0] != k0_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
          else if (bit & k0_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_k0_i[0] = k0_i[0];
    sim_k0_i[1] = k0_i[1];
  }
  if (sim_k1_i[1] != k1_i[1] || sim_k1_i[0] != k1_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
          else if (bit & k1_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_k1_i[0] = k1_i[0];
    sim_k1_i[1] = k1_i[1];
  }
  if (sim_k2_i[1] != k2_i[1] || sim_k2_i[0] != k2_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
          else if (bit & k2_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_k2_i[0] = k2_i[0];
    sim_k2_i[1] = k2_i[1];
  }
  if (sim_k3_i[1] != k3_i[1] || sim_k3_i[0] != k3_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
          else if (bit & k3_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_k3_i[0] = k3_i[0];
    sim_k3_i[1] = k3_i[1];
  }
  if (sim_k4_i[1] != k4_i[1] || sim_k4_i[0] != k4_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
          else if (bit & k4_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_k4_i[0] = k4_i[0];
    sim_k4_i[1] = k4_i[1];
  }
  if (sim_k5_i[1] != k5_i[1] || sim_k5_i[0] != k5_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
          else if (bit & k5_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_k5_i[0] = k5_i[0];
    sim_k5_i[1] = k5_i[1];
  }
  if (sim_k6_i[1] != k6_i[1] || sim_k6_i[0] != k6_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
          else if (bit & k6_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_k6_i[0] = k6_i[0];
    sim_k6_i[1] = k6_i[1];
  }
  if (sim_k7_i[1] != k7_i[1] || sim_k7_i[0] != k7_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
          else if (bit & k7_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_k7_i[0] = k7_i[0];
    sim_k7_i[1] = k7_i[1];
  }
  if (sim_k8_i[1] != k8_i[1] || sim_k8_i[0] != k8_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
          else if (bit & k8_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_k8_i[0] = k8_i[0];
    sim_k8_i[1] = k8_i[1];
  }
  if (sim_k9_i[1] != k9_i[1] || sim_k9_i[0] != k9_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
          else if (bit & k9_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_k9_i[0] = k9_i[0];
    sim_k9_i[1] = k9_i[1];
  }
  if (sim_k10_i[1] != k10_i[1] || sim_k10_i[0] != k10_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
          else if (bit & k10_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_k10_i[0] = k10_i[0];
    sim_k10_i[1] = k10_i[1];
  }
  if (sim_k11_i[1] != k11_i[1] || sim_k11_i[0] != k11_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
          else if (bit & k11_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_k11_i[0] = k11_i[0];
    sim_k11_i[1] = k11_i[1];
  }
  if (sim_k12_i[1] != k12_i[1] || sim_k12_i[0] != k12_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
          else if (bit & k12_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_k12_i[0] = k12_i[0];
    sim_k12_i[1] = k12_i[1];
  }
  if (sim_data_o[3] != data_o[3] || sim_data_o[2] != data_o[2] || sim_data_o[1] != data_o[1] || sim_data_o[0] != data_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 3; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
          else if (bit & data_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_data_o[0] = data_o[0];
    sim_data_o[1] = data_o[1];
    sim_data_o[2] = data_o[2];
    sim_data_o[3] = data_o[3];
  }
  sim_count++;
}

