#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs finite impulse response (FIR) filtering.
#    The filter's sum of products is pipelined with a register after
#    every multiplier and adder.  The adder network is a balanced binary
#    tree to minimize latency.  The sum of products has no numeric loss because the
#    multipliers keep all resulting bits and each adder extends the precision by 1.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
#  
#    Inputs:
#      data_i  : Input data.
#      k0_i    : Coefficient 0 multiplied by in_i(0).
#      k1_i    : Coefficient 1 multiplied by in_i(k-1).
#      k2_i    : Coefficient 2 multiplied by in_i(k-2).
#      ...
#      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
#  
#    Outputs:
#      data_o : Output data.
#  
#  Built In Parameters:
#  
#    Filter Order             = 12
#    Input Precision          = 16
#    Coefficient Precision    = 10
#    Sum of Products Latency  = 5
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:45:51 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fir_12_16_10
#    Clock Domains : clock_c  
#    Vector Input  : reset_i(1)
#    Vector Input  : data_i(16)
#    Vector Input  : k0_i(10)
#    Vector Input  : k1_i(10)
#    Vector Input  : k2_i(10)
#    Vector Input  : k3_i(10)
#    Vector Input  : k4_i(10)
#    Vector Input  : k5_i(10)
#    Vector Input  : k6_i(10)
#    Vector Input  : k7_i(10)
#    Vector Input  : k8_i(10)
#    Vector Input  : k9_i(10)
#    Vector Input  : k10_i(10)
#    Vector Input  : k11_i(10)
#    Vector Input  : k12_i(10)
#    Vector Output : data_o(30)
#  
#  
#  

import sys
import time

class cf_fir_12_16_10:

  def init(self):
    self.n375 = 0L
    self.n365 = 0L
    self.n363 = 0L
    self.n353 = 0L
    self.n351 = 0L
    self.n341 = 0L
    self.n339 = 0L
    self.n330 = 0L
    self.n320 = 0L
    self.n318 = 0L
    self.n308 = 0L
    self.n306 = 0L
    self.n296 = 0L
    self.n294 = 0L
    self.n285 = 0L
    self.n275 = 0L
    self.n273 = 0L
    self.n263 = 0L
    self.n261 = 0L
    self.n251 = 0L
    self.n249 = 0L
    self.n239 = 0L
    self.n237 = 0L
    self.n227 = 0L
    self.n225 = 0L
    self.n215 = 0L
    self.n213 = 0L
    self.n17 = 0L
    self.n16 = 0L
    self.n15 = 0L
    self.n14 = 0L
    self.n13 = 0L
    self.n12 = 0L
    self.n11 = 0L
    self.n10 = 0L
    self.n9 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n366 = 0L
    self.n364 = 0L
    self.n354 = 0L
    self.n352 = 0L
    self.n342 = 0L
    self.n340 = 0L
    self.n331 = 0L
    self.n321 = 0L
    self.n319 = 0L
    self.n309 = 0L
    self.n307 = 0L
    self.n297 = 0L
    self.n295 = 0L
    self.n286 = 0L
    self.n276 = 0L
    self.n274 = 0L
    self.n264 = 0L
    self.n262 = 0L
    self.n252 = 0L
    self.n250 = 0L
    self.n240 = 0L
    self.n238 = 0L
    self.n228 = 0L
    self.n226 = 0L
    self.n216 = 0L
    self.n214 = 0L
    self.n205 = 0L
    self.n197 = 0L
    self.n189 = 0L
    self.n181 = 0L
    self.n173 = 0L
    self.n165 = 0L
    self.n157 = 0L
    self.n149 = 0L
    self.n141 = 0L
    self.n133 = 0L
    self.n125 = 0L
    self.n117 = 0L
    self.n109 = 0L
    self.n108 = 0L
    self.n108r = 0L
    self.n108e = 0L
    self.n108d = 0L
    self.n101 = 0L
    self.n101r = 0L
    self.n101e = 0L
    self.n101d = 0L
    self.n94 = 0L
    self.n94r = 0L
    self.n94e = 0L
    self.n94d = 0L
    self.n87 = 0L
    self.n87r = 0L
    self.n87e = 0L
    self.n87d = 0L
    self.n80 = 0L
    self.n80r = 0L
    self.n80e = 0L
    self.n80d = 0L
    self.n73 = 0L
    self.n73r = 0L
    self.n73e = 0L
    self.n73d = 0L
    self.n66 = 0L
    self.n66r = 0L
    self.n66e = 0L
    self.n66d = 0L
    self.n59 = 0L
    self.n59r = 0L
    self.n59e = 0L
    self.n59d = 0L
    self.n52 = 0L
    self.n52r = 0L
    self.n52e = 0L
    self.n52d = 0L
    self.n45 = 0L
    self.n45r = 0L
    self.n45e = 0L
    self.n45d = 0L
    self.n38 = 0L
    self.n38r = 0L
    self.n38e = 0L
    self.n38d = 0L
    self.n31 = 0L
    self.n31r = 0L
    self.n31e = 0L
    self.n31d = 0L
    self.n24 = 0L
    self.n24r = 0L
    self.n24e = 0L
    self.n24d = 0L
    self.n367 = 0L
    self.n355 = 0L
    self.n343 = 0L
    self.n338 = 0L
    self.n338r = 0L
    self.n338e = 0L
    self.n338d = 0L
    self.n322 = 0L
    self.n310 = 0L
    self.n298 = 0L
    self.n293 = 0L
    self.n293r = 0L
    self.n293e = 0L
    self.n293d = 0L
    self.n277 = 0L
    self.n265 = 0L
    self.n253 = 0L
    self.n241 = 0L
    self.n229 = 0L
    self.n217 = 0L
    self.n212 = 0L
    self.n212r = 0L
    self.n212e = 0L
    self.n212d = 0L
    self.n204 = 0L
    self.n204r = 0L
    self.n204e = 0L
    self.n204d = 0L
    self.n196 = 0L
    self.n196r = 0L
    self.n196e = 0L
    self.n196d = 0L
    self.n188 = 0L
    self.n188r = 0L
    self.n188e = 0L
    self.n188d = 0L
    self.n180 = 0L
    self.n180r = 0L
    self.n180e = 0L
    self.n180d = 0L
    self.n172 = 0L
    self.n172r = 0L
    self.n172e = 0L
    self.n172d = 0L
    self.n164 = 0L
    self.n164r = 0L
    self.n164e = 0L
    self.n164d = 0L
    self.n156 = 0L
    self.n156r = 0L
    self.n156e = 0L
    self.n156d = 0L
    self.n148 = 0L
    self.n148r = 0L
    self.n148e = 0L
    self.n148d = 0L
    self.n140 = 0L
    self.n140r = 0L
    self.n140e = 0L
    self.n140d = 0L
    self.n132 = 0L
    self.n132r = 0L
    self.n132e = 0L
    self.n132d = 0L
    self.n124 = 0L
    self.n124r = 0L
    self.n124e = 0L
    self.n124d = 0L
    self.n116 = 0L
    self.n116r = 0L
    self.n116e = 0L
    self.n116d = 0L
    self.n374 = 0L
    self.n374r = 0L
    self.n374e = 0L
    self.n374d = 0L
    self.n362 = 0L
    self.n362r = 0L
    self.n362e = 0L
    self.n362d = 0L
    self.n350 = 0L
    self.n350r = 0L
    self.n350e = 0L
    self.n350d = 0L
    self.n329 = 0L
    self.n329r = 0L
    self.n329e = 0L
    self.n329d = 0L
    self.n317 = 0L
    self.n317r = 0L
    self.n317e = 0L
    self.n317d = 0L
    self.n305 = 0L
    self.n305r = 0L
    self.n305e = 0L
    self.n305d = 0L
    self.n284 = 0L
    self.n284r = 0L
    self.n284e = 0L
    self.n284d = 0L
    self.n272 = 0L
    self.n272r = 0L
    self.n272e = 0L
    self.n272d = 0L
    self.n260 = 0L
    self.n260r = 0L
    self.n260e = 0L
    self.n260d = 0L
    self.n248 = 0L
    self.n248r = 0L
    self.n248e = 0L
    self.n248d = 0L
    self.n236 = 0L
    self.n236r = 0L
    self.n236e = 0L
    self.n236d = 0L
    self.n224 = 0L
    self.n224r = 0L
    self.n224e = 0L
    self.n224d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_i, data_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, k8_i, k9_i, k10_i, k11_i, k12_i, ):
    data_o = self.n374
    self.n375 = self.n374
    self.n365 = ((self.n362 & 0x10000000L) >> 28)
    self.n363 = ((self.n350 & 0x10000000L) >> 28)
    self.n353 = ((self.n338 & 0x8000000L) >> 27)
    self.n351 = ((self.n329 & 0x8000000L) >> 27)
    self.n341 = ((self.n317 & 0x8000000L) >> 27)
    self.n339 = ((self.n305 & 0x8000000L) >> 27)
    self.n330 = ((self.n293 & 0x4000000L) >> 26)
    self.n320 = ((self.n284 & 0x4000000L) >> 26)
    self.n318 = ((self.n272 & 0x4000000L) >> 26)
    self.n308 = ((self.n260 & 0x4000000L) >> 26)
    self.n306 = ((self.n248 & 0x4000000L) >> 26)
    self.n296 = ((self.n236 & 0x4000000L) >> 26)
    self.n294 = ((self.n224 & 0x4000000L) >> 26)
    self.n285 = ((self.n212 & 0x2000000L) >> 25)
    self.n275 = ((self.n204 & 0x2000000L) >> 25)
    self.n273 = ((self.n196 & 0x2000000L) >> 25)
    self.n263 = ((self.n188 & 0x2000000L) >> 25)
    self.n261 = ((self.n180 & 0x2000000L) >> 25)
    self.n251 = ((self.n172 & 0x2000000L) >> 25)
    self.n249 = ((self.n164 & 0x2000000L) >> 25)
    self.n239 = ((self.n156 & 0x2000000L) >> 25)
    self.n237 = ((self.n148 & 0x2000000L) >> 25)
    self.n227 = ((self.n140 & 0x2000000L) >> 25)
    self.n225 = ((self.n132 & 0x2000000L) >> 25)
    self.n215 = ((self.n124 & 0x2000000L) >> 25)
    self.n213 = ((self.n116 & 0x2000000L) >> 25)
    self.n17 = data_i
    self.n16 = k12_i
    self.n15 = k11_i
    self.n14 = k10_i
    self.n13 = k9_i
    self.n12 = k8_i
    self.n11 = k7_i
    self.n10 = k6_i
    self.n9 = k5_i
    self.n8 = k4_i
    self.n7 = k3_i
    self.n6 = k2_i
    self.n5 = k1_i
    self.n4 = k0_i
    self.n3 = reset_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    self.n366 = self.n365 << 29 | self.n362
    self.n364 = self.n363 << 29 | self.n350
    self.n354 = self.n353 << 28 | self.n338
    self.n352 = self.n351 << 28 | self.n329
    self.n342 = self.n341 << 28 | self.n317
    self.n340 = self.n339 << 28 | self.n305
    self.n331 = self.n330 << 27 | self.n293
    self.n321 = self.n320 << 27 | self.n284
    self.n319 = self.n318 << 27 | self.n272
    self.n309 = self.n308 << 27 | self.n260
    self.n307 = self.n306 << 27 | self.n248
    self.n297 = self.n296 << 27 | self.n236
    self.n295 = self.n294 << 27 | self.n224
    self.n286 = self.n285 << 26 | self.n212
    self.n276 = self.n275 << 26 | self.n204
    self.n274 = self.n273 << 26 | self.n196
    self.n264 = self.n263 << 26 | self.n188
    self.n262 = self.n261 << 26 | self.n180
    self.n252 = self.n251 << 26 | self.n172
    self.n250 = self.n249 << 26 | self.n164
    self.n240 = self.n239 << 26 | self.n156
    self.n238 = self.n237 << 26 | self.n148
    self.n228 = self.n227 << 26 | self.n140
    self.n226 = self.n225 << 26 | self.n132
    self.n216 = self.n215 << 26 | self.n124
    self.n214 = self.n213 << 26 | self.n116
    self.n205 = (self.n16 * self.n108) & 0x3FFFFFFL
    self.n197 = (self.n15 * self.n101) & 0x3FFFFFFL
    self.n189 = (self.n14 * self.n94) & 0x3FFFFFFL
    self.n181 = (self.n13 * self.n87) & 0x3FFFFFFL
    self.n173 = (self.n12 * self.n80) & 0x3FFFFFFL
    self.n165 = (self.n11 * self.n73) & 0x3FFFFFFL
    self.n157 = (self.n10 * self.n66) & 0x3FFFFFFL
    self.n149 = (self.n9 * self.n59) & 0x3FFFFFFL
    self.n141 = (self.n8 * self.n52) & 0x3FFFFFFL
    self.n133 = (self.n7 * self.n45) & 0x3FFFFFFL
    self.n125 = (self.n6 * self.n38) & 0x3FFFFFFL
    self.n117 = (self.n5 * self.n31) & 0x3FFFFFFL
    self.n109 = (self.n4 * self.n24) & 0x3FFFFFFL
    self.n108r = self.n3
    self.n108e = self.n1
    self.n108d = self.n101
    self.n101r = self.n3
    self.n101e = self.n1
    self.n101d = self.n94
    self.n94r = self.n3
    self.n94e = self.n1
    self.n94d = self.n87
    self.n87r = self.n3
    self.n87e = self.n1
    self.n87d = self.n80
    self.n80r = self.n3
    self.n80e = self.n1
    self.n80d = self.n73
    self.n73r = self.n3
    self.n73e = self.n1
    self.n73d = self.n66
    self.n66r = self.n3
    self.n66e = self.n1
    self.n66d = self.n59
    self.n59r = self.n3
    self.n59e = self.n1
    self.n59d = self.n52
    self.n52r = self.n3
    self.n52e = self.n1
    self.n52d = self.n45
    self.n45r = self.n3
    self.n45e = self.n1
    self.n45d = self.n38
    self.n38r = self.n3
    self.n38e = self.n1
    self.n38d = self.n31
    self.n31r = self.n3
    self.n31e = self.n1
    self.n31d = self.n24
    self.n24r = self.n3
    self.n24e = self.n1
    self.n24d = self.n17
    self.n367 = (self.n364 + self.n366) & 0x3FFFFFFFL
    self.n355 = (self.n352 + self.n354) & 0x1FFFFFFFL
    self.n343 = (self.n340 + self.n342) & 0x1FFFFFFFL
    self.n338r = self.n2
    self.n338e = self.n1
    self.n338d = self.n331
    self.n322 = (self.n319 + self.n321) & 0xFFFFFFFL
    self.n310 = (self.n307 + self.n309) & 0xFFFFFFFL
    self.n298 = (self.n295 + self.n297) & 0xFFFFFFFL
    self.n293r = self.n2
    self.n293e = self.n1
    self.n293d = self.n286
    self.n277 = (self.n274 + self.n276) & 0x7FFFFFFL
    self.n265 = (self.n262 + self.n264) & 0x7FFFFFFL
    self.n253 = (self.n250 + self.n252) & 0x7FFFFFFL
    self.n241 = (self.n238 + self.n240) & 0x7FFFFFFL
    self.n229 = (self.n226 + self.n228) & 0x7FFFFFFL
    self.n217 = (self.n214 + self.n216) & 0x7FFFFFFL
    self.n212r = self.n2
    self.n212e = self.n1
    self.n212d = self.n205
    self.n204r = self.n2
    self.n204e = self.n1
    self.n204d = self.n197
    self.n196r = self.n2
    self.n196e = self.n1
    self.n196d = self.n189
    self.n188r = self.n2
    self.n188e = self.n1
    self.n188d = self.n181
    self.n180r = self.n2
    self.n180e = self.n1
    self.n180d = self.n173
    self.n172r = self.n2
    self.n172e = self.n1
    self.n172d = self.n165
    self.n164r = self.n2
    self.n164e = self.n1
    self.n164d = self.n157
    self.n156r = self.n2
    self.n156e = self.n1
    self.n156d = self.n149
    self.n148r = self.n2
    self.n148e = self.n1
    self.n148d = self.n141
    self.n140r = self.n2
    self.n140e = self.n1
    self.n140d = self.n133
    self.n132r = self.n2
    self.n132e = self.n1
    self.n132d = self.n125
    self.n124r = self.n2
    self.n124e = self.n1
    self.n124d = self.n117
    self.n116r = self.n2
    self.n116e = self.n1
    self.n116d = self.n109
    self.n374r = self.n2
    self.n374e = self.n1
    self.n374d = self.n367
    self.n362r = self.n2
    self.n362e = self.n1
    self.n362d = self.n355
    self.n350r = self.n2
    self.n350e = self.n1
    self.n350d = self.n343
    self.n329r = self.n2
    self.n329e = self.n1
    self.n329d = self.n322
    self.n317r = self.n2
    self.n317e = self.n1
    self.n317d = self.n310
    self.n305r = self.n2
    self.n305e = self.n1
    self.n305d = self.n298
    self.n284r = self.n2
    self.n284e = self.n1
    self.n284d = self.n277
    self.n272r = self.n2
    self.n272e = self.n1
    self.n272d = self.n265
    self.n260r = self.n2
    self.n260e = self.n1
    self.n260d = self.n253
    self.n248r = self.n2
    self.n248e = self.n1
    self.n248d = self.n241
    self.n236r = self.n2
    self.n236e = self.n1
    self.n236d = self.n229
    self.n224r = self.n2
    self.n224e = self.n1
    self.n224d = self.n217
    return (data_o, )

  def cycle_clock(self):
    if self.n24r:
      self.n24 = 0L
    elif self.n24e:
        self.n24 = self.n24d
    if self.n31r:
      self.n31 = 0L
    elif self.n31e:
        self.n31 = self.n31d
    if self.n38r:
      self.n38 = 0L
    elif self.n38e:
        self.n38 = self.n38d
    if self.n45r:
      self.n45 = 0L
    elif self.n45e:
        self.n45 = self.n45d
    if self.n52r:
      self.n52 = 0L
    elif self.n52e:
        self.n52 = self.n52d
    if self.n59r:
      self.n59 = 0L
    elif self.n59e:
        self.n59 = self.n59d
    if self.n66r:
      self.n66 = 0L
    elif self.n66e:
        self.n66 = self.n66d
    if self.n73r:
      self.n73 = 0L
    elif self.n73e:
        self.n73 = self.n73d
    if self.n80r:
      self.n80 = 0L
    elif self.n80e:
        self.n80 = self.n80d
    if self.n87r:
      self.n87 = 0L
    elif self.n87e:
        self.n87 = self.n87d
    if self.n94r:
      self.n94 = 0L
    elif self.n94e:
        self.n94 = self.n94d
    if self.n101r:
      self.n101 = 0L
    elif self.n101e:
        self.n101 = self.n101d
    if self.n108r:
      self.n108 = 0L
    elif self.n108e:
        self.n108 = self.n108d
    if self.n116r:
      self.n116 = 0L
    elif self.n116e:
        self.n116 = self.n116d
    if self.n124r:
      self.n124 = 0L
    elif self.n124e:
        self.n124 = self.n124d
    if self.n132r:
      self.n132 = 0L
    elif self.n132e:
        self.n132 = self.n132d
    if self.n140r:
      self.n140 = 0L
    elif self.n140e:
        self.n140 = self.n140d
    if self.n148r:
      self.n148 = 0L
    elif self.n148e:
        self.n148 = self.n148d
    if self.n156r:
      self.n156 = 0L
    elif self.n156e:
        self.n156 = self.n156d
    if self.n164r:
      self.n164 = 0L
    elif self.n164e:
        self.n164 = self.n164d
    if self.n172r:
      self.n172 = 0L
    elif self.n172e:
        self.n172 = self.n172d
    if self.n180r:
      self.n180 = 0L
    elif self.n180e:
        self.n180 = self.n180d
    if self.n188r:
      self.n188 = 0L
    elif self.n188e:
        self.n188 = self.n188d
    if self.n196r:
      self.n196 = 0L
    elif self.n196e:
        self.n196 = self.n196d
    if self.n204r:
      self.n204 = 0L
    elif self.n204e:
        self.n204 = self.n204d
    if self.n212r:
      self.n212 = 0L
    elif self.n212e:
        self.n212 = self.n212d
    if self.n224r:
      self.n224 = 0L
    elif self.n224e:
        self.n224 = self.n224d
    if self.n236r:
      self.n236 = 0L
    elif self.n236e:
        self.n236 = self.n236d
    if self.n248r:
      self.n248 = 0L
    elif self.n248e:
        self.n248 = self.n248d
    if self.n260r:
      self.n260 = 0L
    elif self.n260e:
        self.n260 = self.n260d
    if self.n272r:
      self.n272 = 0L
    elif self.n272e:
        self.n272 = self.n272d
    if self.n284r:
      self.n284 = 0L
    elif self.n284e:
        self.n284 = self.n284d
    if self.n293r:
      self.n293 = 0L
    elif self.n293e:
        self.n293 = self.n293d
    if self.n305r:
      self.n305 = 0L
    elif self.n305e:
        self.n305 = self.n305d
    if self.n317r:
      self.n317 = 0L
    elif self.n317e:
        self.n317 = self.n317d
    if self.n329r:
      self.n329 = 0L
    elif self.n329e:
        self.n329 = self.n329d
    if self.n338r:
      self.n338 = 0L
    elif self.n338e:
        self.n338 = self.n338d
    if self.n350r:
      self.n350 = 0L
    elif self.n350e:
        self.n350 = self.n350d
    if self.n362r:
      self.n362 = 0L
    elif self.n362e:
        self.n362 = self.n362d
    if self.n374r:
      self.n374 = 0L
    elif self.n374e:
        self.n374 = self.n374d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n17 = self.n17
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n9 = self.n9
    self.sim_n10 = self.n10
    self.sim_n11 = self.n11
    self.sim_n12 = self.n12
    self.sim_n13 = self.n13
    self.sim_n14 = self.n14
    self.sim_n15 = self.n15
    self.sim_n16 = self.n16
    self.sim_n375 = self.n375
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fir_12_16_10 $end\n")
    self.sim_file.write("$var wire 1 ! reset_i $end\n")
    self.sim_file.write("$var wire 16 \" data_i $end\n")
    self.sim_file.write("$var wire 10 # k0_i $end\n")
    self.sim_file.write("$var wire 10 $ k1_i $end\n")
    self.sim_file.write("$var wire 10 % k2_i $end\n")
    self.sim_file.write("$var wire 10 & k3_i $end\n")
    self.sim_file.write("$var wire 10 ' k4_i $end\n")
    self.sim_file.write("$var wire 10 ( k5_i $end\n")
    self.sim_file.write("$var wire 10 ) k6_i $end\n")
    self.sim_file.write("$var wire 10 * k7_i $end\n")
    self.sim_file.write("$var wire 10 + k8_i $end\n")
    self.sim_file.write("$var wire 10 , k9_i $end\n")
    self.sim_file.write("$var wire 10 - k10_i $end\n")
    self.sim_file.write("$var wire 10 . k11_i $end\n")
    self.sim_file.write("$var wire 10 / k12_i $end\n")
    self.sim_file.write("$var wire 30 0 data_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n17 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n17 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" \"\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n9 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n9 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n10 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n10 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n11 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n11 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" *\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n12 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n12 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" +\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n13 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n13 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ,\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n14 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n14 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" -\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n15 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n15 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" .\n")
    found = 0
    for bit in range(9, -1, -1):
      if found:
        if self.n16 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n16 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" /\n")
    found = 0
    for bit in range(29, -1, -1):
      if found:
        if self.n375 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n375 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 0\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n17 != self.n17:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n17 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n17 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" \"\n")
      self.sim_n17 = self.n17
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n8 = self.n8
    if self.sim_n9 != self.n9:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n9 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n9 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n9 = self.n9
    if self.sim_n10 != self.n10:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n10 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n10 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n10 = self.n10
    if self.sim_n11 != self.n11:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n11 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n11 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" *\n")
      self.sim_n11 = self.n11
    if self.sim_n12 != self.n12:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n12 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n12 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" +\n")
      self.sim_n12 = self.n12
    if self.sim_n13 != self.n13:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n13 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n13 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ,\n")
      self.sim_n13 = self.n13
    if self.sim_n14 != self.n14:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n14 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n14 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" -\n")
      self.sim_n14 = self.n14
    if self.sim_n15 != self.n15:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n15 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n15 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" .\n")
      self.sim_n15 = self.n15
    if self.sim_n16 != self.n16:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(9, -1, -1):
        if found:
          if self.n16 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n16 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" /\n")
      self.sim_n16 = self.n16
    if self.sim_n375 != self.n375:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(29, -1, -1):
        if found:
          if self.n375 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n375 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 0\n")
      self.sim_n375 = self.n375
    self.sim_count = self.sim_count + 1

