--
--  Copyright (c) 2003 Launchbird Design Systems, Inc.
--  All rights reserved.
--  
--  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
--    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
--    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
--  
--  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
--  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
--  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
--  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
--  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
--  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--  
--  
--  Overview:
--  
--    Performs finite impulse response (FIR) filtering.
--    The filter's sum of products is pipelined with a register after
--    every multiplier and adder.  The adder network is a balanced binary
--    tree to minimize latency.  The sum of products has no numeric loss because the
--    multipliers keep all resulting bits and each adder extends the precision by 1.
--  
--  Interface:
--  
--    Synchronization:
--      clock_c  : Clock input.
--      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
--  
--    Inputs:
--      data_i  : Input data.
--      k0_i    : Coefficient 0 multiplied by in_i(0).
--      k1_i    : Coefficient 1 multiplied by in_i(k-1).
--      k2_i    : Coefficient 2 multiplied by in_i(k-2).
--      ...
--      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
--  
--    Outputs:
--      data_o : Output data.
--  
--  Built In Parameters:
--  
--    Filter Order             = 12
--    Input Precision          = 16
--    Coefficient Precision    = 10
--    Sum of Products Latency  = 5
--  
--  
--  
--  
--  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
--  
--  Build Date : Fri Aug 22 09:45:51 CDT 2003
--  
--  Interface
--  
--    Build Name    : cf_fir_12_16_10
--    Clock Domains : clock_c  
--    Vector Input  : reset_i(1)
--    Vector Input  : data_i(16)
--    Vector Input  : k0_i(10)
--    Vector Input  : k1_i(10)
--    Vector Input  : k2_i(10)
--    Vector Input  : k3_i(10)
--    Vector Input  : k4_i(10)
--    Vector Input  : k5_i(10)
--    Vector Input  : k6_i(10)
--    Vector Input  : k7_i(10)
--    Vector Input  : k8_i(10)
--    Vector Input  : k9_i(10)
--    Vector Input  : k10_i(10)
--    Vector Input  : k11_i(10)
--    Vector Input  : k12_i(10)
--    Vector Output : data_o(30)
--  
--  
--  

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_14 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0));
end entity cf_fir_12_16_10_14;
architecture rtl of cf_fir_12_16_10_14 is
signal n1 : unsigned(15 downto 0) := "0000000000000000";
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0) := "0000000000000000";
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0) := "0000000000000000";
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0) := "0000000000000000";
signal n8 : unsigned(15 downto 0) := "0000000000000000";
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0000000000000000";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0000000000000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0000000000000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "0000000000000000";
    elsif i1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o8 <= n8;
o7 <= n7;
o6 <= n6;
o5 <= n5;
o4 <= n4;
o3 <= n3;
o2 <= n2;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_13 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
o1 : out unsigned(25 downto 0);
o2 : out unsigned(25 downto 0);
o3 : out unsigned(25 downto 0);
o4 : out unsigned(25 downto 0));
end entity cf_fir_12_16_10_13;
architecture rtl of cf_fir_12_16_10_13 is
signal n1 : unsigned(25 downto 0);
signal n2 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n3 : unsigned(25 downto 0);
signal n4 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n5 : unsigned(25 downto 0);
signal n6 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n7 : unsigned(25 downto 0);
signal n8 : unsigned(25 downto 0) := "00000000000000000000000000";
begin
n1 <= i3 * i7;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i8;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i9;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_12 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
o1 : out unsigned(25 downto 0);
o2 : out unsigned(25 downto 0);
o3 : out unsigned(25 downto 0);
o4 : out unsigned(25 downto 0);
o5 : out unsigned(25 downto 0);
o6 : out unsigned(25 downto 0);
o7 : out unsigned(25 downto 0);
o8 : out unsigned(25 downto 0));
end entity cf_fir_12_16_10_12;
architecture rtl of cf_fir_12_16_10_12 is
signal n1 : unsigned(25 downto 0);
signal n2 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n3 : unsigned(25 downto 0);
signal n4 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n5 : unsigned(25 downto 0);
signal n6 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n7 : unsigned(25 downto 0);
signal n8 : unsigned(25 downto 0) := "00000000000000000000000000";
signal s9_1 : unsigned(25 downto 0);
signal s9_2 : unsigned(25 downto 0);
signal s9_3 : unsigned(25 downto 0);
signal s9_4 : unsigned(25 downto 0);
component cf_fir_12_16_10_13 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
o1 : out unsigned(25 downto 0);
o2 : out unsigned(25 downto 0);
o3 : out unsigned(25 downto 0);
o4 : out unsigned(25 downto 0));
end component cf_fir_12_16_10_13;
begin
n1 <= i3 * i11;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i12;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i13;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i14;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_12_16_10_13 port map (clock_c, i1, i2, i7, i8, i9, i10, i15, i16, i17, i18, s9_1, s9_2, s9_3, s9_4);
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_11 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(9 downto 0);
i12 : in  unsigned(9 downto 0);
i13 : in  unsigned(9 downto 0);
i14 : in  unsigned(9 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
i22 : in  unsigned(15 downto 0);
i23 : in  unsigned(15 downto 0);
i24 : in  unsigned(15 downto 0);
i25 : in  unsigned(15 downto 0);
i26 : in  unsigned(15 downto 0);
o1 : out unsigned(25 downto 0);
o2 : out unsigned(25 downto 0);
o3 : out unsigned(25 downto 0);
o4 : out unsigned(25 downto 0);
o5 : out unsigned(25 downto 0);
o6 : out unsigned(25 downto 0);
o7 : out unsigned(25 downto 0);
o8 : out unsigned(25 downto 0);
o9 : out unsigned(25 downto 0);
o10 : out unsigned(25 downto 0);
o11 : out unsigned(25 downto 0);
o12 : out unsigned(25 downto 0));
end entity cf_fir_12_16_10_11;
architecture rtl of cf_fir_12_16_10_11 is
signal n1 : unsigned(25 downto 0);
signal n2 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n3 : unsigned(25 downto 0);
signal n4 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n5 : unsigned(25 downto 0);
signal n6 : unsigned(25 downto 0) := "00000000000000000000000000";
signal n7 : unsigned(25 downto 0);
signal n8 : unsigned(25 downto 0) := "00000000000000000000000000";
signal s9_1 : unsigned(25 downto 0);
signal s9_2 : unsigned(25 downto 0);
signal s9_3 : unsigned(25 downto 0);
signal s9_4 : unsigned(25 downto 0);
signal s9_5 : unsigned(25 downto 0);
signal s9_6 : unsigned(25 downto 0);
signal s9_7 : unsigned(25 downto 0);
signal s9_8 : unsigned(25 downto 0);
component cf_fir_12_16_10_12 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
o1 : out unsigned(25 downto 0);
o2 : out unsigned(25 downto 0);
o3 : out unsigned(25 downto 0);
o4 : out unsigned(25 downto 0);
o5 : out unsigned(25 downto 0);
o6 : out unsigned(25 downto 0);
o7 : out unsigned(25 downto 0);
o8 : out unsigned(25 downto 0));
end component cf_fir_12_16_10_12;
begin
n1 <= i3 * i15;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i16;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i17;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i18;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_12_16_10_12 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i19, i20, i21, i22, i23, i24, i25, i26, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8);
o12 <= s9_8;
o11 <= s9_7;
o10 <= s9_6;
o9 <= s9_5;
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_10 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
o1 : out unsigned(26 downto 0);
o2 : out unsigned(26 downto 0));
end entity cf_fir_12_16_10_10;
architecture rtl of cf_fir_12_16_10_10 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(26 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(26 downto 0);
signal n5 : unsigned(26 downto 0);
signal n6 : unsigned(26 downto 0) := "000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(26 downto 0);
signal n9 : unsigned(26 downto 0) := "000000000000000000000000000";
begin
n1 <= i3(25 downto 25);
n2 <= n1 & i3;
n3 <= i4(25 downto 25);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(25 downto 25);
n8 <= n7 & i5;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n9 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n9 <= n8;
    end if;
  end if;
end process;
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_9 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
i6 : in  unsigned(25 downto 0);
i7 : in  unsigned(25 downto 0);
i8 : in  unsigned(25 downto 0);
i9 : in  unsigned(25 downto 0);
o1 : out unsigned(26 downto 0);
o2 : out unsigned(26 downto 0);
o3 : out unsigned(26 downto 0);
o4 : out unsigned(26 downto 0));
end entity cf_fir_12_16_10_9;
architecture rtl of cf_fir_12_16_10_9 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(26 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(26 downto 0);
signal n5 : unsigned(26 downto 0);
signal n6 : unsigned(26 downto 0) := "000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(26 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(26 downto 0);
signal n11 : unsigned(26 downto 0);
signal n12 : unsigned(26 downto 0) := "000000000000000000000000000";
signal s13_1 : unsigned(26 downto 0);
signal s13_2 : unsigned(26 downto 0);
component cf_fir_12_16_10_10 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
o1 : out unsigned(26 downto 0);
o2 : out unsigned(26 downto 0));
end component cf_fir_12_16_10_10;
begin
n1 <= i3(25 downto 25);
n2 <= n1 & i3;
n3 <= i4(25 downto 25);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(25 downto 25);
n8 <= n7 & i5;
n9 <= i6(25 downto 25);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_12_16_10_10 port map (clock_c, i1, i2, i7, i8, i9, s13_1, s13_2);
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
i6 : in  unsigned(25 downto 0);
i7 : in  unsigned(25 downto 0);
i8 : in  unsigned(25 downto 0);
i9 : in  unsigned(25 downto 0);
i10 : in  unsigned(25 downto 0);
i11 : in  unsigned(25 downto 0);
i12 : in  unsigned(25 downto 0);
i13 : in  unsigned(25 downto 0);
o1 : out unsigned(26 downto 0);
o2 : out unsigned(26 downto 0);
o3 : out unsigned(26 downto 0);
o4 : out unsigned(26 downto 0);
o5 : out unsigned(26 downto 0);
o6 : out unsigned(26 downto 0));
end entity cf_fir_12_16_10_8;
architecture rtl of cf_fir_12_16_10_8 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(26 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(26 downto 0);
signal n5 : unsigned(26 downto 0);
signal n6 : unsigned(26 downto 0) := "000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(26 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(26 downto 0);
signal n11 : unsigned(26 downto 0);
signal n12 : unsigned(26 downto 0) := "000000000000000000000000000";
signal s13_1 : unsigned(26 downto 0);
signal s13_2 : unsigned(26 downto 0);
signal s13_3 : unsigned(26 downto 0);
signal s13_4 : unsigned(26 downto 0);
component cf_fir_12_16_10_9 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
i6 : in  unsigned(25 downto 0);
i7 : in  unsigned(25 downto 0);
i8 : in  unsigned(25 downto 0);
i9 : in  unsigned(25 downto 0);
o1 : out unsigned(26 downto 0);
o2 : out unsigned(26 downto 0);
o3 : out unsigned(26 downto 0);
o4 : out unsigned(26 downto 0));
end component cf_fir_12_16_10_9;
begin
n1 <= i3(25 downto 25);
n2 <= n1 & i3;
n3 <= i4(25 downto 25);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(25 downto 25);
n8 <= n7 & i5;
n9 <= i6(25 downto 25);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_12_16_10_9 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, s13_1, s13_2, s13_3, s13_4);
o6 <= s13_4;
o5 <= s13_3;
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(27 downto 0);
i4 : in  unsigned(27 downto 0);
i5 : in  unsigned(27 downto 0);
i6 : in  unsigned(27 downto 0);
o1 : out unsigned(28 downto 0);
o2 : out unsigned(28 downto 0));
end entity cf_fir_12_16_10_7;
architecture rtl of cf_fir_12_16_10_7 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(28 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(28 downto 0);
signal n5 : unsigned(28 downto 0);
signal n6 : unsigned(28 downto 0) := "00000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(28 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(28 downto 0);
signal n11 : unsigned(28 downto 0);
signal n12 : unsigned(28 downto 0) := "00000000000000000000000000000";
begin
n1 <= i3(27 downto 27);
n2 <= n1 & i3;
n3 <= i4(27 downto 27);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(27 downto 27);
n8 <= n7 & i5;
n9 <= i6(27 downto 27);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(26 downto 0);
i4 : in  unsigned(26 downto 0);
i5 : in  unsigned(26 downto 0);
o1 : out unsigned(27 downto 0);
o2 : out unsigned(27 downto 0));
end entity cf_fir_12_16_10_6;
architecture rtl of cf_fir_12_16_10_6 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(27 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(27 downto 0);
signal n5 : unsigned(27 downto 0);
signal n6 : unsigned(27 downto 0) := "0000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(27 downto 0);
signal n9 : unsigned(27 downto 0) := "0000000000000000000000000000";
begin
n1 <= i3(26 downto 26);
n2 <= n1 & i3;
n3 <= i4(26 downto 26);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(26 downto 26);
n8 <= n7 & i5;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n9 <= "0000000000000000000000000000";
    elsif i1 = "1" then
      n9 <= n8;
    end if;
  end if;
end process;
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(26 downto 0);
i4 : in  unsigned(26 downto 0);
i5 : in  unsigned(26 downto 0);
i6 : in  unsigned(26 downto 0);
i7 : in  unsigned(26 downto 0);
i8 : in  unsigned(26 downto 0);
i9 : in  unsigned(26 downto 0);
o1 : out unsigned(27 downto 0);
o2 : out unsigned(27 downto 0);
o3 : out unsigned(27 downto 0);
o4 : out unsigned(27 downto 0));
end entity cf_fir_12_16_10_5;
architecture rtl of cf_fir_12_16_10_5 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(27 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(27 downto 0);
signal n5 : unsigned(27 downto 0);
signal n6 : unsigned(27 downto 0) := "0000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(27 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(27 downto 0);
signal n11 : unsigned(27 downto 0);
signal n12 : unsigned(27 downto 0) := "0000000000000000000000000000";
signal s13_1 : unsigned(27 downto 0);
signal s13_2 : unsigned(27 downto 0);
component cf_fir_12_16_10_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(26 downto 0);
i4 : in  unsigned(26 downto 0);
i5 : in  unsigned(26 downto 0);
o1 : out unsigned(27 downto 0);
o2 : out unsigned(27 downto 0));
end component cf_fir_12_16_10_6;
begin
n1 <= i3(26 downto 26);
n2 <= n1 & i3;
n3 <= i4(26 downto 26);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(26 downto 26);
n8 <= n7 & i5;
n9 <= i6(26 downto 26);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "0000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_12_16_10_6 port map (clock_c, i1, i2, i7, i8, i9, s13_1, s13_2);
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(26 downto 0);
i4 : in  unsigned(26 downto 0);
i5 : in  unsigned(26 downto 0);
i6 : in  unsigned(26 downto 0);
i7 : in  unsigned(26 downto 0);
i8 : in  unsigned(26 downto 0);
i9 : in  unsigned(26 downto 0);
o1 : out unsigned(29 downto 0));
end entity cf_fir_12_16_10_4;
architecture rtl of cf_fir_12_16_10_4 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(29 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(29 downto 0);
signal n5 : unsigned(29 downto 0);
signal n6 : unsigned(29 downto 0) := "000000000000000000000000000000";
signal s7_1 : unsigned(28 downto 0);
signal s7_2 : unsigned(28 downto 0);
signal s8_1 : unsigned(27 downto 0);
signal s8_2 : unsigned(27 downto 0);
signal s8_3 : unsigned(27 downto 0);
signal s8_4 : unsigned(27 downto 0);
component cf_fir_12_16_10_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(27 downto 0);
i4 : in  unsigned(27 downto 0);
i5 : in  unsigned(27 downto 0);
i6 : in  unsigned(27 downto 0);
o1 : out unsigned(28 downto 0);
o2 : out unsigned(28 downto 0));
end component cf_fir_12_16_10_7;
component cf_fir_12_16_10_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(26 downto 0);
i4 : in  unsigned(26 downto 0);
i5 : in  unsigned(26 downto 0);
i6 : in  unsigned(26 downto 0);
i7 : in  unsigned(26 downto 0);
i8 : in  unsigned(26 downto 0);
i9 : in  unsigned(26 downto 0);
o1 : out unsigned(27 downto 0);
o2 : out unsigned(27 downto 0);
o3 : out unsigned(27 downto 0);
o4 : out unsigned(27 downto 0));
end component cf_fir_12_16_10_5;
begin
n1 <= s7_1(28 downto 28);
n2 <= n1 & s7_1;
n3 <= s7_2(28 downto 28);
n4 <= n3 & s7_2;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
s7 : cf_fir_12_16_10_7 port map (clock_c, i1, i2, s8_1, s8_2, s8_3, s8_4, s7_1, s7_2);
s8 : cf_fir_12_16_10_5 port map (clock_c, i1, i2, i3, i4, i5, i6, i7, i8, i9, s8_1, s8_2, s8_3, s8_4);
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
i6 : in  unsigned(25 downto 0);
i7 : in  unsigned(25 downto 0);
i8 : in  unsigned(25 downto 0);
i9 : in  unsigned(25 downto 0);
i10 : in  unsigned(25 downto 0);
i11 : in  unsigned(25 downto 0);
i12 : in  unsigned(25 downto 0);
i13 : in  unsigned(25 downto 0);
i14 : in  unsigned(25 downto 0);
i15 : in  unsigned(25 downto 0);
o1 : out unsigned(29 downto 0));
end entity cf_fir_12_16_10_3;
architecture rtl of cf_fir_12_16_10_3 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(26 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(26 downto 0);
signal n5 : unsigned(26 downto 0);
signal n6 : unsigned(26 downto 0) := "000000000000000000000000000";
signal s7_1 : unsigned(26 downto 0);
signal s7_2 : unsigned(26 downto 0);
signal s7_3 : unsigned(26 downto 0);
signal s7_4 : unsigned(26 downto 0);
signal s7_5 : unsigned(26 downto 0);
signal s7_6 : unsigned(26 downto 0);
signal s8_1 : unsigned(29 downto 0);
component cf_fir_12_16_10_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
i6 : in  unsigned(25 downto 0);
i7 : in  unsigned(25 downto 0);
i8 : in  unsigned(25 downto 0);
i9 : in  unsigned(25 downto 0);
i10 : in  unsigned(25 downto 0);
i11 : in  unsigned(25 downto 0);
i12 : in  unsigned(25 downto 0);
i13 : in  unsigned(25 downto 0);
o1 : out unsigned(26 downto 0);
o2 : out unsigned(26 downto 0);
o3 : out unsigned(26 downto 0);
o4 : out unsigned(26 downto 0);
o5 : out unsigned(26 downto 0);
o6 : out unsigned(26 downto 0));
end component cf_fir_12_16_10_8;
component cf_fir_12_16_10_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(26 downto 0);
i4 : in  unsigned(26 downto 0);
i5 : in  unsigned(26 downto 0);
i6 : in  unsigned(26 downto 0);
i7 : in  unsigned(26 downto 0);
i8 : in  unsigned(26 downto 0);
i9 : in  unsigned(26 downto 0);
o1 : out unsigned(29 downto 0));
end component cf_fir_12_16_10_4;
begin
n1 <= i3(25 downto 25);
n2 <= n1 & i3;
n3 <= i4(25 downto 25);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
s7 : cf_fir_12_16_10_8 port map (clock_c, i1, i2, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6);
s8 : cf_fir_12_16_10_4 port map (clock_c, i1, i2, n6, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s8_1);
o1 <= s8_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(9 downto 0);
i12 : in  unsigned(9 downto 0);
i13 : in  unsigned(9 downto 0);
i14 : in  unsigned(9 downto 0);
i15 : in  unsigned(9 downto 0);
i16 : in  unsigned(9 downto 0);
i17 : in  unsigned(15 downto 0);
o1 : out unsigned(29 downto 0));
end entity cf_fir_12_16_10_2;
architecture rtl of cf_fir_12_16_10_2 is
signal n1 : unsigned(15 downto 0) := "0000000000000000";
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0) := "0000000000000000";
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0) := "0000000000000000";
signal n6 : unsigned(25 downto 0);
signal n7 : unsigned(25 downto 0) := "00000000000000000000000000";
signal s8_1 : unsigned(15 downto 0);
signal s8_2 : unsigned(15 downto 0);
signal s8_3 : unsigned(15 downto 0);
signal s8_4 : unsigned(15 downto 0);
signal s8_5 : unsigned(15 downto 0);
signal s8_6 : unsigned(15 downto 0);
signal s8_7 : unsigned(15 downto 0);
signal s8_8 : unsigned(15 downto 0);
signal s9_1 : unsigned(25 downto 0);
signal s9_2 : unsigned(25 downto 0);
signal s9_3 : unsigned(25 downto 0);
signal s9_4 : unsigned(25 downto 0);
signal s9_5 : unsigned(25 downto 0);
signal s9_6 : unsigned(25 downto 0);
signal s9_7 : unsigned(25 downto 0);
signal s9_8 : unsigned(25 downto 0);
signal s9_9 : unsigned(25 downto 0);
signal s9_10 : unsigned(25 downto 0);
signal s9_11 : unsigned(25 downto 0);
signal s9_12 : unsigned(25 downto 0);
signal s10_1 : unsigned(29 downto 0);
component cf_fir_12_16_10_14 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0));
end component cf_fir_12_16_10_14;
component cf_fir_12_16_10_11 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(9 downto 0);
i12 : in  unsigned(9 downto 0);
i13 : in  unsigned(9 downto 0);
i14 : in  unsigned(9 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
i22 : in  unsigned(15 downto 0);
i23 : in  unsigned(15 downto 0);
i24 : in  unsigned(15 downto 0);
i25 : in  unsigned(15 downto 0);
i26 : in  unsigned(15 downto 0);
o1 : out unsigned(25 downto 0);
o2 : out unsigned(25 downto 0);
o3 : out unsigned(25 downto 0);
o4 : out unsigned(25 downto 0);
o5 : out unsigned(25 downto 0);
o6 : out unsigned(25 downto 0);
o7 : out unsigned(25 downto 0);
o8 : out unsigned(25 downto 0);
o9 : out unsigned(25 downto 0);
o10 : out unsigned(25 downto 0);
o11 : out unsigned(25 downto 0);
o12 : out unsigned(25 downto 0));
end component cf_fir_12_16_10_11;
component cf_fir_12_16_10_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(25 downto 0);
i4 : in  unsigned(25 downto 0);
i5 : in  unsigned(25 downto 0);
i6 : in  unsigned(25 downto 0);
i7 : in  unsigned(25 downto 0);
i8 : in  unsigned(25 downto 0);
i9 : in  unsigned(25 downto 0);
i10 : in  unsigned(25 downto 0);
i11 : in  unsigned(25 downto 0);
i12 : in  unsigned(25 downto 0);
i13 : in  unsigned(25 downto 0);
i14 : in  unsigned(25 downto 0);
i15 : in  unsigned(25 downto 0);
o1 : out unsigned(29 downto 0));
end component cf_fir_12_16_10_3;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n1 <= "0000000000000000";
    elsif i1 = "1" then
      n1 <= i17;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n3 <= "0000000000000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n5 <= "0000000000000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
n6 <= i4 * n1;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000000000000000000000";
    elsif i1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
s8 : cf_fir_12_16_10_14 port map (clock_c, i1, i3, n5, s8_1, s8_2, s8_3, s8_4, s8_5, s8_6, s8_7, s8_8);
s9 : cf_fir_12_16_10_11 port map (clock_c, i1, i2, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, n2, n3, n4, n5, s8_1, s8_2, s8_3, s8_4, s8_5, s8_6, s8_7, s8_8, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8, s9_9, s9_10, s9_11, s9_12);
s10 : cf_fir_12_16_10_3 port map (clock_c, i1, i2, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8, s9_9, s9_10, s9_11, s9_12, s10_1);
o1 <= s10_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(9 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(9 downto 0);
i12 : in  unsigned(9 downto 0);
i13 : in  unsigned(9 downto 0);
i14 : in  unsigned(9 downto 0);
i15 : in  unsigned(15 downto 0);
o1 : out unsigned(29 downto 0));
end entity cf_fir_12_16_10_1;
architecture rtl of cf_fir_12_16_10_1 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal s3_1 : unsigned(29 downto 0);
component cf_fir_12_16_10_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(9 downto 0);
i12 : in  unsigned(9 downto 0);
i13 : in  unsigned(9 downto 0);
i14 : in  unsigned(9 downto 0);
i15 : in  unsigned(9 downto 0);
i16 : in  unsigned(9 downto 0);
i17 : in  unsigned(15 downto 0);
o1 : out unsigned(29 downto 0));
end component cf_fir_12_16_10_2;
begin
n1 <= "1";
n2 <= "0";
s3 : cf_fir_12_16_10_2 port map (clock_c, n1, n2, i1, i2, i3, i4, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, s3_1);
o1 <= s3_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_12_16_10 is
port(
signal clock_c : in std_logic;
signal reset_i : in unsigned(0 downto 0);
signal data_i : in unsigned(15 downto 0);
signal k0_i : in unsigned(9 downto 0);
signal k1_i : in unsigned(9 downto 0);
signal k2_i : in unsigned(9 downto 0);
signal k3_i : in unsigned(9 downto 0);
signal k4_i : in unsigned(9 downto 0);
signal k5_i : in unsigned(9 downto 0);
signal k6_i : in unsigned(9 downto 0);
signal k7_i : in unsigned(9 downto 0);
signal k8_i : in unsigned(9 downto 0);
signal k9_i : in unsigned(9 downto 0);
signal k10_i : in unsigned(9 downto 0);
signal k11_i : in unsigned(9 downto 0);
signal k12_i : in unsigned(9 downto 0);
signal data_o : out unsigned(29 downto 0));
end entity cf_fir_12_16_10;
architecture rtl of cf_fir_12_16_10 is
component cf_fir_12_16_10_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(9 downto 0);
i3 : in  unsigned(9 downto 0);
i4 : in  unsigned(9 downto 0);
i5 : in  unsigned(9 downto 0);
i6 : in  unsigned(9 downto 0);
i7 : in  unsigned(9 downto 0);
i8 : in  unsigned(9 downto 0);
i9 : in  unsigned(9 downto 0);
i10 : in  unsigned(9 downto 0);
i11 : in  unsigned(9 downto 0);
i12 : in  unsigned(9 downto 0);
i13 : in  unsigned(9 downto 0);
i14 : in  unsigned(9 downto 0);
i15 : in  unsigned(15 downto 0);
o1 : out unsigned(29 downto 0));
end component cf_fir_12_16_10_1;
signal n1 : unsigned(29 downto 0);
begin
s1 : cf_fir_12_16_10_1 port map (clock_c, reset_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, k8_i, k9_i, k10_i, k11_i, k12_i, data_i, n1);
data_o <= n1;
end architecture rtl;


