//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs finite impulse response (FIR) filtering.
//    The filter's sum of products is pipelined with a register after
//    every multiplier and adder.  The adder network is a balanced binary
//    tree to minimize latency.  The sum of products has no numeric loss because the
//    multipliers keep all resulting bits and each adder extends the precision by 1.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
//  
//    Inputs:
//      data_i  : Input data.
//      k0_i    : Coefficient 0 multiplied by in_i(0).
//      k1_i    : Coefficient 1 multiplied by in_i(k-1).
//      k2_i    : Coefficient 2 multiplied by in_i(k-2).
//      ...
//      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
//  
//    Outputs:
//      data_o : Output data.
//  
//  Built In Parameters:
//  
//    Filter Order             = 16
//    Input Precision          = 16
//    Coefficient Precision    = 16
//    Sum of Products Latency  = 6
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:45:53 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fir_16_16_16
//    Clock Domains : clock_c  
//    Vector Input  : reset_i(1)
//    Vector Input  : data_i(16)
//    Vector Input  : k0_i(16)
//    Vector Input  : k1_i(16)
//    Vector Input  : k2_i(16)
//    Vector Input  : k3_i(16)
//    Vector Input  : k4_i(16)
//    Vector Input  : k5_i(16)
//    Vector Input  : k6_i(16)
//    Vector Input  : k7_i(16)
//    Vector Input  : k8_i(16)
//    Vector Input  : k9_i(16)
//    Vector Input  : k10_i(16)
//    Vector Input  : k11_i(16)
//    Vector Input  : k12_i(16)
//    Vector Input  : k13_i(16)
//    Vector Input  : k14_i(16)
//    Vector Input  : k15_i(16)
//    Vector Input  : k16_i(16)
//    Vector Output : data_o(37)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_fir_16_16_16.h"

static unsigned char *data_o;
static unsigned char n495[1];
static unsigned char n493[1];
static unsigned char n484[1];
static unsigned char n474[1];
static unsigned char n472[1];
static unsigned char n463[1];
static unsigned char n453[1];
static unsigned char n451[1];
static unsigned char n441[1];
static unsigned char n439[1];
static unsigned char n430[1];
static unsigned char n420[1];
static unsigned char n418[1];
static unsigned char n408[1];
static unsigned char n406[1];
static unsigned char n396[1];
static unsigned char n394[1];
static unsigned char n384[1];
static unsigned char n382[1];
static unsigned char n373[1];
static unsigned char n363[1];
static unsigned char n361[1];
static unsigned char n351[1];
static unsigned char n349[1];
static unsigned char n339[1];
static unsigned char n337[1];
static unsigned char n327[1];
static unsigned char n325[1];
static unsigned char n315[1];
static unsigned char n313[1];
static unsigned char n303[1];
static unsigned char n301[1];
static unsigned char n291[1];
static unsigned char n289[1];
static unsigned char n279[1];
static unsigned char n277[1];
static unsigned char *data_i;
static unsigned char *k16_i;
static unsigned char *k15_i;
static unsigned char *k14_i;
static unsigned char *k13_i;
static unsigned char *k12_i;
static unsigned char *k11_i;
static unsigned char *k10_i;
static unsigned char *k9_i;
static unsigned char *k8_i;
static unsigned char *k7_i;
static unsigned char *k6_i;
static unsigned char *k5_i;
static unsigned char *k4_i;
static unsigned char *k3_i;
static unsigned char *k2_i;
static unsigned char *k1_i;
static unsigned char *k0_i;
static unsigned char *reset_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char n496[5];
static unsigned char n494[5];
static unsigned char n485[5];
static unsigned char n475[5];
static unsigned char n473[5];
static unsigned char n464[5];
static unsigned char n454[5];
static unsigned char n452[5];
static unsigned char n442[5];
static unsigned char n440[5];
static unsigned char n431[5];
static unsigned char n421[5];
static unsigned char n419[5];
static unsigned char n409[5];
static unsigned char n407[5];
static unsigned char n397[5];
static unsigned char n395[5];
static unsigned char n385[5];
static unsigned char n383[5];
static unsigned char n374[5];
static unsigned char n364[5];
static unsigned char n362[5];
static unsigned char n352[5];
static unsigned char n350[5];
static unsigned char n340[5];
static unsigned char n338[5];
static unsigned char n328[5];
static unsigned char n326[5];
static unsigned char n316[5];
static unsigned char n314[5];
static unsigned char n304[5];
static unsigned char n302[5];
static unsigned char n292[5];
static unsigned char n290[5];
static unsigned char n280[5];
static unsigned char n278[5];
static unsigned char n269[4];
static unsigned char n261[4];
static unsigned char n253[4];
static unsigned char n245[4];
static unsigned char n237[4];
static unsigned char n229[4];
static unsigned char n221[4];
static unsigned char n213[4];
static unsigned char n205[4];
static unsigned char n197[4];
static unsigned char n189[4];
static unsigned char n181[4];
static unsigned char n173[4];
static unsigned char n165[4];
static unsigned char n157[4];
static unsigned char n149[4];
static unsigned char n141[4];
static unsigned char n140[2];
static unsigned char n140r[1];
static unsigned char n140e[1];
static unsigned char n140d[2];
static unsigned char n133[2];
static unsigned char n133r[1];
static unsigned char n133e[1];
static unsigned char n133d[2];
static unsigned char n126[2];
static unsigned char n126r[1];
static unsigned char n126e[1];
static unsigned char n126d[2];
static unsigned char n119[2];
static unsigned char n119r[1];
static unsigned char n119e[1];
static unsigned char n119d[2];
static unsigned char n112[2];
static unsigned char n112r[1];
static unsigned char n112e[1];
static unsigned char n112d[2];
static unsigned char n105[2];
static unsigned char n105r[1];
static unsigned char n105e[1];
static unsigned char n105d[2];
static unsigned char n98[2];
static unsigned char n98r[1];
static unsigned char n98e[1];
static unsigned char n98d[2];
static unsigned char n91[2];
static unsigned char n91r[1];
static unsigned char n91e[1];
static unsigned char n91d[2];
static unsigned char n84[2];
static unsigned char n84r[1];
static unsigned char n84e[1];
static unsigned char n84d[2];
static unsigned char n77[2];
static unsigned char n77r[1];
static unsigned char n77e[1];
static unsigned char n77d[2];
static unsigned char n70[2];
static unsigned char n70r[1];
static unsigned char n70e[1];
static unsigned char n70d[2];
static unsigned char n63[2];
static unsigned char n63r[1];
static unsigned char n63e[1];
static unsigned char n63d[2];
static unsigned char n56[2];
static unsigned char n56r[1];
static unsigned char n56e[1];
static unsigned char n56d[2];
static unsigned char n49[2];
static unsigned char n49r[1];
static unsigned char n49e[1];
static unsigned char n49d[2];
static unsigned char n42[2];
static unsigned char n42r[1];
static unsigned char n42e[1];
static unsigned char n42d[2];
static unsigned char n35[2];
static unsigned char n35r[1];
static unsigned char n35e[1];
static unsigned char n35d[2];
static unsigned char n28[2];
static unsigned char n28r[1];
static unsigned char n28e[1];
static unsigned char n28d[2];
static unsigned char n497[5];
static unsigned char n492[5];
static unsigned char n492r[1];
static unsigned char n492e[1];
static unsigned char n492d[5];
static unsigned char n476[5];
static unsigned char n471[5];
static unsigned char n471r[1];
static unsigned char n471e[1];
static unsigned char n471d[5];
static unsigned char n455[5];
static unsigned char n443[5];
static unsigned char n438[5];
static unsigned char n438r[1];
static unsigned char n438e[1];
static unsigned char n438d[5];
static unsigned char n422[5];
static unsigned char n410[5];
static unsigned char n398[5];
static unsigned char n386[5];
static unsigned char n381[5];
static unsigned char n381r[1];
static unsigned char n381e[1];
static unsigned char n381d[5];
static unsigned char n365[5];
static unsigned char n353[5];
static unsigned char n341[5];
static unsigned char n329[5];
static unsigned char n317[5];
static unsigned char n305[5];
static unsigned char n293[5];
static unsigned char n281[5];
static unsigned char n276[4];
static unsigned char n276r[1];
static unsigned char n276e[1];
static unsigned char n276d[4];
static unsigned char n268[4];
static unsigned char n268r[1];
static unsigned char n268e[1];
static unsigned char n268d[4];
static unsigned char n260[4];
static unsigned char n260r[1];
static unsigned char n260e[1];
static unsigned char n260d[4];
static unsigned char n252[4];
static unsigned char n252r[1];
static unsigned char n252e[1];
static unsigned char n252d[4];
static unsigned char n244[4];
static unsigned char n244r[1];
static unsigned char n244e[1];
static unsigned char n244d[4];
static unsigned char n236[4];
static unsigned char n236r[1];
static unsigned char n236e[1];
static unsigned char n236d[4];
static unsigned char n228[4];
static unsigned char n228r[1];
static unsigned char n228e[1];
static unsigned char n228d[4];
static unsigned char n220[4];
static unsigned char n220r[1];
static unsigned char n220e[1];
static unsigned char n220d[4];
static unsigned char n212[4];
static unsigned char n212r[1];
static unsigned char n212e[1];
static unsigned char n212d[4];
static unsigned char n204[4];
static unsigned char n204r[1];
static unsigned char n204e[1];
static unsigned char n204d[4];
static unsigned char n196[4];
static unsigned char n196r[1];
static unsigned char n196e[1];
static unsigned char n196d[4];
static unsigned char n188[4];
static unsigned char n188r[1];
static unsigned char n188e[1];
static unsigned char n188d[4];
static unsigned char n180[4];
static unsigned char n180r[1];
static unsigned char n180e[1];
static unsigned char n180d[4];
static unsigned char n172[4];
static unsigned char n172r[1];
static unsigned char n172e[1];
static unsigned char n172d[4];
static unsigned char n164[4];
static unsigned char n164r[1];
static unsigned char n164e[1];
static unsigned char n164d[4];
static unsigned char n156[4];
static unsigned char n156r[1];
static unsigned char n156e[1];
static unsigned char n156d[4];
static unsigned char n148[4];
static unsigned char n148r[1];
static unsigned char n148e[1];
static unsigned char n148d[4];
static unsigned char n504[5];
static unsigned char n504r[1];
static unsigned char n504e[1];
static unsigned char n504d[5];
static unsigned char n483[5];
static unsigned char n483r[1];
static unsigned char n483e[1];
static unsigned char n483d[5];
static unsigned char n462[5];
static unsigned char n462r[1];
static unsigned char n462e[1];
static unsigned char n462d[5];
static unsigned char n450[5];
static unsigned char n450r[1];
static unsigned char n450e[1];
static unsigned char n450d[5];
static unsigned char n429[5];
static unsigned char n429r[1];
static unsigned char n429e[1];
static unsigned char n429d[5];
static unsigned char n417[5];
static unsigned char n417r[1];
static unsigned char n417e[1];
static unsigned char n417d[5];
static unsigned char n405[5];
static unsigned char n405r[1];
static unsigned char n405e[1];
static unsigned char n405d[5];
static unsigned char n393[5];
static unsigned char n393r[1];
static unsigned char n393e[1];
static unsigned char n393d[5];
static unsigned char n372[5];
static unsigned char n372r[1];
static unsigned char n372e[1];
static unsigned char n372d[5];
static unsigned char n360[5];
static unsigned char n360r[1];
static unsigned char n360e[1];
static unsigned char n360d[5];
static unsigned char n348[5];
static unsigned char n348r[1];
static unsigned char n348e[1];
static unsigned char n348d[5];
static unsigned char n336[5];
static unsigned char n336r[1];
static unsigned char n336e[1];
static unsigned char n336d[5];
static unsigned char n324[5];
static unsigned char n324r[1];
static unsigned char n324e[1];
static unsigned char n324d[5];
static unsigned char n312[5];
static unsigned char n312r[1];
static unsigned char n312e[1];
static unsigned char n312d[5];
static unsigned char n300[5];
static unsigned char n300r[1];
static unsigned char n300e[1];
static unsigned char n300d[5];
static unsigned char n288[5];
static unsigned char n288r[1];
static unsigned char n288e[1];
static unsigned char n288d[5];

void cf_fir_16_16_16_ports(unsigned char* port_reset_i, unsigned char* port_data_i, unsigned char* port_k0_i, unsigned char* port_k1_i, unsigned char* port_k2_i, unsigned char* port_k3_i, unsigned char* port_k4_i, unsigned char* port_k5_i, unsigned char* port_k6_i, unsigned char* port_k7_i, unsigned char* port_k8_i, unsigned char* port_k9_i, unsigned char* port_k10_i, unsigned char* port_k11_i, unsigned char* port_k12_i, unsigned char* port_k13_i, unsigned char* port_k14_i, unsigned char* port_k15_i, unsigned char* port_k16_i, unsigned char* port_data_o) {
  reset_i = port_reset_i;
  data_i = port_data_i;
  k0_i = port_k0_i;
  k1_i = port_k1_i;
  k2_i = port_k2_i;
  k3_i = port_k3_i;
  k4_i = port_k4_i;
  k5_i = port_k5_i;
  k6_i = port_k6_i;
  k7_i = port_k7_i;
  k8_i = port_k8_i;
  k9_i = port_k9_i;
  k10_i = port_k10_i;
  k11_i = port_k11_i;
  k12_i = port_k12_i;
  k13_i = port_k13_i;
  k14_i = port_k14_i;
  k15_i = port_k15_i;
  k16_i = port_k16_i;
  data_o = port_data_o;
}

void cf_fir_16_16_16_calc() {
  data_o[0] = n504[0];
  data_o[1] = n504[1];
  data_o[2] = n504[2];
  data_o[3] = n504[3];
  data_o[4] = n504[4];
  n495[0] = (1 & (n492[4] >> 3));
  n493[0] = (1 & (n483[4] >> 3));
  n484[0] = (1 & (n471[4] >> 2));
  n474[0] = (1 & (n462[4] >> 2));
  n472[0] = (1 & (n450[4] >> 2));
  n463[0] = (1 & (n438[4] >> 1));
  n453[0] = (1 & (n429[4] >> 1));
  n451[0] = (1 & (n417[4] >> 1));
  n441[0] = (1 & (n405[4] >> 1));
  n439[0] = (1 & (n393[4] >> 1));
  n430[0] = (1 & (n381[4]));
  n420[0] = (1 & (n372[4]));
  n418[0] = (1 & (n360[4]));
  n408[0] = (1 & (n348[4]));
  n406[0] = (1 & (n336[4]));
  n396[0] = (1 & (n324[4]));
  n394[0] = (1 & (n312[4]));
  n384[0] = (1 & (n300[4]));
  n382[0] = (1 & (n288[4]));
  n373[0] = (1 & (n276[3] >> 7));
  n363[0] = (1 & (n268[3] >> 7));
  n361[0] = (1 & (n260[3] >> 7));
  n351[0] = (1 & (n252[3] >> 7));
  n349[0] = (1 & (n244[3] >> 7));
  n339[0] = (1 & (n236[3] >> 7));
  n337[0] = (1 & (n228[3] >> 7));
  n327[0] = (1 & (n220[3] >> 7));
  n325[0] = (1 & (n212[3] >> 7));
  n315[0] = (1 & (n204[3] >> 7));
  n313[0] = (1 & (n196[3] >> 7));
  n303[0] = (1 & (n188[3] >> 7));
  n301[0] = (1 & (n180[3] >> 7));
  n291[0] = (1 & (n172[3] >> 7));
  n289[0] = (1 & (n164[3] >> 7));
  n279[0] = (1 & (n156[3] >> 7));
  n277[0] = (1 & (n148[3] >> 7));
  n2[0] = 0;
  n1[0] = 1;
  n496[0] = n492[0];
  n496[1] = n492[1];
  n496[2] = n492[2];
  n496[3] = n492[3];
  n496[4] = 255 & (n495[0] << 4 | n492[4]);
  n494[0] = n483[0];
  n494[1] = n483[1];
  n494[2] = n483[2];
  n494[3] = n483[3];
  n494[4] = 255 & (n493[0] << 4 | n483[4]);
  n485[0] = n471[0];
  n485[1] = n471[1];
  n485[2] = n471[2];
  n485[3] = n471[3];
  n485[4] = 255 & (n484[0] << 3 | n471[4]);
  n475[0] = n462[0];
  n475[1] = n462[1];
  n475[2] = n462[2];
  n475[3] = n462[3];
  n475[4] = 255 & (n474[0] << 3 | n462[4]);
  n473[0] = n450[0];
  n473[1] = n450[1];
  n473[2] = n450[2];
  n473[3] = n450[3];
  n473[4] = 255 & (n472[0] << 3 | n450[4]);
  n464[0] = n438[0];
  n464[1] = n438[1];
  n464[2] = n438[2];
  n464[3] = n438[3];
  n464[4] = 255 & (n463[0] << 2 | n438[4]);
  n454[0] = n429[0];
  n454[1] = n429[1];
  n454[2] = n429[2];
  n454[3] = n429[3];
  n454[4] = 255 & (n453[0] << 2 | n429[4]);
  n452[0] = n417[0];
  n452[1] = n417[1];
  n452[2] = n417[2];
  n452[3] = n417[3];
  n452[4] = 255 & (n451[0] << 2 | n417[4]);
  n442[0] = n405[0];
  n442[1] = n405[1];
  n442[2] = n405[2];
  n442[3] = n405[3];
  n442[4] = 255 & (n441[0] << 2 | n405[4]);
  n440[0] = n393[0];
  n440[1] = n393[1];
  n440[2] = n393[2];
  n440[3] = n393[3];
  n440[4] = 255 & (n439[0] << 2 | n393[4]);
  n431[0] = n381[0];
  n431[1] = n381[1];
  n431[2] = n381[2];
  n431[3] = n381[3];
  n431[4] = 255 & (n430[0] << 1 | n381[4]);
  n421[0] = n372[0];
  n421[1] = n372[1];
  n421[2] = n372[2];
  n421[3] = n372[3];
  n421[4] = 255 & (n420[0] << 1 | n372[4]);
  n419[0] = n360[0];
  n419[1] = n360[1];
  n419[2] = n360[2];
  n419[3] = n360[3];
  n419[4] = 255 & (n418[0] << 1 | n360[4]);
  n409[0] = n348[0];
  n409[1] = n348[1];
  n409[2] = n348[2];
  n409[3] = n348[3];
  n409[4] = 255 & (n408[0] << 1 | n348[4]);
  n407[0] = n336[0];
  n407[1] = n336[1];
  n407[2] = n336[2];
  n407[3] = n336[3];
  n407[4] = 255 & (n406[0] << 1 | n336[4]);
  n397[0] = n324[0];
  n397[1] = n324[1];
  n397[2] = n324[2];
  n397[3] = n324[3];
  n397[4] = 255 & (n396[0] << 1 | n324[4]);
  n395[0] = n312[0];
  n395[1] = n312[1];
  n395[2] = n312[2];
  n395[3] = n312[3];
  n395[4] = 255 & (n394[0] << 1 | n312[4]);
  n385[0] = n300[0];
  n385[1] = n300[1];
  n385[2] = n300[2];
  n385[3] = n300[3];
  n385[4] = 255 & (n384[0] << 1 | n300[4]);
  n383[0] = n288[0];
  n383[1] = n288[1];
  n383[2] = n288[2];
  n383[3] = n288[3];
  n383[4] = 255 & (n382[0] << 1 | n288[4]);
  n374[0] = n276[0];
  n374[1] = n276[1];
  n374[2] = n276[2];
  n374[3] = n276[3];
  n374[4] = n373[0];
  n364[0] = n268[0];
  n364[1] = n268[1];
  n364[2] = n268[2];
  n364[3] = n268[3];
  n364[4] = n363[0];
  n362[0] = n260[0];
  n362[1] = n260[1];
  n362[2] = n260[2];
  n362[3] = n260[3];
  n362[4] = n361[0];
  n352[0] = n252[0];
  n352[1] = n252[1];
  n352[2] = n252[2];
  n352[3] = n252[3];
  n352[4] = n351[0];
  n350[0] = n244[0];
  n350[1] = n244[1];
  n350[2] = n244[2];
  n350[3] = n244[3];
  n350[4] = n349[0];
  n340[0] = n236[0];
  n340[1] = n236[1];
  n340[2] = n236[2];
  n340[3] = n236[3];
  n340[4] = n339[0];
  n338[0] = n228[0];
  n338[1] = n228[1];
  n338[2] = n228[2];
  n338[3] = n228[3];
  n338[4] = n337[0];
  n328[0] = n220[0];
  n328[1] = n220[1];
  n328[2] = n220[2];
  n328[3] = n220[3];
  n328[4] = n327[0];
  n326[0] = n212[0];
  n326[1] = n212[1];
  n326[2] = n212[2];
  n326[3] = n212[3];
  n326[4] = n325[0];
  n316[0] = n204[0];
  n316[1] = n204[1];
  n316[2] = n204[2];
  n316[3] = n204[3];
  n316[4] = n315[0];
  n314[0] = n196[0];
  n314[1] = n196[1];
  n314[2] = n196[2];
  n314[3] = n196[3];
  n314[4] = n313[0];
  n304[0] = n188[0];
  n304[1] = n188[1];
  n304[2] = n188[2];
  n304[3] = n188[3];
  n304[4] = n303[0];
  n302[0] = n180[0];
  n302[1] = n180[1];
  n302[2] = n180[2];
  n302[3] = n180[3];
  n302[4] = n301[0];
  n292[0] = n172[0];
  n292[1] = n172[1];
  n292[2] = n172[2];
  n292[3] = n172[3];
  n292[4] = n291[0];
  n290[0] = n164[0];
  n290[1] = n164[1];
  n290[2] = n164[2];
  n290[3] = n164[3];
  n290[4] = n289[0];
  n280[0] = n156[0];
  n280[1] = n156[1];
  n280[2] = n156[2];
  n280[3] = n156[3];
  n280[4] = n279[0];
  n278[0] = n148[0];
  n278[1] = n148[1];
  n278[2] = n148[2];
  n278[3] = n148[3];
  n278[4] = n277[0];
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k16_i[1];
    a[0] = k16_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n140[1];
    b[0] = n140[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n269[0] = 255 & (unsigned char) tmp, tmp >> 8), n269[1] = 255 & (unsigned char) tmp, tmp >> 8), n269[2] = 255 & (unsigned char) tmp, tmp >> 8), n269[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k15_i[1];
    a[0] = k15_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n133[1];
    b[0] = n133[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n261[0] = 255 & (unsigned char) tmp, tmp >> 8), n261[1] = 255 & (unsigned char) tmp, tmp >> 8), n261[2] = 255 & (unsigned char) tmp, tmp >> 8), n261[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k14_i[1];
    a[0] = k14_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n126[1];
    b[0] = n126[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n253[0] = 255 & (unsigned char) tmp, tmp >> 8), n253[1] = 255 & (unsigned char) tmp, tmp >> 8), n253[2] = 255 & (unsigned char) tmp, tmp >> 8), n253[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k13_i[1];
    a[0] = k13_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n119[1];
    b[0] = n119[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n245[0] = 255 & (unsigned char) tmp, tmp >> 8), n245[1] = 255 & (unsigned char) tmp, tmp >> 8), n245[2] = 255 & (unsigned char) tmp, tmp >> 8), n245[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k12_i[1];
    a[0] = k12_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n112[1];
    b[0] = n112[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n237[0] = 255 & (unsigned char) tmp, tmp >> 8), n237[1] = 255 & (unsigned char) tmp, tmp >> 8), n237[2] = 255 & (unsigned char) tmp, tmp >> 8), n237[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k11_i[1];
    a[0] = k11_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n105[1];
    b[0] = n105[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n229[0] = 255 & (unsigned char) tmp, tmp >> 8), n229[1] = 255 & (unsigned char) tmp, tmp >> 8), n229[2] = 255 & (unsigned char) tmp, tmp >> 8), n229[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k10_i[1];
    a[0] = k10_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n98[1];
    b[0] = n98[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n221[0] = 255 & (unsigned char) tmp, tmp >> 8), n221[1] = 255 & (unsigned char) tmp, tmp >> 8), n221[2] = 255 & (unsigned char) tmp, tmp >> 8), n221[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k9_i[1];
    a[0] = k9_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n91[1];
    b[0] = n91[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n213[0] = 255 & (unsigned char) tmp, tmp >> 8), n213[1] = 255 & (unsigned char) tmp, tmp >> 8), n213[2] = 255 & (unsigned char) tmp, tmp >> 8), n213[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k8_i[1];
    a[0] = k8_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n84[1];
    b[0] = n84[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n205[0] = 255 & (unsigned char) tmp, tmp >> 8), n205[1] = 255 & (unsigned char) tmp, tmp >> 8), n205[2] = 255 & (unsigned char) tmp, tmp >> 8), n205[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k7_i[1];
    a[0] = k7_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n77[1];
    b[0] = n77[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n197[0] = 255 & (unsigned char) tmp, tmp >> 8), n197[1] = 255 & (unsigned char) tmp, tmp >> 8), n197[2] = 255 & (unsigned char) tmp, tmp >> 8), n197[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k6_i[1];
    a[0] = k6_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n70[1];
    b[0] = n70[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n189[0] = 255 & (unsigned char) tmp, tmp >> 8), n189[1] = 255 & (unsigned char) tmp, tmp >> 8), n189[2] = 255 & (unsigned char) tmp, tmp >> 8), n189[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k5_i[1];
    a[0] = k5_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n63[1];
    b[0] = n63[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n181[0] = 255 & (unsigned char) tmp, tmp >> 8), n181[1] = 255 & (unsigned char) tmp, tmp >> 8), n181[2] = 255 & (unsigned char) tmp, tmp >> 8), n181[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k4_i[1];
    a[0] = k4_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n56[1];
    b[0] = n56[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n173[0] = 255 & (unsigned char) tmp, tmp >> 8), n173[1] = 255 & (unsigned char) tmp, tmp >> 8), n173[2] = 255 & (unsigned char) tmp, tmp >> 8), n173[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k3_i[1];
    a[0] = k3_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n49[1];
    b[0] = n49[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n165[0] = 255 & (unsigned char) tmp, tmp >> 8), n165[1] = 255 & (unsigned char) tmp, tmp >> 8), n165[2] = 255 & (unsigned char) tmp, tmp >> 8), n165[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k2_i[1];
    a[0] = k2_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n42[1];
    b[0] = n42[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n157[0] = 255 & (unsigned char) tmp, tmp >> 8), n157[1] = 255 & (unsigned char) tmp, tmp >> 8), n157[2] = 255 & (unsigned char) tmp, tmp >> 8), n157[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k1_i[1];
    a[0] = k1_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n35[1];
    b[0] = n35[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n149[0] = 255 & (unsigned char) tmp, tmp >> 8), n149[1] = 255 & (unsigned char) tmp, tmp >> 8), n149[2] = 255 & (unsigned char) tmp, tmp >> 8), n149[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k0_i[1];
    a[0] = k0_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n28[1];
    b[0] = n28[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n141[0] = 255 & (unsigned char) tmp, tmp >> 8), n141[1] = 255 & (unsigned char) tmp, tmp >> 8), n141[2] = 255 & (unsigned char) tmp, tmp >> 8), n141[3] = 255 & (unsigned char) tmp);
  }
  n140r[0] = reset_i[0];
  n140e[0] = n1[0];
  n140d[0] = n133[0];
  n140d[1] = n133[1];
  n133r[0] = reset_i[0];
  n133e[0] = n1[0];
  n133d[0] = n126[0];
  n133d[1] = n126[1];
  n126r[0] = reset_i[0];
  n126e[0] = n1[0];
  n126d[0] = n119[0];
  n126d[1] = n119[1];
  n119r[0] = reset_i[0];
  n119e[0] = n1[0];
  n119d[0] = n112[0];
  n119d[1] = n112[1];
  n112r[0] = reset_i[0];
  n112e[0] = n1[0];
  n112d[0] = n105[0];
  n112d[1] = n105[1];
  n105r[0] = reset_i[0];
  n105e[0] = n1[0];
  n105d[0] = n98[0];
  n105d[1] = n98[1];
  n98r[0] = reset_i[0];
  n98e[0] = n1[0];
  n98d[0] = n91[0];
  n98d[1] = n91[1];
  n91r[0] = reset_i[0];
  n91e[0] = n1[0];
  n91d[0] = n84[0];
  n91d[1] = n84[1];
  n84r[0] = reset_i[0];
  n84e[0] = n1[0];
  n84d[0] = n77[0];
  n84d[1] = n77[1];
  n77r[0] = reset_i[0];
  n77e[0] = n1[0];
  n77d[0] = n70[0];
  n77d[1] = n70[1];
  n70r[0] = reset_i[0];
  n70e[0] = n1[0];
  n70d[0] = n63[0];
  n70d[1] = n63[1];
  n63r[0] = reset_i[0];
  n63e[0] = n1[0];
  n63d[0] = n56[0];
  n63d[1] = n56[1];
  n56r[0] = reset_i[0];
  n56e[0] = n1[0];
  n56d[0] = n49[0];
  n56d[1] = n49[1];
  n49r[0] = reset_i[0];
  n49e[0] = n1[0];
  n49d[0] = n42[0];
  n49d[1] = n42[1];
  n42r[0] = reset_i[0];
  n42e[0] = n1[0];
  n42d[0] = n35[0];
  n42d[1] = n35[1];
  n35r[0] = reset_i[0];
  n35e[0] = n1[0];
  n35d[0] = n28[0];
  n35d[1] = n28[1];
  n28r[0] = reset_i[0];
  n28e[0] = n1[0];
  n28d[0] = data_i[0];
  n28d[1] = data_i[1];
  { unsigned int tmp; (tmp = (unsigned int) n494[4] + (unsigned int) n496[4] + (tmp = (unsigned int) n494[3] + (unsigned int) n496[3] + (tmp = (unsigned int) n494[2] + (unsigned int) n496[2] + (tmp = (unsigned int) n494[1] + (unsigned int) n496[1] + (tmp = (unsigned int) n494[0] + (unsigned int) n496[0], n497[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n497[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n497[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n497[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n497[4] = 31 & (unsigned char) tmp); }
  n492r[0] = n2[0];
  n492e[0] = n1[0];
  n492d[0] = n485[0];
  n492d[1] = n485[1];
  n492d[2] = n485[2];
  n492d[3] = n485[3];
  n492d[4] = n485[4];
  { unsigned int tmp; (tmp = (unsigned int) n473[4] + (unsigned int) n475[4] + (tmp = (unsigned int) n473[3] + (unsigned int) n475[3] + (tmp = (unsigned int) n473[2] + (unsigned int) n475[2] + (tmp = (unsigned int) n473[1] + (unsigned int) n475[1] + (tmp = (unsigned int) n473[0] + (unsigned int) n475[0], n476[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n476[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n476[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n476[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n476[4] = 15 & (unsigned char) tmp); }
  n471r[0] = n2[0];
  n471e[0] = n1[0];
  n471d[0] = n464[0];
  n471d[1] = n464[1];
  n471d[2] = n464[2];
  n471d[3] = n464[3];
  n471d[4] = n464[4];
  { unsigned int tmp; (tmp = (unsigned int) n452[4] + (unsigned int) n454[4] + (tmp = (unsigned int) n452[3] + (unsigned int) n454[3] + (tmp = (unsigned int) n452[2] + (unsigned int) n454[2] + (tmp = (unsigned int) n452[1] + (unsigned int) n454[1] + (tmp = (unsigned int) n452[0] + (unsigned int) n454[0], n455[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n455[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n455[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n455[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n455[4] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n440[4] + (unsigned int) n442[4] + (tmp = (unsigned int) n440[3] + (unsigned int) n442[3] + (tmp = (unsigned int) n440[2] + (unsigned int) n442[2] + (tmp = (unsigned int) n440[1] + (unsigned int) n442[1] + (tmp = (unsigned int) n440[0] + (unsigned int) n442[0], n443[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n443[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n443[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n443[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n443[4] = 7 & (unsigned char) tmp); }
  n438r[0] = n2[0];
  n438e[0] = n1[0];
  n438d[0] = n431[0];
  n438d[1] = n431[1];
  n438d[2] = n431[2];
  n438d[3] = n431[3];
  n438d[4] = n431[4];
  { unsigned int tmp; (tmp = (unsigned int) n419[4] + (unsigned int) n421[4] + (tmp = (unsigned int) n419[3] + (unsigned int) n421[3] + (tmp = (unsigned int) n419[2] + (unsigned int) n421[2] + (tmp = (unsigned int) n419[1] + (unsigned int) n421[1] + (tmp = (unsigned int) n419[0] + (unsigned int) n421[0], n422[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n422[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n422[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n422[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n422[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n407[4] + (unsigned int) n409[4] + (tmp = (unsigned int) n407[3] + (unsigned int) n409[3] + (tmp = (unsigned int) n407[2] + (unsigned int) n409[2] + (tmp = (unsigned int) n407[1] + (unsigned int) n409[1] + (tmp = (unsigned int) n407[0] + (unsigned int) n409[0], n410[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n410[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n410[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n410[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n410[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n395[4] + (unsigned int) n397[4] + (tmp = (unsigned int) n395[3] + (unsigned int) n397[3] + (tmp = (unsigned int) n395[2] + (unsigned int) n397[2] + (tmp = (unsigned int) n395[1] + (unsigned int) n397[1] + (tmp = (unsigned int) n395[0] + (unsigned int) n397[0], n398[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n398[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n398[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n398[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n398[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n383[4] + (unsigned int) n385[4] + (tmp = (unsigned int) n383[3] + (unsigned int) n385[3] + (tmp = (unsigned int) n383[2] + (unsigned int) n385[2] + (tmp = (unsigned int) n383[1] + (unsigned int) n385[1] + (tmp = (unsigned int) n383[0] + (unsigned int) n385[0], n386[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n386[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n386[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n386[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n386[4] = 3 & (unsigned char) tmp); }
  n381r[0] = n2[0];
  n381e[0] = n1[0];
  n381d[0] = n374[0];
  n381d[1] = n374[1];
  n381d[2] = n374[2];
  n381d[3] = n374[3];
  n381d[4] = n374[4];
  { unsigned int tmp; (tmp = (unsigned int) n362[4] + (unsigned int) n364[4] + (tmp = (unsigned int) n362[3] + (unsigned int) n364[3] + (tmp = (unsigned int) n362[2] + (unsigned int) n364[2] + (tmp = (unsigned int) n362[1] + (unsigned int) n364[1] + (tmp = (unsigned int) n362[0] + (unsigned int) n364[0], n365[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n365[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n365[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n365[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n365[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n350[4] + (unsigned int) n352[4] + (tmp = (unsigned int) n350[3] + (unsigned int) n352[3] + (tmp = (unsigned int) n350[2] + (unsigned int) n352[2] + (tmp = (unsigned int) n350[1] + (unsigned int) n352[1] + (tmp = (unsigned int) n350[0] + (unsigned int) n352[0], n353[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n353[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n353[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n353[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n353[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n338[4] + (unsigned int) n340[4] + (tmp = (unsigned int) n338[3] + (unsigned int) n340[3] + (tmp = (unsigned int) n338[2] + (unsigned int) n340[2] + (tmp = (unsigned int) n338[1] + (unsigned int) n340[1] + (tmp = (unsigned int) n338[0] + (unsigned int) n340[0], n341[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n341[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n341[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n341[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n341[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n326[4] + (unsigned int) n328[4] + (tmp = (unsigned int) n326[3] + (unsigned int) n328[3] + (tmp = (unsigned int) n326[2] + (unsigned int) n328[2] + (tmp = (unsigned int) n326[1] + (unsigned int) n328[1] + (tmp = (unsigned int) n326[0] + (unsigned int) n328[0], n329[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n329[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n329[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n329[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n329[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n314[4] + (unsigned int) n316[4] + (tmp = (unsigned int) n314[3] + (unsigned int) n316[3] + (tmp = (unsigned int) n314[2] + (unsigned int) n316[2] + (tmp = (unsigned int) n314[1] + (unsigned int) n316[1] + (tmp = (unsigned int) n314[0] + (unsigned int) n316[0], n317[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n317[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n317[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n317[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n317[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n302[4] + (unsigned int) n304[4] + (tmp = (unsigned int) n302[3] + (unsigned int) n304[3] + (tmp = (unsigned int) n302[2] + (unsigned int) n304[2] + (tmp = (unsigned int) n302[1] + (unsigned int) n304[1] + (tmp = (unsigned int) n302[0] + (unsigned int) n304[0], n305[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n305[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n305[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n305[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n305[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n290[4] + (unsigned int) n292[4] + (tmp = (unsigned int) n290[3] + (unsigned int) n292[3] + (tmp = (unsigned int) n290[2] + (unsigned int) n292[2] + (tmp = (unsigned int) n290[1] + (unsigned int) n292[1] + (tmp = (unsigned int) n290[0] + (unsigned int) n292[0], n293[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n293[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n293[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n293[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n293[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n278[4] + (unsigned int) n280[4] + (tmp = (unsigned int) n278[3] + (unsigned int) n280[3] + (tmp = (unsigned int) n278[2] + (unsigned int) n280[2] + (tmp = (unsigned int) n278[1] + (unsigned int) n280[1] + (tmp = (unsigned int) n278[0] + (unsigned int) n280[0], n281[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n281[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n281[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n281[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n281[4] = 1 & (unsigned char) tmp); }
  n276r[0] = n2[0];
  n276e[0] = n1[0];
  n276d[0] = n269[0];
  n276d[1] = n269[1];
  n276d[2] = n269[2];
  n276d[3] = n269[3];
  n268r[0] = n2[0];
  n268e[0] = n1[0];
  n268d[0] = n261[0];
  n268d[1] = n261[1];
  n268d[2] = n261[2];
  n268d[3] = n261[3];
  n260r[0] = n2[0];
  n260e[0] = n1[0];
  n260d[0] = n253[0];
  n260d[1] = n253[1];
  n260d[2] = n253[2];
  n260d[3] = n253[3];
  n252r[0] = n2[0];
  n252e[0] = n1[0];
  n252d[0] = n245[0];
  n252d[1] = n245[1];
  n252d[2] = n245[2];
  n252d[3] = n245[3];
  n244r[0] = n2[0];
  n244e[0] = n1[0];
  n244d[0] = n237[0];
  n244d[1] = n237[1];
  n244d[2] = n237[2];
  n244d[3] = n237[3];
  n236r[0] = n2[0];
  n236e[0] = n1[0];
  n236d[0] = n229[0];
  n236d[1] = n229[1];
  n236d[2] = n229[2];
  n236d[3] = n229[3];
  n228r[0] = n2[0];
  n228e[0] = n1[0];
  n228d[0] = n221[0];
  n228d[1] = n221[1];
  n228d[2] = n221[2];
  n228d[3] = n221[3];
  n220r[0] = n2[0];
  n220e[0] = n1[0];
  n220d[0] = n213[0];
  n220d[1] = n213[1];
  n220d[2] = n213[2];
  n220d[3] = n213[3];
  n212r[0] = n2[0];
  n212e[0] = n1[0];
  n212d[0] = n205[0];
  n212d[1] = n205[1];
  n212d[2] = n205[2];
  n212d[3] = n205[3];
  n204r[0] = n2[0];
  n204e[0] = n1[0];
  n204d[0] = n197[0];
  n204d[1] = n197[1];
  n204d[2] = n197[2];
  n204d[3] = n197[3];
  n196r[0] = n2[0];
  n196e[0] = n1[0];
  n196d[0] = n189[0];
  n196d[1] = n189[1];
  n196d[2] = n189[2];
  n196d[3] = n189[3];
  n188r[0] = n2[0];
  n188e[0] = n1[0];
  n188d[0] = n181[0];
  n188d[1] = n181[1];
  n188d[2] = n181[2];
  n188d[3] = n181[3];
  n180r[0] = n2[0];
  n180e[0] = n1[0];
  n180d[0] = n173[0];
  n180d[1] = n173[1];
  n180d[2] = n173[2];
  n180d[3] = n173[3];
  n172r[0] = n2[0];
  n172e[0] = n1[0];
  n172d[0] = n165[0];
  n172d[1] = n165[1];
  n172d[2] = n165[2];
  n172d[3] = n165[3];
  n164r[0] = n2[0];
  n164e[0] = n1[0];
  n164d[0] = n157[0];
  n164d[1] = n157[1];
  n164d[2] = n157[2];
  n164d[3] = n157[3];
  n156r[0] = n2[0];
  n156e[0] = n1[0];
  n156d[0] = n149[0];
  n156d[1] = n149[1];
  n156d[2] = n149[2];
  n156d[3] = n149[3];
  n148r[0] = n2[0];
  n148e[0] = n1[0];
  n148d[0] = n141[0];
  n148d[1] = n141[1];
  n148d[2] = n141[2];
  n148d[3] = n141[3];
  n504r[0] = n2[0];
  n504e[0] = n1[0];
  n504d[0] = n497[0];
  n504d[1] = n497[1];
  n504d[2] = n497[2];
  n504d[3] = n497[3];
  n504d[4] = n497[4];
  n483r[0] = n2[0];
  n483e[0] = n1[0];
  n483d[0] = n476[0];
  n483d[1] = n476[1];
  n483d[2] = n476[2];
  n483d[3] = n476[3];
  n483d[4] = n476[4];
  n462r[0] = n2[0];
  n462e[0] = n1[0];
  n462d[0] = n455[0];
  n462d[1] = n455[1];
  n462d[2] = n455[2];
  n462d[3] = n455[3];
  n462d[4] = n455[4];
  n450r[0] = n2[0];
  n450e[0] = n1[0];
  n450d[0] = n443[0];
  n450d[1] = n443[1];
  n450d[2] = n443[2];
  n450d[3] = n443[3];
  n450d[4] = n443[4];
  n429r[0] = n2[0];
  n429e[0] = n1[0];
  n429d[0] = n422[0];
  n429d[1] = n422[1];
  n429d[2] = n422[2];
  n429d[3] = n422[3];
  n429d[4] = n422[4];
  n417r[0] = n2[0];
  n417e[0] = n1[0];
  n417d[0] = n410[0];
  n417d[1] = n410[1];
  n417d[2] = n410[2];
  n417d[3] = n410[3];
  n417d[4] = n410[4];
  n405r[0] = n2[0];
  n405e[0] = n1[0];
  n405d[0] = n398[0];
  n405d[1] = n398[1];
  n405d[2] = n398[2];
  n405d[3] = n398[3];
  n405d[4] = n398[4];
  n393r[0] = n2[0];
  n393e[0] = n1[0];
  n393d[0] = n386[0];
  n393d[1] = n386[1];
  n393d[2] = n386[2];
  n393d[3] = n386[3];
  n393d[4] = n386[4];
  n372r[0] = n2[0];
  n372e[0] = n1[0];
  n372d[0] = n365[0];
  n372d[1] = n365[1];
  n372d[2] = n365[2];
  n372d[3] = n365[3];
  n372d[4] = n365[4];
  n360r[0] = n2[0];
  n360e[0] = n1[0];
  n360d[0] = n353[0];
  n360d[1] = n353[1];
  n360d[2] = n353[2];
  n360d[3] = n353[3];
  n360d[4] = n353[4];
  n348r[0] = n2[0];
  n348e[0] = n1[0];
  n348d[0] = n341[0];
  n348d[1] = n341[1];
  n348d[2] = n341[2];
  n348d[3] = n341[3];
  n348d[4] = n341[4];
  n336r[0] = n2[0];
  n336e[0] = n1[0];
  n336d[0] = n329[0];
  n336d[1] = n329[1];
  n336d[2] = n329[2];
  n336d[3] = n329[3];
  n336d[4] = n329[4];
  n324r[0] = n2[0];
  n324e[0] = n1[0];
  n324d[0] = n317[0];
  n324d[1] = n317[1];
  n324d[2] = n317[2];
  n324d[3] = n317[3];
  n324d[4] = n317[4];
  n312r[0] = n2[0];
  n312e[0] = n1[0];
  n312d[0] = n305[0];
  n312d[1] = n305[1];
  n312d[2] = n305[2];
  n312d[3] = n305[3];
  n312d[4] = n305[4];
  n300r[0] = n2[0];
  n300e[0] = n1[0];
  n300d[0] = n293[0];
  n300d[1] = n293[1];
  n300d[2] = n293[2];
  n300d[3] = n293[3];
  n300d[4] = n293[4];
  n288r[0] = n2[0];
  n288e[0] = n1[0];
  n288d[0] = n281[0];
  n288d[1] = n281[1];
  n288d[2] = n281[2];
  n288d[3] = n281[3];
  n288d[4] = n281[4];
}

void cf_fir_16_16_16_init() {
  n495[0] = 0;
  n493[0] = 0;
  n484[0] = 0;
  n474[0] = 0;
  n472[0] = 0;
  n463[0] = 0;
  n453[0] = 0;
  n451[0] = 0;
  n441[0] = 0;
  n439[0] = 0;
  n430[0] = 0;
  n420[0] = 0;
  n418[0] = 0;
  n408[0] = 0;
  n406[0] = 0;
  n396[0] = 0;
  n394[0] = 0;
  n384[0] = 0;
  n382[0] = 0;
  n373[0] = 0;
  n363[0] = 0;
  n361[0] = 0;
  n351[0] = 0;
  n349[0] = 0;
  n339[0] = 0;
  n337[0] = 0;
  n327[0] = 0;
  n325[0] = 0;
  n315[0] = 0;
  n313[0] = 0;
  n303[0] = 0;
  n301[0] = 0;
  n291[0] = 0;
  n289[0] = 0;
  n279[0] = 0;
  n277[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  { int index; for (index = 5; index > 0;) n496[--index] = 0; }
  { int index; for (index = 5; index > 0;) n494[--index] = 0; }
  { int index; for (index = 5; index > 0;) n485[--index] = 0; }
  { int index; for (index = 5; index > 0;) n475[--index] = 0; }
  { int index; for (index = 5; index > 0;) n473[--index] = 0; }
  { int index; for (index = 5; index > 0;) n464[--index] = 0; }
  { int index; for (index = 5; index > 0;) n454[--index] = 0; }
  { int index; for (index = 5; index > 0;) n452[--index] = 0; }
  { int index; for (index = 5; index > 0;) n442[--index] = 0; }
  { int index; for (index = 5; index > 0;) n440[--index] = 0; }
  { int index; for (index = 5; index > 0;) n431[--index] = 0; }
  { int index; for (index = 5; index > 0;) n421[--index] = 0; }
  { int index; for (index = 5; index > 0;) n419[--index] = 0; }
  { int index; for (index = 5; index > 0;) n409[--index] = 0; }
  { int index; for (index = 5; index > 0;) n407[--index] = 0; }
  { int index; for (index = 5; index > 0;) n397[--index] = 0; }
  { int index; for (index = 5; index > 0;) n395[--index] = 0; }
  { int index; for (index = 5; index > 0;) n385[--index] = 0; }
  { int index; for (index = 5; index > 0;) n383[--index] = 0; }
  { int index; for (index = 5; index > 0;) n374[--index] = 0; }
  { int index; for (index = 5; index > 0;) n364[--index] = 0; }
  { int index; for (index = 5; index > 0;) n362[--index] = 0; }
  { int index; for (index = 5; index > 0;) n352[--index] = 0; }
  { int index; for (index = 5; index > 0;) n350[--index] = 0; }
  { int index; for (index = 5; index > 0;) n340[--index] = 0; }
  { int index; for (index = 5; index > 0;) n338[--index] = 0; }
  { int index; for (index = 5; index > 0;) n328[--index] = 0; }
  { int index; for (index = 5; index > 0;) n326[--index] = 0; }
  { int index; for (index = 5; index > 0;) n316[--index] = 0; }
  { int index; for (index = 5; index > 0;) n314[--index] = 0; }
  { int index; for (index = 5; index > 0;) n304[--index] = 0; }
  { int index; for (index = 5; index > 0;) n302[--index] = 0; }
  { int index; for (index = 5; index > 0;) n292[--index] = 0; }
  { int index; for (index = 5; index > 0;) n290[--index] = 0; }
  { int index; for (index = 5; index > 0;) n280[--index] = 0; }
  { int index; for (index = 5; index > 0;) n278[--index] = 0; }
  { int index; for (index = 4; index > 0;) n269[--index] = 0; }
  { int index; for (index = 4; index > 0;) n261[--index] = 0; }
  { int index; for (index = 4; index > 0;) n253[--index] = 0; }
  { int index; for (index = 4; index > 0;) n245[--index] = 0; }
  { int index; for (index = 4; index > 0;) n237[--index] = 0; }
  { int index; for (index = 4; index > 0;) n229[--index] = 0; }
  { int index; for (index = 4; index > 0;) n221[--index] = 0; }
  { int index; for (index = 4; index > 0;) n213[--index] = 0; }
  { int index; for (index = 4; index > 0;) n205[--index] = 0; }
  { int index; for (index = 4; index > 0;) n197[--index] = 0; }
  { int index; for (index = 4; index > 0;) n189[--index] = 0; }
  { int index; for (index = 4; index > 0;) n181[--index] = 0; }
  { int index; for (index = 4; index > 0;) n173[--index] = 0; }
  { int index; for (index = 4; index > 0;) n165[--index] = 0; }
  { int index; for (index = 4; index > 0;) n157[--index] = 0; }
  { int index; for (index = 4; index > 0;) n149[--index] = 0; }
  { int index; for (index = 4; index > 0;) n141[--index] = 0; }
  { int index; for (index = 2; index > 0;) n140[--index] = 0; }
  n140r[0] = 0;
  n140e[0] = 0;
  { int index; for (index = 2; index > 0;) n140d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n133[--index] = 0; }
  n133r[0] = 0;
  n133e[0] = 0;
  { int index; for (index = 2; index > 0;) n133d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n126[--index] = 0; }
  n126r[0] = 0;
  n126e[0] = 0;
  { int index; for (index = 2; index > 0;) n126d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n119[--index] = 0; }
  n119r[0] = 0;
  n119e[0] = 0;
  { int index; for (index = 2; index > 0;) n119d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n112[--index] = 0; }
  n112r[0] = 0;
  n112e[0] = 0;
  { int index; for (index = 2; index > 0;) n112d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n105[--index] = 0; }
  n105r[0] = 0;
  n105e[0] = 0;
  { int index; for (index = 2; index > 0;) n105d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n98[--index] = 0; }
  n98r[0] = 0;
  n98e[0] = 0;
  { int index; for (index = 2; index > 0;) n98d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n91[--index] = 0; }
  n91r[0] = 0;
  n91e[0] = 0;
  { int index; for (index = 2; index > 0;) n91d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n84[--index] = 0; }
  n84r[0] = 0;
  n84e[0] = 0;
  { int index; for (index = 2; index > 0;) n84d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n77[--index] = 0; }
  n77r[0] = 0;
  n77e[0] = 0;
  { int index; for (index = 2; index > 0;) n77d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n70[--index] = 0; }
  n70r[0] = 0;
  n70e[0] = 0;
  { int index; for (index = 2; index > 0;) n70d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n63[--index] = 0; }
  n63r[0] = 0;
  n63e[0] = 0;
  { int index; for (index = 2; index > 0;) n63d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n56[--index] = 0; }
  n56r[0] = 0;
  n56e[0] = 0;
  { int index; for (index = 2; index > 0;) n56d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n49[--index] = 0; }
  n49r[0] = 0;
  n49e[0] = 0;
  { int index; for (index = 2; index > 0;) n49d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n42[--index] = 0; }
  n42r[0] = 0;
  n42e[0] = 0;
  { int index; for (index = 2; index > 0;) n42d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n35[--index] = 0; }
  n35r[0] = 0;
  n35e[0] = 0;
  { int index; for (index = 2; index > 0;) n35d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n28[--index] = 0; }
  n28r[0] = 0;
  n28e[0] = 0;
  { int index; for (index = 2; index > 0;) n28d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n497[--index] = 0; }
  { int index; for (index = 5; index > 0;) n492[--index] = 0; }
  n492r[0] = 0;
  n492e[0] = 0;
  { int index; for (index = 5; index > 0;) n492d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n476[--index] = 0; }
  { int index; for (index = 5; index > 0;) n471[--index] = 0; }
  n471r[0] = 0;
  n471e[0] = 0;
  { int index; for (index = 5; index > 0;) n471d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n455[--index] = 0; }
  { int index; for (index = 5; index > 0;) n443[--index] = 0; }
  { int index; for (index = 5; index > 0;) n438[--index] = 0; }
  n438r[0] = 0;
  n438e[0] = 0;
  { int index; for (index = 5; index > 0;) n438d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n422[--index] = 0; }
  { int index; for (index = 5; index > 0;) n410[--index] = 0; }
  { int index; for (index = 5; index > 0;) n398[--index] = 0; }
  { int index; for (index = 5; index > 0;) n386[--index] = 0; }
  { int index; for (index = 5; index > 0;) n381[--index] = 0; }
  n381r[0] = 0;
  n381e[0] = 0;
  { int index; for (index = 5; index > 0;) n381d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n365[--index] = 0; }
  { int index; for (index = 5; index > 0;) n353[--index] = 0; }
  { int index; for (index = 5; index > 0;) n341[--index] = 0; }
  { int index; for (index = 5; index > 0;) n329[--index] = 0; }
  { int index; for (index = 5; index > 0;) n317[--index] = 0; }
  { int index; for (index = 5; index > 0;) n305[--index] = 0; }
  { int index; for (index = 5; index > 0;) n293[--index] = 0; }
  { int index; for (index = 5; index > 0;) n281[--index] = 0; }
  { int index; for (index = 4; index > 0;) n276[--index] = 0; }
  n276r[0] = 0;
  n276e[0] = 0;
  { int index; for (index = 4; index > 0;) n276d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n268[--index] = 0; }
  n268r[0] = 0;
  n268e[0] = 0;
  { int index; for (index = 4; index > 0;) n268d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n260[--index] = 0; }
  n260r[0] = 0;
  n260e[0] = 0;
  { int index; for (index = 4; index > 0;) n260d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n252[--index] = 0; }
  n252r[0] = 0;
  n252e[0] = 0;
  { int index; for (index = 4; index > 0;) n252d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n244[--index] = 0; }
  n244r[0] = 0;
  n244e[0] = 0;
  { int index; for (index = 4; index > 0;) n244d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n236[--index] = 0; }
  n236r[0] = 0;
  n236e[0] = 0;
  { int index; for (index = 4; index > 0;) n236d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n228[--index] = 0; }
  n228r[0] = 0;
  n228e[0] = 0;
  { int index; for (index = 4; index > 0;) n228d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n220[--index] = 0; }
  n220r[0] = 0;
  n220e[0] = 0;
  { int index; for (index = 4; index > 0;) n220d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n212[--index] = 0; }
  n212r[0] = 0;
  n212e[0] = 0;
  { int index; for (index = 4; index > 0;) n212d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n204[--index] = 0; }
  n204r[0] = 0;
  n204e[0] = 0;
  { int index; for (index = 4; index > 0;) n204d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n196[--index] = 0; }
  n196r[0] = 0;
  n196e[0] = 0;
  { int index; for (index = 4; index > 0;) n196d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n188[--index] = 0; }
  n188r[0] = 0;
  n188e[0] = 0;
  { int index; for (index = 4; index > 0;) n188d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n180[--index] = 0; }
  n180r[0] = 0;
  n180e[0] = 0;
  { int index; for (index = 4; index > 0;) n180d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n172[--index] = 0; }
  n172r[0] = 0;
  n172e[0] = 0;
  { int index; for (index = 4; index > 0;) n172d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n164[--index] = 0; }
  n164r[0] = 0;
  n164e[0] = 0;
  { int index; for (index = 4; index > 0;) n164d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n156[--index] = 0; }
  n156r[0] = 0;
  n156e[0] = 0;
  { int index; for (index = 4; index > 0;) n156d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n148[--index] = 0; }
  n148r[0] = 0;
  n148e[0] = 0;
  { int index; for (index = 4; index > 0;) n148d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n504[--index] = 0; }
  n504r[0] = 0;
  n504e[0] = 0;
  { int index; for (index = 5; index > 0;) n504d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n483[--index] = 0; }
  n483r[0] = 0;
  n483e[0] = 0;
  { int index; for (index = 5; index > 0;) n483d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n462[--index] = 0; }
  n462r[0] = 0;
  n462e[0] = 0;
  { int index; for (index = 5; index > 0;) n462d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n450[--index] = 0; }
  n450r[0] = 0;
  n450e[0] = 0;
  { int index; for (index = 5; index > 0;) n450d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n429[--index] = 0; }
  n429r[0] = 0;
  n429e[0] = 0;
  { int index; for (index = 5; index > 0;) n429d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n417[--index] = 0; }
  n417r[0] = 0;
  n417e[0] = 0;
  { int index; for (index = 5; index > 0;) n417d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n405[--index] = 0; }
  n405r[0] = 0;
  n405e[0] = 0;
  { int index; for (index = 5; index > 0;) n405d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n393[--index] = 0; }
  n393r[0] = 0;
  n393e[0] = 0;
  { int index; for (index = 5; index > 0;) n393d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n372[--index] = 0; }
  n372r[0] = 0;
  n372e[0] = 0;
  { int index; for (index = 5; index > 0;) n372d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n360[--index] = 0; }
  n360r[0] = 0;
  n360e[0] = 0;
  { int index; for (index = 5; index > 0;) n360d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n348[--index] = 0; }
  n348r[0] = 0;
  n348e[0] = 0;
  { int index; for (index = 5; index > 0;) n348d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n336[--index] = 0; }
  n336r[0] = 0;
  n336e[0] = 0;
  { int index; for (index = 5; index > 0;) n336d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n324[--index] = 0; }
  n324r[0] = 0;
  n324e[0] = 0;
  { int index; for (index = 5; index > 0;) n324d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n312[--index] = 0; }
  n312r[0] = 0;
  n312e[0] = 0;
  { int index; for (index = 5; index > 0;) n312d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n300[--index] = 0; }
  n300r[0] = 0;
  n300e[0] = 0;
  { int index; for (index = 5; index > 0;) n300d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n288[--index] = 0; }
  n288r[0] = 0;
  n288e[0] = 0;
  { int index; for (index = 5; index > 0;) n288d[--index] = 0; }
  cf_fir_16_16_16_calc();
}

void cf_fir_16_16_16_cycle_clock()
{
  if (n28r[0]) {
    n28[0] = 0;
    n28[1] = 0;
  }
  else if (n28e[0]) {
    n28[0] = n28d[0];
    n28[1] = n28d[1];
  }
  if (n35r[0]) {
    n35[0] = 0;
    n35[1] = 0;
  }
  else if (n35e[0]) {
    n35[0] = n35d[0];
    n35[1] = n35d[1];
  }
  if (n42r[0]) {
    n42[0] = 0;
    n42[1] = 0;
  }
  else if (n42e[0]) {
    n42[0] = n42d[0];
    n42[1] = n42d[1];
  }
  if (n49r[0]) {
    n49[0] = 0;
    n49[1] = 0;
  }
  else if (n49e[0]) {
    n49[0] = n49d[0];
    n49[1] = n49d[1];
  }
  if (n56r[0]) {
    n56[0] = 0;
    n56[1] = 0;
  }
  else if (n56e[0]) {
    n56[0] = n56d[0];
    n56[1] = n56d[1];
  }
  if (n63r[0]) {
    n63[0] = 0;
    n63[1] = 0;
  }
  else if (n63e[0]) {
    n63[0] = n63d[0];
    n63[1] = n63d[1];
  }
  if (n70r[0]) {
    n70[0] = 0;
    n70[1] = 0;
  }
  else if (n70e[0]) {
    n70[0] = n70d[0];
    n70[1] = n70d[1];
  }
  if (n77r[0]) {
    n77[0] = 0;
    n77[1] = 0;
  }
  else if (n77e[0]) {
    n77[0] = n77d[0];
    n77[1] = n77d[1];
  }
  if (n84r[0]) {
    n84[0] = 0;
    n84[1] = 0;
  }
  else if (n84e[0]) {
    n84[0] = n84d[0];
    n84[1] = n84d[1];
  }
  if (n91r[0]) {
    n91[0] = 0;
    n91[1] = 0;
  }
  else if (n91e[0]) {
    n91[0] = n91d[0];
    n91[1] = n91d[1];
  }
  if (n98r[0]) {
    n98[0] = 0;
    n98[1] = 0;
  }
  else if (n98e[0]) {
    n98[0] = n98d[0];
    n98[1] = n98d[1];
  }
  if (n105r[0]) {
    n105[0] = 0;
    n105[1] = 0;
  }
  else if (n105e[0]) {
    n105[0] = n105d[0];
    n105[1] = n105d[1];
  }
  if (n112r[0]) {
    n112[0] = 0;
    n112[1] = 0;
  }
  else if (n112e[0]) {
    n112[0] = n112d[0];
    n112[1] = n112d[1];
  }
  if (n119r[0]) {
    n119[0] = 0;
    n119[1] = 0;
  }
  else if (n119e[0]) {
    n119[0] = n119d[0];
    n119[1] = n119d[1];
  }
  if (n126r[0]) {
    n126[0] = 0;
    n126[1] = 0;
  }
  else if (n126e[0]) {
    n126[0] = n126d[0];
    n126[1] = n126d[1];
  }
  if (n133r[0]) {
    n133[0] = 0;
    n133[1] = 0;
  }
  else if (n133e[0]) {
    n133[0] = n133d[0];
    n133[1] = n133d[1];
  }
  if (n140r[0]) {
    n140[0] = 0;
    n140[1] = 0;
  }
  else if (n140e[0]) {
    n140[0] = n140d[0];
    n140[1] = n140d[1];
  }
  if (n148r[0]) {
    n148[0] = 0;
    n148[1] = 0;
    n148[2] = 0;
    n148[3] = 0;
  }
  else if (n148e[0]) {
    n148[0] = n148d[0];
    n148[1] = n148d[1];
    n148[2] = n148d[2];
    n148[3] = n148d[3];
  }
  if (n156r[0]) {
    n156[0] = 0;
    n156[1] = 0;
    n156[2] = 0;
    n156[3] = 0;
  }
  else if (n156e[0]) {
    n156[0] = n156d[0];
    n156[1] = n156d[1];
    n156[2] = n156d[2];
    n156[3] = n156d[3];
  }
  if (n164r[0]) {
    n164[0] = 0;
    n164[1] = 0;
    n164[2] = 0;
    n164[3] = 0;
  }
  else if (n164e[0]) {
    n164[0] = n164d[0];
    n164[1] = n164d[1];
    n164[2] = n164d[2];
    n164[3] = n164d[3];
  }
  if (n172r[0]) {
    n172[0] = 0;
    n172[1] = 0;
    n172[2] = 0;
    n172[3] = 0;
  }
  else if (n172e[0]) {
    n172[0] = n172d[0];
    n172[1] = n172d[1];
    n172[2] = n172d[2];
    n172[3] = n172d[3];
  }
  if (n180r[0]) {
    n180[0] = 0;
    n180[1] = 0;
    n180[2] = 0;
    n180[3] = 0;
  }
  else if (n180e[0]) {
    n180[0] = n180d[0];
    n180[1] = n180d[1];
    n180[2] = n180d[2];
    n180[3] = n180d[3];
  }
  if (n188r[0]) {
    n188[0] = 0;
    n188[1] = 0;
    n188[2] = 0;
    n188[3] = 0;
  }
  else if (n188e[0]) {
    n188[0] = n188d[0];
    n188[1] = n188d[1];
    n188[2] = n188d[2];
    n188[3] = n188d[3];
  }
  if (n196r[0]) {
    n196[0] = 0;
    n196[1] = 0;
    n196[2] = 0;
    n196[3] = 0;
  }
  else if (n196e[0]) {
    n196[0] = n196d[0];
    n196[1] = n196d[1];
    n196[2] = n196d[2];
    n196[3] = n196d[3];
  }
  if (n204r[0]) {
    n204[0] = 0;
    n204[1] = 0;
    n204[2] = 0;
    n204[3] = 0;
  }
  else if (n204e[0]) {
    n204[0] = n204d[0];
    n204[1] = n204d[1];
    n204[2] = n204d[2];
    n204[3] = n204d[3];
  }
  if (n212r[0]) {
    n212[0] = 0;
    n212[1] = 0;
    n212[2] = 0;
    n212[3] = 0;
  }
  else if (n212e[0]) {
    n212[0] = n212d[0];
    n212[1] = n212d[1];
    n212[2] = n212d[2];
    n212[3] = n212d[3];
  }
  if (n220r[0]) {
    n220[0] = 0;
    n220[1] = 0;
    n220[2] = 0;
    n220[3] = 0;
  }
  else if (n220e[0]) {
    n220[0] = n220d[0];
    n220[1] = n220d[1];
    n220[2] = n220d[2];
    n220[3] = n220d[3];
  }
  if (n228r[0]) {
    n228[0] = 0;
    n228[1] = 0;
    n228[2] = 0;
    n228[3] = 0;
  }
  else if (n228e[0]) {
    n228[0] = n228d[0];
    n228[1] = n228d[1];
    n228[2] = n228d[2];
    n228[3] = n228d[3];
  }
  if (n236r[0]) {
    n236[0] = 0;
    n236[1] = 0;
    n236[2] = 0;
    n236[3] = 0;
  }
  else if (n236e[0]) {
    n236[0] = n236d[0];
    n236[1] = n236d[1];
    n236[2] = n236d[2];
    n236[3] = n236d[3];
  }
  if (n244r[0]) {
    n244[0] = 0;
    n244[1] = 0;
    n244[2] = 0;
    n244[3] = 0;
  }
  else if (n244e[0]) {
    n244[0] = n244d[0];
    n244[1] = n244d[1];
    n244[2] = n244d[2];
    n244[3] = n244d[3];
  }
  if (n252r[0]) {
    n252[0] = 0;
    n252[1] = 0;
    n252[2] = 0;
    n252[3] = 0;
  }
  else if (n252e[0]) {
    n252[0] = n252d[0];
    n252[1] = n252d[1];
    n252[2] = n252d[2];
    n252[3] = n252d[3];
  }
  if (n260r[0]) {
    n260[0] = 0;
    n260[1] = 0;
    n260[2] = 0;
    n260[3] = 0;
  }
  else if (n260e[0]) {
    n260[0] = n260d[0];
    n260[1] = n260d[1];
    n260[2] = n260d[2];
    n260[3] = n260d[3];
  }
  if (n268r[0]) {
    n268[0] = 0;
    n268[1] = 0;
    n268[2] = 0;
    n268[3] = 0;
  }
  else if (n268e[0]) {
    n268[0] = n268d[0];
    n268[1] = n268d[1];
    n268[2] = n268d[2];
    n268[3] = n268d[3];
  }
  if (n276r[0]) {
    n276[0] = 0;
    n276[1] = 0;
    n276[2] = 0;
    n276[3] = 0;
  }
  else if (n276e[0]) {
    n276[0] = n276d[0];
    n276[1] = n276d[1];
    n276[2] = n276d[2];
    n276[3] = n276d[3];
  }
  if (n288r[0]) {
    n288[0] = 0;
    n288[1] = 0;
    n288[2] = 0;
    n288[3] = 0;
    n288[4] = 0;
  }
  else if (n288e[0]) {
    n288[0] = n288d[0];
    n288[1] = n288d[1];
    n288[2] = n288d[2];
    n288[3] = n288d[3];
    n288[4] = n288d[4];
  }
  if (n300r[0]) {
    n300[0] = 0;
    n300[1] = 0;
    n300[2] = 0;
    n300[3] = 0;
    n300[4] = 0;
  }
  else if (n300e[0]) {
    n300[0] = n300d[0];
    n300[1] = n300d[1];
    n300[2] = n300d[2];
    n300[3] = n300d[3];
    n300[4] = n300d[4];
  }
  if (n312r[0]) {
    n312[0] = 0;
    n312[1] = 0;
    n312[2] = 0;
    n312[3] = 0;
    n312[4] = 0;
  }
  else if (n312e[0]) {
    n312[0] = n312d[0];
    n312[1] = n312d[1];
    n312[2] = n312d[2];
    n312[3] = n312d[3];
    n312[4] = n312d[4];
  }
  if (n324r[0]) {
    n324[0] = 0;
    n324[1] = 0;
    n324[2] = 0;
    n324[3] = 0;
    n324[4] = 0;
  }
  else if (n324e[0]) {
    n324[0] = n324d[0];
    n324[1] = n324d[1];
    n324[2] = n324d[2];
    n324[3] = n324d[3];
    n324[4] = n324d[4];
  }
  if (n336r[0]) {
    n336[0] = 0;
    n336[1] = 0;
    n336[2] = 0;
    n336[3] = 0;
    n336[4] = 0;
  }
  else if (n336e[0]) {
    n336[0] = n336d[0];
    n336[1] = n336d[1];
    n336[2] = n336d[2];
    n336[3] = n336d[3];
    n336[4] = n336d[4];
  }
  if (n348r[0]) {
    n348[0] = 0;
    n348[1] = 0;
    n348[2] = 0;
    n348[3] = 0;
    n348[4] = 0;
  }
  else if (n348e[0]) {
    n348[0] = n348d[0];
    n348[1] = n348d[1];
    n348[2] = n348d[2];
    n348[3] = n348d[3];
    n348[4] = n348d[4];
  }
  if (n360r[0]) {
    n360[0] = 0;
    n360[1] = 0;
    n360[2] = 0;
    n360[3] = 0;
    n360[4] = 0;
  }
  else if (n360e[0]) {
    n360[0] = n360d[0];
    n360[1] = n360d[1];
    n360[2] = n360d[2];
    n360[3] = n360d[3];
    n360[4] = n360d[4];
  }
  if (n372r[0]) {
    n372[0] = 0;
    n372[1] = 0;
    n372[2] = 0;
    n372[3] = 0;
    n372[4] = 0;
  }
  else if (n372e[0]) {
    n372[0] = n372d[0];
    n372[1] = n372d[1];
    n372[2] = n372d[2];
    n372[3] = n372d[3];
    n372[4] = n372d[4];
  }
  if (n381r[0]) {
    n381[0] = 0;
    n381[1] = 0;
    n381[2] = 0;
    n381[3] = 0;
    n381[4] = 0;
  }
  else if (n381e[0]) {
    n381[0] = n381d[0];
    n381[1] = n381d[1];
    n381[2] = n381d[2];
    n381[3] = n381d[3];
    n381[4] = n381d[4];
  }
  if (n393r[0]) {
    n393[0] = 0;
    n393[1] = 0;
    n393[2] = 0;
    n393[3] = 0;
    n393[4] = 0;
  }
  else if (n393e[0]) {
    n393[0] = n393d[0];
    n393[1] = n393d[1];
    n393[2] = n393d[2];
    n393[3] = n393d[3];
    n393[4] = n393d[4];
  }
  if (n405r[0]) {
    n405[0] = 0;
    n405[1] = 0;
    n405[2] = 0;
    n405[3] = 0;
    n405[4] = 0;
  }
  else if (n405e[0]) {
    n405[0] = n405d[0];
    n405[1] = n405d[1];
    n405[2] = n405d[2];
    n405[3] = n405d[3];
    n405[4] = n405d[4];
  }
  if (n417r[0]) {
    n417[0] = 0;
    n417[1] = 0;
    n417[2] = 0;
    n417[3] = 0;
    n417[4] = 0;
  }
  else if (n417e[0]) {
    n417[0] = n417d[0];
    n417[1] = n417d[1];
    n417[2] = n417d[2];
    n417[3] = n417d[3];
    n417[4] = n417d[4];
  }
  if (n429r[0]) {
    n429[0] = 0;
    n429[1] = 0;
    n429[2] = 0;
    n429[3] = 0;
    n429[4] = 0;
  }
  else if (n429e[0]) {
    n429[0] = n429d[0];
    n429[1] = n429d[1];
    n429[2] = n429d[2];
    n429[3] = n429d[3];
    n429[4] = n429d[4];
  }
  if (n438r[0]) {
    n438[0] = 0;
    n438[1] = 0;
    n438[2] = 0;
    n438[3] = 0;
    n438[4] = 0;
  }
  else if (n438e[0]) {
    n438[0] = n438d[0];
    n438[1] = n438d[1];
    n438[2] = n438d[2];
    n438[3] = n438d[3];
    n438[4] = n438d[4];
  }
  if (n450r[0]) {
    n450[0] = 0;
    n450[1] = 0;
    n450[2] = 0;
    n450[3] = 0;
    n450[4] = 0;
  }
  else if (n450e[0]) {
    n450[0] = n450d[0];
    n450[1] = n450d[1];
    n450[2] = n450d[2];
    n450[3] = n450d[3];
    n450[4] = n450d[4];
  }
  if (n462r[0]) {
    n462[0] = 0;
    n462[1] = 0;
    n462[2] = 0;
    n462[3] = 0;
    n462[4] = 0;
  }
  else if (n462e[0]) {
    n462[0] = n462d[0];
    n462[1] = n462d[1];
    n462[2] = n462d[2];
    n462[3] = n462d[3];
    n462[4] = n462d[4];
  }
  if (n471r[0]) {
    n471[0] = 0;
    n471[1] = 0;
    n471[2] = 0;
    n471[3] = 0;
    n471[4] = 0;
  }
  else if (n471e[0]) {
    n471[0] = n471d[0];
    n471[1] = n471d[1];
    n471[2] = n471d[2];
    n471[3] = n471d[3];
    n471[4] = n471d[4];
  }
  if (n483r[0]) {
    n483[0] = 0;
    n483[1] = 0;
    n483[2] = 0;
    n483[3] = 0;
    n483[4] = 0;
  }
  else if (n483e[0]) {
    n483[0] = n483d[0];
    n483[1] = n483d[1];
    n483[2] = n483d[2];
    n483[3] = n483d[3];
    n483[4] = n483d[4];
  }
  if (n492r[0]) {
    n492[0] = 0;
    n492[1] = 0;
    n492[2] = 0;
    n492[3] = 0;
    n492[4] = 0;
  }
  else if (n492e[0]) {
    n492[0] = n492d[0];
    n492[1] = n492d[1];
    n492[2] = n492d[2];
    n492[3] = n492d[3];
    n492[4] = n492d[4];
  }
  if (n504r[0]) {
    n504[0] = 0;
    n504[1] = 0;
    n504[2] = 0;
    n504[3] = 0;
    n504[4] = 0;
  }
  else if (n504e[0]) {
    n504[0] = n504d[0];
    n504[1] = n504d[1];
    n504[2] = n504d[2];
    n504[3] = n504d[3];
    n504[4] = n504d[4];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_i[1];
static unsigned char sim_data_i[2];
static unsigned char sim_k0_i[2];
static unsigned char sim_k1_i[2];
static unsigned char sim_k2_i[2];
static unsigned char sim_k3_i[2];
static unsigned char sim_k4_i[2];
static unsigned char sim_k5_i[2];
static unsigned char sim_k6_i[2];
static unsigned char sim_k7_i[2];
static unsigned char sim_k8_i[2];
static unsigned char sim_k9_i[2];
static unsigned char sim_k10_i[2];
static unsigned char sim_k11_i[2];
static unsigned char sim_k12_i[2];
static unsigned char sim_k13_i[2];
static unsigned char sim_k14_i[2];
static unsigned char sim_k15_i[2];
static unsigned char sim_k16_i[2];
static unsigned char sim_data_o[5];

void cf_fir_16_16_16_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_fir_16_16_16_init();
  sim_reset_i[0] = reset_i[0];
  sim_data_i[0] = data_i[0];
  sim_data_i[1] = data_i[1];
  sim_k0_i[0] = k0_i[0];
  sim_k0_i[1] = k0_i[1];
  sim_k1_i[0] = k1_i[0];
  sim_k1_i[1] = k1_i[1];
  sim_k2_i[0] = k2_i[0];
  sim_k2_i[1] = k2_i[1];
  sim_k3_i[0] = k3_i[0];
  sim_k3_i[1] = k3_i[1];
  sim_k4_i[0] = k4_i[0];
  sim_k4_i[1] = k4_i[1];
  sim_k5_i[0] = k5_i[0];
  sim_k5_i[1] = k5_i[1];
  sim_k6_i[0] = k6_i[0];
  sim_k6_i[1] = k6_i[1];
  sim_k7_i[0] = k7_i[0];
  sim_k7_i[1] = k7_i[1];
  sim_k8_i[0] = k8_i[0];
  sim_k8_i[1] = k8_i[1];
  sim_k9_i[0] = k9_i[0];
  sim_k9_i[1] = k9_i[1];
  sim_k10_i[0] = k10_i[0];
  sim_k10_i[1] = k10_i[1];
  sim_k11_i[0] = k11_i[0];
  sim_k11_i[1] = k11_i[1];
  sim_k12_i[0] = k12_i[0];
  sim_k12_i[1] = k12_i[1];
  sim_k13_i[0] = k13_i[0];
  sim_k13_i[1] = k13_i[1];
  sim_k14_i[0] = k14_i[0];
  sim_k14_i[1] = k14_i[1];
  sim_k15_i[0] = k15_i[0];
  sim_k15_i[1] = k15_i[1];
  sim_k16_i[0] = k16_i[0];
  sim_k16_i[1] = k16_i[1];
  sim_data_o[0] = data_o[0];
  sim_data_o[1] = data_o[1];
  sim_data_o[2] = data_o[2];
  sim_data_o[3] = data_o[3];
  sim_data_o[4] = data_o[4];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_fir_16_16_16 $end\n"
    "$var wire 1 ! reset_i $end\n"
    "$var wire 16 \" data_i $end\n"
    "$var wire 16 # k0_i $end\n"
    "$var wire 16 $ k1_i $end\n"
    "$var wire 16 %% k2_i $end\n"
    "$var wire 16 & k3_i $end\n"
    "$var wire 16 ' k4_i $end\n"
    "$var wire 16 ( k5_i $end\n"
    "$var wire 16 ) k6_i $end\n"
    "$var wire 16 * k7_i $end\n"
    "$var wire 16 + k8_i $end\n"
    "$var wire 16 , k9_i $end\n"
    "$var wire 16 - k10_i $end\n"
    "$var wire 16 . k11_i $end\n"
    "$var wire 16 / k12_i $end\n"
    "$var wire 16 0 k13_i $end\n"
    "$var wire 16 1 k14_i $end\n"
    "$var wire 16 2 k15_i $end\n"
    "$var wire 16 3 k16_i $end\n"
    "$var wire 37 4 data_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
        else if (bit & data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " \"\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
        else if (bit & k0_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
        else if (bit & k1_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
        else if (bit & k2_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
        else if (bit & k3_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
        else if (bit & k4_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
        else if (bit & k5_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
        else if (bit & k6_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
        else if (bit & k7_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
        else if (bit & k8_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
        else if (bit & k9_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
        else if (bit & k10_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
        else if (bit & k11_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
        else if (bit & k12_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k13_i[byte]) ? "1" : "0");
        else if (bit & k13_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k14_i[byte]) ? "1" : "0");
        else if (bit & k14_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 1\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k15_i[byte]) ? "1" : "0");
        else if (bit & k15_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 2\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k16_i[byte]) ? "1" : "0");
        else if (bit & k16_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 3\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 4; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
        else if (bit & data_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 4\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_fir_16_16_16_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_fir_16_16_16_sim_sample() {
  int changed = 0;
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_data_i[1] != data_i[1] || sim_data_i[0] != data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
          else if (bit & data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " \"\n");
    }
    sim_data_i[0] = data_i[0];
    sim_data_i[1] = data_i[1];
  }
  if (sim_k0_i[1] != k0_i[1] || sim_k0_i[0] != k0_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
          else if (bit & k0_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_k0_i[0] = k0_i[0];
    sim_k0_i[1] = k0_i[1];
  }
  if (sim_k1_i[1] != k1_i[1] || sim_k1_i[0] != k1_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
          else if (bit & k1_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_k1_i[0] = k1_i[0];
    sim_k1_i[1] = k1_i[1];
  }
  if (sim_k2_i[1] != k2_i[1] || sim_k2_i[0] != k2_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
          else if (bit & k2_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_k2_i[0] = k2_i[0];
    sim_k2_i[1] = k2_i[1];
  }
  if (sim_k3_i[1] != k3_i[1] || sim_k3_i[0] != k3_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
          else if (bit & k3_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_k3_i[0] = k3_i[0];
    sim_k3_i[1] = k3_i[1];
  }
  if (sim_k4_i[1] != k4_i[1] || sim_k4_i[0] != k4_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
          else if (bit & k4_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_k4_i[0] = k4_i[0];
    sim_k4_i[1] = k4_i[1];
  }
  if (sim_k5_i[1] != k5_i[1] || sim_k5_i[0] != k5_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
          else if (bit & k5_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_k5_i[0] = k5_i[0];
    sim_k5_i[1] = k5_i[1];
  }
  if (sim_k6_i[1] != k6_i[1] || sim_k6_i[0] != k6_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
          else if (bit & k6_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_k6_i[0] = k6_i[0];
    sim_k6_i[1] = k6_i[1];
  }
  if (sim_k7_i[1] != k7_i[1] || sim_k7_i[0] != k7_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
          else if (bit & k7_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_k7_i[0] = k7_i[0];
    sim_k7_i[1] = k7_i[1];
  }
  if (sim_k8_i[1] != k8_i[1] || sim_k8_i[0] != k8_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
          else if (bit & k8_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_k8_i[0] = k8_i[0];
    sim_k8_i[1] = k8_i[1];
  }
  if (sim_k9_i[1] != k9_i[1] || sim_k9_i[0] != k9_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
          else if (bit & k9_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_k9_i[0] = k9_i[0];
    sim_k9_i[1] = k9_i[1];
  }
  if (sim_k10_i[1] != k10_i[1] || sim_k10_i[0] != k10_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
          else if (bit & k10_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_k10_i[0] = k10_i[0];
    sim_k10_i[1] = k10_i[1];
  }
  if (sim_k11_i[1] != k11_i[1] || sim_k11_i[0] != k11_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
          else if (bit & k11_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_k11_i[0] = k11_i[0];
    sim_k11_i[1] = k11_i[1];
  }
  if (sim_k12_i[1] != k12_i[1] || sim_k12_i[0] != k12_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
          else if (bit & k12_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_k12_i[0] = k12_i[0];
    sim_k12_i[1] = k12_i[1];
  }
  if (sim_k13_i[1] != k13_i[1] || sim_k13_i[0] != k13_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k13_i[byte]) ? "1" : "0");
          else if (bit & k13_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_k13_i[0] = k13_i[0];
    sim_k13_i[1] = k13_i[1];
  }
  if (sim_k14_i[1] != k14_i[1] || sim_k14_i[0] != k14_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k14_i[byte]) ? "1" : "0");
          else if (bit & k14_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 1\n");
    }
    sim_k14_i[0] = k14_i[0];
    sim_k14_i[1] = k14_i[1];
  }
  if (sim_k15_i[1] != k15_i[1] || sim_k15_i[0] != k15_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k15_i[byte]) ? "1" : "0");
          else if (bit & k15_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 2\n");
    }
    sim_k15_i[0] = k15_i[0];
    sim_k15_i[1] = k15_i[1];
  }
  if (sim_k16_i[1] != k16_i[1] || sim_k16_i[0] != k16_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k16_i[byte]) ? "1" : "0");
          else if (bit & k16_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 3\n");
    }
    sim_k16_i[0] = k16_i[0];
    sim_k16_i[1] = k16_i[1];
  }
  if (sim_data_o[4] != data_o[4] || sim_data_o[3] != data_o[3] || sim_data_o[2] != data_o[2] || sim_data_o[1] != data_o[1] || sim_data_o[0] != data_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 4; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
          else if (bit & data_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 4\n");
    }
    sim_data_o[0] = data_o[0];
    sim_data_o[1] = data_o[1];
    sim_data_o[2] = data_o[2];
    sim_data_o[3] = data_o[3];
    sim_data_o[4] = data_o[4];
  }
  sim_count++;
}

