#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs finite impulse response (FIR) filtering.
#    The filter's sum of products is pipelined with a register after
#    every multiplier and adder.  The adder network is a balanced binary
#    tree to minimize latency.  The sum of products has no numeric loss because the
#    multipliers keep all resulting bits and each adder extends the precision by 1.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
#  
#    Inputs:
#      data_i  : Input data.
#      k0_i    : Coefficient 0 multiplied by in_i(0).
#      k1_i    : Coefficient 1 multiplied by in_i(k-1).
#      k2_i    : Coefficient 2 multiplied by in_i(k-2).
#      ...
#      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
#  
#    Outputs:
#      data_o : Output data.
#  
#  Built In Parameters:
#  
#    Filter Order             = 16
#    Input Precision          = 16
#    Coefficient Precision    = 16
#    Sum of Products Latency  = 6
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:45:53 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fir_16_16_16
#    Clock Domains : clock_c  
#    Vector Input  : reset_i(1)
#    Vector Input  : data_i(16)
#    Vector Input  : k0_i(16)
#    Vector Input  : k1_i(16)
#    Vector Input  : k2_i(16)
#    Vector Input  : k3_i(16)
#    Vector Input  : k4_i(16)
#    Vector Input  : k5_i(16)
#    Vector Input  : k6_i(16)
#    Vector Input  : k7_i(16)
#    Vector Input  : k8_i(16)
#    Vector Input  : k9_i(16)
#    Vector Input  : k10_i(16)
#    Vector Input  : k11_i(16)
#    Vector Input  : k12_i(16)
#    Vector Input  : k13_i(16)
#    Vector Input  : k14_i(16)
#    Vector Input  : k15_i(16)
#    Vector Input  : k16_i(16)
#    Vector Output : data_o(37)
#  
#  
#  

import sys
import time

class cf_fir_16_16_16:

  def init(self):
    self.n505 = 0L
    self.n495 = 0L
    self.n493 = 0L
    self.n484 = 0L
    self.n474 = 0L
    self.n472 = 0L
    self.n463 = 0L
    self.n453 = 0L
    self.n451 = 0L
    self.n441 = 0L
    self.n439 = 0L
    self.n430 = 0L
    self.n420 = 0L
    self.n418 = 0L
    self.n408 = 0L
    self.n406 = 0L
    self.n396 = 0L
    self.n394 = 0L
    self.n384 = 0L
    self.n382 = 0L
    self.n373 = 0L
    self.n363 = 0L
    self.n361 = 0L
    self.n351 = 0L
    self.n349 = 0L
    self.n339 = 0L
    self.n337 = 0L
    self.n327 = 0L
    self.n325 = 0L
    self.n315 = 0L
    self.n313 = 0L
    self.n303 = 0L
    self.n301 = 0L
    self.n291 = 0L
    self.n289 = 0L
    self.n279 = 0L
    self.n277 = 0L
    self.n21 = 0L
    self.n20 = 0L
    self.n19 = 0L
    self.n18 = 0L
    self.n17 = 0L
    self.n16 = 0L
    self.n15 = 0L
    self.n14 = 0L
    self.n13 = 0L
    self.n12 = 0L
    self.n11 = 0L
    self.n10 = 0L
    self.n9 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n496 = 0L
    self.n494 = 0L
    self.n485 = 0L
    self.n475 = 0L
    self.n473 = 0L
    self.n464 = 0L
    self.n454 = 0L
    self.n452 = 0L
    self.n442 = 0L
    self.n440 = 0L
    self.n431 = 0L
    self.n421 = 0L
    self.n419 = 0L
    self.n409 = 0L
    self.n407 = 0L
    self.n397 = 0L
    self.n395 = 0L
    self.n385 = 0L
    self.n383 = 0L
    self.n374 = 0L
    self.n364 = 0L
    self.n362 = 0L
    self.n352 = 0L
    self.n350 = 0L
    self.n340 = 0L
    self.n338 = 0L
    self.n328 = 0L
    self.n326 = 0L
    self.n316 = 0L
    self.n314 = 0L
    self.n304 = 0L
    self.n302 = 0L
    self.n292 = 0L
    self.n290 = 0L
    self.n280 = 0L
    self.n278 = 0L
    self.n269 = 0L
    self.n261 = 0L
    self.n253 = 0L
    self.n245 = 0L
    self.n237 = 0L
    self.n229 = 0L
    self.n221 = 0L
    self.n213 = 0L
    self.n205 = 0L
    self.n197 = 0L
    self.n189 = 0L
    self.n181 = 0L
    self.n173 = 0L
    self.n165 = 0L
    self.n157 = 0L
    self.n149 = 0L
    self.n141 = 0L
    self.n140 = 0L
    self.n140r = 0L
    self.n140e = 0L
    self.n140d = 0L
    self.n133 = 0L
    self.n133r = 0L
    self.n133e = 0L
    self.n133d = 0L
    self.n126 = 0L
    self.n126r = 0L
    self.n126e = 0L
    self.n126d = 0L
    self.n119 = 0L
    self.n119r = 0L
    self.n119e = 0L
    self.n119d = 0L
    self.n112 = 0L
    self.n112r = 0L
    self.n112e = 0L
    self.n112d = 0L
    self.n105 = 0L
    self.n105r = 0L
    self.n105e = 0L
    self.n105d = 0L
    self.n98 = 0L
    self.n98r = 0L
    self.n98e = 0L
    self.n98d = 0L
    self.n91 = 0L
    self.n91r = 0L
    self.n91e = 0L
    self.n91d = 0L
    self.n84 = 0L
    self.n84r = 0L
    self.n84e = 0L
    self.n84d = 0L
    self.n77 = 0L
    self.n77r = 0L
    self.n77e = 0L
    self.n77d = 0L
    self.n70 = 0L
    self.n70r = 0L
    self.n70e = 0L
    self.n70d = 0L
    self.n63 = 0L
    self.n63r = 0L
    self.n63e = 0L
    self.n63d = 0L
    self.n56 = 0L
    self.n56r = 0L
    self.n56e = 0L
    self.n56d = 0L
    self.n49 = 0L
    self.n49r = 0L
    self.n49e = 0L
    self.n49d = 0L
    self.n42 = 0L
    self.n42r = 0L
    self.n42e = 0L
    self.n42d = 0L
    self.n35 = 0L
    self.n35r = 0L
    self.n35e = 0L
    self.n35d = 0L
    self.n28 = 0L
    self.n28r = 0L
    self.n28e = 0L
    self.n28d = 0L
    self.n497 = 0L
    self.n492 = 0L
    self.n492r = 0L
    self.n492e = 0L
    self.n492d = 0L
    self.n476 = 0L
    self.n471 = 0L
    self.n471r = 0L
    self.n471e = 0L
    self.n471d = 0L
    self.n455 = 0L
    self.n443 = 0L
    self.n438 = 0L
    self.n438r = 0L
    self.n438e = 0L
    self.n438d = 0L
    self.n422 = 0L
    self.n410 = 0L
    self.n398 = 0L
    self.n386 = 0L
    self.n381 = 0L
    self.n381r = 0L
    self.n381e = 0L
    self.n381d = 0L
    self.n365 = 0L
    self.n353 = 0L
    self.n341 = 0L
    self.n329 = 0L
    self.n317 = 0L
    self.n305 = 0L
    self.n293 = 0L
    self.n281 = 0L
    self.n276 = 0L
    self.n276r = 0L
    self.n276e = 0L
    self.n276d = 0L
    self.n268 = 0L
    self.n268r = 0L
    self.n268e = 0L
    self.n268d = 0L
    self.n260 = 0L
    self.n260r = 0L
    self.n260e = 0L
    self.n260d = 0L
    self.n252 = 0L
    self.n252r = 0L
    self.n252e = 0L
    self.n252d = 0L
    self.n244 = 0L
    self.n244r = 0L
    self.n244e = 0L
    self.n244d = 0L
    self.n236 = 0L
    self.n236r = 0L
    self.n236e = 0L
    self.n236d = 0L
    self.n228 = 0L
    self.n228r = 0L
    self.n228e = 0L
    self.n228d = 0L
    self.n220 = 0L
    self.n220r = 0L
    self.n220e = 0L
    self.n220d = 0L
    self.n212 = 0L
    self.n212r = 0L
    self.n212e = 0L
    self.n212d = 0L
    self.n204 = 0L
    self.n204r = 0L
    self.n204e = 0L
    self.n204d = 0L
    self.n196 = 0L
    self.n196r = 0L
    self.n196e = 0L
    self.n196d = 0L
    self.n188 = 0L
    self.n188r = 0L
    self.n188e = 0L
    self.n188d = 0L
    self.n180 = 0L
    self.n180r = 0L
    self.n180e = 0L
    self.n180d = 0L
    self.n172 = 0L
    self.n172r = 0L
    self.n172e = 0L
    self.n172d = 0L
    self.n164 = 0L
    self.n164r = 0L
    self.n164e = 0L
    self.n164d = 0L
    self.n156 = 0L
    self.n156r = 0L
    self.n156e = 0L
    self.n156d = 0L
    self.n148 = 0L
    self.n148r = 0L
    self.n148e = 0L
    self.n148d = 0L
    self.n504 = 0L
    self.n504r = 0L
    self.n504e = 0L
    self.n504d = 0L
    self.n483 = 0L
    self.n483r = 0L
    self.n483e = 0L
    self.n483d = 0L
    self.n462 = 0L
    self.n462r = 0L
    self.n462e = 0L
    self.n462d = 0L
    self.n450 = 0L
    self.n450r = 0L
    self.n450e = 0L
    self.n450d = 0L
    self.n429 = 0L
    self.n429r = 0L
    self.n429e = 0L
    self.n429d = 0L
    self.n417 = 0L
    self.n417r = 0L
    self.n417e = 0L
    self.n417d = 0L
    self.n405 = 0L
    self.n405r = 0L
    self.n405e = 0L
    self.n405d = 0L
    self.n393 = 0L
    self.n393r = 0L
    self.n393e = 0L
    self.n393d = 0L
    self.n372 = 0L
    self.n372r = 0L
    self.n372e = 0L
    self.n372d = 0L
    self.n360 = 0L
    self.n360r = 0L
    self.n360e = 0L
    self.n360d = 0L
    self.n348 = 0L
    self.n348r = 0L
    self.n348e = 0L
    self.n348d = 0L
    self.n336 = 0L
    self.n336r = 0L
    self.n336e = 0L
    self.n336d = 0L
    self.n324 = 0L
    self.n324r = 0L
    self.n324e = 0L
    self.n324d = 0L
    self.n312 = 0L
    self.n312r = 0L
    self.n312e = 0L
    self.n312d = 0L
    self.n300 = 0L
    self.n300r = 0L
    self.n300e = 0L
    self.n300d = 0L
    self.n288 = 0L
    self.n288r = 0L
    self.n288e = 0L
    self.n288d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_i, data_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, k8_i, k9_i, k10_i, k11_i, k12_i, k13_i, k14_i, k15_i, k16_i, ):
    data_o = self.n504
    self.n505 = self.n504
    self.n495 = ((self.n492 & 0x800000000L) >> 35)
    self.n493 = ((self.n483 & 0x800000000L) >> 35)
    self.n484 = ((self.n471 & 0x400000000L) >> 34)
    self.n474 = ((self.n462 & 0x400000000L) >> 34)
    self.n472 = ((self.n450 & 0x400000000L) >> 34)
    self.n463 = ((self.n438 & 0x200000000L) >> 33)
    self.n453 = ((self.n429 & 0x200000000L) >> 33)
    self.n451 = ((self.n417 & 0x200000000L) >> 33)
    self.n441 = ((self.n405 & 0x200000000L) >> 33)
    self.n439 = ((self.n393 & 0x200000000L) >> 33)
    self.n430 = ((self.n381 & 0x100000000L) >> 32)
    self.n420 = ((self.n372 & 0x100000000L) >> 32)
    self.n418 = ((self.n360 & 0x100000000L) >> 32)
    self.n408 = ((self.n348 & 0x100000000L) >> 32)
    self.n406 = ((self.n336 & 0x100000000L) >> 32)
    self.n396 = ((self.n324 & 0x100000000L) >> 32)
    self.n394 = ((self.n312 & 0x100000000L) >> 32)
    self.n384 = ((self.n300 & 0x100000000L) >> 32)
    self.n382 = ((self.n288 & 0x100000000L) >> 32)
    self.n373 = ((self.n276 & 0x80000000L) >> 31)
    self.n363 = ((self.n268 & 0x80000000L) >> 31)
    self.n361 = ((self.n260 & 0x80000000L) >> 31)
    self.n351 = ((self.n252 & 0x80000000L) >> 31)
    self.n349 = ((self.n244 & 0x80000000L) >> 31)
    self.n339 = ((self.n236 & 0x80000000L) >> 31)
    self.n337 = ((self.n228 & 0x80000000L) >> 31)
    self.n327 = ((self.n220 & 0x80000000L) >> 31)
    self.n325 = ((self.n212 & 0x80000000L) >> 31)
    self.n315 = ((self.n204 & 0x80000000L) >> 31)
    self.n313 = ((self.n196 & 0x80000000L) >> 31)
    self.n303 = ((self.n188 & 0x80000000L) >> 31)
    self.n301 = ((self.n180 & 0x80000000L) >> 31)
    self.n291 = ((self.n172 & 0x80000000L) >> 31)
    self.n289 = ((self.n164 & 0x80000000L) >> 31)
    self.n279 = ((self.n156 & 0x80000000L) >> 31)
    self.n277 = ((self.n148 & 0x80000000L) >> 31)
    self.n21 = data_i
    self.n20 = k16_i
    self.n19 = k15_i
    self.n18 = k14_i
    self.n17 = k13_i
    self.n16 = k12_i
    self.n15 = k11_i
    self.n14 = k10_i
    self.n13 = k9_i
    self.n12 = k8_i
    self.n11 = k7_i
    self.n10 = k6_i
    self.n9 = k5_i
    self.n8 = k4_i
    self.n7 = k3_i
    self.n6 = k2_i
    self.n5 = k1_i
    self.n4 = k0_i
    self.n3 = reset_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    self.n496 = self.n495 << 36 | self.n492
    self.n494 = self.n493 << 36 | self.n483
    self.n485 = self.n484 << 35 | self.n471
    self.n475 = self.n474 << 35 | self.n462
    self.n473 = self.n472 << 35 | self.n450
    self.n464 = self.n463 << 34 | self.n438
    self.n454 = self.n453 << 34 | self.n429
    self.n452 = self.n451 << 34 | self.n417
    self.n442 = self.n441 << 34 | self.n405
    self.n440 = self.n439 << 34 | self.n393
    self.n431 = self.n430 << 33 | self.n381
    self.n421 = self.n420 << 33 | self.n372
    self.n419 = self.n418 << 33 | self.n360
    self.n409 = self.n408 << 33 | self.n348
    self.n407 = self.n406 << 33 | self.n336
    self.n397 = self.n396 << 33 | self.n324
    self.n395 = self.n394 << 33 | self.n312
    self.n385 = self.n384 << 33 | self.n300
    self.n383 = self.n382 << 33 | self.n288
    self.n374 = self.n373 << 32 | self.n276
    self.n364 = self.n363 << 32 | self.n268
    self.n362 = self.n361 << 32 | self.n260
    self.n352 = self.n351 << 32 | self.n252
    self.n350 = self.n349 << 32 | self.n244
    self.n340 = self.n339 << 32 | self.n236
    self.n338 = self.n337 << 32 | self.n228
    self.n328 = self.n327 << 32 | self.n220
    self.n326 = self.n325 << 32 | self.n212
    self.n316 = self.n315 << 32 | self.n204
    self.n314 = self.n313 << 32 | self.n196
    self.n304 = self.n303 << 32 | self.n188
    self.n302 = self.n301 << 32 | self.n180
    self.n292 = self.n291 << 32 | self.n172
    self.n290 = self.n289 << 32 | self.n164
    self.n280 = self.n279 << 32 | self.n156
    self.n278 = self.n277 << 32 | self.n148
    self.n269 = (self.n20 * self.n140) & 0xFFFFFFFFL
    self.n261 = (self.n19 * self.n133) & 0xFFFFFFFFL
    self.n253 = (self.n18 * self.n126) & 0xFFFFFFFFL
    self.n245 = (self.n17 * self.n119) & 0xFFFFFFFFL
    self.n237 = (self.n16 * self.n112) & 0xFFFFFFFFL
    self.n229 = (self.n15 * self.n105) & 0xFFFFFFFFL
    self.n221 = (self.n14 * self.n98) & 0xFFFFFFFFL
    self.n213 = (self.n13 * self.n91) & 0xFFFFFFFFL
    self.n205 = (self.n12 * self.n84) & 0xFFFFFFFFL
    self.n197 = (self.n11 * self.n77) & 0xFFFFFFFFL
    self.n189 = (self.n10 * self.n70) & 0xFFFFFFFFL
    self.n181 = (self.n9 * self.n63) & 0xFFFFFFFFL
    self.n173 = (self.n8 * self.n56) & 0xFFFFFFFFL
    self.n165 = (self.n7 * self.n49) & 0xFFFFFFFFL
    self.n157 = (self.n6 * self.n42) & 0xFFFFFFFFL
    self.n149 = (self.n5 * self.n35) & 0xFFFFFFFFL
    self.n141 = (self.n4 * self.n28) & 0xFFFFFFFFL
    self.n140r = self.n3
    self.n140e = self.n1
    self.n140d = self.n133
    self.n133r = self.n3
    self.n133e = self.n1
    self.n133d = self.n126
    self.n126r = self.n3
    self.n126e = self.n1
    self.n126d = self.n119
    self.n119r = self.n3
    self.n119e = self.n1
    self.n119d = self.n112
    self.n112r = self.n3
    self.n112e = self.n1
    self.n112d = self.n105
    self.n105r = self.n3
    self.n105e = self.n1
    self.n105d = self.n98
    self.n98r = self.n3
    self.n98e = self.n1
    self.n98d = self.n91
    self.n91r = self.n3
    self.n91e = self.n1
    self.n91d = self.n84
    self.n84r = self.n3
    self.n84e = self.n1
    self.n84d = self.n77
    self.n77r = self.n3
    self.n77e = self.n1
    self.n77d = self.n70
    self.n70r = self.n3
    self.n70e = self.n1
    self.n70d = self.n63
    self.n63r = self.n3
    self.n63e = self.n1
    self.n63d = self.n56
    self.n56r = self.n3
    self.n56e = self.n1
    self.n56d = self.n49
    self.n49r = self.n3
    self.n49e = self.n1
    self.n49d = self.n42
    self.n42r = self.n3
    self.n42e = self.n1
    self.n42d = self.n35
    self.n35r = self.n3
    self.n35e = self.n1
    self.n35d = self.n28
    self.n28r = self.n3
    self.n28e = self.n1
    self.n28d = self.n21
    self.n497 = (self.n494 + self.n496) & 0x1FFFFFFFFFL
    self.n492r = self.n2
    self.n492e = self.n1
    self.n492d = self.n485
    self.n476 = (self.n473 + self.n475) & 0xFFFFFFFFFL
    self.n471r = self.n2
    self.n471e = self.n1
    self.n471d = self.n464
    self.n455 = (self.n452 + self.n454) & 0x7FFFFFFFFL
    self.n443 = (self.n440 + self.n442) & 0x7FFFFFFFFL
    self.n438r = self.n2
    self.n438e = self.n1
    self.n438d = self.n431
    self.n422 = (self.n419 + self.n421) & 0x3FFFFFFFFL
    self.n410 = (self.n407 + self.n409) & 0x3FFFFFFFFL
    self.n398 = (self.n395 + self.n397) & 0x3FFFFFFFFL
    self.n386 = (self.n383 + self.n385) & 0x3FFFFFFFFL
    self.n381r = self.n2
    self.n381e = self.n1
    self.n381d = self.n374
    self.n365 = (self.n362 + self.n364) & 0x1FFFFFFFFL
    self.n353 = (self.n350 + self.n352) & 0x1FFFFFFFFL
    self.n341 = (self.n338 + self.n340) & 0x1FFFFFFFFL
    self.n329 = (self.n326 + self.n328) & 0x1FFFFFFFFL
    self.n317 = (self.n314 + self.n316) & 0x1FFFFFFFFL
    self.n305 = (self.n302 + self.n304) & 0x1FFFFFFFFL
    self.n293 = (self.n290 + self.n292) & 0x1FFFFFFFFL
    self.n281 = (self.n278 + self.n280) & 0x1FFFFFFFFL
    self.n276r = self.n2
    self.n276e = self.n1
    self.n276d = self.n269
    self.n268r = self.n2
    self.n268e = self.n1
    self.n268d = self.n261
    self.n260r = self.n2
    self.n260e = self.n1
    self.n260d = self.n253
    self.n252r = self.n2
    self.n252e = self.n1
    self.n252d = self.n245
    self.n244r = self.n2
    self.n244e = self.n1
    self.n244d = self.n237
    self.n236r = self.n2
    self.n236e = self.n1
    self.n236d = self.n229
    self.n228r = self.n2
    self.n228e = self.n1
    self.n228d = self.n221
    self.n220r = self.n2
    self.n220e = self.n1
    self.n220d = self.n213
    self.n212r = self.n2
    self.n212e = self.n1
    self.n212d = self.n205
    self.n204r = self.n2
    self.n204e = self.n1
    self.n204d = self.n197
    self.n196r = self.n2
    self.n196e = self.n1
    self.n196d = self.n189
    self.n188r = self.n2
    self.n188e = self.n1
    self.n188d = self.n181
    self.n180r = self.n2
    self.n180e = self.n1
    self.n180d = self.n173
    self.n172r = self.n2
    self.n172e = self.n1
    self.n172d = self.n165
    self.n164r = self.n2
    self.n164e = self.n1
    self.n164d = self.n157
    self.n156r = self.n2
    self.n156e = self.n1
    self.n156d = self.n149
    self.n148r = self.n2
    self.n148e = self.n1
    self.n148d = self.n141
    self.n504r = self.n2
    self.n504e = self.n1
    self.n504d = self.n497
    self.n483r = self.n2
    self.n483e = self.n1
    self.n483d = self.n476
    self.n462r = self.n2
    self.n462e = self.n1
    self.n462d = self.n455
    self.n450r = self.n2
    self.n450e = self.n1
    self.n450d = self.n443
    self.n429r = self.n2
    self.n429e = self.n1
    self.n429d = self.n422
    self.n417r = self.n2
    self.n417e = self.n1
    self.n417d = self.n410
    self.n405r = self.n2
    self.n405e = self.n1
    self.n405d = self.n398
    self.n393r = self.n2
    self.n393e = self.n1
    self.n393d = self.n386
    self.n372r = self.n2
    self.n372e = self.n1
    self.n372d = self.n365
    self.n360r = self.n2
    self.n360e = self.n1
    self.n360d = self.n353
    self.n348r = self.n2
    self.n348e = self.n1
    self.n348d = self.n341
    self.n336r = self.n2
    self.n336e = self.n1
    self.n336d = self.n329
    self.n324r = self.n2
    self.n324e = self.n1
    self.n324d = self.n317
    self.n312r = self.n2
    self.n312e = self.n1
    self.n312d = self.n305
    self.n300r = self.n2
    self.n300e = self.n1
    self.n300d = self.n293
    self.n288r = self.n2
    self.n288e = self.n1
    self.n288d = self.n281
    return (data_o, )

  def cycle_clock(self):
    if self.n28r:
      self.n28 = 0L
    elif self.n28e:
        self.n28 = self.n28d
    if self.n35r:
      self.n35 = 0L
    elif self.n35e:
        self.n35 = self.n35d
    if self.n42r:
      self.n42 = 0L
    elif self.n42e:
        self.n42 = self.n42d
    if self.n49r:
      self.n49 = 0L
    elif self.n49e:
        self.n49 = self.n49d
    if self.n56r:
      self.n56 = 0L
    elif self.n56e:
        self.n56 = self.n56d
    if self.n63r:
      self.n63 = 0L
    elif self.n63e:
        self.n63 = self.n63d
    if self.n70r:
      self.n70 = 0L
    elif self.n70e:
        self.n70 = self.n70d
    if self.n77r:
      self.n77 = 0L
    elif self.n77e:
        self.n77 = self.n77d
    if self.n84r:
      self.n84 = 0L
    elif self.n84e:
        self.n84 = self.n84d
    if self.n91r:
      self.n91 = 0L
    elif self.n91e:
        self.n91 = self.n91d
    if self.n98r:
      self.n98 = 0L
    elif self.n98e:
        self.n98 = self.n98d
    if self.n105r:
      self.n105 = 0L
    elif self.n105e:
        self.n105 = self.n105d
    if self.n112r:
      self.n112 = 0L
    elif self.n112e:
        self.n112 = self.n112d
    if self.n119r:
      self.n119 = 0L
    elif self.n119e:
        self.n119 = self.n119d
    if self.n126r:
      self.n126 = 0L
    elif self.n126e:
        self.n126 = self.n126d
    if self.n133r:
      self.n133 = 0L
    elif self.n133e:
        self.n133 = self.n133d
    if self.n140r:
      self.n140 = 0L
    elif self.n140e:
        self.n140 = self.n140d
    if self.n148r:
      self.n148 = 0L
    elif self.n148e:
        self.n148 = self.n148d
    if self.n156r:
      self.n156 = 0L
    elif self.n156e:
        self.n156 = self.n156d
    if self.n164r:
      self.n164 = 0L
    elif self.n164e:
        self.n164 = self.n164d
    if self.n172r:
      self.n172 = 0L
    elif self.n172e:
        self.n172 = self.n172d
    if self.n180r:
      self.n180 = 0L
    elif self.n180e:
        self.n180 = self.n180d
    if self.n188r:
      self.n188 = 0L
    elif self.n188e:
        self.n188 = self.n188d
    if self.n196r:
      self.n196 = 0L
    elif self.n196e:
        self.n196 = self.n196d
    if self.n204r:
      self.n204 = 0L
    elif self.n204e:
        self.n204 = self.n204d
    if self.n212r:
      self.n212 = 0L
    elif self.n212e:
        self.n212 = self.n212d
    if self.n220r:
      self.n220 = 0L
    elif self.n220e:
        self.n220 = self.n220d
    if self.n228r:
      self.n228 = 0L
    elif self.n228e:
        self.n228 = self.n228d
    if self.n236r:
      self.n236 = 0L
    elif self.n236e:
        self.n236 = self.n236d
    if self.n244r:
      self.n244 = 0L
    elif self.n244e:
        self.n244 = self.n244d
    if self.n252r:
      self.n252 = 0L
    elif self.n252e:
        self.n252 = self.n252d
    if self.n260r:
      self.n260 = 0L
    elif self.n260e:
        self.n260 = self.n260d
    if self.n268r:
      self.n268 = 0L
    elif self.n268e:
        self.n268 = self.n268d
    if self.n276r:
      self.n276 = 0L
    elif self.n276e:
        self.n276 = self.n276d
    if self.n288r:
      self.n288 = 0L
    elif self.n288e:
        self.n288 = self.n288d
    if self.n300r:
      self.n300 = 0L
    elif self.n300e:
        self.n300 = self.n300d
    if self.n312r:
      self.n312 = 0L
    elif self.n312e:
        self.n312 = self.n312d
    if self.n324r:
      self.n324 = 0L
    elif self.n324e:
        self.n324 = self.n324d
    if self.n336r:
      self.n336 = 0L
    elif self.n336e:
        self.n336 = self.n336d
    if self.n348r:
      self.n348 = 0L
    elif self.n348e:
        self.n348 = self.n348d
    if self.n360r:
      self.n360 = 0L
    elif self.n360e:
        self.n360 = self.n360d
    if self.n372r:
      self.n372 = 0L
    elif self.n372e:
        self.n372 = self.n372d
    if self.n381r:
      self.n381 = 0L
    elif self.n381e:
        self.n381 = self.n381d
    if self.n393r:
      self.n393 = 0L
    elif self.n393e:
        self.n393 = self.n393d
    if self.n405r:
      self.n405 = 0L
    elif self.n405e:
        self.n405 = self.n405d
    if self.n417r:
      self.n417 = 0L
    elif self.n417e:
        self.n417 = self.n417d
    if self.n429r:
      self.n429 = 0L
    elif self.n429e:
        self.n429 = self.n429d
    if self.n438r:
      self.n438 = 0L
    elif self.n438e:
        self.n438 = self.n438d
    if self.n450r:
      self.n450 = 0L
    elif self.n450e:
        self.n450 = self.n450d
    if self.n462r:
      self.n462 = 0L
    elif self.n462e:
        self.n462 = self.n462d
    if self.n471r:
      self.n471 = 0L
    elif self.n471e:
        self.n471 = self.n471d
    if self.n483r:
      self.n483 = 0L
    elif self.n483e:
        self.n483 = self.n483d
    if self.n492r:
      self.n492 = 0L
    elif self.n492e:
        self.n492 = self.n492d
    if self.n504r:
      self.n504 = 0L
    elif self.n504e:
        self.n504 = self.n504d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n21 = self.n21
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n9 = self.n9
    self.sim_n10 = self.n10
    self.sim_n11 = self.n11
    self.sim_n12 = self.n12
    self.sim_n13 = self.n13
    self.sim_n14 = self.n14
    self.sim_n15 = self.n15
    self.sim_n16 = self.n16
    self.sim_n17 = self.n17
    self.sim_n18 = self.n18
    self.sim_n19 = self.n19
    self.sim_n20 = self.n20
    self.sim_n505 = self.n505
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fir_16_16_16 $end\n")
    self.sim_file.write("$var wire 1 ! reset_i $end\n")
    self.sim_file.write("$var wire 16 \" data_i $end\n")
    self.sim_file.write("$var wire 16 # k0_i $end\n")
    self.sim_file.write("$var wire 16 $ k1_i $end\n")
    self.sim_file.write("$var wire 16 % k2_i $end\n")
    self.sim_file.write("$var wire 16 & k3_i $end\n")
    self.sim_file.write("$var wire 16 ' k4_i $end\n")
    self.sim_file.write("$var wire 16 ( k5_i $end\n")
    self.sim_file.write("$var wire 16 ) k6_i $end\n")
    self.sim_file.write("$var wire 16 * k7_i $end\n")
    self.sim_file.write("$var wire 16 + k8_i $end\n")
    self.sim_file.write("$var wire 16 , k9_i $end\n")
    self.sim_file.write("$var wire 16 - k10_i $end\n")
    self.sim_file.write("$var wire 16 . k11_i $end\n")
    self.sim_file.write("$var wire 16 / k12_i $end\n")
    self.sim_file.write("$var wire 16 0 k13_i $end\n")
    self.sim_file.write("$var wire 16 1 k14_i $end\n")
    self.sim_file.write("$var wire 16 2 k15_i $end\n")
    self.sim_file.write("$var wire 16 3 k16_i $end\n")
    self.sim_file.write("$var wire 37 4 data_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n21 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n21 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" \"\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n9 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n9 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n10 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n10 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n11 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n11 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" *\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n12 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n12 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" +\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n13 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n13 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ,\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n14 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n14 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" -\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n15 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n15 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" .\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n16 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n16 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" /\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n17 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n17 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 0\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n18 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n18 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 1\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n19 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n19 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 2\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n20 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n20 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 3\n")
    found = 0
    for bit in range(36, -1, -1):
      if found:
        if self.n505 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n505 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 4\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n21 != self.n21:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n21 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n21 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" \"\n")
      self.sim_n21 = self.n21
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n8 = self.n8
    if self.sim_n9 != self.n9:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n9 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n9 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n9 = self.n9
    if self.sim_n10 != self.n10:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n10 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n10 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n10 = self.n10
    if self.sim_n11 != self.n11:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n11 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n11 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" *\n")
      self.sim_n11 = self.n11
    if self.sim_n12 != self.n12:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n12 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n12 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" +\n")
      self.sim_n12 = self.n12
    if self.sim_n13 != self.n13:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n13 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n13 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ,\n")
      self.sim_n13 = self.n13
    if self.sim_n14 != self.n14:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n14 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n14 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" -\n")
      self.sim_n14 = self.n14
    if self.sim_n15 != self.n15:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n15 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n15 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" .\n")
      self.sim_n15 = self.n15
    if self.sim_n16 != self.n16:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n16 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n16 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" /\n")
      self.sim_n16 = self.n16
    if self.sim_n17 != self.n17:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n17 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n17 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 0\n")
      self.sim_n17 = self.n17
    if self.sim_n18 != self.n18:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n18 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n18 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 1\n")
      self.sim_n18 = self.n18
    if self.sim_n19 != self.n19:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n19 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n19 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 2\n")
      self.sim_n19 = self.n19
    if self.sim_n20 != self.n20:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n20 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n20 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 3\n")
      self.sim_n20 = self.n20
    if self.sim_n505 != self.n505:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(36, -1, -1):
        if found:
          if self.n505 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n505 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 4\n")
      self.sim_n505 = self.n505
    self.sim_count = self.sim_count + 1

