//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs finite impulse response (FIR) filtering.
//    The filter's sum of products is pipelined with a register after
//    every multiplier and adder.  The adder network is a balanced binary
//    tree to minimize latency.  The sum of products has no numeric loss because the
//    multipliers keep all resulting bits and each adder extends the precision by 1.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
//  
//    Inputs:
//      data_i  : Input data.
//      k0_i    : Coefficient 0 multiplied by in_i(0).
//      k1_i    : Coefficient 1 multiplied by in_i(k-1).
//      k2_i    : Coefficient 2 multiplied by in_i(k-2).
//      ...
//      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
//  
//    Outputs:
//      data_o : Output data.
//  
//  Built In Parameters:
//  
//    Filter Order             = 24
//    Input Precision          = 8
//    Coefficient Precision    = 8
//    Sum of Products Latency  = 6
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:45:55 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fir_24_8_8
//    Clock Domains : clock_c  
//    Vector Input  : reset_i(1)
//    Vector Input  : data_i(8)
//    Vector Input  : k0_i(8)
//    Vector Input  : k1_i(8)
//    Vector Input  : k2_i(8)
//    Vector Input  : k3_i(8)
//    Vector Input  : k4_i(8)
//    Vector Input  : k5_i(8)
//    Vector Input  : k6_i(8)
//    Vector Input  : k7_i(8)
//    Vector Input  : k8_i(8)
//    Vector Input  : k9_i(8)
//    Vector Input  : k10_i(8)
//    Vector Input  : k11_i(8)
//    Vector Input  : k12_i(8)
//    Vector Input  : k13_i(8)
//    Vector Input  : k14_i(8)
//    Vector Input  : k15_i(8)
//    Vector Input  : k16_i(8)
//    Vector Input  : k17_i(8)
//    Vector Input  : k18_i(8)
//    Vector Input  : k19_i(8)
//    Vector Input  : k20_i(8)
//    Vector Input  : k21_i(8)
//    Vector Input  : k22_i(8)
//    Vector Input  : k23_i(8)
//    Vector Input  : k24_i(8)
//    Vector Output : data_o(21)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_fir_24_8_8.h"

static unsigned char *data_o;
static unsigned char n710[1];
static unsigned char n708[1];
static unsigned char n698[1];
static unsigned char n696[1];
static unsigned char n686[1];
static unsigned char n684[1];
static unsigned char n675[1];
static unsigned char n665[1];
static unsigned char n663[1];
static unsigned char n653[1];
static unsigned char n651[1];
static unsigned char n641[1];
static unsigned char n639[1];
static unsigned char n630[1];
static unsigned char n620[1];
static unsigned char n618[1];
static unsigned char n608[1];
static unsigned char n606[1];
static unsigned char n596[1];
static unsigned char n594[1];
static unsigned char n584[1];
static unsigned char n582[1];
static unsigned char n572[1];
static unsigned char n570[1];
static unsigned char n560[1];
static unsigned char n558[1];
static unsigned char n549[1];
static unsigned char n539[1];
static unsigned char n537[1];
static unsigned char n527[1];
static unsigned char n525[1];
static unsigned char n515[1];
static unsigned char n513[1];
static unsigned char n503[1];
static unsigned char n501[1];
static unsigned char n491[1];
static unsigned char n489[1];
static unsigned char n479[1];
static unsigned char n477[1];
static unsigned char n467[1];
static unsigned char n465[1];
static unsigned char n455[1];
static unsigned char n453[1];
static unsigned char n443[1];
static unsigned char n441[1];
static unsigned char n431[1];
static unsigned char n429[1];
static unsigned char n419[1];
static unsigned char n417[1];
static unsigned char n407[1];
static unsigned char n405[1];
static unsigned char *data_i;
static unsigned char *k24_i;
static unsigned char *k23_i;
static unsigned char *k22_i;
static unsigned char *k21_i;
static unsigned char *k20_i;
static unsigned char *k19_i;
static unsigned char *k18_i;
static unsigned char *k17_i;
static unsigned char *k16_i;
static unsigned char *k15_i;
static unsigned char *k14_i;
static unsigned char *k13_i;
static unsigned char *k12_i;
static unsigned char *k11_i;
static unsigned char *k10_i;
static unsigned char *k9_i;
static unsigned char *k8_i;
static unsigned char *k7_i;
static unsigned char *k6_i;
static unsigned char *k5_i;
static unsigned char *k4_i;
static unsigned char *k3_i;
static unsigned char *k2_i;
static unsigned char *k1_i;
static unsigned char *k0_i;
static unsigned char *reset_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char n711[3];
static unsigned char n709[3];
static unsigned char n699[3];
static unsigned char n697[3];
static unsigned char n687[3];
static unsigned char n685[3];
static unsigned char n676[3];
static unsigned char n666[3];
static unsigned char n664[3];
static unsigned char n654[3];
static unsigned char n652[3];
static unsigned char n642[3];
static unsigned char n640[3];
static unsigned char n631[3];
static unsigned char n621[3];
static unsigned char n619[3];
static unsigned char n609[3];
static unsigned char n607[3];
static unsigned char n597[3];
static unsigned char n595[3];
static unsigned char n585[3];
static unsigned char n583[3];
static unsigned char n573[3];
static unsigned char n571[3];
static unsigned char n561[3];
static unsigned char n559[3];
static unsigned char n550[3];
static unsigned char n540[3];
static unsigned char n538[3];
static unsigned char n528[3];
static unsigned char n526[3];
static unsigned char n516[3];
static unsigned char n514[3];
static unsigned char n504[3];
static unsigned char n502[3];
static unsigned char n492[3];
static unsigned char n490[3];
static unsigned char n480[3];
static unsigned char n478[3];
static unsigned char n468[3];
static unsigned char n466[3];
static unsigned char n456[3];
static unsigned char n454[3];
static unsigned char n444[3];
static unsigned char n442[3];
static unsigned char n432[3];
static unsigned char n430[3];
static unsigned char n420[3];
static unsigned char n418[3];
static unsigned char n408[3];
static unsigned char n406[3];
static unsigned char n397[2];
static unsigned char n389[2];
static unsigned char n381[2];
static unsigned char n373[2];
static unsigned char n365[2];
static unsigned char n357[2];
static unsigned char n349[2];
static unsigned char n341[2];
static unsigned char n333[2];
static unsigned char n325[2];
static unsigned char n317[2];
static unsigned char n309[2];
static unsigned char n301[2];
static unsigned char n293[2];
static unsigned char n285[2];
static unsigned char n277[2];
static unsigned char n269[2];
static unsigned char n261[2];
static unsigned char n253[2];
static unsigned char n245[2];
static unsigned char n237[2];
static unsigned char n229[2];
static unsigned char n221[2];
static unsigned char n213[2];
static unsigned char n205[2];
static unsigned char n204[1];
static unsigned char n204r[1];
static unsigned char n204e[1];
static unsigned char n204d[1];
static unsigned char n197[1];
static unsigned char n197r[1];
static unsigned char n197e[1];
static unsigned char n197d[1];
static unsigned char n190[1];
static unsigned char n190r[1];
static unsigned char n190e[1];
static unsigned char n190d[1];
static unsigned char n183[1];
static unsigned char n183r[1];
static unsigned char n183e[1];
static unsigned char n183d[1];
static unsigned char n176[1];
static unsigned char n176r[1];
static unsigned char n176e[1];
static unsigned char n176d[1];
static unsigned char n169[1];
static unsigned char n169r[1];
static unsigned char n169e[1];
static unsigned char n169d[1];
static unsigned char n162[1];
static unsigned char n162r[1];
static unsigned char n162e[1];
static unsigned char n162d[1];
static unsigned char n155[1];
static unsigned char n155r[1];
static unsigned char n155e[1];
static unsigned char n155d[1];
static unsigned char n148[1];
static unsigned char n148r[1];
static unsigned char n148e[1];
static unsigned char n148d[1];
static unsigned char n141[1];
static unsigned char n141r[1];
static unsigned char n141e[1];
static unsigned char n141d[1];
static unsigned char n134[1];
static unsigned char n134r[1];
static unsigned char n134e[1];
static unsigned char n134d[1];
static unsigned char n127[1];
static unsigned char n127r[1];
static unsigned char n127e[1];
static unsigned char n127d[1];
static unsigned char n120[1];
static unsigned char n120r[1];
static unsigned char n120e[1];
static unsigned char n120d[1];
static unsigned char n113[1];
static unsigned char n113r[1];
static unsigned char n113e[1];
static unsigned char n113d[1];
static unsigned char n106[1];
static unsigned char n106r[1];
static unsigned char n106e[1];
static unsigned char n106d[1];
static unsigned char n99[1];
static unsigned char n99r[1];
static unsigned char n99e[1];
static unsigned char n99d[1];
static unsigned char n92[1];
static unsigned char n92r[1];
static unsigned char n92e[1];
static unsigned char n92d[1];
static unsigned char n85[1];
static unsigned char n85r[1];
static unsigned char n85e[1];
static unsigned char n85d[1];
static unsigned char n78[1];
static unsigned char n78r[1];
static unsigned char n78e[1];
static unsigned char n78d[1];
static unsigned char n71[1];
static unsigned char n71r[1];
static unsigned char n71e[1];
static unsigned char n71d[1];
static unsigned char n64[1];
static unsigned char n64r[1];
static unsigned char n64e[1];
static unsigned char n64d[1];
static unsigned char n57[1];
static unsigned char n57r[1];
static unsigned char n57e[1];
static unsigned char n57d[1];
static unsigned char n50[1];
static unsigned char n50r[1];
static unsigned char n50e[1];
static unsigned char n50d[1];
static unsigned char n43[1];
static unsigned char n43r[1];
static unsigned char n43e[1];
static unsigned char n43d[1];
static unsigned char n36[1];
static unsigned char n36r[1];
static unsigned char n36e[1];
static unsigned char n36d[1];
static unsigned char n712[3];
static unsigned char n700[3];
static unsigned char n688[3];
static unsigned char n683[3];
static unsigned char n683r[1];
static unsigned char n683e[1];
static unsigned char n683d[3];
static unsigned char n667[3];
static unsigned char n655[3];
static unsigned char n643[3];
static unsigned char n638[3];
static unsigned char n638r[1];
static unsigned char n638e[1];
static unsigned char n638d[3];
static unsigned char n622[3];
static unsigned char n610[3];
static unsigned char n598[3];
static unsigned char n586[3];
static unsigned char n574[3];
static unsigned char n562[3];
static unsigned char n557[3];
static unsigned char n557r[1];
static unsigned char n557e[1];
static unsigned char n557d[3];
static unsigned char n541[3];
static unsigned char n529[3];
static unsigned char n517[3];
static unsigned char n505[3];
static unsigned char n493[3];
static unsigned char n481[3];
static unsigned char n469[3];
static unsigned char n457[3];
static unsigned char n445[3];
static unsigned char n433[3];
static unsigned char n421[3];
static unsigned char n409[3];
static unsigned char n404[2];
static unsigned char n404r[1];
static unsigned char n404e[1];
static unsigned char n404d[2];
static unsigned char n396[2];
static unsigned char n396r[1];
static unsigned char n396e[1];
static unsigned char n396d[2];
static unsigned char n388[2];
static unsigned char n388r[1];
static unsigned char n388e[1];
static unsigned char n388d[2];
static unsigned char n380[2];
static unsigned char n380r[1];
static unsigned char n380e[1];
static unsigned char n380d[2];
static unsigned char n372[2];
static unsigned char n372r[1];
static unsigned char n372e[1];
static unsigned char n372d[2];
static unsigned char n364[2];
static unsigned char n364r[1];
static unsigned char n364e[1];
static unsigned char n364d[2];
static unsigned char n356[2];
static unsigned char n356r[1];
static unsigned char n356e[1];
static unsigned char n356d[2];
static unsigned char n348[2];
static unsigned char n348r[1];
static unsigned char n348e[1];
static unsigned char n348d[2];
static unsigned char n340[2];
static unsigned char n340r[1];
static unsigned char n340e[1];
static unsigned char n340d[2];
static unsigned char n332[2];
static unsigned char n332r[1];
static unsigned char n332e[1];
static unsigned char n332d[2];
static unsigned char n324[2];
static unsigned char n324r[1];
static unsigned char n324e[1];
static unsigned char n324d[2];
static unsigned char n316[2];
static unsigned char n316r[1];
static unsigned char n316e[1];
static unsigned char n316d[2];
static unsigned char n308[2];
static unsigned char n308r[1];
static unsigned char n308e[1];
static unsigned char n308d[2];
static unsigned char n300[2];
static unsigned char n300r[1];
static unsigned char n300e[1];
static unsigned char n300d[2];
static unsigned char n292[2];
static unsigned char n292r[1];
static unsigned char n292e[1];
static unsigned char n292d[2];
static unsigned char n284[2];
static unsigned char n284r[1];
static unsigned char n284e[1];
static unsigned char n284d[2];
static unsigned char n276[2];
static unsigned char n276r[1];
static unsigned char n276e[1];
static unsigned char n276d[2];
static unsigned char n268[2];
static unsigned char n268r[1];
static unsigned char n268e[1];
static unsigned char n268d[2];
static unsigned char n260[2];
static unsigned char n260r[1];
static unsigned char n260e[1];
static unsigned char n260d[2];
static unsigned char n252[2];
static unsigned char n252r[1];
static unsigned char n252e[1];
static unsigned char n252d[2];
static unsigned char n244[2];
static unsigned char n244r[1];
static unsigned char n244e[1];
static unsigned char n244d[2];
static unsigned char n236[2];
static unsigned char n236r[1];
static unsigned char n236e[1];
static unsigned char n236d[2];
static unsigned char n228[2];
static unsigned char n228r[1];
static unsigned char n228e[1];
static unsigned char n228d[2];
static unsigned char n220[2];
static unsigned char n220r[1];
static unsigned char n220e[1];
static unsigned char n220d[2];
static unsigned char n212[2];
static unsigned char n212r[1];
static unsigned char n212e[1];
static unsigned char n212d[2];
static unsigned char n719[3];
static unsigned char n719r[1];
static unsigned char n719e[1];
static unsigned char n719d[3];
static unsigned char n707[3];
static unsigned char n707r[1];
static unsigned char n707e[1];
static unsigned char n707d[3];
static unsigned char n695[3];
static unsigned char n695r[1];
static unsigned char n695e[1];
static unsigned char n695d[3];
static unsigned char n674[3];
static unsigned char n674r[1];
static unsigned char n674e[1];
static unsigned char n674d[3];
static unsigned char n662[3];
static unsigned char n662r[1];
static unsigned char n662e[1];
static unsigned char n662d[3];
static unsigned char n650[3];
static unsigned char n650r[1];
static unsigned char n650e[1];
static unsigned char n650d[3];
static unsigned char n629[3];
static unsigned char n629r[1];
static unsigned char n629e[1];
static unsigned char n629d[3];
static unsigned char n617[3];
static unsigned char n617r[1];
static unsigned char n617e[1];
static unsigned char n617d[3];
static unsigned char n605[3];
static unsigned char n605r[1];
static unsigned char n605e[1];
static unsigned char n605d[3];
static unsigned char n593[3];
static unsigned char n593r[1];
static unsigned char n593e[1];
static unsigned char n593d[3];
static unsigned char n581[3];
static unsigned char n581r[1];
static unsigned char n581e[1];
static unsigned char n581d[3];
static unsigned char n569[3];
static unsigned char n569r[1];
static unsigned char n569e[1];
static unsigned char n569d[3];
static unsigned char n548[3];
static unsigned char n548r[1];
static unsigned char n548e[1];
static unsigned char n548d[3];
static unsigned char n536[3];
static unsigned char n536r[1];
static unsigned char n536e[1];
static unsigned char n536d[3];
static unsigned char n524[3];
static unsigned char n524r[1];
static unsigned char n524e[1];
static unsigned char n524d[3];
static unsigned char n512[3];
static unsigned char n512r[1];
static unsigned char n512e[1];
static unsigned char n512d[3];
static unsigned char n500[3];
static unsigned char n500r[1];
static unsigned char n500e[1];
static unsigned char n500d[3];
static unsigned char n488[3];
static unsigned char n488r[1];
static unsigned char n488e[1];
static unsigned char n488d[3];
static unsigned char n476[3];
static unsigned char n476r[1];
static unsigned char n476e[1];
static unsigned char n476d[3];
static unsigned char n464[3];
static unsigned char n464r[1];
static unsigned char n464e[1];
static unsigned char n464d[3];
static unsigned char n452[3];
static unsigned char n452r[1];
static unsigned char n452e[1];
static unsigned char n452d[3];
static unsigned char n440[3];
static unsigned char n440r[1];
static unsigned char n440e[1];
static unsigned char n440d[3];
static unsigned char n428[3];
static unsigned char n428r[1];
static unsigned char n428e[1];
static unsigned char n428d[3];
static unsigned char n416[3];
static unsigned char n416r[1];
static unsigned char n416e[1];
static unsigned char n416d[3];

void cf_fir_24_8_8_ports(unsigned char* port_reset_i, unsigned char* port_data_i, unsigned char* port_k0_i, unsigned char* port_k1_i, unsigned char* port_k2_i, unsigned char* port_k3_i, unsigned char* port_k4_i, unsigned char* port_k5_i, unsigned char* port_k6_i, unsigned char* port_k7_i, unsigned char* port_k8_i, unsigned char* port_k9_i, unsigned char* port_k10_i, unsigned char* port_k11_i, unsigned char* port_k12_i, unsigned char* port_k13_i, unsigned char* port_k14_i, unsigned char* port_k15_i, unsigned char* port_k16_i, unsigned char* port_k17_i, unsigned char* port_k18_i, unsigned char* port_k19_i, unsigned char* port_k20_i, unsigned char* port_k21_i, unsigned char* port_k22_i, unsigned char* port_k23_i, unsigned char* port_k24_i, unsigned char* port_data_o) {
  reset_i = port_reset_i;
  data_i = port_data_i;
  k0_i = port_k0_i;
  k1_i = port_k1_i;
  k2_i = port_k2_i;
  k3_i = port_k3_i;
  k4_i = port_k4_i;
  k5_i = port_k5_i;
  k6_i = port_k6_i;
  k7_i = port_k7_i;
  k8_i = port_k8_i;
  k9_i = port_k9_i;
  k10_i = port_k10_i;
  k11_i = port_k11_i;
  k12_i = port_k12_i;
  k13_i = port_k13_i;
  k14_i = port_k14_i;
  k15_i = port_k15_i;
  k16_i = port_k16_i;
  k17_i = port_k17_i;
  k18_i = port_k18_i;
  k19_i = port_k19_i;
  k20_i = port_k20_i;
  k21_i = port_k21_i;
  k22_i = port_k22_i;
  k23_i = port_k23_i;
  k24_i = port_k24_i;
  data_o = port_data_o;
}

void cf_fir_24_8_8_calc() {
  data_o[0] = n719[0];
  data_o[1] = n719[1];
  data_o[2] = n719[2];
  n710[0] = (1 & (n707[2] >> 3));
  n708[0] = (1 & (n695[2] >> 3));
  n698[0] = (1 & (n683[2] >> 2));
  n696[0] = (1 & (n674[2] >> 2));
  n686[0] = (1 & (n662[2] >> 2));
  n684[0] = (1 & (n650[2] >> 2));
  n675[0] = (1 & (n638[2] >> 1));
  n665[0] = (1 & (n629[2] >> 1));
  n663[0] = (1 & (n617[2] >> 1));
  n653[0] = (1 & (n605[2] >> 1));
  n651[0] = (1 & (n593[2] >> 1));
  n641[0] = (1 & (n581[2] >> 1));
  n639[0] = (1 & (n569[2] >> 1));
  n630[0] = (1 & (n557[2]));
  n620[0] = (1 & (n548[2]));
  n618[0] = (1 & (n536[2]));
  n608[0] = (1 & (n524[2]));
  n606[0] = (1 & (n512[2]));
  n596[0] = (1 & (n500[2]));
  n594[0] = (1 & (n488[2]));
  n584[0] = (1 & (n476[2]));
  n582[0] = (1 & (n464[2]));
  n572[0] = (1 & (n452[2]));
  n570[0] = (1 & (n440[2]));
  n560[0] = (1 & (n428[2]));
  n558[0] = (1 & (n416[2]));
  n549[0] = (1 & (n404[1] >> 7));
  n539[0] = (1 & (n396[1] >> 7));
  n537[0] = (1 & (n388[1] >> 7));
  n527[0] = (1 & (n380[1] >> 7));
  n525[0] = (1 & (n372[1] >> 7));
  n515[0] = (1 & (n364[1] >> 7));
  n513[0] = (1 & (n356[1] >> 7));
  n503[0] = (1 & (n348[1] >> 7));
  n501[0] = (1 & (n340[1] >> 7));
  n491[0] = (1 & (n332[1] >> 7));
  n489[0] = (1 & (n324[1] >> 7));
  n479[0] = (1 & (n316[1] >> 7));
  n477[0] = (1 & (n308[1] >> 7));
  n467[0] = (1 & (n300[1] >> 7));
  n465[0] = (1 & (n292[1] >> 7));
  n455[0] = (1 & (n284[1] >> 7));
  n453[0] = (1 & (n276[1] >> 7));
  n443[0] = (1 & (n268[1] >> 7));
  n441[0] = (1 & (n260[1] >> 7));
  n431[0] = (1 & (n252[1] >> 7));
  n429[0] = (1 & (n244[1] >> 7));
  n419[0] = (1 & (n236[1] >> 7));
  n417[0] = (1 & (n228[1] >> 7));
  n407[0] = (1 & (n220[1] >> 7));
  n405[0] = (1 & (n212[1] >> 7));
  n2[0] = 0;
  n1[0] = 1;
  n711[0] = n707[0];
  n711[1] = n707[1];
  n711[2] = 255 & (n710[0] << 4 | n707[2]);
  n709[0] = n695[0];
  n709[1] = n695[1];
  n709[2] = 255 & (n708[0] << 4 | n695[2]);
  n699[0] = n683[0];
  n699[1] = n683[1];
  n699[2] = 255 & (n698[0] << 3 | n683[2]);
  n697[0] = n674[0];
  n697[1] = n674[1];
  n697[2] = 255 & (n696[0] << 3 | n674[2]);
  n687[0] = n662[0];
  n687[1] = n662[1];
  n687[2] = 255 & (n686[0] << 3 | n662[2]);
  n685[0] = n650[0];
  n685[1] = n650[1];
  n685[2] = 255 & (n684[0] << 3 | n650[2]);
  n676[0] = n638[0];
  n676[1] = n638[1];
  n676[2] = 255 & (n675[0] << 2 | n638[2]);
  n666[0] = n629[0];
  n666[1] = n629[1];
  n666[2] = 255 & (n665[0] << 2 | n629[2]);
  n664[0] = n617[0];
  n664[1] = n617[1];
  n664[2] = 255 & (n663[0] << 2 | n617[2]);
  n654[0] = n605[0];
  n654[1] = n605[1];
  n654[2] = 255 & (n653[0] << 2 | n605[2]);
  n652[0] = n593[0];
  n652[1] = n593[1];
  n652[2] = 255 & (n651[0] << 2 | n593[2]);
  n642[0] = n581[0];
  n642[1] = n581[1];
  n642[2] = 255 & (n641[0] << 2 | n581[2]);
  n640[0] = n569[0];
  n640[1] = n569[1];
  n640[2] = 255 & (n639[0] << 2 | n569[2]);
  n631[0] = n557[0];
  n631[1] = n557[1];
  n631[2] = 255 & (n630[0] << 1 | n557[2]);
  n621[0] = n548[0];
  n621[1] = n548[1];
  n621[2] = 255 & (n620[0] << 1 | n548[2]);
  n619[0] = n536[0];
  n619[1] = n536[1];
  n619[2] = 255 & (n618[0] << 1 | n536[2]);
  n609[0] = n524[0];
  n609[1] = n524[1];
  n609[2] = 255 & (n608[0] << 1 | n524[2]);
  n607[0] = n512[0];
  n607[1] = n512[1];
  n607[2] = 255 & (n606[0] << 1 | n512[2]);
  n597[0] = n500[0];
  n597[1] = n500[1];
  n597[2] = 255 & (n596[0] << 1 | n500[2]);
  n595[0] = n488[0];
  n595[1] = n488[1];
  n595[2] = 255 & (n594[0] << 1 | n488[2]);
  n585[0] = n476[0];
  n585[1] = n476[1];
  n585[2] = 255 & (n584[0] << 1 | n476[2]);
  n583[0] = n464[0];
  n583[1] = n464[1];
  n583[2] = 255 & (n582[0] << 1 | n464[2]);
  n573[0] = n452[0];
  n573[1] = n452[1];
  n573[2] = 255 & (n572[0] << 1 | n452[2]);
  n571[0] = n440[0];
  n571[1] = n440[1];
  n571[2] = 255 & (n570[0] << 1 | n440[2]);
  n561[0] = n428[0];
  n561[1] = n428[1];
  n561[2] = 255 & (n560[0] << 1 | n428[2]);
  n559[0] = n416[0];
  n559[1] = n416[1];
  n559[2] = 255 & (n558[0] << 1 | n416[2]);
  n550[0] = n404[0];
  n550[1] = n404[1];
  n550[2] = n549[0];
  n540[0] = n396[0];
  n540[1] = n396[1];
  n540[2] = n539[0];
  n538[0] = n388[0];
  n538[1] = n388[1];
  n538[2] = n537[0];
  n528[0] = n380[0];
  n528[1] = n380[1];
  n528[2] = n527[0];
  n526[0] = n372[0];
  n526[1] = n372[1];
  n526[2] = n525[0];
  n516[0] = n364[0];
  n516[1] = n364[1];
  n516[2] = n515[0];
  n514[0] = n356[0];
  n514[1] = n356[1];
  n514[2] = n513[0];
  n504[0] = n348[0];
  n504[1] = n348[1];
  n504[2] = n503[0];
  n502[0] = n340[0];
  n502[1] = n340[1];
  n502[2] = n501[0];
  n492[0] = n332[0];
  n492[1] = n332[1];
  n492[2] = n491[0];
  n490[0] = n324[0];
  n490[1] = n324[1];
  n490[2] = n489[0];
  n480[0] = n316[0];
  n480[1] = n316[1];
  n480[2] = n479[0];
  n478[0] = n308[0];
  n478[1] = n308[1];
  n478[2] = n477[0];
  n468[0] = n300[0];
  n468[1] = n300[1];
  n468[2] = n467[0];
  n466[0] = n292[0];
  n466[1] = n292[1];
  n466[2] = n465[0];
  n456[0] = n284[0];
  n456[1] = n284[1];
  n456[2] = n455[0];
  n454[0] = n276[0];
  n454[1] = n276[1];
  n454[2] = n453[0];
  n444[0] = n268[0];
  n444[1] = n268[1];
  n444[2] = n443[0];
  n442[0] = n260[0];
  n442[1] = n260[1];
  n442[2] = n441[0];
  n432[0] = n252[0];
  n432[1] = n252[1];
  n432[2] = n431[0];
  n430[0] = n244[0];
  n430[1] = n244[1];
  n430[2] = n429[0];
  n420[0] = n236[0];
  n420[1] = n236[1];
  n420[2] = n419[0];
  n418[0] = n228[0];
  n418[1] = n228[1];
  n418[2] = n417[0];
  n408[0] = n220[0];
  n408[1] = n220[1];
  n408[2] = n407[0];
  n406[0] = n212[0];
  n406[1] = n212[1];
  n406[2] = n405[0];
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k24_i[0];
    b[1] = 0;
    b[0] = n204[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n397[0] = 255 & (unsigned char) tmp, tmp >> 8), n397[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k23_i[0];
    b[1] = 0;
    b[0] = n197[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n389[0] = 255 & (unsigned char) tmp, tmp >> 8), n389[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k22_i[0];
    b[1] = 0;
    b[0] = n190[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n381[0] = 255 & (unsigned char) tmp, tmp >> 8), n381[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k21_i[0];
    b[1] = 0;
    b[0] = n183[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n373[0] = 255 & (unsigned char) tmp, tmp >> 8), n373[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k20_i[0];
    b[1] = 0;
    b[0] = n176[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n365[0] = 255 & (unsigned char) tmp, tmp >> 8), n365[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k19_i[0];
    b[1] = 0;
    b[0] = n169[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n357[0] = 255 & (unsigned char) tmp, tmp >> 8), n357[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k18_i[0];
    b[1] = 0;
    b[0] = n162[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n349[0] = 255 & (unsigned char) tmp, tmp >> 8), n349[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k17_i[0];
    b[1] = 0;
    b[0] = n155[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n341[0] = 255 & (unsigned char) tmp, tmp >> 8), n341[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k16_i[0];
    b[1] = 0;
    b[0] = n148[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n333[0] = 255 & (unsigned char) tmp, tmp >> 8), n333[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k15_i[0];
    b[1] = 0;
    b[0] = n141[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n325[0] = 255 & (unsigned char) tmp, tmp >> 8), n325[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k14_i[0];
    b[1] = 0;
    b[0] = n134[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n317[0] = 255 & (unsigned char) tmp, tmp >> 8), n317[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k13_i[0];
    b[1] = 0;
    b[0] = n127[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n309[0] = 255 & (unsigned char) tmp, tmp >> 8), n309[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k12_i[0];
    b[1] = 0;
    b[0] = n120[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n301[0] = 255 & (unsigned char) tmp, tmp >> 8), n301[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k11_i[0];
    b[1] = 0;
    b[0] = n113[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n293[0] = 255 & (unsigned char) tmp, tmp >> 8), n293[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k10_i[0];
    b[1] = 0;
    b[0] = n106[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n285[0] = 255 & (unsigned char) tmp, tmp >> 8), n285[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k9_i[0];
    b[1] = 0;
    b[0] = n99[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n277[0] = 255 & (unsigned char) tmp, tmp >> 8), n277[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k8_i[0];
    b[1] = 0;
    b[0] = n92[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n269[0] = 255 & (unsigned char) tmp, tmp >> 8), n269[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k7_i[0];
    b[1] = 0;
    b[0] = n85[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n261[0] = 255 & (unsigned char) tmp, tmp >> 8), n261[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k6_i[0];
    b[1] = 0;
    b[0] = n78[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n253[0] = 255 & (unsigned char) tmp, tmp >> 8), n253[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k5_i[0];
    b[1] = 0;
    b[0] = n71[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n245[0] = 255 & (unsigned char) tmp, tmp >> 8), n245[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k4_i[0];
    b[1] = 0;
    b[0] = n64[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n237[0] = 255 & (unsigned char) tmp, tmp >> 8), n237[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k3_i[0];
    b[1] = 0;
    b[0] = n57[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n229[0] = 255 & (unsigned char) tmp, tmp >> 8), n229[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k2_i[0];
    b[1] = 0;
    b[0] = n50[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n221[0] = 255 & (unsigned char) tmp, tmp >> 8), n221[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k1_i[0];
    b[1] = 0;
    b[0] = n43[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n213[0] = 255 & (unsigned char) tmp, tmp >> 8), n213[1] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[2];
    unsigned char b[2];
    a[1] = 0;
    a[0] = k0_i[0];
    b[1] = 0;
    b[0] = n36[0];
    (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n205[0] = 255 & (unsigned char) tmp, tmp >> 8), n205[1] = 255 & (unsigned char) tmp);
  }
  n204r[0] = reset_i[0];
  n204e[0] = n1[0];
  n204d[0] = n197[0];
  n197r[0] = reset_i[0];
  n197e[0] = n1[0];
  n197d[0] = n190[0];
  n190r[0] = reset_i[0];
  n190e[0] = n1[0];
  n190d[0] = n183[0];
  n183r[0] = reset_i[0];
  n183e[0] = n1[0];
  n183d[0] = n176[0];
  n176r[0] = reset_i[0];
  n176e[0] = n1[0];
  n176d[0] = n169[0];
  n169r[0] = reset_i[0];
  n169e[0] = n1[0];
  n169d[0] = n162[0];
  n162r[0] = reset_i[0];
  n162e[0] = n1[0];
  n162d[0] = n155[0];
  n155r[0] = reset_i[0];
  n155e[0] = n1[0];
  n155d[0] = n148[0];
  n148r[0] = reset_i[0];
  n148e[0] = n1[0];
  n148d[0] = n141[0];
  n141r[0] = reset_i[0];
  n141e[0] = n1[0];
  n141d[0] = n134[0];
  n134r[0] = reset_i[0];
  n134e[0] = n1[0];
  n134d[0] = n127[0];
  n127r[0] = reset_i[0];
  n127e[0] = n1[0];
  n127d[0] = n120[0];
  n120r[0] = reset_i[0];
  n120e[0] = n1[0];
  n120d[0] = n113[0];
  n113r[0] = reset_i[0];
  n113e[0] = n1[0];
  n113d[0] = n106[0];
  n106r[0] = reset_i[0];
  n106e[0] = n1[0];
  n106d[0] = n99[0];
  n99r[0] = reset_i[0];
  n99e[0] = n1[0];
  n99d[0] = n92[0];
  n92r[0] = reset_i[0];
  n92e[0] = n1[0];
  n92d[0] = n85[0];
  n85r[0] = reset_i[0];
  n85e[0] = n1[0];
  n85d[0] = n78[0];
  n78r[0] = reset_i[0];
  n78e[0] = n1[0];
  n78d[0] = n71[0];
  n71r[0] = reset_i[0];
  n71e[0] = n1[0];
  n71d[0] = n64[0];
  n64r[0] = reset_i[0];
  n64e[0] = n1[0];
  n64d[0] = n57[0];
  n57r[0] = reset_i[0];
  n57e[0] = n1[0];
  n57d[0] = n50[0];
  n50r[0] = reset_i[0];
  n50e[0] = n1[0];
  n50d[0] = n43[0];
  n43r[0] = reset_i[0];
  n43e[0] = n1[0];
  n43d[0] = n36[0];
  n36r[0] = reset_i[0];
  n36e[0] = n1[0];
  n36d[0] = data_i[0];
  { unsigned int tmp; (tmp = (unsigned int) n709[2] + (unsigned int) n711[2] + (tmp = (unsigned int) n709[1] + (unsigned int) n711[1] + (tmp = (unsigned int) n709[0] + (unsigned int) n711[0], n712[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n712[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n712[2] = 31 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n697[2] + (unsigned int) n699[2] + (tmp = (unsigned int) n697[1] + (unsigned int) n699[1] + (tmp = (unsigned int) n697[0] + (unsigned int) n699[0], n700[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n700[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n700[2] = 15 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n685[2] + (unsigned int) n687[2] + (tmp = (unsigned int) n685[1] + (unsigned int) n687[1] + (tmp = (unsigned int) n685[0] + (unsigned int) n687[0], n688[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n688[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n688[2] = 15 & (unsigned char) tmp); }
  n683r[0] = n2[0];
  n683e[0] = n1[0];
  n683d[0] = n676[0];
  n683d[1] = n676[1];
  n683d[2] = n676[2];
  { unsigned int tmp; (tmp = (unsigned int) n664[2] + (unsigned int) n666[2] + (tmp = (unsigned int) n664[1] + (unsigned int) n666[1] + (tmp = (unsigned int) n664[0] + (unsigned int) n666[0], n667[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n667[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n667[2] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n652[2] + (unsigned int) n654[2] + (tmp = (unsigned int) n652[1] + (unsigned int) n654[1] + (tmp = (unsigned int) n652[0] + (unsigned int) n654[0], n655[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n655[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n655[2] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n640[2] + (unsigned int) n642[2] + (tmp = (unsigned int) n640[1] + (unsigned int) n642[1] + (tmp = (unsigned int) n640[0] + (unsigned int) n642[0], n643[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n643[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n643[2] = 7 & (unsigned char) tmp); }
  n638r[0] = n2[0];
  n638e[0] = n1[0];
  n638d[0] = n631[0];
  n638d[1] = n631[1];
  n638d[2] = n631[2];
  { unsigned int tmp; (tmp = (unsigned int) n619[2] + (unsigned int) n621[2] + (tmp = (unsigned int) n619[1] + (unsigned int) n621[1] + (tmp = (unsigned int) n619[0] + (unsigned int) n621[0], n622[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n622[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n622[2] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n607[2] + (unsigned int) n609[2] + (tmp = (unsigned int) n607[1] + (unsigned int) n609[1] + (tmp = (unsigned int) n607[0] + (unsigned int) n609[0], n610[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n610[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n610[2] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n595[2] + (unsigned int) n597[2] + (tmp = (unsigned int) n595[1] + (unsigned int) n597[1] + (tmp = (unsigned int) n595[0] + (unsigned int) n597[0], n598[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n598[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n598[2] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n583[2] + (unsigned int) n585[2] + (tmp = (unsigned int) n583[1] + (unsigned int) n585[1] + (tmp = (unsigned int) n583[0] + (unsigned int) n585[0], n586[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n586[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n586[2] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n571[2] + (unsigned int) n573[2] + (tmp = (unsigned int) n571[1] + (unsigned int) n573[1] + (tmp = (unsigned int) n571[0] + (unsigned int) n573[0], n574[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n574[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n574[2] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n559[2] + (unsigned int) n561[2] + (tmp = (unsigned int) n559[1] + (unsigned int) n561[1] + (tmp = (unsigned int) n559[0] + (unsigned int) n561[0], n562[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n562[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n562[2] = 3 & (unsigned char) tmp); }
  n557r[0] = n2[0];
  n557e[0] = n1[0];
  n557d[0] = n550[0];
  n557d[1] = n550[1];
  n557d[2] = n550[2];
  { unsigned int tmp; (tmp = (unsigned int) n538[2] + (unsigned int) n540[2] + (tmp = (unsigned int) n538[1] + (unsigned int) n540[1] + (tmp = (unsigned int) n538[0] + (unsigned int) n540[0], n541[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n541[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n541[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n526[2] + (unsigned int) n528[2] + (tmp = (unsigned int) n526[1] + (unsigned int) n528[1] + (tmp = (unsigned int) n526[0] + (unsigned int) n528[0], n529[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n529[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n529[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n514[2] + (unsigned int) n516[2] + (tmp = (unsigned int) n514[1] + (unsigned int) n516[1] + (tmp = (unsigned int) n514[0] + (unsigned int) n516[0], n517[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n517[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n517[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n502[2] + (unsigned int) n504[2] + (tmp = (unsigned int) n502[1] + (unsigned int) n504[1] + (tmp = (unsigned int) n502[0] + (unsigned int) n504[0], n505[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n505[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n505[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n490[2] + (unsigned int) n492[2] + (tmp = (unsigned int) n490[1] + (unsigned int) n492[1] + (tmp = (unsigned int) n490[0] + (unsigned int) n492[0], n493[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n493[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n493[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n478[2] + (unsigned int) n480[2] + (tmp = (unsigned int) n478[1] + (unsigned int) n480[1] + (tmp = (unsigned int) n478[0] + (unsigned int) n480[0], n481[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n481[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n481[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n466[2] + (unsigned int) n468[2] + (tmp = (unsigned int) n466[1] + (unsigned int) n468[1] + (tmp = (unsigned int) n466[0] + (unsigned int) n468[0], n469[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n469[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n469[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n454[2] + (unsigned int) n456[2] + (tmp = (unsigned int) n454[1] + (unsigned int) n456[1] + (tmp = (unsigned int) n454[0] + (unsigned int) n456[0], n457[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n457[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n457[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n442[2] + (unsigned int) n444[2] + (tmp = (unsigned int) n442[1] + (unsigned int) n444[1] + (tmp = (unsigned int) n442[0] + (unsigned int) n444[0], n445[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n445[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n445[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n430[2] + (unsigned int) n432[2] + (tmp = (unsigned int) n430[1] + (unsigned int) n432[1] + (tmp = (unsigned int) n430[0] + (unsigned int) n432[0], n433[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n433[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n433[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n418[2] + (unsigned int) n420[2] + (tmp = (unsigned int) n418[1] + (unsigned int) n420[1] + (tmp = (unsigned int) n418[0] + (unsigned int) n420[0], n421[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n421[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n421[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n406[2] + (unsigned int) n408[2] + (tmp = (unsigned int) n406[1] + (unsigned int) n408[1] + (tmp = (unsigned int) n406[0] + (unsigned int) n408[0], n409[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n409[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n409[2] = 1 & (unsigned char) tmp); }
  n404r[0] = n2[0];
  n404e[0] = n1[0];
  n404d[0] = n397[0];
  n404d[1] = n397[1];
  n396r[0] = n2[0];
  n396e[0] = n1[0];
  n396d[0] = n389[0];
  n396d[1] = n389[1];
  n388r[0] = n2[0];
  n388e[0] = n1[0];
  n388d[0] = n381[0];
  n388d[1] = n381[1];
  n380r[0] = n2[0];
  n380e[0] = n1[0];
  n380d[0] = n373[0];
  n380d[1] = n373[1];
  n372r[0] = n2[0];
  n372e[0] = n1[0];
  n372d[0] = n365[0];
  n372d[1] = n365[1];
  n364r[0] = n2[0];
  n364e[0] = n1[0];
  n364d[0] = n357[0];
  n364d[1] = n357[1];
  n356r[0] = n2[0];
  n356e[0] = n1[0];
  n356d[0] = n349[0];
  n356d[1] = n349[1];
  n348r[0] = n2[0];
  n348e[0] = n1[0];
  n348d[0] = n341[0];
  n348d[1] = n341[1];
  n340r[0] = n2[0];
  n340e[0] = n1[0];
  n340d[0] = n333[0];
  n340d[1] = n333[1];
  n332r[0] = n2[0];
  n332e[0] = n1[0];
  n332d[0] = n325[0];
  n332d[1] = n325[1];
  n324r[0] = n2[0];
  n324e[0] = n1[0];
  n324d[0] = n317[0];
  n324d[1] = n317[1];
  n316r[0] = n2[0];
  n316e[0] = n1[0];
  n316d[0] = n309[0];
  n316d[1] = n309[1];
  n308r[0] = n2[0];
  n308e[0] = n1[0];
  n308d[0] = n301[0];
  n308d[1] = n301[1];
  n300r[0] = n2[0];
  n300e[0] = n1[0];
  n300d[0] = n293[0];
  n300d[1] = n293[1];
  n292r[0] = n2[0];
  n292e[0] = n1[0];
  n292d[0] = n285[0];
  n292d[1] = n285[1];
  n284r[0] = n2[0];
  n284e[0] = n1[0];
  n284d[0] = n277[0];
  n284d[1] = n277[1];
  n276r[0] = n2[0];
  n276e[0] = n1[0];
  n276d[0] = n269[0];
  n276d[1] = n269[1];
  n268r[0] = n2[0];
  n268e[0] = n1[0];
  n268d[0] = n261[0];
  n268d[1] = n261[1];
  n260r[0] = n2[0];
  n260e[0] = n1[0];
  n260d[0] = n253[0];
  n260d[1] = n253[1];
  n252r[0] = n2[0];
  n252e[0] = n1[0];
  n252d[0] = n245[0];
  n252d[1] = n245[1];
  n244r[0] = n2[0];
  n244e[0] = n1[0];
  n244d[0] = n237[0];
  n244d[1] = n237[1];
  n236r[0] = n2[0];
  n236e[0] = n1[0];
  n236d[0] = n229[0];
  n236d[1] = n229[1];
  n228r[0] = n2[0];
  n228e[0] = n1[0];
  n228d[0] = n221[0];
  n228d[1] = n221[1];
  n220r[0] = n2[0];
  n220e[0] = n1[0];
  n220d[0] = n213[0];
  n220d[1] = n213[1];
  n212r[0] = n2[0];
  n212e[0] = n1[0];
  n212d[0] = n205[0];
  n212d[1] = n205[1];
  n719r[0] = n2[0];
  n719e[0] = n1[0];
  n719d[0] = n712[0];
  n719d[1] = n712[1];
  n719d[2] = n712[2];
  n707r[0] = n2[0];
  n707e[0] = n1[0];
  n707d[0] = n700[0];
  n707d[1] = n700[1];
  n707d[2] = n700[2];
  n695r[0] = n2[0];
  n695e[0] = n1[0];
  n695d[0] = n688[0];
  n695d[1] = n688[1];
  n695d[2] = n688[2];
  n674r[0] = n2[0];
  n674e[0] = n1[0];
  n674d[0] = n667[0];
  n674d[1] = n667[1];
  n674d[2] = n667[2];
  n662r[0] = n2[0];
  n662e[0] = n1[0];
  n662d[0] = n655[0];
  n662d[1] = n655[1];
  n662d[2] = n655[2];
  n650r[0] = n2[0];
  n650e[0] = n1[0];
  n650d[0] = n643[0];
  n650d[1] = n643[1];
  n650d[2] = n643[2];
  n629r[0] = n2[0];
  n629e[0] = n1[0];
  n629d[0] = n622[0];
  n629d[1] = n622[1];
  n629d[2] = n622[2];
  n617r[0] = n2[0];
  n617e[0] = n1[0];
  n617d[0] = n610[0];
  n617d[1] = n610[1];
  n617d[2] = n610[2];
  n605r[0] = n2[0];
  n605e[0] = n1[0];
  n605d[0] = n598[0];
  n605d[1] = n598[1];
  n605d[2] = n598[2];
  n593r[0] = n2[0];
  n593e[0] = n1[0];
  n593d[0] = n586[0];
  n593d[1] = n586[1];
  n593d[2] = n586[2];
  n581r[0] = n2[0];
  n581e[0] = n1[0];
  n581d[0] = n574[0];
  n581d[1] = n574[1];
  n581d[2] = n574[2];
  n569r[0] = n2[0];
  n569e[0] = n1[0];
  n569d[0] = n562[0];
  n569d[1] = n562[1];
  n569d[2] = n562[2];
  n548r[0] = n2[0];
  n548e[0] = n1[0];
  n548d[0] = n541[0];
  n548d[1] = n541[1];
  n548d[2] = n541[2];
  n536r[0] = n2[0];
  n536e[0] = n1[0];
  n536d[0] = n529[0];
  n536d[1] = n529[1];
  n536d[2] = n529[2];
  n524r[0] = n2[0];
  n524e[0] = n1[0];
  n524d[0] = n517[0];
  n524d[1] = n517[1];
  n524d[2] = n517[2];
  n512r[0] = n2[0];
  n512e[0] = n1[0];
  n512d[0] = n505[0];
  n512d[1] = n505[1];
  n512d[2] = n505[2];
  n500r[0] = n2[0];
  n500e[0] = n1[0];
  n500d[0] = n493[0];
  n500d[1] = n493[1];
  n500d[2] = n493[2];
  n488r[0] = n2[0];
  n488e[0] = n1[0];
  n488d[0] = n481[0];
  n488d[1] = n481[1];
  n488d[2] = n481[2];
  n476r[0] = n2[0];
  n476e[0] = n1[0];
  n476d[0] = n469[0];
  n476d[1] = n469[1];
  n476d[2] = n469[2];
  n464r[0] = n2[0];
  n464e[0] = n1[0];
  n464d[0] = n457[0];
  n464d[1] = n457[1];
  n464d[2] = n457[2];
  n452r[0] = n2[0];
  n452e[0] = n1[0];
  n452d[0] = n445[0];
  n452d[1] = n445[1];
  n452d[2] = n445[2];
  n440r[0] = n2[0];
  n440e[0] = n1[0];
  n440d[0] = n433[0];
  n440d[1] = n433[1];
  n440d[2] = n433[2];
  n428r[0] = n2[0];
  n428e[0] = n1[0];
  n428d[0] = n421[0];
  n428d[1] = n421[1];
  n428d[2] = n421[2];
  n416r[0] = n2[0];
  n416e[0] = n1[0];
  n416d[0] = n409[0];
  n416d[1] = n409[1];
  n416d[2] = n409[2];
}

void cf_fir_24_8_8_init() {
  n710[0] = 0;
  n708[0] = 0;
  n698[0] = 0;
  n696[0] = 0;
  n686[0] = 0;
  n684[0] = 0;
  n675[0] = 0;
  n665[0] = 0;
  n663[0] = 0;
  n653[0] = 0;
  n651[0] = 0;
  n641[0] = 0;
  n639[0] = 0;
  n630[0] = 0;
  n620[0] = 0;
  n618[0] = 0;
  n608[0] = 0;
  n606[0] = 0;
  n596[0] = 0;
  n594[0] = 0;
  n584[0] = 0;
  n582[0] = 0;
  n572[0] = 0;
  n570[0] = 0;
  n560[0] = 0;
  n558[0] = 0;
  n549[0] = 0;
  n539[0] = 0;
  n537[0] = 0;
  n527[0] = 0;
  n525[0] = 0;
  n515[0] = 0;
  n513[0] = 0;
  n503[0] = 0;
  n501[0] = 0;
  n491[0] = 0;
  n489[0] = 0;
  n479[0] = 0;
  n477[0] = 0;
  n467[0] = 0;
  n465[0] = 0;
  n455[0] = 0;
  n453[0] = 0;
  n443[0] = 0;
  n441[0] = 0;
  n431[0] = 0;
  n429[0] = 0;
  n419[0] = 0;
  n417[0] = 0;
  n407[0] = 0;
  n405[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  { int index; for (index = 3; index > 0;) n711[--index] = 0; }
  { int index; for (index = 3; index > 0;) n709[--index] = 0; }
  { int index; for (index = 3; index > 0;) n699[--index] = 0; }
  { int index; for (index = 3; index > 0;) n697[--index] = 0; }
  { int index; for (index = 3; index > 0;) n687[--index] = 0; }
  { int index; for (index = 3; index > 0;) n685[--index] = 0; }
  { int index; for (index = 3; index > 0;) n676[--index] = 0; }
  { int index; for (index = 3; index > 0;) n666[--index] = 0; }
  { int index; for (index = 3; index > 0;) n664[--index] = 0; }
  { int index; for (index = 3; index > 0;) n654[--index] = 0; }
  { int index; for (index = 3; index > 0;) n652[--index] = 0; }
  { int index; for (index = 3; index > 0;) n642[--index] = 0; }
  { int index; for (index = 3; index > 0;) n640[--index] = 0; }
  { int index; for (index = 3; index > 0;) n631[--index] = 0; }
  { int index; for (index = 3; index > 0;) n621[--index] = 0; }
  { int index; for (index = 3; index > 0;) n619[--index] = 0; }
  { int index; for (index = 3; index > 0;) n609[--index] = 0; }
  { int index; for (index = 3; index > 0;) n607[--index] = 0; }
  { int index; for (index = 3; index > 0;) n597[--index] = 0; }
  { int index; for (index = 3; index > 0;) n595[--index] = 0; }
  { int index; for (index = 3; index > 0;) n585[--index] = 0; }
  { int index; for (index = 3; index > 0;) n583[--index] = 0; }
  { int index; for (index = 3; index > 0;) n573[--index] = 0; }
  { int index; for (index = 3; index > 0;) n571[--index] = 0; }
  { int index; for (index = 3; index > 0;) n561[--index] = 0; }
  { int index; for (index = 3; index > 0;) n559[--index] = 0; }
  { int index; for (index = 3; index > 0;) n550[--index] = 0; }
  { int index; for (index = 3; index > 0;) n540[--index] = 0; }
  { int index; for (index = 3; index > 0;) n538[--index] = 0; }
  { int index; for (index = 3; index > 0;) n528[--index] = 0; }
  { int index; for (index = 3; index > 0;) n526[--index] = 0; }
  { int index; for (index = 3; index > 0;) n516[--index] = 0; }
  { int index; for (index = 3; index > 0;) n514[--index] = 0; }
  { int index; for (index = 3; index > 0;) n504[--index] = 0; }
  { int index; for (index = 3; index > 0;) n502[--index] = 0; }
  { int index; for (index = 3; index > 0;) n492[--index] = 0; }
  { int index; for (index = 3; index > 0;) n490[--index] = 0; }
  { int index; for (index = 3; index > 0;) n480[--index] = 0; }
  { int index; for (index = 3; index > 0;) n478[--index] = 0; }
  { int index; for (index = 3; index > 0;) n468[--index] = 0; }
  { int index; for (index = 3; index > 0;) n466[--index] = 0; }
  { int index; for (index = 3; index > 0;) n456[--index] = 0; }
  { int index; for (index = 3; index > 0;) n454[--index] = 0; }
  { int index; for (index = 3; index > 0;) n444[--index] = 0; }
  { int index; for (index = 3; index > 0;) n442[--index] = 0; }
  { int index; for (index = 3; index > 0;) n432[--index] = 0; }
  { int index; for (index = 3; index > 0;) n430[--index] = 0; }
  { int index; for (index = 3; index > 0;) n420[--index] = 0; }
  { int index; for (index = 3; index > 0;) n418[--index] = 0; }
  { int index; for (index = 3; index > 0;) n408[--index] = 0; }
  { int index; for (index = 3; index > 0;) n406[--index] = 0; }
  { int index; for (index = 2; index > 0;) n397[--index] = 0; }
  { int index; for (index = 2; index > 0;) n389[--index] = 0; }
  { int index; for (index = 2; index > 0;) n381[--index] = 0; }
  { int index; for (index = 2; index > 0;) n373[--index] = 0; }
  { int index; for (index = 2; index > 0;) n365[--index] = 0; }
  { int index; for (index = 2; index > 0;) n357[--index] = 0; }
  { int index; for (index = 2; index > 0;) n349[--index] = 0; }
  { int index; for (index = 2; index > 0;) n341[--index] = 0; }
  { int index; for (index = 2; index > 0;) n333[--index] = 0; }
  { int index; for (index = 2; index > 0;) n325[--index] = 0; }
  { int index; for (index = 2; index > 0;) n317[--index] = 0; }
  { int index; for (index = 2; index > 0;) n309[--index] = 0; }
  { int index; for (index = 2; index > 0;) n301[--index] = 0; }
  { int index; for (index = 2; index > 0;) n293[--index] = 0; }
  { int index; for (index = 2; index > 0;) n285[--index] = 0; }
  { int index; for (index = 2; index > 0;) n277[--index] = 0; }
  { int index; for (index = 2; index > 0;) n269[--index] = 0; }
  { int index; for (index = 2; index > 0;) n261[--index] = 0; }
  { int index; for (index = 2; index > 0;) n253[--index] = 0; }
  { int index; for (index = 2; index > 0;) n245[--index] = 0; }
  { int index; for (index = 2; index > 0;) n237[--index] = 0; }
  { int index; for (index = 2; index > 0;) n229[--index] = 0; }
  { int index; for (index = 2; index > 0;) n221[--index] = 0; }
  { int index; for (index = 2; index > 0;) n213[--index] = 0; }
  { int index; for (index = 2; index > 0;) n205[--index] = 0; }
  n204[0] = 0;
  n204r[0] = 0;
  n204e[0] = 0;
  n204d[0] = 0;
  n197[0] = 0;
  n197r[0] = 0;
  n197e[0] = 0;
  n197d[0] = 0;
  n190[0] = 0;
  n190r[0] = 0;
  n190e[0] = 0;
  n190d[0] = 0;
  n183[0] = 0;
  n183r[0] = 0;
  n183e[0] = 0;
  n183d[0] = 0;
  n176[0] = 0;
  n176r[0] = 0;
  n176e[0] = 0;
  n176d[0] = 0;
  n169[0] = 0;
  n169r[0] = 0;
  n169e[0] = 0;
  n169d[0] = 0;
  n162[0] = 0;
  n162r[0] = 0;
  n162e[0] = 0;
  n162d[0] = 0;
  n155[0] = 0;
  n155r[0] = 0;
  n155e[0] = 0;
  n155d[0] = 0;
  n148[0] = 0;
  n148r[0] = 0;
  n148e[0] = 0;
  n148d[0] = 0;
  n141[0] = 0;
  n141r[0] = 0;
  n141e[0] = 0;
  n141d[0] = 0;
  n134[0] = 0;
  n134r[0] = 0;
  n134e[0] = 0;
  n134d[0] = 0;
  n127[0] = 0;
  n127r[0] = 0;
  n127e[0] = 0;
  n127d[0] = 0;
  n120[0] = 0;
  n120r[0] = 0;
  n120e[0] = 0;
  n120d[0] = 0;
  n113[0] = 0;
  n113r[0] = 0;
  n113e[0] = 0;
  n113d[0] = 0;
  n106[0] = 0;
  n106r[0] = 0;
  n106e[0] = 0;
  n106d[0] = 0;
  n99[0] = 0;
  n99r[0] = 0;
  n99e[0] = 0;
  n99d[0] = 0;
  n92[0] = 0;
  n92r[0] = 0;
  n92e[0] = 0;
  n92d[0] = 0;
  n85[0] = 0;
  n85r[0] = 0;
  n85e[0] = 0;
  n85d[0] = 0;
  n78[0] = 0;
  n78r[0] = 0;
  n78e[0] = 0;
  n78d[0] = 0;
  n71[0] = 0;
  n71r[0] = 0;
  n71e[0] = 0;
  n71d[0] = 0;
  n64[0] = 0;
  n64r[0] = 0;
  n64e[0] = 0;
  n64d[0] = 0;
  n57[0] = 0;
  n57r[0] = 0;
  n57e[0] = 0;
  n57d[0] = 0;
  n50[0] = 0;
  n50r[0] = 0;
  n50e[0] = 0;
  n50d[0] = 0;
  n43[0] = 0;
  n43r[0] = 0;
  n43e[0] = 0;
  n43d[0] = 0;
  n36[0] = 0;
  n36r[0] = 0;
  n36e[0] = 0;
  n36d[0] = 0;
  { int index; for (index = 3; index > 0;) n712[--index] = 0; }
  { int index; for (index = 3; index > 0;) n700[--index] = 0; }
  { int index; for (index = 3; index > 0;) n688[--index] = 0; }
  { int index; for (index = 3; index > 0;) n683[--index] = 0; }
  n683r[0] = 0;
  n683e[0] = 0;
  { int index; for (index = 3; index > 0;) n683d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n667[--index] = 0; }
  { int index; for (index = 3; index > 0;) n655[--index] = 0; }
  { int index; for (index = 3; index > 0;) n643[--index] = 0; }
  { int index; for (index = 3; index > 0;) n638[--index] = 0; }
  n638r[0] = 0;
  n638e[0] = 0;
  { int index; for (index = 3; index > 0;) n638d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n622[--index] = 0; }
  { int index; for (index = 3; index > 0;) n610[--index] = 0; }
  { int index; for (index = 3; index > 0;) n598[--index] = 0; }
  { int index; for (index = 3; index > 0;) n586[--index] = 0; }
  { int index; for (index = 3; index > 0;) n574[--index] = 0; }
  { int index; for (index = 3; index > 0;) n562[--index] = 0; }
  { int index; for (index = 3; index > 0;) n557[--index] = 0; }
  n557r[0] = 0;
  n557e[0] = 0;
  { int index; for (index = 3; index > 0;) n557d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n541[--index] = 0; }
  { int index; for (index = 3; index > 0;) n529[--index] = 0; }
  { int index; for (index = 3; index > 0;) n517[--index] = 0; }
  { int index; for (index = 3; index > 0;) n505[--index] = 0; }
  { int index; for (index = 3; index > 0;) n493[--index] = 0; }
  { int index; for (index = 3; index > 0;) n481[--index] = 0; }
  { int index; for (index = 3; index > 0;) n469[--index] = 0; }
  { int index; for (index = 3; index > 0;) n457[--index] = 0; }
  { int index; for (index = 3; index > 0;) n445[--index] = 0; }
  { int index; for (index = 3; index > 0;) n433[--index] = 0; }
  { int index; for (index = 3; index > 0;) n421[--index] = 0; }
  { int index; for (index = 3; index > 0;) n409[--index] = 0; }
  { int index; for (index = 2; index > 0;) n404[--index] = 0; }
  n404r[0] = 0;
  n404e[0] = 0;
  { int index; for (index = 2; index > 0;) n404d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n396[--index] = 0; }
  n396r[0] = 0;
  n396e[0] = 0;
  { int index; for (index = 2; index > 0;) n396d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n388[--index] = 0; }
  n388r[0] = 0;
  n388e[0] = 0;
  { int index; for (index = 2; index > 0;) n388d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n380[--index] = 0; }
  n380r[0] = 0;
  n380e[0] = 0;
  { int index; for (index = 2; index > 0;) n380d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n372[--index] = 0; }
  n372r[0] = 0;
  n372e[0] = 0;
  { int index; for (index = 2; index > 0;) n372d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n364[--index] = 0; }
  n364r[0] = 0;
  n364e[0] = 0;
  { int index; for (index = 2; index > 0;) n364d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n356[--index] = 0; }
  n356r[0] = 0;
  n356e[0] = 0;
  { int index; for (index = 2; index > 0;) n356d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n348[--index] = 0; }
  n348r[0] = 0;
  n348e[0] = 0;
  { int index; for (index = 2; index > 0;) n348d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n340[--index] = 0; }
  n340r[0] = 0;
  n340e[0] = 0;
  { int index; for (index = 2; index > 0;) n340d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n332[--index] = 0; }
  n332r[0] = 0;
  n332e[0] = 0;
  { int index; for (index = 2; index > 0;) n332d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n324[--index] = 0; }
  n324r[0] = 0;
  n324e[0] = 0;
  { int index; for (index = 2; index > 0;) n324d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n316[--index] = 0; }
  n316r[0] = 0;
  n316e[0] = 0;
  { int index; for (index = 2; index > 0;) n316d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n308[--index] = 0; }
  n308r[0] = 0;
  n308e[0] = 0;
  { int index; for (index = 2; index > 0;) n308d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n300[--index] = 0; }
  n300r[0] = 0;
  n300e[0] = 0;
  { int index; for (index = 2; index > 0;) n300d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n292[--index] = 0; }
  n292r[0] = 0;
  n292e[0] = 0;
  { int index; for (index = 2; index > 0;) n292d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n284[--index] = 0; }
  n284r[0] = 0;
  n284e[0] = 0;
  { int index; for (index = 2; index > 0;) n284d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n276[--index] = 0; }
  n276r[0] = 0;
  n276e[0] = 0;
  { int index; for (index = 2; index > 0;) n276d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n268[--index] = 0; }
  n268r[0] = 0;
  n268e[0] = 0;
  { int index; for (index = 2; index > 0;) n268d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n260[--index] = 0; }
  n260r[0] = 0;
  n260e[0] = 0;
  { int index; for (index = 2; index > 0;) n260d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n252[--index] = 0; }
  n252r[0] = 0;
  n252e[0] = 0;
  { int index; for (index = 2; index > 0;) n252d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n244[--index] = 0; }
  n244r[0] = 0;
  n244e[0] = 0;
  { int index; for (index = 2; index > 0;) n244d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n236[--index] = 0; }
  n236r[0] = 0;
  n236e[0] = 0;
  { int index; for (index = 2; index > 0;) n236d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n228[--index] = 0; }
  n228r[0] = 0;
  n228e[0] = 0;
  { int index; for (index = 2; index > 0;) n228d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n220[--index] = 0; }
  n220r[0] = 0;
  n220e[0] = 0;
  { int index; for (index = 2; index > 0;) n220d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n212[--index] = 0; }
  n212r[0] = 0;
  n212e[0] = 0;
  { int index; for (index = 2; index > 0;) n212d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n719[--index] = 0; }
  n719r[0] = 0;
  n719e[0] = 0;
  { int index; for (index = 3; index > 0;) n719d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n707[--index] = 0; }
  n707r[0] = 0;
  n707e[0] = 0;
  { int index; for (index = 3; index > 0;) n707d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n695[--index] = 0; }
  n695r[0] = 0;
  n695e[0] = 0;
  { int index; for (index = 3; index > 0;) n695d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n674[--index] = 0; }
  n674r[0] = 0;
  n674e[0] = 0;
  { int index; for (index = 3; index > 0;) n674d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n662[--index] = 0; }
  n662r[0] = 0;
  n662e[0] = 0;
  { int index; for (index = 3; index > 0;) n662d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n650[--index] = 0; }
  n650r[0] = 0;
  n650e[0] = 0;
  { int index; for (index = 3; index > 0;) n650d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n629[--index] = 0; }
  n629r[0] = 0;
  n629e[0] = 0;
  { int index; for (index = 3; index > 0;) n629d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n617[--index] = 0; }
  n617r[0] = 0;
  n617e[0] = 0;
  { int index; for (index = 3; index > 0;) n617d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n605[--index] = 0; }
  n605r[0] = 0;
  n605e[0] = 0;
  { int index; for (index = 3; index > 0;) n605d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n593[--index] = 0; }
  n593r[0] = 0;
  n593e[0] = 0;
  { int index; for (index = 3; index > 0;) n593d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n581[--index] = 0; }
  n581r[0] = 0;
  n581e[0] = 0;
  { int index; for (index = 3; index > 0;) n581d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n569[--index] = 0; }
  n569r[0] = 0;
  n569e[0] = 0;
  { int index; for (index = 3; index > 0;) n569d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n548[--index] = 0; }
  n548r[0] = 0;
  n548e[0] = 0;
  { int index; for (index = 3; index > 0;) n548d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n536[--index] = 0; }
  n536r[0] = 0;
  n536e[0] = 0;
  { int index; for (index = 3; index > 0;) n536d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n524[--index] = 0; }
  n524r[0] = 0;
  n524e[0] = 0;
  { int index; for (index = 3; index > 0;) n524d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n512[--index] = 0; }
  n512r[0] = 0;
  n512e[0] = 0;
  { int index; for (index = 3; index > 0;) n512d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n500[--index] = 0; }
  n500r[0] = 0;
  n500e[0] = 0;
  { int index; for (index = 3; index > 0;) n500d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n488[--index] = 0; }
  n488r[0] = 0;
  n488e[0] = 0;
  { int index; for (index = 3; index > 0;) n488d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n476[--index] = 0; }
  n476r[0] = 0;
  n476e[0] = 0;
  { int index; for (index = 3; index > 0;) n476d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n464[--index] = 0; }
  n464r[0] = 0;
  n464e[0] = 0;
  { int index; for (index = 3; index > 0;) n464d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n452[--index] = 0; }
  n452r[0] = 0;
  n452e[0] = 0;
  { int index; for (index = 3; index > 0;) n452d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n440[--index] = 0; }
  n440r[0] = 0;
  n440e[0] = 0;
  { int index; for (index = 3; index > 0;) n440d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n428[--index] = 0; }
  n428r[0] = 0;
  n428e[0] = 0;
  { int index; for (index = 3; index > 0;) n428d[--index] = 0; }
  { int index; for (index = 3; index > 0;) n416[--index] = 0; }
  n416r[0] = 0;
  n416e[0] = 0;
  { int index; for (index = 3; index > 0;) n416d[--index] = 0; }
  cf_fir_24_8_8_calc();
}

void cf_fir_24_8_8_cycle_clock()
{
  if (n36r[0]) {
    n36[0] = 0;
  }
  else if (n36e[0]) {
    n36[0] = n36d[0];
  }
  if (n43r[0]) {
    n43[0] = 0;
  }
  else if (n43e[0]) {
    n43[0] = n43d[0];
  }
  if (n50r[0]) {
    n50[0] = 0;
  }
  else if (n50e[0]) {
    n50[0] = n50d[0];
  }
  if (n57r[0]) {
    n57[0] = 0;
  }
  else if (n57e[0]) {
    n57[0] = n57d[0];
  }
  if (n64r[0]) {
    n64[0] = 0;
  }
  else if (n64e[0]) {
    n64[0] = n64d[0];
  }
  if (n71r[0]) {
    n71[0] = 0;
  }
  else if (n71e[0]) {
    n71[0] = n71d[0];
  }
  if (n78r[0]) {
    n78[0] = 0;
  }
  else if (n78e[0]) {
    n78[0] = n78d[0];
  }
  if (n85r[0]) {
    n85[0] = 0;
  }
  else if (n85e[0]) {
    n85[0] = n85d[0];
  }
  if (n92r[0]) {
    n92[0] = 0;
  }
  else if (n92e[0]) {
    n92[0] = n92d[0];
  }
  if (n99r[0]) {
    n99[0] = 0;
  }
  else if (n99e[0]) {
    n99[0] = n99d[0];
  }
  if (n106r[0]) {
    n106[0] = 0;
  }
  else if (n106e[0]) {
    n106[0] = n106d[0];
  }
  if (n113r[0]) {
    n113[0] = 0;
  }
  else if (n113e[0]) {
    n113[0] = n113d[0];
  }
  if (n120r[0]) {
    n120[0] = 0;
  }
  else if (n120e[0]) {
    n120[0] = n120d[0];
  }
  if (n127r[0]) {
    n127[0] = 0;
  }
  else if (n127e[0]) {
    n127[0] = n127d[0];
  }
  if (n134r[0]) {
    n134[0] = 0;
  }
  else if (n134e[0]) {
    n134[0] = n134d[0];
  }
  if (n141r[0]) {
    n141[0] = 0;
  }
  else if (n141e[0]) {
    n141[0] = n141d[0];
  }
  if (n148r[0]) {
    n148[0] = 0;
  }
  else if (n148e[0]) {
    n148[0] = n148d[0];
  }
  if (n155r[0]) {
    n155[0] = 0;
  }
  else if (n155e[0]) {
    n155[0] = n155d[0];
  }
  if (n162r[0]) {
    n162[0] = 0;
  }
  else if (n162e[0]) {
    n162[0] = n162d[0];
  }
  if (n169r[0]) {
    n169[0] = 0;
  }
  else if (n169e[0]) {
    n169[0] = n169d[0];
  }
  if (n176r[0]) {
    n176[0] = 0;
  }
  else if (n176e[0]) {
    n176[0] = n176d[0];
  }
  if (n183r[0]) {
    n183[0] = 0;
  }
  else if (n183e[0]) {
    n183[0] = n183d[0];
  }
  if (n190r[0]) {
    n190[0] = 0;
  }
  else if (n190e[0]) {
    n190[0] = n190d[0];
  }
  if (n197r[0]) {
    n197[0] = 0;
  }
  else if (n197e[0]) {
    n197[0] = n197d[0];
  }
  if (n204r[0]) {
    n204[0] = 0;
  }
  else if (n204e[0]) {
    n204[0] = n204d[0];
  }
  if (n212r[0]) {
    n212[0] = 0;
    n212[1] = 0;
  }
  else if (n212e[0]) {
    n212[0] = n212d[0];
    n212[1] = n212d[1];
  }
  if (n220r[0]) {
    n220[0] = 0;
    n220[1] = 0;
  }
  else if (n220e[0]) {
    n220[0] = n220d[0];
    n220[1] = n220d[1];
  }
  if (n228r[0]) {
    n228[0] = 0;
    n228[1] = 0;
  }
  else if (n228e[0]) {
    n228[0] = n228d[0];
    n228[1] = n228d[1];
  }
  if (n236r[0]) {
    n236[0] = 0;
    n236[1] = 0;
  }
  else if (n236e[0]) {
    n236[0] = n236d[0];
    n236[1] = n236d[1];
  }
  if (n244r[0]) {
    n244[0] = 0;
    n244[1] = 0;
  }
  else if (n244e[0]) {
    n244[0] = n244d[0];
    n244[1] = n244d[1];
  }
  if (n252r[0]) {
    n252[0] = 0;
    n252[1] = 0;
  }
  else if (n252e[0]) {
    n252[0] = n252d[0];
    n252[1] = n252d[1];
  }
  if (n260r[0]) {
    n260[0] = 0;
    n260[1] = 0;
  }
  else if (n260e[0]) {
    n260[0] = n260d[0];
    n260[1] = n260d[1];
  }
  if (n268r[0]) {
    n268[0] = 0;
    n268[1] = 0;
  }
  else if (n268e[0]) {
    n268[0] = n268d[0];
    n268[1] = n268d[1];
  }
  if (n276r[0]) {
    n276[0] = 0;
    n276[1] = 0;
  }
  else if (n276e[0]) {
    n276[0] = n276d[0];
    n276[1] = n276d[1];
  }
  if (n284r[0]) {
    n284[0] = 0;
    n284[1] = 0;
  }
  else if (n284e[0]) {
    n284[0] = n284d[0];
    n284[1] = n284d[1];
  }
  if (n292r[0]) {
    n292[0] = 0;
    n292[1] = 0;
  }
  else if (n292e[0]) {
    n292[0] = n292d[0];
    n292[1] = n292d[1];
  }
  if (n300r[0]) {
    n300[0] = 0;
    n300[1] = 0;
  }
  else if (n300e[0]) {
    n300[0] = n300d[0];
    n300[1] = n300d[1];
  }
  if (n308r[0]) {
    n308[0] = 0;
    n308[1] = 0;
  }
  else if (n308e[0]) {
    n308[0] = n308d[0];
    n308[1] = n308d[1];
  }
  if (n316r[0]) {
    n316[0] = 0;
    n316[1] = 0;
  }
  else if (n316e[0]) {
    n316[0] = n316d[0];
    n316[1] = n316d[1];
  }
  if (n324r[0]) {
    n324[0] = 0;
    n324[1] = 0;
  }
  else if (n324e[0]) {
    n324[0] = n324d[0];
    n324[1] = n324d[1];
  }
  if (n332r[0]) {
    n332[0] = 0;
    n332[1] = 0;
  }
  else if (n332e[0]) {
    n332[0] = n332d[0];
    n332[1] = n332d[1];
  }
  if (n340r[0]) {
    n340[0] = 0;
    n340[1] = 0;
  }
  else if (n340e[0]) {
    n340[0] = n340d[0];
    n340[1] = n340d[1];
  }
  if (n348r[0]) {
    n348[0] = 0;
    n348[1] = 0;
  }
  else if (n348e[0]) {
    n348[0] = n348d[0];
    n348[1] = n348d[1];
  }
  if (n356r[0]) {
    n356[0] = 0;
    n356[1] = 0;
  }
  else if (n356e[0]) {
    n356[0] = n356d[0];
    n356[1] = n356d[1];
  }
  if (n364r[0]) {
    n364[0] = 0;
    n364[1] = 0;
  }
  else if (n364e[0]) {
    n364[0] = n364d[0];
    n364[1] = n364d[1];
  }
  if (n372r[0]) {
    n372[0] = 0;
    n372[1] = 0;
  }
  else if (n372e[0]) {
    n372[0] = n372d[0];
    n372[1] = n372d[1];
  }
  if (n380r[0]) {
    n380[0] = 0;
    n380[1] = 0;
  }
  else if (n380e[0]) {
    n380[0] = n380d[0];
    n380[1] = n380d[1];
  }
  if (n388r[0]) {
    n388[0] = 0;
    n388[1] = 0;
  }
  else if (n388e[0]) {
    n388[0] = n388d[0];
    n388[1] = n388d[1];
  }
  if (n396r[0]) {
    n396[0] = 0;
    n396[1] = 0;
  }
  else if (n396e[0]) {
    n396[0] = n396d[0];
    n396[1] = n396d[1];
  }
  if (n404r[0]) {
    n404[0] = 0;
    n404[1] = 0;
  }
  else if (n404e[0]) {
    n404[0] = n404d[0];
    n404[1] = n404d[1];
  }
  if (n416r[0]) {
    n416[0] = 0;
    n416[1] = 0;
    n416[2] = 0;
  }
  else if (n416e[0]) {
    n416[0] = n416d[0];
    n416[1] = n416d[1];
    n416[2] = n416d[2];
  }
  if (n428r[0]) {
    n428[0] = 0;
    n428[1] = 0;
    n428[2] = 0;
  }
  else if (n428e[0]) {
    n428[0] = n428d[0];
    n428[1] = n428d[1];
    n428[2] = n428d[2];
  }
  if (n440r[0]) {
    n440[0] = 0;
    n440[1] = 0;
    n440[2] = 0;
  }
  else if (n440e[0]) {
    n440[0] = n440d[0];
    n440[1] = n440d[1];
    n440[2] = n440d[2];
  }
  if (n452r[0]) {
    n452[0] = 0;
    n452[1] = 0;
    n452[2] = 0;
  }
  else if (n452e[0]) {
    n452[0] = n452d[0];
    n452[1] = n452d[1];
    n452[2] = n452d[2];
  }
  if (n464r[0]) {
    n464[0] = 0;
    n464[1] = 0;
    n464[2] = 0;
  }
  else if (n464e[0]) {
    n464[0] = n464d[0];
    n464[1] = n464d[1];
    n464[2] = n464d[2];
  }
  if (n476r[0]) {
    n476[0] = 0;
    n476[1] = 0;
    n476[2] = 0;
  }
  else if (n476e[0]) {
    n476[0] = n476d[0];
    n476[1] = n476d[1];
    n476[2] = n476d[2];
  }
  if (n488r[0]) {
    n488[0] = 0;
    n488[1] = 0;
    n488[2] = 0;
  }
  else if (n488e[0]) {
    n488[0] = n488d[0];
    n488[1] = n488d[1];
    n488[2] = n488d[2];
  }
  if (n500r[0]) {
    n500[0] = 0;
    n500[1] = 0;
    n500[2] = 0;
  }
  else if (n500e[0]) {
    n500[0] = n500d[0];
    n500[1] = n500d[1];
    n500[2] = n500d[2];
  }
  if (n512r[0]) {
    n512[0] = 0;
    n512[1] = 0;
    n512[2] = 0;
  }
  else if (n512e[0]) {
    n512[0] = n512d[0];
    n512[1] = n512d[1];
    n512[2] = n512d[2];
  }
  if (n524r[0]) {
    n524[0] = 0;
    n524[1] = 0;
    n524[2] = 0;
  }
  else if (n524e[0]) {
    n524[0] = n524d[0];
    n524[1] = n524d[1];
    n524[2] = n524d[2];
  }
  if (n536r[0]) {
    n536[0] = 0;
    n536[1] = 0;
    n536[2] = 0;
  }
  else if (n536e[0]) {
    n536[0] = n536d[0];
    n536[1] = n536d[1];
    n536[2] = n536d[2];
  }
  if (n548r[0]) {
    n548[0] = 0;
    n548[1] = 0;
    n548[2] = 0;
  }
  else if (n548e[0]) {
    n548[0] = n548d[0];
    n548[1] = n548d[1];
    n548[2] = n548d[2];
  }
  if (n557r[0]) {
    n557[0] = 0;
    n557[1] = 0;
    n557[2] = 0;
  }
  else if (n557e[0]) {
    n557[0] = n557d[0];
    n557[1] = n557d[1];
    n557[2] = n557d[2];
  }
  if (n569r[0]) {
    n569[0] = 0;
    n569[1] = 0;
    n569[2] = 0;
  }
  else if (n569e[0]) {
    n569[0] = n569d[0];
    n569[1] = n569d[1];
    n569[2] = n569d[2];
  }
  if (n581r[0]) {
    n581[0] = 0;
    n581[1] = 0;
    n581[2] = 0;
  }
  else if (n581e[0]) {
    n581[0] = n581d[0];
    n581[1] = n581d[1];
    n581[2] = n581d[2];
  }
  if (n593r[0]) {
    n593[0] = 0;
    n593[1] = 0;
    n593[2] = 0;
  }
  else if (n593e[0]) {
    n593[0] = n593d[0];
    n593[1] = n593d[1];
    n593[2] = n593d[2];
  }
  if (n605r[0]) {
    n605[0] = 0;
    n605[1] = 0;
    n605[2] = 0;
  }
  else if (n605e[0]) {
    n605[0] = n605d[0];
    n605[1] = n605d[1];
    n605[2] = n605d[2];
  }
  if (n617r[0]) {
    n617[0] = 0;
    n617[1] = 0;
    n617[2] = 0;
  }
  else if (n617e[0]) {
    n617[0] = n617d[0];
    n617[1] = n617d[1];
    n617[2] = n617d[2];
  }
  if (n629r[0]) {
    n629[0] = 0;
    n629[1] = 0;
    n629[2] = 0;
  }
  else if (n629e[0]) {
    n629[0] = n629d[0];
    n629[1] = n629d[1];
    n629[2] = n629d[2];
  }
  if (n638r[0]) {
    n638[0] = 0;
    n638[1] = 0;
    n638[2] = 0;
  }
  else if (n638e[0]) {
    n638[0] = n638d[0];
    n638[1] = n638d[1];
    n638[2] = n638d[2];
  }
  if (n650r[0]) {
    n650[0] = 0;
    n650[1] = 0;
    n650[2] = 0;
  }
  else if (n650e[0]) {
    n650[0] = n650d[0];
    n650[1] = n650d[1];
    n650[2] = n650d[2];
  }
  if (n662r[0]) {
    n662[0] = 0;
    n662[1] = 0;
    n662[2] = 0;
  }
  else if (n662e[0]) {
    n662[0] = n662d[0];
    n662[1] = n662d[1];
    n662[2] = n662d[2];
  }
  if (n674r[0]) {
    n674[0] = 0;
    n674[1] = 0;
    n674[2] = 0;
  }
  else if (n674e[0]) {
    n674[0] = n674d[0];
    n674[1] = n674d[1];
    n674[2] = n674d[2];
  }
  if (n683r[0]) {
    n683[0] = 0;
    n683[1] = 0;
    n683[2] = 0;
  }
  else if (n683e[0]) {
    n683[0] = n683d[0];
    n683[1] = n683d[1];
    n683[2] = n683d[2];
  }
  if (n695r[0]) {
    n695[0] = 0;
    n695[1] = 0;
    n695[2] = 0;
  }
  else if (n695e[0]) {
    n695[0] = n695d[0];
    n695[1] = n695d[1];
    n695[2] = n695d[2];
  }
  if (n707r[0]) {
    n707[0] = 0;
    n707[1] = 0;
    n707[2] = 0;
  }
  else if (n707e[0]) {
    n707[0] = n707d[0];
    n707[1] = n707d[1];
    n707[2] = n707d[2];
  }
  if (n719r[0]) {
    n719[0] = 0;
    n719[1] = 0;
    n719[2] = 0;
  }
  else if (n719e[0]) {
    n719[0] = n719d[0];
    n719[1] = n719d[1];
    n719[2] = n719d[2];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_i[1];
static unsigned char sim_data_i[1];
static unsigned char sim_k0_i[1];
static unsigned char sim_k1_i[1];
static unsigned char sim_k2_i[1];
static unsigned char sim_k3_i[1];
static unsigned char sim_k4_i[1];
static unsigned char sim_k5_i[1];
static unsigned char sim_k6_i[1];
static unsigned char sim_k7_i[1];
static unsigned char sim_k8_i[1];
static unsigned char sim_k9_i[1];
static unsigned char sim_k10_i[1];
static unsigned char sim_k11_i[1];
static unsigned char sim_k12_i[1];
static unsigned char sim_k13_i[1];
static unsigned char sim_k14_i[1];
static unsigned char sim_k15_i[1];
static unsigned char sim_k16_i[1];
static unsigned char sim_k17_i[1];
static unsigned char sim_k18_i[1];
static unsigned char sim_k19_i[1];
static unsigned char sim_k20_i[1];
static unsigned char sim_k21_i[1];
static unsigned char sim_k22_i[1];
static unsigned char sim_k23_i[1];
static unsigned char sim_k24_i[1];
static unsigned char sim_data_o[3];

void cf_fir_24_8_8_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_fir_24_8_8_init();
  sim_reset_i[0] = reset_i[0];
  sim_data_i[0] = data_i[0];
  sim_k0_i[0] = k0_i[0];
  sim_k1_i[0] = k1_i[0];
  sim_k2_i[0] = k2_i[0];
  sim_k3_i[0] = k3_i[0];
  sim_k4_i[0] = k4_i[0];
  sim_k5_i[0] = k5_i[0];
  sim_k6_i[0] = k6_i[0];
  sim_k7_i[0] = k7_i[0];
  sim_k8_i[0] = k8_i[0];
  sim_k9_i[0] = k9_i[0];
  sim_k10_i[0] = k10_i[0];
  sim_k11_i[0] = k11_i[0];
  sim_k12_i[0] = k12_i[0];
  sim_k13_i[0] = k13_i[0];
  sim_k14_i[0] = k14_i[0];
  sim_k15_i[0] = k15_i[0];
  sim_k16_i[0] = k16_i[0];
  sim_k17_i[0] = k17_i[0];
  sim_k18_i[0] = k18_i[0];
  sim_k19_i[0] = k19_i[0];
  sim_k20_i[0] = k20_i[0];
  sim_k21_i[0] = k21_i[0];
  sim_k22_i[0] = k22_i[0];
  sim_k23_i[0] = k23_i[0];
  sim_k24_i[0] = k24_i[0];
  sim_data_o[0] = data_o[0];
  sim_data_o[1] = data_o[1];
  sim_data_o[2] = data_o[2];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_fir_24_8_8 $end\n"
    "$var wire 1 ! reset_i $end\n"
    "$var wire 8 \" data_i $end\n"
    "$var wire 8 # k0_i $end\n"
    "$var wire 8 $ k1_i $end\n"
    "$var wire 8 %% k2_i $end\n"
    "$var wire 8 & k3_i $end\n"
    "$var wire 8 ' k4_i $end\n"
    "$var wire 8 ( k5_i $end\n"
    "$var wire 8 ) k6_i $end\n"
    "$var wire 8 * k7_i $end\n"
    "$var wire 8 + k8_i $end\n"
    "$var wire 8 , k9_i $end\n"
    "$var wire 8 - k10_i $end\n"
    "$var wire 8 . k11_i $end\n"
    "$var wire 8 / k12_i $end\n"
    "$var wire 8 0 k13_i $end\n"
    "$var wire 8 1 k14_i $end\n"
    "$var wire 8 2 k15_i $end\n"
    "$var wire 8 3 k16_i $end\n"
    "$var wire 8 4 k17_i $end\n"
    "$var wire 8 5 k18_i $end\n"
    "$var wire 8 6 k19_i $end\n"
    "$var wire 8 7 k20_i $end\n"
    "$var wire 8 8 k21_i $end\n"
    "$var wire 8 9 k22_i $end\n"
    "$var wire 8 : k23_i $end\n"
    "$var wire 8 ; k24_i $end\n"
    "$var wire 21 < data_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
        else if (bit & data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " \"\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
        else if (bit & k0_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
        else if (bit & k1_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
        else if (bit & k2_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
        else if (bit & k3_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
        else if (bit & k4_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
        else if (bit & k5_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
        else if (bit & k6_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
        else if (bit & k7_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
        else if (bit & k8_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
        else if (bit & k9_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
        else if (bit & k10_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
        else if (bit & k11_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
        else if (bit & k12_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k13_i[byte]) ? "1" : "0");
        else if (bit & k13_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k14_i[byte]) ? "1" : "0");
        else if (bit & k14_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 1\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k15_i[byte]) ? "1" : "0");
        else if (bit & k15_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 2\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k16_i[byte]) ? "1" : "0");
        else if (bit & k16_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 3\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k17_i[byte]) ? "1" : "0");
        else if (bit & k17_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 4\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k18_i[byte]) ? "1" : "0");
        else if (bit & k18_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 5\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k19_i[byte]) ? "1" : "0");
        else if (bit & k19_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 6\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k20_i[byte]) ? "1" : "0");
        else if (bit & k20_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 7\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k21_i[byte]) ? "1" : "0");
        else if (bit & k21_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 8\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k22_i[byte]) ? "1" : "0");
        else if (bit & k22_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 9\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k23_i[byte]) ? "1" : "0");
        else if (bit & k23_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " :\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k24_i[byte]) ? "1" : "0");
        else if (bit & k24_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ;\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 2; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
        else if (bit & data_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " <\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_fir_24_8_8_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_fir_24_8_8_sim_sample() {
  int changed = 0;
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_data_i[0] != data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
          else if (bit & data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " \"\n");
    }
    sim_data_i[0] = data_i[0];
  }
  if (sim_k0_i[0] != k0_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
          else if (bit & k0_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_k0_i[0] = k0_i[0];
  }
  if (sim_k1_i[0] != k1_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
          else if (bit & k1_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_k1_i[0] = k1_i[0];
  }
  if (sim_k2_i[0] != k2_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
          else if (bit & k2_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_k2_i[0] = k2_i[0];
  }
  if (sim_k3_i[0] != k3_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
          else if (bit & k3_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_k3_i[0] = k3_i[0];
  }
  if (sim_k4_i[0] != k4_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
          else if (bit & k4_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_k4_i[0] = k4_i[0];
  }
  if (sim_k5_i[0] != k5_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
          else if (bit & k5_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_k5_i[0] = k5_i[0];
  }
  if (sim_k6_i[0] != k6_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
          else if (bit & k6_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_k6_i[0] = k6_i[0];
  }
  if (sim_k7_i[0] != k7_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
          else if (bit & k7_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_k7_i[0] = k7_i[0];
  }
  if (sim_k8_i[0] != k8_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
          else if (bit & k8_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_k8_i[0] = k8_i[0];
  }
  if (sim_k9_i[0] != k9_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
          else if (bit & k9_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_k9_i[0] = k9_i[0];
  }
  if (sim_k10_i[0] != k10_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
          else if (bit & k10_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_k10_i[0] = k10_i[0];
  }
  if (sim_k11_i[0] != k11_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
          else if (bit & k11_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_k11_i[0] = k11_i[0];
  }
  if (sim_k12_i[0] != k12_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
          else if (bit & k12_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_k12_i[0] = k12_i[0];
  }
  if (sim_k13_i[0] != k13_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k13_i[byte]) ? "1" : "0");
          else if (bit & k13_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_k13_i[0] = k13_i[0];
  }
  if (sim_k14_i[0] != k14_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k14_i[byte]) ? "1" : "0");
          else if (bit & k14_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 1\n");
    }
    sim_k14_i[0] = k14_i[0];
  }
  if (sim_k15_i[0] != k15_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k15_i[byte]) ? "1" : "0");
          else if (bit & k15_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 2\n");
    }
    sim_k15_i[0] = k15_i[0];
  }
  if (sim_k16_i[0] != k16_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k16_i[byte]) ? "1" : "0");
          else if (bit & k16_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 3\n");
    }
    sim_k16_i[0] = k16_i[0];
  }
  if (sim_k17_i[0] != k17_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k17_i[byte]) ? "1" : "0");
          else if (bit & k17_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 4\n");
    }
    sim_k17_i[0] = k17_i[0];
  }
  if (sim_k18_i[0] != k18_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k18_i[byte]) ? "1" : "0");
          else if (bit & k18_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 5\n");
    }
    sim_k18_i[0] = k18_i[0];
  }
  if (sim_k19_i[0] != k19_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k19_i[byte]) ? "1" : "0");
          else if (bit & k19_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 6\n");
    }
    sim_k19_i[0] = k19_i[0];
  }
  if (sim_k20_i[0] != k20_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k20_i[byte]) ? "1" : "0");
          else if (bit & k20_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 7\n");
    }
    sim_k20_i[0] = k20_i[0];
  }
  if (sim_k21_i[0] != k21_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k21_i[byte]) ? "1" : "0");
          else if (bit & k21_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 8\n");
    }
    sim_k21_i[0] = k21_i[0];
  }
  if (sim_k22_i[0] != k22_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k22_i[byte]) ? "1" : "0");
          else if (bit & k22_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 9\n");
    }
    sim_k22_i[0] = k22_i[0];
  }
  if (sim_k23_i[0] != k23_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k23_i[byte]) ? "1" : "0");
          else if (bit & k23_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " :\n");
    }
    sim_k23_i[0] = k23_i[0];
  }
  if (sim_k24_i[0] != k24_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k24_i[byte]) ? "1" : "0");
          else if (bit & k24_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ;\n");
    }
    sim_k24_i[0] = k24_i[0];
  }
  if (sim_data_o[2] != data_o[2] || sim_data_o[1] != data_o[1] || sim_data_o[0] != data_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 2; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
          else if (bit & data_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " <\n");
    }
    sim_data_o[0] = data_o[0];
    sim_data_o[1] = data_o[1];
    sim_data_o[2] = data_o[2];
  }
  sim_count++;
}

