//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs finite impulse response (FIR) filtering.
//    The filter's sum of products is pipelined with a register after
//    every multiplier and adder.  The adder network is a balanced binary
//    tree to minimize latency.  The sum of products has no numeric loss because the
//    multipliers keep all resulting bits and each adder extends the precision by 1.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
//  
//    Inputs:
//      data_i  : Input data.
//      k0_i    : Coefficient 0 multiplied by in_i(0).
//      k1_i    : Coefficient 1 multiplied by in_i(k-1).
//      k2_i    : Coefficient 2 multiplied by in_i(k-2).
//      ...
//      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
//  
//    Outputs:
//      data_o : Output data.
//  
//  Built In Parameters:
//  
//    Filter Order             = 24
//    Input Precision          = 8
//    Coefficient Precision    = 8
//    Sum of Products Latency  = 6
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:45:54 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fir_24_8_8
//    Clock Domains : clock_c  
//    Vector Input  : reset_i(1)
//    Vector Input  : data_i(8)
//    Vector Input  : k0_i(8)
//    Vector Input  : k1_i(8)
//    Vector Input  : k2_i(8)
//    Vector Input  : k3_i(8)
//    Vector Input  : k4_i(8)
//    Vector Input  : k5_i(8)
//    Vector Input  : k6_i(8)
//    Vector Input  : k7_i(8)
//    Vector Input  : k8_i(8)
//    Vector Input  : k9_i(8)
//    Vector Input  : k10_i(8)
//    Vector Input  : k11_i(8)
//    Vector Input  : k12_i(8)
//    Vector Input  : k13_i(8)
//    Vector Input  : k14_i(8)
//    Vector Input  : k15_i(8)
//    Vector Input  : k16_i(8)
//    Vector Input  : k17_i(8)
//    Vector Input  : k18_i(8)
//    Vector Input  : k19_i(8)
//    Vector Input  : k20_i(8)
//    Vector Input  : k21_i(8)
//    Vector Input  : k22_i(8)
//    Vector Input  : k23_i(8)
//    Vector Input  : k24_i(8)
//    Vector Output : data_o(21)
//  
//  
//  

#ifdef __cplusplus
extern "C" {
#endif

void cf_fir_24_8_8_ports(unsigned char* port_reset_i, unsigned char* port_data_i, unsigned char* port_k0_i, unsigned char* port_k1_i, unsigned char* port_k2_i, unsigned char* port_k3_i, unsigned char* port_k4_i, unsigned char* port_k5_i, unsigned char* port_k6_i, unsigned char* port_k7_i, unsigned char* port_k8_i, unsigned char* port_k9_i, unsigned char* port_k10_i, unsigned char* port_k11_i, unsigned char* port_k12_i, unsigned char* port_k13_i, unsigned char* port_k14_i, unsigned char* port_k15_i, unsigned char* port_k16_i, unsigned char* port_k17_i, unsigned char* port_k18_i, unsigned char* port_k19_i, unsigned char* port_k20_i, unsigned char* port_k21_i, unsigned char* port_k22_i, unsigned char* port_k23_i, unsigned char* port_k24_i, unsigned char* port_data_o);
void cf_fir_24_8_8_init();
void cf_fir_24_8_8_calc();
void cf_fir_24_8_8_cycle_clock();
void cf_fir_24_8_8_sim_init(const char* file);
void cf_fir_24_8_8_sim_end();
void cf_fir_24_8_8_sim_sample();

#ifdef __cplusplus
}
#endif

