#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs finite impulse response (FIR) filtering.
#    The filter's sum of products is pipelined with a register after
#    every multiplier and adder.  The adder network is a balanced binary
#    tree to minimize latency.  The sum of products has no numeric loss because the
#    multipliers keep all resulting bits and each adder extends the precision by 1.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
#  
#    Inputs:
#      data_i  : Input data.
#      k0_i    : Coefficient 0 multiplied by in_i(0).
#      k1_i    : Coefficient 1 multiplied by in_i(k-1).
#      k2_i    : Coefficient 2 multiplied by in_i(k-2).
#      ...
#      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
#  
#    Outputs:
#      data_o : Output data.
#  
#  Built In Parameters:
#  
#    Filter Order             = 24
#    Input Precision          = 8
#    Coefficient Precision    = 8
#    Sum of Products Latency  = 6
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:45:55 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fir_24_8_8
#    Clock Domains : clock_c  
#    Vector Input  : reset_i(1)
#    Vector Input  : data_i(8)
#    Vector Input  : k0_i(8)
#    Vector Input  : k1_i(8)
#    Vector Input  : k2_i(8)
#    Vector Input  : k3_i(8)
#    Vector Input  : k4_i(8)
#    Vector Input  : k5_i(8)
#    Vector Input  : k6_i(8)
#    Vector Input  : k7_i(8)
#    Vector Input  : k8_i(8)
#    Vector Input  : k9_i(8)
#    Vector Input  : k10_i(8)
#    Vector Input  : k11_i(8)
#    Vector Input  : k12_i(8)
#    Vector Input  : k13_i(8)
#    Vector Input  : k14_i(8)
#    Vector Input  : k15_i(8)
#    Vector Input  : k16_i(8)
#    Vector Input  : k17_i(8)
#    Vector Input  : k18_i(8)
#    Vector Input  : k19_i(8)
#    Vector Input  : k20_i(8)
#    Vector Input  : k21_i(8)
#    Vector Input  : k22_i(8)
#    Vector Input  : k23_i(8)
#    Vector Input  : k24_i(8)
#    Vector Output : data_o(21)
#  
#  
#  

import sys
import time

class cf_fir_24_8_8:

  def init(self):
    self.n720 = 0L
    self.n710 = 0L
    self.n708 = 0L
    self.n698 = 0L
    self.n696 = 0L
    self.n686 = 0L
    self.n684 = 0L
    self.n675 = 0L
    self.n665 = 0L
    self.n663 = 0L
    self.n653 = 0L
    self.n651 = 0L
    self.n641 = 0L
    self.n639 = 0L
    self.n630 = 0L
    self.n620 = 0L
    self.n618 = 0L
    self.n608 = 0L
    self.n606 = 0L
    self.n596 = 0L
    self.n594 = 0L
    self.n584 = 0L
    self.n582 = 0L
    self.n572 = 0L
    self.n570 = 0L
    self.n560 = 0L
    self.n558 = 0L
    self.n549 = 0L
    self.n539 = 0L
    self.n537 = 0L
    self.n527 = 0L
    self.n525 = 0L
    self.n515 = 0L
    self.n513 = 0L
    self.n503 = 0L
    self.n501 = 0L
    self.n491 = 0L
    self.n489 = 0L
    self.n479 = 0L
    self.n477 = 0L
    self.n467 = 0L
    self.n465 = 0L
    self.n455 = 0L
    self.n453 = 0L
    self.n443 = 0L
    self.n441 = 0L
    self.n431 = 0L
    self.n429 = 0L
    self.n419 = 0L
    self.n417 = 0L
    self.n407 = 0L
    self.n405 = 0L
    self.n29 = 0L
    self.n28 = 0L
    self.n27 = 0L
    self.n26 = 0L
    self.n25 = 0L
    self.n24 = 0L
    self.n23 = 0L
    self.n22 = 0L
    self.n21 = 0L
    self.n20 = 0L
    self.n19 = 0L
    self.n18 = 0L
    self.n17 = 0L
    self.n16 = 0L
    self.n15 = 0L
    self.n14 = 0L
    self.n13 = 0L
    self.n12 = 0L
    self.n11 = 0L
    self.n10 = 0L
    self.n9 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n711 = 0L
    self.n709 = 0L
    self.n699 = 0L
    self.n697 = 0L
    self.n687 = 0L
    self.n685 = 0L
    self.n676 = 0L
    self.n666 = 0L
    self.n664 = 0L
    self.n654 = 0L
    self.n652 = 0L
    self.n642 = 0L
    self.n640 = 0L
    self.n631 = 0L
    self.n621 = 0L
    self.n619 = 0L
    self.n609 = 0L
    self.n607 = 0L
    self.n597 = 0L
    self.n595 = 0L
    self.n585 = 0L
    self.n583 = 0L
    self.n573 = 0L
    self.n571 = 0L
    self.n561 = 0L
    self.n559 = 0L
    self.n550 = 0L
    self.n540 = 0L
    self.n538 = 0L
    self.n528 = 0L
    self.n526 = 0L
    self.n516 = 0L
    self.n514 = 0L
    self.n504 = 0L
    self.n502 = 0L
    self.n492 = 0L
    self.n490 = 0L
    self.n480 = 0L
    self.n478 = 0L
    self.n468 = 0L
    self.n466 = 0L
    self.n456 = 0L
    self.n454 = 0L
    self.n444 = 0L
    self.n442 = 0L
    self.n432 = 0L
    self.n430 = 0L
    self.n420 = 0L
    self.n418 = 0L
    self.n408 = 0L
    self.n406 = 0L
    self.n397 = 0L
    self.n389 = 0L
    self.n381 = 0L
    self.n373 = 0L
    self.n365 = 0L
    self.n357 = 0L
    self.n349 = 0L
    self.n341 = 0L
    self.n333 = 0L
    self.n325 = 0L
    self.n317 = 0L
    self.n309 = 0L
    self.n301 = 0L
    self.n293 = 0L
    self.n285 = 0L
    self.n277 = 0L
    self.n269 = 0L
    self.n261 = 0L
    self.n253 = 0L
    self.n245 = 0L
    self.n237 = 0L
    self.n229 = 0L
    self.n221 = 0L
    self.n213 = 0L
    self.n205 = 0L
    self.n204 = 0L
    self.n204r = 0L
    self.n204e = 0L
    self.n204d = 0L
    self.n197 = 0L
    self.n197r = 0L
    self.n197e = 0L
    self.n197d = 0L
    self.n190 = 0L
    self.n190r = 0L
    self.n190e = 0L
    self.n190d = 0L
    self.n183 = 0L
    self.n183r = 0L
    self.n183e = 0L
    self.n183d = 0L
    self.n176 = 0L
    self.n176r = 0L
    self.n176e = 0L
    self.n176d = 0L
    self.n169 = 0L
    self.n169r = 0L
    self.n169e = 0L
    self.n169d = 0L
    self.n162 = 0L
    self.n162r = 0L
    self.n162e = 0L
    self.n162d = 0L
    self.n155 = 0L
    self.n155r = 0L
    self.n155e = 0L
    self.n155d = 0L
    self.n148 = 0L
    self.n148r = 0L
    self.n148e = 0L
    self.n148d = 0L
    self.n141 = 0L
    self.n141r = 0L
    self.n141e = 0L
    self.n141d = 0L
    self.n134 = 0L
    self.n134r = 0L
    self.n134e = 0L
    self.n134d = 0L
    self.n127 = 0L
    self.n127r = 0L
    self.n127e = 0L
    self.n127d = 0L
    self.n120 = 0L
    self.n120r = 0L
    self.n120e = 0L
    self.n120d = 0L
    self.n113 = 0L
    self.n113r = 0L
    self.n113e = 0L
    self.n113d = 0L
    self.n106 = 0L
    self.n106r = 0L
    self.n106e = 0L
    self.n106d = 0L
    self.n99 = 0L
    self.n99r = 0L
    self.n99e = 0L
    self.n99d = 0L
    self.n92 = 0L
    self.n92r = 0L
    self.n92e = 0L
    self.n92d = 0L
    self.n85 = 0L
    self.n85r = 0L
    self.n85e = 0L
    self.n85d = 0L
    self.n78 = 0L
    self.n78r = 0L
    self.n78e = 0L
    self.n78d = 0L
    self.n71 = 0L
    self.n71r = 0L
    self.n71e = 0L
    self.n71d = 0L
    self.n64 = 0L
    self.n64r = 0L
    self.n64e = 0L
    self.n64d = 0L
    self.n57 = 0L
    self.n57r = 0L
    self.n57e = 0L
    self.n57d = 0L
    self.n50 = 0L
    self.n50r = 0L
    self.n50e = 0L
    self.n50d = 0L
    self.n43 = 0L
    self.n43r = 0L
    self.n43e = 0L
    self.n43d = 0L
    self.n36 = 0L
    self.n36r = 0L
    self.n36e = 0L
    self.n36d = 0L
    self.n712 = 0L
    self.n700 = 0L
    self.n688 = 0L
    self.n683 = 0L
    self.n683r = 0L
    self.n683e = 0L
    self.n683d = 0L
    self.n667 = 0L
    self.n655 = 0L
    self.n643 = 0L
    self.n638 = 0L
    self.n638r = 0L
    self.n638e = 0L
    self.n638d = 0L
    self.n622 = 0L
    self.n610 = 0L
    self.n598 = 0L
    self.n586 = 0L
    self.n574 = 0L
    self.n562 = 0L
    self.n557 = 0L
    self.n557r = 0L
    self.n557e = 0L
    self.n557d = 0L
    self.n541 = 0L
    self.n529 = 0L
    self.n517 = 0L
    self.n505 = 0L
    self.n493 = 0L
    self.n481 = 0L
    self.n469 = 0L
    self.n457 = 0L
    self.n445 = 0L
    self.n433 = 0L
    self.n421 = 0L
    self.n409 = 0L
    self.n404 = 0L
    self.n404r = 0L
    self.n404e = 0L
    self.n404d = 0L
    self.n396 = 0L
    self.n396r = 0L
    self.n396e = 0L
    self.n396d = 0L
    self.n388 = 0L
    self.n388r = 0L
    self.n388e = 0L
    self.n388d = 0L
    self.n380 = 0L
    self.n380r = 0L
    self.n380e = 0L
    self.n380d = 0L
    self.n372 = 0L
    self.n372r = 0L
    self.n372e = 0L
    self.n372d = 0L
    self.n364 = 0L
    self.n364r = 0L
    self.n364e = 0L
    self.n364d = 0L
    self.n356 = 0L
    self.n356r = 0L
    self.n356e = 0L
    self.n356d = 0L
    self.n348 = 0L
    self.n348r = 0L
    self.n348e = 0L
    self.n348d = 0L
    self.n340 = 0L
    self.n340r = 0L
    self.n340e = 0L
    self.n340d = 0L
    self.n332 = 0L
    self.n332r = 0L
    self.n332e = 0L
    self.n332d = 0L
    self.n324 = 0L
    self.n324r = 0L
    self.n324e = 0L
    self.n324d = 0L
    self.n316 = 0L
    self.n316r = 0L
    self.n316e = 0L
    self.n316d = 0L
    self.n308 = 0L
    self.n308r = 0L
    self.n308e = 0L
    self.n308d = 0L
    self.n300 = 0L
    self.n300r = 0L
    self.n300e = 0L
    self.n300d = 0L
    self.n292 = 0L
    self.n292r = 0L
    self.n292e = 0L
    self.n292d = 0L
    self.n284 = 0L
    self.n284r = 0L
    self.n284e = 0L
    self.n284d = 0L
    self.n276 = 0L
    self.n276r = 0L
    self.n276e = 0L
    self.n276d = 0L
    self.n268 = 0L
    self.n268r = 0L
    self.n268e = 0L
    self.n268d = 0L
    self.n260 = 0L
    self.n260r = 0L
    self.n260e = 0L
    self.n260d = 0L
    self.n252 = 0L
    self.n252r = 0L
    self.n252e = 0L
    self.n252d = 0L
    self.n244 = 0L
    self.n244r = 0L
    self.n244e = 0L
    self.n244d = 0L
    self.n236 = 0L
    self.n236r = 0L
    self.n236e = 0L
    self.n236d = 0L
    self.n228 = 0L
    self.n228r = 0L
    self.n228e = 0L
    self.n228d = 0L
    self.n220 = 0L
    self.n220r = 0L
    self.n220e = 0L
    self.n220d = 0L
    self.n212 = 0L
    self.n212r = 0L
    self.n212e = 0L
    self.n212d = 0L
    self.n719 = 0L
    self.n719r = 0L
    self.n719e = 0L
    self.n719d = 0L
    self.n707 = 0L
    self.n707r = 0L
    self.n707e = 0L
    self.n707d = 0L
    self.n695 = 0L
    self.n695r = 0L
    self.n695e = 0L
    self.n695d = 0L
    self.n674 = 0L
    self.n674r = 0L
    self.n674e = 0L
    self.n674d = 0L
    self.n662 = 0L
    self.n662r = 0L
    self.n662e = 0L
    self.n662d = 0L
    self.n650 = 0L
    self.n650r = 0L
    self.n650e = 0L
    self.n650d = 0L
    self.n629 = 0L
    self.n629r = 0L
    self.n629e = 0L
    self.n629d = 0L
    self.n617 = 0L
    self.n617r = 0L
    self.n617e = 0L
    self.n617d = 0L
    self.n605 = 0L
    self.n605r = 0L
    self.n605e = 0L
    self.n605d = 0L
    self.n593 = 0L
    self.n593r = 0L
    self.n593e = 0L
    self.n593d = 0L
    self.n581 = 0L
    self.n581r = 0L
    self.n581e = 0L
    self.n581d = 0L
    self.n569 = 0L
    self.n569r = 0L
    self.n569e = 0L
    self.n569d = 0L
    self.n548 = 0L
    self.n548r = 0L
    self.n548e = 0L
    self.n548d = 0L
    self.n536 = 0L
    self.n536r = 0L
    self.n536e = 0L
    self.n536d = 0L
    self.n524 = 0L
    self.n524r = 0L
    self.n524e = 0L
    self.n524d = 0L
    self.n512 = 0L
    self.n512r = 0L
    self.n512e = 0L
    self.n512d = 0L
    self.n500 = 0L
    self.n500r = 0L
    self.n500e = 0L
    self.n500d = 0L
    self.n488 = 0L
    self.n488r = 0L
    self.n488e = 0L
    self.n488d = 0L
    self.n476 = 0L
    self.n476r = 0L
    self.n476e = 0L
    self.n476d = 0L
    self.n464 = 0L
    self.n464r = 0L
    self.n464e = 0L
    self.n464d = 0L
    self.n452 = 0L
    self.n452r = 0L
    self.n452e = 0L
    self.n452d = 0L
    self.n440 = 0L
    self.n440r = 0L
    self.n440e = 0L
    self.n440d = 0L
    self.n428 = 0L
    self.n428r = 0L
    self.n428e = 0L
    self.n428d = 0L
    self.n416 = 0L
    self.n416r = 0L
    self.n416e = 0L
    self.n416d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_i, data_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, k8_i, k9_i, k10_i, k11_i, k12_i, k13_i, k14_i, k15_i, k16_i, k17_i, k18_i, k19_i, k20_i, k21_i, k22_i, k23_i, k24_i, ):
    data_o = self.n719
    self.n720 = self.n719
    self.n710 = ((self.n707 & 0x80000L) >> 19)
    self.n708 = ((self.n695 & 0x80000L) >> 19)
    self.n698 = ((self.n683 & 0x40000L) >> 18)
    self.n696 = ((self.n674 & 0x40000L) >> 18)
    self.n686 = ((self.n662 & 0x40000L) >> 18)
    self.n684 = ((self.n650 & 0x40000L) >> 18)
    self.n675 = ((self.n638 & 0x20000L) >> 17)
    self.n665 = ((self.n629 & 0x20000L) >> 17)
    self.n663 = ((self.n617 & 0x20000L) >> 17)
    self.n653 = ((self.n605 & 0x20000L) >> 17)
    self.n651 = ((self.n593 & 0x20000L) >> 17)
    self.n641 = ((self.n581 & 0x20000L) >> 17)
    self.n639 = ((self.n569 & 0x20000L) >> 17)
    self.n630 = ((self.n557 & 0x10000L) >> 16)
    self.n620 = ((self.n548 & 0x10000L) >> 16)
    self.n618 = ((self.n536 & 0x10000L) >> 16)
    self.n608 = ((self.n524 & 0x10000L) >> 16)
    self.n606 = ((self.n512 & 0x10000L) >> 16)
    self.n596 = ((self.n500 & 0x10000L) >> 16)
    self.n594 = ((self.n488 & 0x10000L) >> 16)
    self.n584 = ((self.n476 & 0x10000L) >> 16)
    self.n582 = ((self.n464 & 0x10000L) >> 16)
    self.n572 = ((self.n452 & 0x10000L) >> 16)
    self.n570 = ((self.n440 & 0x10000L) >> 16)
    self.n560 = ((self.n428 & 0x10000L) >> 16)
    self.n558 = ((self.n416 & 0x10000L) >> 16)
    self.n549 = ((self.n404 & 0x8000L) >> 15)
    self.n539 = ((self.n396 & 0x8000L) >> 15)
    self.n537 = ((self.n388 & 0x8000L) >> 15)
    self.n527 = ((self.n380 & 0x8000L) >> 15)
    self.n525 = ((self.n372 & 0x8000L) >> 15)
    self.n515 = ((self.n364 & 0x8000L) >> 15)
    self.n513 = ((self.n356 & 0x8000L) >> 15)
    self.n503 = ((self.n348 & 0x8000L) >> 15)
    self.n501 = ((self.n340 & 0x8000L) >> 15)
    self.n491 = ((self.n332 & 0x8000L) >> 15)
    self.n489 = ((self.n324 & 0x8000L) >> 15)
    self.n479 = ((self.n316 & 0x8000L) >> 15)
    self.n477 = ((self.n308 & 0x8000L) >> 15)
    self.n467 = ((self.n300 & 0x8000L) >> 15)
    self.n465 = ((self.n292 & 0x8000L) >> 15)
    self.n455 = ((self.n284 & 0x8000L) >> 15)
    self.n453 = ((self.n276 & 0x8000L) >> 15)
    self.n443 = ((self.n268 & 0x8000L) >> 15)
    self.n441 = ((self.n260 & 0x8000L) >> 15)
    self.n431 = ((self.n252 & 0x8000L) >> 15)
    self.n429 = ((self.n244 & 0x8000L) >> 15)
    self.n419 = ((self.n236 & 0x8000L) >> 15)
    self.n417 = ((self.n228 & 0x8000L) >> 15)
    self.n407 = ((self.n220 & 0x8000L) >> 15)
    self.n405 = ((self.n212 & 0x8000L) >> 15)
    self.n29 = data_i
    self.n28 = k24_i
    self.n27 = k23_i
    self.n26 = k22_i
    self.n25 = k21_i
    self.n24 = k20_i
    self.n23 = k19_i
    self.n22 = k18_i
    self.n21 = k17_i
    self.n20 = k16_i
    self.n19 = k15_i
    self.n18 = k14_i
    self.n17 = k13_i
    self.n16 = k12_i
    self.n15 = k11_i
    self.n14 = k10_i
    self.n13 = k9_i
    self.n12 = k8_i
    self.n11 = k7_i
    self.n10 = k6_i
    self.n9 = k5_i
    self.n8 = k4_i
    self.n7 = k3_i
    self.n6 = k2_i
    self.n5 = k1_i
    self.n4 = k0_i
    self.n3 = reset_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    self.n711 = self.n710 << 20 | self.n707
    self.n709 = self.n708 << 20 | self.n695
    self.n699 = self.n698 << 19 | self.n683
    self.n697 = self.n696 << 19 | self.n674
    self.n687 = self.n686 << 19 | self.n662
    self.n685 = self.n684 << 19 | self.n650
    self.n676 = self.n675 << 18 | self.n638
    self.n666 = self.n665 << 18 | self.n629
    self.n664 = self.n663 << 18 | self.n617
    self.n654 = self.n653 << 18 | self.n605
    self.n652 = self.n651 << 18 | self.n593
    self.n642 = self.n641 << 18 | self.n581
    self.n640 = self.n639 << 18 | self.n569
    self.n631 = self.n630 << 17 | self.n557
    self.n621 = self.n620 << 17 | self.n548
    self.n619 = self.n618 << 17 | self.n536
    self.n609 = self.n608 << 17 | self.n524
    self.n607 = self.n606 << 17 | self.n512
    self.n597 = self.n596 << 17 | self.n500
    self.n595 = self.n594 << 17 | self.n488
    self.n585 = self.n584 << 17 | self.n476
    self.n583 = self.n582 << 17 | self.n464
    self.n573 = self.n572 << 17 | self.n452
    self.n571 = self.n570 << 17 | self.n440
    self.n561 = self.n560 << 17 | self.n428
    self.n559 = self.n558 << 17 | self.n416
    self.n550 = self.n549 << 16 | self.n404
    self.n540 = self.n539 << 16 | self.n396
    self.n538 = self.n537 << 16 | self.n388
    self.n528 = self.n527 << 16 | self.n380
    self.n526 = self.n525 << 16 | self.n372
    self.n516 = self.n515 << 16 | self.n364
    self.n514 = self.n513 << 16 | self.n356
    self.n504 = self.n503 << 16 | self.n348
    self.n502 = self.n501 << 16 | self.n340
    self.n492 = self.n491 << 16 | self.n332
    self.n490 = self.n489 << 16 | self.n324
    self.n480 = self.n479 << 16 | self.n316
    self.n478 = self.n477 << 16 | self.n308
    self.n468 = self.n467 << 16 | self.n300
    self.n466 = self.n465 << 16 | self.n292
    self.n456 = self.n455 << 16 | self.n284
    self.n454 = self.n453 << 16 | self.n276
    self.n444 = self.n443 << 16 | self.n268
    self.n442 = self.n441 << 16 | self.n260
    self.n432 = self.n431 << 16 | self.n252
    self.n430 = self.n429 << 16 | self.n244
    self.n420 = self.n419 << 16 | self.n236
    self.n418 = self.n417 << 16 | self.n228
    self.n408 = self.n407 << 16 | self.n220
    self.n406 = self.n405 << 16 | self.n212
    self.n397 = (self.n28 * self.n204) & 0xFFFFL
    self.n389 = (self.n27 * self.n197) & 0xFFFFL
    self.n381 = (self.n26 * self.n190) & 0xFFFFL
    self.n373 = (self.n25 * self.n183) & 0xFFFFL
    self.n365 = (self.n24 * self.n176) & 0xFFFFL
    self.n357 = (self.n23 * self.n169) & 0xFFFFL
    self.n349 = (self.n22 * self.n162) & 0xFFFFL
    self.n341 = (self.n21 * self.n155) & 0xFFFFL
    self.n333 = (self.n20 * self.n148) & 0xFFFFL
    self.n325 = (self.n19 * self.n141) & 0xFFFFL
    self.n317 = (self.n18 * self.n134) & 0xFFFFL
    self.n309 = (self.n17 * self.n127) & 0xFFFFL
    self.n301 = (self.n16 * self.n120) & 0xFFFFL
    self.n293 = (self.n15 * self.n113) & 0xFFFFL
    self.n285 = (self.n14 * self.n106) & 0xFFFFL
    self.n277 = (self.n13 * self.n99) & 0xFFFFL
    self.n269 = (self.n12 * self.n92) & 0xFFFFL
    self.n261 = (self.n11 * self.n85) & 0xFFFFL
    self.n253 = (self.n10 * self.n78) & 0xFFFFL
    self.n245 = (self.n9 * self.n71) & 0xFFFFL
    self.n237 = (self.n8 * self.n64) & 0xFFFFL
    self.n229 = (self.n7 * self.n57) & 0xFFFFL
    self.n221 = (self.n6 * self.n50) & 0xFFFFL
    self.n213 = (self.n5 * self.n43) & 0xFFFFL
    self.n205 = (self.n4 * self.n36) & 0xFFFFL
    self.n204r = self.n3
    self.n204e = self.n1
    self.n204d = self.n197
    self.n197r = self.n3
    self.n197e = self.n1
    self.n197d = self.n190
    self.n190r = self.n3
    self.n190e = self.n1
    self.n190d = self.n183
    self.n183r = self.n3
    self.n183e = self.n1
    self.n183d = self.n176
    self.n176r = self.n3
    self.n176e = self.n1
    self.n176d = self.n169
    self.n169r = self.n3
    self.n169e = self.n1
    self.n169d = self.n162
    self.n162r = self.n3
    self.n162e = self.n1
    self.n162d = self.n155
    self.n155r = self.n3
    self.n155e = self.n1
    self.n155d = self.n148
    self.n148r = self.n3
    self.n148e = self.n1
    self.n148d = self.n141
    self.n141r = self.n3
    self.n141e = self.n1
    self.n141d = self.n134
    self.n134r = self.n3
    self.n134e = self.n1
    self.n134d = self.n127
    self.n127r = self.n3
    self.n127e = self.n1
    self.n127d = self.n120
    self.n120r = self.n3
    self.n120e = self.n1
    self.n120d = self.n113
    self.n113r = self.n3
    self.n113e = self.n1
    self.n113d = self.n106
    self.n106r = self.n3
    self.n106e = self.n1
    self.n106d = self.n99
    self.n99r = self.n3
    self.n99e = self.n1
    self.n99d = self.n92
    self.n92r = self.n3
    self.n92e = self.n1
    self.n92d = self.n85
    self.n85r = self.n3
    self.n85e = self.n1
    self.n85d = self.n78
    self.n78r = self.n3
    self.n78e = self.n1
    self.n78d = self.n71
    self.n71r = self.n3
    self.n71e = self.n1
    self.n71d = self.n64
    self.n64r = self.n3
    self.n64e = self.n1
    self.n64d = self.n57
    self.n57r = self.n3
    self.n57e = self.n1
    self.n57d = self.n50
    self.n50r = self.n3
    self.n50e = self.n1
    self.n50d = self.n43
    self.n43r = self.n3
    self.n43e = self.n1
    self.n43d = self.n36
    self.n36r = self.n3
    self.n36e = self.n1
    self.n36d = self.n29
    self.n712 = (self.n709 + self.n711) & 0x1FFFFFL
    self.n700 = (self.n697 + self.n699) & 0xFFFFFL
    self.n688 = (self.n685 + self.n687) & 0xFFFFFL
    self.n683r = self.n2
    self.n683e = self.n1
    self.n683d = self.n676
    self.n667 = (self.n664 + self.n666) & 0x7FFFFL
    self.n655 = (self.n652 + self.n654) & 0x7FFFFL
    self.n643 = (self.n640 + self.n642) & 0x7FFFFL
    self.n638r = self.n2
    self.n638e = self.n1
    self.n638d = self.n631
    self.n622 = (self.n619 + self.n621) & 0x3FFFFL
    self.n610 = (self.n607 + self.n609) & 0x3FFFFL
    self.n598 = (self.n595 + self.n597) & 0x3FFFFL
    self.n586 = (self.n583 + self.n585) & 0x3FFFFL
    self.n574 = (self.n571 + self.n573) & 0x3FFFFL
    self.n562 = (self.n559 + self.n561) & 0x3FFFFL
    self.n557r = self.n2
    self.n557e = self.n1
    self.n557d = self.n550
    self.n541 = (self.n538 + self.n540) & 0x1FFFFL
    self.n529 = (self.n526 + self.n528) & 0x1FFFFL
    self.n517 = (self.n514 + self.n516) & 0x1FFFFL
    self.n505 = (self.n502 + self.n504) & 0x1FFFFL
    self.n493 = (self.n490 + self.n492) & 0x1FFFFL
    self.n481 = (self.n478 + self.n480) & 0x1FFFFL
    self.n469 = (self.n466 + self.n468) & 0x1FFFFL
    self.n457 = (self.n454 + self.n456) & 0x1FFFFL
    self.n445 = (self.n442 + self.n444) & 0x1FFFFL
    self.n433 = (self.n430 + self.n432) & 0x1FFFFL
    self.n421 = (self.n418 + self.n420) & 0x1FFFFL
    self.n409 = (self.n406 + self.n408) & 0x1FFFFL
    self.n404r = self.n2
    self.n404e = self.n1
    self.n404d = self.n397
    self.n396r = self.n2
    self.n396e = self.n1
    self.n396d = self.n389
    self.n388r = self.n2
    self.n388e = self.n1
    self.n388d = self.n381
    self.n380r = self.n2
    self.n380e = self.n1
    self.n380d = self.n373
    self.n372r = self.n2
    self.n372e = self.n1
    self.n372d = self.n365
    self.n364r = self.n2
    self.n364e = self.n1
    self.n364d = self.n357
    self.n356r = self.n2
    self.n356e = self.n1
    self.n356d = self.n349
    self.n348r = self.n2
    self.n348e = self.n1
    self.n348d = self.n341
    self.n340r = self.n2
    self.n340e = self.n1
    self.n340d = self.n333
    self.n332r = self.n2
    self.n332e = self.n1
    self.n332d = self.n325
    self.n324r = self.n2
    self.n324e = self.n1
    self.n324d = self.n317
    self.n316r = self.n2
    self.n316e = self.n1
    self.n316d = self.n309
    self.n308r = self.n2
    self.n308e = self.n1
    self.n308d = self.n301
    self.n300r = self.n2
    self.n300e = self.n1
    self.n300d = self.n293
    self.n292r = self.n2
    self.n292e = self.n1
    self.n292d = self.n285
    self.n284r = self.n2
    self.n284e = self.n1
    self.n284d = self.n277
    self.n276r = self.n2
    self.n276e = self.n1
    self.n276d = self.n269
    self.n268r = self.n2
    self.n268e = self.n1
    self.n268d = self.n261
    self.n260r = self.n2
    self.n260e = self.n1
    self.n260d = self.n253
    self.n252r = self.n2
    self.n252e = self.n1
    self.n252d = self.n245
    self.n244r = self.n2
    self.n244e = self.n1
    self.n244d = self.n237
    self.n236r = self.n2
    self.n236e = self.n1
    self.n236d = self.n229
    self.n228r = self.n2
    self.n228e = self.n1
    self.n228d = self.n221
    self.n220r = self.n2
    self.n220e = self.n1
    self.n220d = self.n213
    self.n212r = self.n2
    self.n212e = self.n1
    self.n212d = self.n205
    self.n719r = self.n2
    self.n719e = self.n1
    self.n719d = self.n712
    self.n707r = self.n2
    self.n707e = self.n1
    self.n707d = self.n700
    self.n695r = self.n2
    self.n695e = self.n1
    self.n695d = self.n688
    self.n674r = self.n2
    self.n674e = self.n1
    self.n674d = self.n667
    self.n662r = self.n2
    self.n662e = self.n1
    self.n662d = self.n655
    self.n650r = self.n2
    self.n650e = self.n1
    self.n650d = self.n643
    self.n629r = self.n2
    self.n629e = self.n1
    self.n629d = self.n622
    self.n617r = self.n2
    self.n617e = self.n1
    self.n617d = self.n610
    self.n605r = self.n2
    self.n605e = self.n1
    self.n605d = self.n598
    self.n593r = self.n2
    self.n593e = self.n1
    self.n593d = self.n586
    self.n581r = self.n2
    self.n581e = self.n1
    self.n581d = self.n574
    self.n569r = self.n2
    self.n569e = self.n1
    self.n569d = self.n562
    self.n548r = self.n2
    self.n548e = self.n1
    self.n548d = self.n541
    self.n536r = self.n2
    self.n536e = self.n1
    self.n536d = self.n529
    self.n524r = self.n2
    self.n524e = self.n1
    self.n524d = self.n517
    self.n512r = self.n2
    self.n512e = self.n1
    self.n512d = self.n505
    self.n500r = self.n2
    self.n500e = self.n1
    self.n500d = self.n493
    self.n488r = self.n2
    self.n488e = self.n1
    self.n488d = self.n481
    self.n476r = self.n2
    self.n476e = self.n1
    self.n476d = self.n469
    self.n464r = self.n2
    self.n464e = self.n1
    self.n464d = self.n457
    self.n452r = self.n2
    self.n452e = self.n1
    self.n452d = self.n445
    self.n440r = self.n2
    self.n440e = self.n1
    self.n440d = self.n433
    self.n428r = self.n2
    self.n428e = self.n1
    self.n428d = self.n421
    self.n416r = self.n2
    self.n416e = self.n1
    self.n416d = self.n409
    return (data_o, )

  def cycle_clock(self):
    if self.n36r:
      self.n36 = 0L
    elif self.n36e:
        self.n36 = self.n36d
    if self.n43r:
      self.n43 = 0L
    elif self.n43e:
        self.n43 = self.n43d
    if self.n50r:
      self.n50 = 0L
    elif self.n50e:
        self.n50 = self.n50d
    if self.n57r:
      self.n57 = 0L
    elif self.n57e:
        self.n57 = self.n57d
    if self.n64r:
      self.n64 = 0L
    elif self.n64e:
        self.n64 = self.n64d
    if self.n71r:
      self.n71 = 0L
    elif self.n71e:
        self.n71 = self.n71d
    if self.n78r:
      self.n78 = 0L
    elif self.n78e:
        self.n78 = self.n78d
    if self.n85r:
      self.n85 = 0L
    elif self.n85e:
        self.n85 = self.n85d
    if self.n92r:
      self.n92 = 0L
    elif self.n92e:
        self.n92 = self.n92d
    if self.n99r:
      self.n99 = 0L
    elif self.n99e:
        self.n99 = self.n99d
    if self.n106r:
      self.n106 = 0L
    elif self.n106e:
        self.n106 = self.n106d
    if self.n113r:
      self.n113 = 0L
    elif self.n113e:
        self.n113 = self.n113d
    if self.n120r:
      self.n120 = 0L
    elif self.n120e:
        self.n120 = self.n120d
    if self.n127r:
      self.n127 = 0L
    elif self.n127e:
        self.n127 = self.n127d
    if self.n134r:
      self.n134 = 0L
    elif self.n134e:
        self.n134 = self.n134d
    if self.n141r:
      self.n141 = 0L
    elif self.n141e:
        self.n141 = self.n141d
    if self.n148r:
      self.n148 = 0L
    elif self.n148e:
        self.n148 = self.n148d
    if self.n155r:
      self.n155 = 0L
    elif self.n155e:
        self.n155 = self.n155d
    if self.n162r:
      self.n162 = 0L
    elif self.n162e:
        self.n162 = self.n162d
    if self.n169r:
      self.n169 = 0L
    elif self.n169e:
        self.n169 = self.n169d
    if self.n176r:
      self.n176 = 0L
    elif self.n176e:
        self.n176 = self.n176d
    if self.n183r:
      self.n183 = 0L
    elif self.n183e:
        self.n183 = self.n183d
    if self.n190r:
      self.n190 = 0L
    elif self.n190e:
        self.n190 = self.n190d
    if self.n197r:
      self.n197 = 0L
    elif self.n197e:
        self.n197 = self.n197d
    if self.n204r:
      self.n204 = 0L
    elif self.n204e:
        self.n204 = self.n204d
    if self.n212r:
      self.n212 = 0L
    elif self.n212e:
        self.n212 = self.n212d
    if self.n220r:
      self.n220 = 0L
    elif self.n220e:
        self.n220 = self.n220d
    if self.n228r:
      self.n228 = 0L
    elif self.n228e:
        self.n228 = self.n228d
    if self.n236r:
      self.n236 = 0L
    elif self.n236e:
        self.n236 = self.n236d
    if self.n244r:
      self.n244 = 0L
    elif self.n244e:
        self.n244 = self.n244d
    if self.n252r:
      self.n252 = 0L
    elif self.n252e:
        self.n252 = self.n252d
    if self.n260r:
      self.n260 = 0L
    elif self.n260e:
        self.n260 = self.n260d
    if self.n268r:
      self.n268 = 0L
    elif self.n268e:
        self.n268 = self.n268d
    if self.n276r:
      self.n276 = 0L
    elif self.n276e:
        self.n276 = self.n276d
    if self.n284r:
      self.n284 = 0L
    elif self.n284e:
        self.n284 = self.n284d
    if self.n292r:
      self.n292 = 0L
    elif self.n292e:
        self.n292 = self.n292d
    if self.n300r:
      self.n300 = 0L
    elif self.n300e:
        self.n300 = self.n300d
    if self.n308r:
      self.n308 = 0L
    elif self.n308e:
        self.n308 = self.n308d
    if self.n316r:
      self.n316 = 0L
    elif self.n316e:
        self.n316 = self.n316d
    if self.n324r:
      self.n324 = 0L
    elif self.n324e:
        self.n324 = self.n324d
    if self.n332r:
      self.n332 = 0L
    elif self.n332e:
        self.n332 = self.n332d
    if self.n340r:
      self.n340 = 0L
    elif self.n340e:
        self.n340 = self.n340d
    if self.n348r:
      self.n348 = 0L
    elif self.n348e:
        self.n348 = self.n348d
    if self.n356r:
      self.n356 = 0L
    elif self.n356e:
        self.n356 = self.n356d
    if self.n364r:
      self.n364 = 0L
    elif self.n364e:
        self.n364 = self.n364d
    if self.n372r:
      self.n372 = 0L
    elif self.n372e:
        self.n372 = self.n372d
    if self.n380r:
      self.n380 = 0L
    elif self.n380e:
        self.n380 = self.n380d
    if self.n388r:
      self.n388 = 0L
    elif self.n388e:
        self.n388 = self.n388d
    if self.n396r:
      self.n396 = 0L
    elif self.n396e:
        self.n396 = self.n396d
    if self.n404r:
      self.n404 = 0L
    elif self.n404e:
        self.n404 = self.n404d
    if self.n416r:
      self.n416 = 0L
    elif self.n416e:
        self.n416 = self.n416d
    if self.n428r:
      self.n428 = 0L
    elif self.n428e:
        self.n428 = self.n428d
    if self.n440r:
      self.n440 = 0L
    elif self.n440e:
        self.n440 = self.n440d
    if self.n452r:
      self.n452 = 0L
    elif self.n452e:
        self.n452 = self.n452d
    if self.n464r:
      self.n464 = 0L
    elif self.n464e:
        self.n464 = self.n464d
    if self.n476r:
      self.n476 = 0L
    elif self.n476e:
        self.n476 = self.n476d
    if self.n488r:
      self.n488 = 0L
    elif self.n488e:
        self.n488 = self.n488d
    if self.n500r:
      self.n500 = 0L
    elif self.n500e:
        self.n500 = self.n500d
    if self.n512r:
      self.n512 = 0L
    elif self.n512e:
        self.n512 = self.n512d
    if self.n524r:
      self.n524 = 0L
    elif self.n524e:
        self.n524 = self.n524d
    if self.n536r:
      self.n536 = 0L
    elif self.n536e:
        self.n536 = self.n536d
    if self.n548r:
      self.n548 = 0L
    elif self.n548e:
        self.n548 = self.n548d
    if self.n557r:
      self.n557 = 0L
    elif self.n557e:
        self.n557 = self.n557d
    if self.n569r:
      self.n569 = 0L
    elif self.n569e:
        self.n569 = self.n569d
    if self.n581r:
      self.n581 = 0L
    elif self.n581e:
        self.n581 = self.n581d
    if self.n593r:
      self.n593 = 0L
    elif self.n593e:
        self.n593 = self.n593d
    if self.n605r:
      self.n605 = 0L
    elif self.n605e:
        self.n605 = self.n605d
    if self.n617r:
      self.n617 = 0L
    elif self.n617e:
        self.n617 = self.n617d
    if self.n629r:
      self.n629 = 0L
    elif self.n629e:
        self.n629 = self.n629d
    if self.n638r:
      self.n638 = 0L
    elif self.n638e:
        self.n638 = self.n638d
    if self.n650r:
      self.n650 = 0L
    elif self.n650e:
        self.n650 = self.n650d
    if self.n662r:
      self.n662 = 0L
    elif self.n662e:
        self.n662 = self.n662d
    if self.n674r:
      self.n674 = 0L
    elif self.n674e:
        self.n674 = self.n674d
    if self.n683r:
      self.n683 = 0L
    elif self.n683e:
        self.n683 = self.n683d
    if self.n695r:
      self.n695 = 0L
    elif self.n695e:
        self.n695 = self.n695d
    if self.n707r:
      self.n707 = 0L
    elif self.n707e:
        self.n707 = self.n707d
    if self.n719r:
      self.n719 = 0L
    elif self.n719e:
        self.n719 = self.n719d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n29 = self.n29
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n9 = self.n9
    self.sim_n10 = self.n10
    self.sim_n11 = self.n11
    self.sim_n12 = self.n12
    self.sim_n13 = self.n13
    self.sim_n14 = self.n14
    self.sim_n15 = self.n15
    self.sim_n16 = self.n16
    self.sim_n17 = self.n17
    self.sim_n18 = self.n18
    self.sim_n19 = self.n19
    self.sim_n20 = self.n20
    self.sim_n21 = self.n21
    self.sim_n22 = self.n22
    self.sim_n23 = self.n23
    self.sim_n24 = self.n24
    self.sim_n25 = self.n25
    self.sim_n26 = self.n26
    self.sim_n27 = self.n27
    self.sim_n28 = self.n28
    self.sim_n720 = self.n720
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fir_24_8_8 $end\n")
    self.sim_file.write("$var wire 1 ! reset_i $end\n")
    self.sim_file.write("$var wire 8 \" data_i $end\n")
    self.sim_file.write("$var wire 8 # k0_i $end\n")
    self.sim_file.write("$var wire 8 $ k1_i $end\n")
    self.sim_file.write("$var wire 8 % k2_i $end\n")
    self.sim_file.write("$var wire 8 & k3_i $end\n")
    self.sim_file.write("$var wire 8 ' k4_i $end\n")
    self.sim_file.write("$var wire 8 ( k5_i $end\n")
    self.sim_file.write("$var wire 8 ) k6_i $end\n")
    self.sim_file.write("$var wire 8 * k7_i $end\n")
    self.sim_file.write("$var wire 8 + k8_i $end\n")
    self.sim_file.write("$var wire 8 , k9_i $end\n")
    self.sim_file.write("$var wire 8 - k10_i $end\n")
    self.sim_file.write("$var wire 8 . k11_i $end\n")
    self.sim_file.write("$var wire 8 / k12_i $end\n")
    self.sim_file.write("$var wire 8 0 k13_i $end\n")
    self.sim_file.write("$var wire 8 1 k14_i $end\n")
    self.sim_file.write("$var wire 8 2 k15_i $end\n")
    self.sim_file.write("$var wire 8 3 k16_i $end\n")
    self.sim_file.write("$var wire 8 4 k17_i $end\n")
    self.sim_file.write("$var wire 8 5 k18_i $end\n")
    self.sim_file.write("$var wire 8 6 k19_i $end\n")
    self.sim_file.write("$var wire 8 7 k20_i $end\n")
    self.sim_file.write("$var wire 8 8 k21_i $end\n")
    self.sim_file.write("$var wire 8 9 k22_i $end\n")
    self.sim_file.write("$var wire 8 : k23_i $end\n")
    self.sim_file.write("$var wire 8 ; k24_i $end\n")
    self.sim_file.write("$var wire 21 < data_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n29 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n29 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" \"\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n9 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n9 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n10 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n10 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n11 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n11 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" *\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n12 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n12 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" +\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n13 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n13 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ,\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n14 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n14 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" -\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n15 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n15 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" .\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n16 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n16 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" /\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n17 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n17 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 0\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n18 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n18 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 1\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n19 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n19 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 2\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n20 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n20 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 3\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n21 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n21 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 4\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n22 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n22 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 5\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n23 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n23 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 6\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n24 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n24 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 7\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n25 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n25 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 8\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n26 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n26 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 9\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n27 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n27 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" :\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n28 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n28 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ;\n")
    found = 0
    for bit in range(20, -1, -1):
      if found:
        if self.n720 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n720 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" <\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n29 != self.n29:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n29 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n29 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" \"\n")
      self.sim_n29 = self.n29
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n8 = self.n8
    if self.sim_n9 != self.n9:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n9 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n9 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n9 = self.n9
    if self.sim_n10 != self.n10:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n10 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n10 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n10 = self.n10
    if self.sim_n11 != self.n11:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n11 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n11 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" *\n")
      self.sim_n11 = self.n11
    if self.sim_n12 != self.n12:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n12 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n12 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" +\n")
      self.sim_n12 = self.n12
    if self.sim_n13 != self.n13:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n13 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n13 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ,\n")
      self.sim_n13 = self.n13
    if self.sim_n14 != self.n14:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n14 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n14 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" -\n")
      self.sim_n14 = self.n14
    if self.sim_n15 != self.n15:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n15 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n15 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" .\n")
      self.sim_n15 = self.n15
    if self.sim_n16 != self.n16:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n16 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n16 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" /\n")
      self.sim_n16 = self.n16
    if self.sim_n17 != self.n17:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n17 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n17 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 0\n")
      self.sim_n17 = self.n17
    if self.sim_n18 != self.n18:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n18 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n18 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 1\n")
      self.sim_n18 = self.n18
    if self.sim_n19 != self.n19:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n19 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n19 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 2\n")
      self.sim_n19 = self.n19
    if self.sim_n20 != self.n20:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n20 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n20 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 3\n")
      self.sim_n20 = self.n20
    if self.sim_n21 != self.n21:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n21 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n21 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 4\n")
      self.sim_n21 = self.n21
    if self.sim_n22 != self.n22:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n22 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n22 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 5\n")
      self.sim_n22 = self.n22
    if self.sim_n23 != self.n23:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n23 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n23 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 6\n")
      self.sim_n23 = self.n23
    if self.sim_n24 != self.n24:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n24 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n24 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 7\n")
      self.sim_n24 = self.n24
    if self.sim_n25 != self.n25:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n25 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n25 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 8\n")
      self.sim_n25 = self.n25
    if self.sim_n26 != self.n26:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n26 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n26 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 9\n")
      self.sim_n26 = self.n26
    if self.sim_n27 != self.n27:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n27 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n27 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" :\n")
      self.sim_n27 = self.n27
    if self.sim_n28 != self.n28:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n28 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n28 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ;\n")
      self.sim_n28 = self.n28
    if self.sim_n720 != self.n720:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(20, -1, -1):
        if found:
          if self.n720 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n720 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" <\n")
      self.sim_n720 = self.n720
    self.sim_count = self.sim_count + 1

