--
--  Copyright (c) 2003 Launchbird Design Systems, Inc.
--  All rights reserved.
--  
--  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
--    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
--    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
--  
--  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
--  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
--  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
--  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
--  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
--  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--  
--  
--  Overview:
--  
--    Performs finite impulse response (FIR) filtering.
--    The filter's sum of products is pipelined with a register after
--    every multiplier and adder.  The adder network is a balanced binary
--    tree to minimize latency.  The sum of products has no numeric loss because the
--    multipliers keep all resulting bits and each adder extends the precision by 1.
--  
--  Interface:
--  
--    Synchronization:
--      clock_c  : Clock input.
--      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
--  
--    Inputs:
--      data_i  : Input data.
--      k0_i    : Coefficient 0 multiplied by in_i(0).
--      k1_i    : Coefficient 1 multiplied by in_i(k-1).
--      k2_i    : Coefficient 2 multiplied by in_i(k-2).
--      ...
--      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
--  
--    Outputs:
--      data_o : Output data.
--  
--  Built In Parameters:
--  
--    Filter Order             = 24
--    Input Precision          = 8
--    Coefficient Precision    = 8
--    Sum of Products Latency  = 6
--  
--  
--  
--  
--  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
--  
--  Build Date : Fri Aug 22 09:45:54 CDT 2003
--  
--  Interface
--  
--    Build Name    : cf_fir_24_8_8
--    Clock Domains : clock_c  
--    Vector Input  : reset_i(1)
--    Vector Input  : data_i(8)
--    Vector Input  : k0_i(8)
--    Vector Input  : k1_i(8)
--    Vector Input  : k2_i(8)
--    Vector Input  : k3_i(8)
--    Vector Input  : k4_i(8)
--    Vector Input  : k5_i(8)
--    Vector Input  : k6_i(8)
--    Vector Input  : k7_i(8)
--    Vector Input  : k8_i(8)
--    Vector Input  : k9_i(8)
--    Vector Input  : k10_i(8)
--    Vector Input  : k11_i(8)
--    Vector Input  : k12_i(8)
--    Vector Input  : k13_i(8)
--    Vector Input  : k14_i(8)
--    Vector Input  : k15_i(8)
--    Vector Input  : k16_i(8)
--    Vector Input  : k17_i(8)
--    Vector Input  : k18_i(8)
--    Vector Input  : k19_i(8)
--    Vector Input  : k20_i(8)
--    Vector Input  : k21_i(8)
--    Vector Input  : k22_i(8)
--    Vector Input  : k23_i(8)
--    Vector Input  : k24_i(8)
--    Vector Output : data_o(21)
--  
--  
--  

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_26 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
o1 : out unsigned(7 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(7 downto 0);
o4 : out unsigned(7 downto 0);
o5 : out unsigned(7 downto 0);
o6 : out unsigned(7 downto 0);
o7 : out unsigned(7 downto 0);
o8 : out unsigned(7 downto 0));
end entity cf_fir_24_8_8_26;
architecture rtl of cf_fir_24_8_8_26 is
signal n1 : unsigned(7 downto 0) := "00000000";
signal n2 : unsigned(7 downto 0) := "00000000";
signal n3 : unsigned(7 downto 0) := "00000000";
signal n4 : unsigned(7 downto 0) := "00000000";
signal n5 : unsigned(7 downto 0) := "00000000";
signal n6 : unsigned(7 downto 0) := "00000000";
signal n7 : unsigned(7 downto 0) := "00000000";
signal n8 : unsigned(7 downto 0) := "00000000";
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "00000000";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "00000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "00000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000";
    elsif i1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "00000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o8 <= n8;
o7 <= n7;
o6 <= n6;
o5 <= n5;
o4 <= n4;
o3 <= n3;
o2 <= n2;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_25 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
o1 : out unsigned(7 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(7 downto 0);
o4 : out unsigned(7 downto 0);
o5 : out unsigned(7 downto 0);
o6 : out unsigned(7 downto 0);
o7 : out unsigned(7 downto 0);
o8 : out unsigned(7 downto 0);
o9 : out unsigned(7 downto 0);
o10 : out unsigned(7 downto 0);
o11 : out unsigned(7 downto 0);
o12 : out unsigned(7 downto 0);
o13 : out unsigned(7 downto 0);
o14 : out unsigned(7 downto 0);
o15 : out unsigned(7 downto 0));
end entity cf_fir_24_8_8_25;
architecture rtl of cf_fir_24_8_8_25 is
signal n1 : unsigned(7 downto 0) := "00000000";
signal n2 : unsigned(7 downto 0) := "00000000";
signal n3 : unsigned(7 downto 0) := "00000000";
signal n4 : unsigned(7 downto 0) := "00000000";
signal n5 : unsigned(7 downto 0) := "00000000";
signal n6 : unsigned(7 downto 0) := "00000000";
signal n7 : unsigned(7 downto 0) := "00000000";
signal s8_1 : unsigned(7 downto 0);
signal s8_2 : unsigned(7 downto 0);
signal s8_3 : unsigned(7 downto 0);
signal s8_4 : unsigned(7 downto 0);
signal s8_5 : unsigned(7 downto 0);
signal s8_6 : unsigned(7 downto 0);
signal s8_7 : unsigned(7 downto 0);
signal s8_8 : unsigned(7 downto 0);
component cf_fir_24_8_8_26 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
o1 : out unsigned(7 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(7 downto 0);
o4 : out unsigned(7 downto 0);
o5 : out unsigned(7 downto 0);
o6 : out unsigned(7 downto 0);
o7 : out unsigned(7 downto 0);
o8 : out unsigned(7 downto 0));
end component cf_fir_24_8_8_26;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "00000000";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "00000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "00000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000";
    elsif i1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
s8 : cf_fir_24_8_8_26 port map (clock_c, i1, i2, n7, s8_1, s8_2, s8_3, s8_4, s8_5, s8_6, s8_7, s8_8);
o15 <= s8_8;
o14 <= s8_7;
o13 <= s8_6;
o12 <= s8_5;
o11 <= s8_4;
o10 <= s8_3;
o9 <= s8_2;
o8 <= s8_1;
o7 <= n7;
o6 <= n6;
o5 <= n5;
o4 <= n4;
o3 <= n3;
o2 <= n2;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_24 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
o1 : out unsigned(7 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(7 downto 0);
o4 : out unsigned(7 downto 0);
o5 : out unsigned(7 downto 0);
o6 : out unsigned(7 downto 0);
o7 : out unsigned(7 downto 0);
o8 : out unsigned(7 downto 0);
o9 : out unsigned(7 downto 0);
o10 : out unsigned(7 downto 0);
o11 : out unsigned(7 downto 0);
o12 : out unsigned(7 downto 0);
o13 : out unsigned(7 downto 0);
o14 : out unsigned(7 downto 0);
o15 : out unsigned(7 downto 0);
o16 : out unsigned(7 downto 0);
o17 : out unsigned(7 downto 0);
o18 : out unsigned(7 downto 0);
o19 : out unsigned(7 downto 0);
o20 : out unsigned(7 downto 0);
o21 : out unsigned(7 downto 0);
o22 : out unsigned(7 downto 0));
end entity cf_fir_24_8_8_24;
architecture rtl of cf_fir_24_8_8_24 is
signal n1 : unsigned(7 downto 0) := "00000000";
signal n2 : unsigned(7 downto 0) := "00000000";
signal n3 : unsigned(7 downto 0) := "00000000";
signal n4 : unsigned(7 downto 0) := "00000000";
signal n5 : unsigned(7 downto 0) := "00000000";
signal n6 : unsigned(7 downto 0) := "00000000";
signal n7 : unsigned(7 downto 0) := "00000000";
signal s8_1 : unsigned(7 downto 0);
signal s8_2 : unsigned(7 downto 0);
signal s8_3 : unsigned(7 downto 0);
signal s8_4 : unsigned(7 downto 0);
signal s8_5 : unsigned(7 downto 0);
signal s8_6 : unsigned(7 downto 0);
signal s8_7 : unsigned(7 downto 0);
signal s8_8 : unsigned(7 downto 0);
signal s8_9 : unsigned(7 downto 0);
signal s8_10 : unsigned(7 downto 0);
signal s8_11 : unsigned(7 downto 0);
signal s8_12 : unsigned(7 downto 0);
signal s8_13 : unsigned(7 downto 0);
signal s8_14 : unsigned(7 downto 0);
signal s8_15 : unsigned(7 downto 0);
component cf_fir_24_8_8_25 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
o1 : out unsigned(7 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(7 downto 0);
o4 : out unsigned(7 downto 0);
o5 : out unsigned(7 downto 0);
o6 : out unsigned(7 downto 0);
o7 : out unsigned(7 downto 0);
o8 : out unsigned(7 downto 0);
o9 : out unsigned(7 downto 0);
o10 : out unsigned(7 downto 0);
o11 : out unsigned(7 downto 0);
o12 : out unsigned(7 downto 0);
o13 : out unsigned(7 downto 0);
o14 : out unsigned(7 downto 0);
o15 : out unsigned(7 downto 0));
end component cf_fir_24_8_8_25;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "00000000";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "00000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "00000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000";
    elsif i1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
s8 : cf_fir_24_8_8_25 port map (clock_c, i1, i2, n7, s8_1, s8_2, s8_3, s8_4, s8_5, s8_6, s8_7, s8_8, s8_9, s8_10, s8_11, s8_12, s8_13, s8_14, s8_15);
o22 <= s8_15;
o21 <= s8_14;
o20 <= s8_13;
o19 <= s8_12;
o18 <= s8_11;
o17 <= s8_10;
o16 <= s8_9;
o15 <= s8_8;
o14 <= s8_7;
o13 <= s8_6;
o12 <= s8_5;
o11 <= s8_4;
o10 <= s8_3;
o9 <= s8_2;
o8 <= s8_1;
o7 <= n7;
o6 <= n6;
o5 <= n5;
o4 <= n4;
o3 <= n3;
o2 <= n2;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_23 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0));
end entity cf_fir_24_8_8_23;
architecture rtl of cf_fir_24_8_8_23 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
begin
n1 <= i3 * i7;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i8;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i9;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_22 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0));
end entity cf_fir_24_8_8_22;
architecture rtl of cf_fir_24_8_8_22 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
signal s9_1 : unsigned(15 downto 0);
signal s9_2 : unsigned(15 downto 0);
signal s9_3 : unsigned(15 downto 0);
signal s9_4 : unsigned(15 downto 0);
component cf_fir_24_8_8_23 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0));
end component cf_fir_24_8_8_23;
begin
n1 <= i3 * i11;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i12;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i13;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i14;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_24_8_8_23 port map (clock_c, i1, i2, i7, i8, i9, i10, i15, i16, i17, i18, s9_1, s9_2, s9_3, s9_4);
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_21 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0));
end entity cf_fir_24_8_8_21;
architecture rtl of cf_fir_24_8_8_21 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
signal s9_1 : unsigned(15 downto 0);
signal s9_2 : unsigned(15 downto 0);
signal s9_3 : unsigned(15 downto 0);
signal s9_4 : unsigned(15 downto 0);
signal s9_5 : unsigned(15 downto 0);
signal s9_6 : unsigned(15 downto 0);
signal s9_7 : unsigned(15 downto 0);
signal s9_8 : unsigned(15 downto 0);
component cf_fir_24_8_8_22 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0));
end component cf_fir_24_8_8_22;
begin
n1 <= i3 * i15;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i16;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i17;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i18;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_24_8_8_22 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i19, i20, i21, i22, i23, i24, i25, i26, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8);
o12 <= s9_8;
o11 <= s9_7;
o10 <= s9_6;
o9 <= s9_5;
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_20 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
i30 : in  unsigned(7 downto 0);
i31 : in  unsigned(7 downto 0);
i32 : in  unsigned(7 downto 0);
i33 : in  unsigned(7 downto 0);
i34 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0);
o13 : out unsigned(15 downto 0);
o14 : out unsigned(15 downto 0);
o15 : out unsigned(15 downto 0);
o16 : out unsigned(15 downto 0));
end entity cf_fir_24_8_8_20;
architecture rtl of cf_fir_24_8_8_20 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
signal s9_1 : unsigned(15 downto 0);
signal s9_2 : unsigned(15 downto 0);
signal s9_3 : unsigned(15 downto 0);
signal s9_4 : unsigned(15 downto 0);
signal s9_5 : unsigned(15 downto 0);
signal s9_6 : unsigned(15 downto 0);
signal s9_7 : unsigned(15 downto 0);
signal s9_8 : unsigned(15 downto 0);
signal s9_9 : unsigned(15 downto 0);
signal s9_10 : unsigned(15 downto 0);
signal s9_11 : unsigned(15 downto 0);
signal s9_12 : unsigned(15 downto 0);
component cf_fir_24_8_8_21 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0));
end component cf_fir_24_8_8_21;
begin
n1 <= i3 * i19;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i20;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i21;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i22;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_24_8_8_21 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i23, i24, i25, i26, i27, i28, i29, i30, i31, i32, i33, i34, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8, s9_9, s9_10, s9_11, s9_12);
o16 <= s9_12;
o15 <= s9_11;
o14 <= s9_10;
o13 <= s9_9;
o12 <= s9_8;
o11 <= s9_7;
o10 <= s9_6;
o9 <= s9_5;
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_19 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
i30 : in  unsigned(7 downto 0);
i31 : in  unsigned(7 downto 0);
i32 : in  unsigned(7 downto 0);
i33 : in  unsigned(7 downto 0);
i34 : in  unsigned(7 downto 0);
i35 : in  unsigned(7 downto 0);
i36 : in  unsigned(7 downto 0);
i37 : in  unsigned(7 downto 0);
i38 : in  unsigned(7 downto 0);
i39 : in  unsigned(7 downto 0);
i40 : in  unsigned(7 downto 0);
i41 : in  unsigned(7 downto 0);
i42 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0);
o13 : out unsigned(15 downto 0);
o14 : out unsigned(15 downto 0);
o15 : out unsigned(15 downto 0);
o16 : out unsigned(15 downto 0);
o17 : out unsigned(15 downto 0);
o18 : out unsigned(15 downto 0);
o19 : out unsigned(15 downto 0);
o20 : out unsigned(15 downto 0));
end entity cf_fir_24_8_8_19;
architecture rtl of cf_fir_24_8_8_19 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
signal s9_1 : unsigned(15 downto 0);
signal s9_2 : unsigned(15 downto 0);
signal s9_3 : unsigned(15 downto 0);
signal s9_4 : unsigned(15 downto 0);
signal s9_5 : unsigned(15 downto 0);
signal s9_6 : unsigned(15 downto 0);
signal s9_7 : unsigned(15 downto 0);
signal s9_8 : unsigned(15 downto 0);
signal s9_9 : unsigned(15 downto 0);
signal s9_10 : unsigned(15 downto 0);
signal s9_11 : unsigned(15 downto 0);
signal s9_12 : unsigned(15 downto 0);
signal s9_13 : unsigned(15 downto 0);
signal s9_14 : unsigned(15 downto 0);
signal s9_15 : unsigned(15 downto 0);
signal s9_16 : unsigned(15 downto 0);
component cf_fir_24_8_8_20 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
i30 : in  unsigned(7 downto 0);
i31 : in  unsigned(7 downto 0);
i32 : in  unsigned(7 downto 0);
i33 : in  unsigned(7 downto 0);
i34 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0);
o13 : out unsigned(15 downto 0);
o14 : out unsigned(15 downto 0);
o15 : out unsigned(15 downto 0);
o16 : out unsigned(15 downto 0));
end component cf_fir_24_8_8_20;
begin
n1 <= i3 * i23;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i24;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i25;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i26;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_24_8_8_20 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, i22, i27, i28, i29, i30, i31, i32, i33, i34, i35, i36, i37, i38, i39, i40, i41, i42, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8, s9_9, s9_10, s9_11, s9_12, s9_13, s9_14, s9_15, s9_16);
o20 <= s9_16;
o19 <= s9_15;
o18 <= s9_14;
o17 <= s9_13;
o16 <= s9_12;
o15 <= s9_11;
o14 <= s9_10;
o13 <= s9_9;
o12 <= s9_8;
o11 <= s9_7;
o10 <= s9_6;
o9 <= s9_5;
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_18 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
i30 : in  unsigned(7 downto 0);
i31 : in  unsigned(7 downto 0);
i32 : in  unsigned(7 downto 0);
i33 : in  unsigned(7 downto 0);
i34 : in  unsigned(7 downto 0);
i35 : in  unsigned(7 downto 0);
i36 : in  unsigned(7 downto 0);
i37 : in  unsigned(7 downto 0);
i38 : in  unsigned(7 downto 0);
i39 : in  unsigned(7 downto 0);
i40 : in  unsigned(7 downto 0);
i41 : in  unsigned(7 downto 0);
i42 : in  unsigned(7 downto 0);
i43 : in  unsigned(7 downto 0);
i44 : in  unsigned(7 downto 0);
i45 : in  unsigned(7 downto 0);
i46 : in  unsigned(7 downto 0);
i47 : in  unsigned(7 downto 0);
i48 : in  unsigned(7 downto 0);
i49 : in  unsigned(7 downto 0);
i50 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0);
o13 : out unsigned(15 downto 0);
o14 : out unsigned(15 downto 0);
o15 : out unsigned(15 downto 0);
o16 : out unsigned(15 downto 0);
o17 : out unsigned(15 downto 0);
o18 : out unsigned(15 downto 0);
o19 : out unsigned(15 downto 0);
o20 : out unsigned(15 downto 0);
o21 : out unsigned(15 downto 0);
o22 : out unsigned(15 downto 0);
o23 : out unsigned(15 downto 0);
o24 : out unsigned(15 downto 0));
end entity cf_fir_24_8_8_18;
architecture rtl of cf_fir_24_8_8_18 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
signal s9_1 : unsigned(15 downto 0);
signal s9_2 : unsigned(15 downto 0);
signal s9_3 : unsigned(15 downto 0);
signal s9_4 : unsigned(15 downto 0);
signal s9_5 : unsigned(15 downto 0);
signal s9_6 : unsigned(15 downto 0);
signal s9_7 : unsigned(15 downto 0);
signal s9_8 : unsigned(15 downto 0);
signal s9_9 : unsigned(15 downto 0);
signal s9_10 : unsigned(15 downto 0);
signal s9_11 : unsigned(15 downto 0);
signal s9_12 : unsigned(15 downto 0);
signal s9_13 : unsigned(15 downto 0);
signal s9_14 : unsigned(15 downto 0);
signal s9_15 : unsigned(15 downto 0);
signal s9_16 : unsigned(15 downto 0);
signal s9_17 : unsigned(15 downto 0);
signal s9_18 : unsigned(15 downto 0);
signal s9_19 : unsigned(15 downto 0);
signal s9_20 : unsigned(15 downto 0);
component cf_fir_24_8_8_19 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
i30 : in  unsigned(7 downto 0);
i31 : in  unsigned(7 downto 0);
i32 : in  unsigned(7 downto 0);
i33 : in  unsigned(7 downto 0);
i34 : in  unsigned(7 downto 0);
i35 : in  unsigned(7 downto 0);
i36 : in  unsigned(7 downto 0);
i37 : in  unsigned(7 downto 0);
i38 : in  unsigned(7 downto 0);
i39 : in  unsigned(7 downto 0);
i40 : in  unsigned(7 downto 0);
i41 : in  unsigned(7 downto 0);
i42 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0);
o13 : out unsigned(15 downto 0);
o14 : out unsigned(15 downto 0);
o15 : out unsigned(15 downto 0);
o16 : out unsigned(15 downto 0);
o17 : out unsigned(15 downto 0);
o18 : out unsigned(15 downto 0);
o19 : out unsigned(15 downto 0);
o20 : out unsigned(15 downto 0));
end component cf_fir_24_8_8_19;
begin
n1 <= i3 * i27;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i28;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i29;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i30;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_24_8_8_19 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, i22, i23, i24, i25, i26, i31, i32, i33, i34, i35, i36, i37, i38, i39, i40, i41, i42, i43, i44, i45, i46, i47, i48, i49, i50, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7, s9_8, s9_9, s9_10, s9_11, s9_12, s9_13, s9_14, s9_15, s9_16, s9_17, s9_18, s9_19, s9_20);
o24 <= s9_20;
o23 <= s9_19;
o22 <= s9_18;
o21 <= s9_17;
o20 <= s9_16;
o19 <= s9_15;
o18 <= s9_14;
o17 <= s9_13;
o16 <= s9_12;
o15 <= s9_11;
o14 <= s9_10;
o13 <= s9_9;
o12 <= s9_8;
o11 <= s9_7;
o10 <= s9_6;
o9 <= s9_5;
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_17 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0));
end entity cf_fir_24_8_8_17;
architecture rtl of cf_fir_24_8_8_17 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(16 downto 0) := "00000000000000000";
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n9 <= "00000000000000000";
    elsif i1 = "1" then
      n9 <= n8;
    end if;
  end if;
end process;
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_16 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0));
end entity cf_fir_24_8_8_16;
architecture rtl of cf_fir_24_8_8_16 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(16 downto 0);
signal n11 : unsigned(16 downto 0);
signal n12 : unsigned(16 downto 0) := "00000000000000000";
signal s13_1 : unsigned(16 downto 0);
signal s13_2 : unsigned(16 downto 0);
component cf_fir_24_8_8_17 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0));
end component cf_fir_24_8_8_17;
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
n9 <= i6(15 downto 15);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_17 port map (clock_c, i1, i2, i7, i8, i9, s13_1, s13_2);
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_15 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0));
end entity cf_fir_24_8_8_15;
architecture rtl of cf_fir_24_8_8_15 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(16 downto 0);
signal n11 : unsigned(16 downto 0);
signal n12 : unsigned(16 downto 0) := "00000000000000000";
signal s13_1 : unsigned(16 downto 0);
signal s13_2 : unsigned(16 downto 0);
signal s13_3 : unsigned(16 downto 0);
signal s13_4 : unsigned(16 downto 0);
component cf_fir_24_8_8_16 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0));
end component cf_fir_24_8_8_16;
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
n9 <= i6(15 downto 15);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_16 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, s13_1, s13_2, s13_3, s13_4);
o6 <= s13_4;
o5 <= s13_3;
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_14 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0);
o7 : out unsigned(16 downto 0);
o8 : out unsigned(16 downto 0));
end entity cf_fir_24_8_8_14;
architecture rtl of cf_fir_24_8_8_14 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(16 downto 0);
signal n11 : unsigned(16 downto 0);
signal n12 : unsigned(16 downto 0) := "00000000000000000";
signal s13_1 : unsigned(16 downto 0);
signal s13_2 : unsigned(16 downto 0);
signal s13_3 : unsigned(16 downto 0);
signal s13_4 : unsigned(16 downto 0);
signal s13_5 : unsigned(16 downto 0);
signal s13_6 : unsigned(16 downto 0);
component cf_fir_24_8_8_15 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0));
end component cf_fir_24_8_8_15;
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
n9 <= i6(15 downto 15);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_15 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, s13_1, s13_2, s13_3, s13_4, s13_5, s13_6);
o8 <= s13_6;
o7 <= s13_5;
o6 <= s13_4;
o5 <= s13_3;
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_13 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0);
o7 : out unsigned(16 downto 0);
o8 : out unsigned(16 downto 0);
o9 : out unsigned(16 downto 0);
o10 : out unsigned(16 downto 0));
end entity cf_fir_24_8_8_13;
architecture rtl of cf_fir_24_8_8_13 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(16 downto 0);
signal n11 : unsigned(16 downto 0);
signal n12 : unsigned(16 downto 0) := "00000000000000000";
signal s13_1 : unsigned(16 downto 0);
signal s13_2 : unsigned(16 downto 0);
signal s13_3 : unsigned(16 downto 0);
signal s13_4 : unsigned(16 downto 0);
signal s13_5 : unsigned(16 downto 0);
signal s13_6 : unsigned(16 downto 0);
signal s13_7 : unsigned(16 downto 0);
signal s13_8 : unsigned(16 downto 0);
component cf_fir_24_8_8_14 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0);
o7 : out unsigned(16 downto 0);
o8 : out unsigned(16 downto 0));
end component cf_fir_24_8_8_14;
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
n9 <= i6(15 downto 15);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_14 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, s13_1, s13_2, s13_3, s13_4, s13_5, s13_6, s13_7, s13_8);
o10 <= s13_8;
o9 <= s13_7;
o8 <= s13_6;
o7 <= s13_5;
o6 <= s13_4;
o5 <= s13_3;
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_12 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
i22 : in  unsigned(15 downto 0);
i23 : in  unsigned(15 downto 0);
i24 : in  unsigned(15 downto 0);
i25 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0);
o7 : out unsigned(16 downto 0);
o8 : out unsigned(16 downto 0);
o9 : out unsigned(16 downto 0);
o10 : out unsigned(16 downto 0);
o11 : out unsigned(16 downto 0);
o12 : out unsigned(16 downto 0));
end entity cf_fir_24_8_8_12;
architecture rtl of cf_fir_24_8_8_12 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(16 downto 0);
signal n11 : unsigned(16 downto 0);
signal n12 : unsigned(16 downto 0) := "00000000000000000";
signal s13_1 : unsigned(16 downto 0);
signal s13_2 : unsigned(16 downto 0);
signal s13_3 : unsigned(16 downto 0);
signal s13_4 : unsigned(16 downto 0);
signal s13_5 : unsigned(16 downto 0);
signal s13_6 : unsigned(16 downto 0);
signal s13_7 : unsigned(16 downto 0);
signal s13_8 : unsigned(16 downto 0);
signal s13_9 : unsigned(16 downto 0);
signal s13_10 : unsigned(16 downto 0);
component cf_fir_24_8_8_13 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0);
o7 : out unsigned(16 downto 0);
o8 : out unsigned(16 downto 0);
o9 : out unsigned(16 downto 0);
o10 : out unsigned(16 downto 0));
end component cf_fir_24_8_8_13;
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
n9 <= i6(15 downto 15);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_13 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, i22, i23, i24, i25, s13_1, s13_2, s13_3, s13_4, s13_5, s13_6, s13_7, s13_8, s13_9, s13_10);
o12 <= s13_10;
o11 <= s13_9;
o10 <= s13_8;
o9 <= s13_7;
o8 <= s13_6;
o7 <= s13_5;
o6 <= s13_4;
o5 <= s13_3;
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_11 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
o1 : out unsigned(17 downto 0);
o2 : out unsigned(17 downto 0));
end entity cf_fir_24_8_8_11;
architecture rtl of cf_fir_24_8_8_11 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(17 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(17 downto 0);
signal n5 : unsigned(17 downto 0);
signal n6 : unsigned(17 downto 0) := "000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(17 downto 0);
signal n9 : unsigned(17 downto 0) := "000000000000000000";
begin
n1 <= i3(16 downto 16);
n2 <= n1 & i3;
n3 <= i4(16 downto 16);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(16 downto 16);
n8 <= n7 & i5;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n9 <= "000000000000000000";
    elsif i1 = "1" then
      n9 <= n8;
    end if;
  end if;
end process;
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_10 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
i6 : in  unsigned(16 downto 0);
i7 : in  unsigned(16 downto 0);
i8 : in  unsigned(16 downto 0);
i9 : in  unsigned(16 downto 0);
o1 : out unsigned(17 downto 0);
o2 : out unsigned(17 downto 0);
o3 : out unsigned(17 downto 0);
o4 : out unsigned(17 downto 0));
end entity cf_fir_24_8_8_10;
architecture rtl of cf_fir_24_8_8_10 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(17 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(17 downto 0);
signal n5 : unsigned(17 downto 0);
signal n6 : unsigned(17 downto 0) := "000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(17 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(17 downto 0);
signal n11 : unsigned(17 downto 0);
signal n12 : unsigned(17 downto 0) := "000000000000000000";
signal s13_1 : unsigned(17 downto 0);
signal s13_2 : unsigned(17 downto 0);
component cf_fir_24_8_8_11 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
o1 : out unsigned(17 downto 0);
o2 : out unsigned(17 downto 0));
end component cf_fir_24_8_8_11;
begin
n1 <= i3(16 downto 16);
n2 <= n1 & i3;
n3 <= i4(16 downto 16);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(16 downto 16);
n8 <= n7 & i5;
n9 <= i6(16 downto 16);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_11 port map (clock_c, i1, i2, i7, i8, i9, s13_1, s13_2);
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_9 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
i6 : in  unsigned(16 downto 0);
i7 : in  unsigned(16 downto 0);
i8 : in  unsigned(16 downto 0);
i9 : in  unsigned(16 downto 0);
i10 : in  unsigned(16 downto 0);
i11 : in  unsigned(16 downto 0);
i12 : in  unsigned(16 downto 0);
i13 : in  unsigned(16 downto 0);
o1 : out unsigned(17 downto 0);
o2 : out unsigned(17 downto 0);
o3 : out unsigned(17 downto 0);
o4 : out unsigned(17 downto 0);
o5 : out unsigned(17 downto 0);
o6 : out unsigned(17 downto 0));
end entity cf_fir_24_8_8_9;
architecture rtl of cf_fir_24_8_8_9 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(17 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(17 downto 0);
signal n5 : unsigned(17 downto 0);
signal n6 : unsigned(17 downto 0) := "000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(17 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(17 downto 0);
signal n11 : unsigned(17 downto 0);
signal n12 : unsigned(17 downto 0) := "000000000000000000";
signal s13_1 : unsigned(17 downto 0);
signal s13_2 : unsigned(17 downto 0);
signal s13_3 : unsigned(17 downto 0);
signal s13_4 : unsigned(17 downto 0);
component cf_fir_24_8_8_10 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
i6 : in  unsigned(16 downto 0);
i7 : in  unsigned(16 downto 0);
i8 : in  unsigned(16 downto 0);
i9 : in  unsigned(16 downto 0);
o1 : out unsigned(17 downto 0);
o2 : out unsigned(17 downto 0);
o3 : out unsigned(17 downto 0);
o4 : out unsigned(17 downto 0));
end component cf_fir_24_8_8_10;
begin
n1 <= i3(16 downto 16);
n2 <= n1 & i3;
n3 <= i4(16 downto 16);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(16 downto 16);
n8 <= n7 & i5;
n9 <= i6(16 downto 16);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_10 port map (clock_c, i1, i2, i7, i8, i9, i10, i11, i12, i13, s13_1, s13_2, s13_3, s13_4);
o6 <= s13_4;
o5 <= s13_3;
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(18 downto 0);
i4 : in  unsigned(18 downto 0);
i5 : in  unsigned(18 downto 0);
i6 : in  unsigned(18 downto 0);
o1 : out unsigned(19 downto 0);
o2 : out unsigned(19 downto 0));
end entity cf_fir_24_8_8_8;
architecture rtl of cf_fir_24_8_8_8 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(19 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(19 downto 0);
signal n5 : unsigned(19 downto 0);
signal n6 : unsigned(19 downto 0) := "00000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(19 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(19 downto 0);
signal n11 : unsigned(19 downto 0);
signal n12 : unsigned(19 downto 0) := "00000000000000000000";
begin
n1 <= i3(18 downto 18);
n2 <= n1 & i3;
n3 <= i4(18 downto 18);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(18 downto 18);
n8 <= n7 & i5;
n9 <= i6(18 downto 18);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(17 downto 0);
i4 : in  unsigned(17 downto 0);
i5 : in  unsigned(17 downto 0);
o1 : out unsigned(18 downto 0);
o2 : out unsigned(18 downto 0));
end entity cf_fir_24_8_8_7;
architecture rtl of cf_fir_24_8_8_7 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(18 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(18 downto 0);
signal n5 : unsigned(18 downto 0);
signal n6 : unsigned(18 downto 0) := "0000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(18 downto 0);
signal n9 : unsigned(18 downto 0) := "0000000000000000000";
begin
n1 <= i3(17 downto 17);
n2 <= n1 & i3;
n3 <= i4(17 downto 17);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(17 downto 17);
n8 <= n7 & i5;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n9 <= "0000000000000000000";
    elsif i1 = "1" then
      n9 <= n8;
    end if;
  end if;
end process;
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(17 downto 0);
i4 : in  unsigned(17 downto 0);
i5 : in  unsigned(17 downto 0);
i6 : in  unsigned(17 downto 0);
i7 : in  unsigned(17 downto 0);
i8 : in  unsigned(17 downto 0);
i9 : in  unsigned(17 downto 0);
o1 : out unsigned(18 downto 0);
o2 : out unsigned(18 downto 0);
o3 : out unsigned(18 downto 0);
o4 : out unsigned(18 downto 0));
end entity cf_fir_24_8_8_6;
architecture rtl of cf_fir_24_8_8_6 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(18 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(18 downto 0);
signal n5 : unsigned(18 downto 0);
signal n6 : unsigned(18 downto 0) := "0000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(18 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(18 downto 0);
signal n11 : unsigned(18 downto 0);
signal n12 : unsigned(18 downto 0) := "0000000000000000000";
signal s13_1 : unsigned(18 downto 0);
signal s13_2 : unsigned(18 downto 0);
component cf_fir_24_8_8_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(17 downto 0);
i4 : in  unsigned(17 downto 0);
i5 : in  unsigned(17 downto 0);
o1 : out unsigned(18 downto 0);
o2 : out unsigned(18 downto 0));
end component cf_fir_24_8_8_7;
begin
n1 <= i3(17 downto 17);
n2 <= n1 & i3;
n3 <= i4(17 downto 17);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(17 downto 17);
n8 <= n7 & i5;
n9 <= i6(17 downto 17);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "0000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_24_8_8_7 port map (clock_c, i1, i2, i7, i8, i9, s13_1, s13_2);
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(17 downto 0);
i4 : in  unsigned(17 downto 0);
i5 : in  unsigned(17 downto 0);
i6 : in  unsigned(17 downto 0);
i7 : in  unsigned(17 downto 0);
i8 : in  unsigned(17 downto 0);
i9 : in  unsigned(17 downto 0);
o1 : out unsigned(20 downto 0));
end entity cf_fir_24_8_8_5;
architecture rtl of cf_fir_24_8_8_5 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(20 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(20 downto 0);
signal n5 : unsigned(20 downto 0);
signal n6 : unsigned(20 downto 0) := "000000000000000000000";
signal s7_1 : unsigned(19 downto 0);
signal s7_2 : unsigned(19 downto 0);
signal s8_1 : unsigned(18 downto 0);
signal s8_2 : unsigned(18 downto 0);
signal s8_3 : unsigned(18 downto 0);
signal s8_4 : unsigned(18 downto 0);
component cf_fir_24_8_8_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(18 downto 0);
i4 : in  unsigned(18 downto 0);
i5 : in  unsigned(18 downto 0);
i6 : in  unsigned(18 downto 0);
o1 : out unsigned(19 downto 0);
o2 : out unsigned(19 downto 0));
end component cf_fir_24_8_8_8;
component cf_fir_24_8_8_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(17 downto 0);
i4 : in  unsigned(17 downto 0);
i5 : in  unsigned(17 downto 0);
i6 : in  unsigned(17 downto 0);
i7 : in  unsigned(17 downto 0);
i8 : in  unsigned(17 downto 0);
i9 : in  unsigned(17 downto 0);
o1 : out unsigned(18 downto 0);
o2 : out unsigned(18 downto 0);
o3 : out unsigned(18 downto 0);
o4 : out unsigned(18 downto 0));
end component cf_fir_24_8_8_6;
begin
n1 <= s7_1(19 downto 19);
n2 <= n1 & s7_1;
n3 <= s7_2(19 downto 19);
n4 <= n3 & s7_2;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
s7 : cf_fir_24_8_8_8 port map (clock_c, i1, i2, s8_1, s8_2, s8_3, s8_4, s7_1, s7_2);
s8 : cf_fir_24_8_8_6 port map (clock_c, i1, i2, i3, i4, i5, i6, i7, i8, i9, s8_1, s8_2, s8_3, s8_4);
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
i6 : in  unsigned(16 downto 0);
i7 : in  unsigned(16 downto 0);
i8 : in  unsigned(16 downto 0);
i9 : in  unsigned(16 downto 0);
i10 : in  unsigned(16 downto 0);
i11 : in  unsigned(16 downto 0);
i12 : in  unsigned(16 downto 0);
i13 : in  unsigned(16 downto 0);
i14 : in  unsigned(16 downto 0);
i15 : in  unsigned(16 downto 0);
o1 : out unsigned(20 downto 0));
end entity cf_fir_24_8_8_4;
architecture rtl of cf_fir_24_8_8_4 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(17 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(17 downto 0);
signal n5 : unsigned(17 downto 0);
signal n6 : unsigned(17 downto 0) := "000000000000000000";
signal s7_1 : unsigned(17 downto 0);
signal s7_2 : unsigned(17 downto 0);
signal s7_3 : unsigned(17 downto 0);
signal s7_4 : unsigned(17 downto 0);
signal s7_5 : unsigned(17 downto 0);
signal s7_6 : unsigned(17 downto 0);
signal s8_1 : unsigned(20 downto 0);
component cf_fir_24_8_8_9 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
i6 : in  unsigned(16 downto 0);
i7 : in  unsigned(16 downto 0);
i8 : in  unsigned(16 downto 0);
i9 : in  unsigned(16 downto 0);
i10 : in  unsigned(16 downto 0);
i11 : in  unsigned(16 downto 0);
i12 : in  unsigned(16 downto 0);
i13 : in  unsigned(16 downto 0);
o1 : out unsigned(17 downto 0);
o2 : out unsigned(17 downto 0);
o3 : out unsigned(17 downto 0);
o4 : out unsigned(17 downto 0);
o5 : out unsigned(17 downto 0);
o6 : out unsigned(17 downto 0));
end component cf_fir_24_8_8_9;
component cf_fir_24_8_8_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(17 downto 0);
i4 : in  unsigned(17 downto 0);
i5 : in  unsigned(17 downto 0);
i6 : in  unsigned(17 downto 0);
i7 : in  unsigned(17 downto 0);
i8 : in  unsigned(17 downto 0);
i9 : in  unsigned(17 downto 0);
o1 : out unsigned(20 downto 0));
end component cf_fir_24_8_8_5;
begin
n1 <= i3(16 downto 16);
n2 <= n1 & i3;
n3 <= i4(16 downto 16);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
s7 : cf_fir_24_8_8_9 port map (clock_c, i1, i2, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6);
s8 : cf_fir_24_8_8_5 port map (clock_c, i1, i2, n6, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s8_1);
o1 <= s8_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
i22 : in  unsigned(15 downto 0);
i23 : in  unsigned(15 downto 0);
i24 : in  unsigned(15 downto 0);
i25 : in  unsigned(15 downto 0);
i26 : in  unsigned(15 downto 0);
i27 : in  unsigned(15 downto 0);
o1 : out unsigned(20 downto 0));
end entity cf_fir_24_8_8_3;
architecture rtl of cf_fir_24_8_8_3 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal s7_1 : unsigned(16 downto 0);
signal s7_2 : unsigned(16 downto 0);
signal s7_3 : unsigned(16 downto 0);
signal s7_4 : unsigned(16 downto 0);
signal s7_5 : unsigned(16 downto 0);
signal s7_6 : unsigned(16 downto 0);
signal s7_7 : unsigned(16 downto 0);
signal s7_8 : unsigned(16 downto 0);
signal s7_9 : unsigned(16 downto 0);
signal s7_10 : unsigned(16 downto 0);
signal s7_11 : unsigned(16 downto 0);
signal s7_12 : unsigned(16 downto 0);
signal s8_1 : unsigned(20 downto 0);
component cf_fir_24_8_8_12 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
i22 : in  unsigned(15 downto 0);
i23 : in  unsigned(15 downto 0);
i24 : in  unsigned(15 downto 0);
i25 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0);
o3 : out unsigned(16 downto 0);
o4 : out unsigned(16 downto 0);
o5 : out unsigned(16 downto 0);
o6 : out unsigned(16 downto 0);
o7 : out unsigned(16 downto 0);
o8 : out unsigned(16 downto 0);
o9 : out unsigned(16 downto 0);
o10 : out unsigned(16 downto 0);
o11 : out unsigned(16 downto 0);
o12 : out unsigned(16 downto 0));
end component cf_fir_24_8_8_12;
component cf_fir_24_8_8_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(16 downto 0);
i4 : in  unsigned(16 downto 0);
i5 : in  unsigned(16 downto 0);
i6 : in  unsigned(16 downto 0);
i7 : in  unsigned(16 downto 0);
i8 : in  unsigned(16 downto 0);
i9 : in  unsigned(16 downto 0);
i10 : in  unsigned(16 downto 0);
i11 : in  unsigned(16 downto 0);
i12 : in  unsigned(16 downto 0);
i13 : in  unsigned(16 downto 0);
i14 : in  unsigned(16 downto 0);
i15 : in  unsigned(16 downto 0);
o1 : out unsigned(20 downto 0));
end component cf_fir_24_8_8_4;
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
s7 : cf_fir_24_8_8_12 port map (clock_c, i1, i2, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, i22, i23, i24, i25, i26, i27, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s7_7, s7_8, s7_9, s7_10, s7_11, s7_12);
s8 : cf_fir_24_8_8_4 port map (clock_c, i1, i2, n6, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s7_7, s7_8, s7_9, s7_10, s7_11, s7_12, s8_1);
o1 <= s8_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
o1 : out unsigned(20 downto 0));
end entity cf_fir_24_8_8_2;
architecture rtl of cf_fir_24_8_8_2 is
signal n1 : unsigned(7 downto 0) := "00000000";
signal n2 : unsigned(7 downto 0) := "00000000";
signal n3 : unsigned(7 downto 0) := "00000000";
signal n4 : unsigned(15 downto 0);
signal n5 : unsigned(15 downto 0) := "0000000000000000";
signal s6_1 : unsigned(7 downto 0);
signal s6_2 : unsigned(7 downto 0);
signal s6_3 : unsigned(7 downto 0);
signal s6_4 : unsigned(7 downto 0);
signal s6_5 : unsigned(7 downto 0);
signal s6_6 : unsigned(7 downto 0);
signal s6_7 : unsigned(7 downto 0);
signal s6_8 : unsigned(7 downto 0);
signal s6_9 : unsigned(7 downto 0);
signal s6_10 : unsigned(7 downto 0);
signal s6_11 : unsigned(7 downto 0);
signal s6_12 : unsigned(7 downto 0);
signal s6_13 : unsigned(7 downto 0);
signal s6_14 : unsigned(7 downto 0);
signal s6_15 : unsigned(7 downto 0);
signal s6_16 : unsigned(7 downto 0);
signal s6_17 : unsigned(7 downto 0);
signal s6_18 : unsigned(7 downto 0);
signal s6_19 : unsigned(7 downto 0);
signal s6_20 : unsigned(7 downto 0);
signal s6_21 : unsigned(7 downto 0);
signal s6_22 : unsigned(7 downto 0);
signal s7_1 : unsigned(15 downto 0);
signal s7_2 : unsigned(15 downto 0);
signal s7_3 : unsigned(15 downto 0);
signal s7_4 : unsigned(15 downto 0);
signal s7_5 : unsigned(15 downto 0);
signal s7_6 : unsigned(15 downto 0);
signal s7_7 : unsigned(15 downto 0);
signal s7_8 : unsigned(15 downto 0);
signal s7_9 : unsigned(15 downto 0);
signal s7_10 : unsigned(15 downto 0);
signal s7_11 : unsigned(15 downto 0);
signal s7_12 : unsigned(15 downto 0);
signal s7_13 : unsigned(15 downto 0);
signal s7_14 : unsigned(15 downto 0);
signal s7_15 : unsigned(15 downto 0);
signal s7_16 : unsigned(15 downto 0);
signal s7_17 : unsigned(15 downto 0);
signal s7_18 : unsigned(15 downto 0);
signal s7_19 : unsigned(15 downto 0);
signal s7_20 : unsigned(15 downto 0);
signal s7_21 : unsigned(15 downto 0);
signal s7_22 : unsigned(15 downto 0);
signal s7_23 : unsigned(15 downto 0);
signal s7_24 : unsigned(15 downto 0);
signal s8_1 : unsigned(20 downto 0);
component cf_fir_24_8_8_24 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
o1 : out unsigned(7 downto 0);
o2 : out unsigned(7 downto 0);
o3 : out unsigned(7 downto 0);
o4 : out unsigned(7 downto 0);
o5 : out unsigned(7 downto 0);
o6 : out unsigned(7 downto 0);
o7 : out unsigned(7 downto 0);
o8 : out unsigned(7 downto 0);
o9 : out unsigned(7 downto 0);
o10 : out unsigned(7 downto 0);
o11 : out unsigned(7 downto 0);
o12 : out unsigned(7 downto 0);
o13 : out unsigned(7 downto 0);
o14 : out unsigned(7 downto 0);
o15 : out unsigned(7 downto 0);
o16 : out unsigned(7 downto 0);
o17 : out unsigned(7 downto 0);
o18 : out unsigned(7 downto 0);
o19 : out unsigned(7 downto 0);
o20 : out unsigned(7 downto 0);
o21 : out unsigned(7 downto 0);
o22 : out unsigned(7 downto 0));
end component cf_fir_24_8_8_24;
component cf_fir_24_8_8_18 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
i30 : in  unsigned(7 downto 0);
i31 : in  unsigned(7 downto 0);
i32 : in  unsigned(7 downto 0);
i33 : in  unsigned(7 downto 0);
i34 : in  unsigned(7 downto 0);
i35 : in  unsigned(7 downto 0);
i36 : in  unsigned(7 downto 0);
i37 : in  unsigned(7 downto 0);
i38 : in  unsigned(7 downto 0);
i39 : in  unsigned(7 downto 0);
i40 : in  unsigned(7 downto 0);
i41 : in  unsigned(7 downto 0);
i42 : in  unsigned(7 downto 0);
i43 : in  unsigned(7 downto 0);
i44 : in  unsigned(7 downto 0);
i45 : in  unsigned(7 downto 0);
i46 : in  unsigned(7 downto 0);
i47 : in  unsigned(7 downto 0);
i48 : in  unsigned(7 downto 0);
i49 : in  unsigned(7 downto 0);
i50 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0);
o9 : out unsigned(15 downto 0);
o10 : out unsigned(15 downto 0);
o11 : out unsigned(15 downto 0);
o12 : out unsigned(15 downto 0);
o13 : out unsigned(15 downto 0);
o14 : out unsigned(15 downto 0);
o15 : out unsigned(15 downto 0);
o16 : out unsigned(15 downto 0);
o17 : out unsigned(15 downto 0);
o18 : out unsigned(15 downto 0);
o19 : out unsigned(15 downto 0);
o20 : out unsigned(15 downto 0);
o21 : out unsigned(15 downto 0);
o22 : out unsigned(15 downto 0);
o23 : out unsigned(15 downto 0);
o24 : out unsigned(15 downto 0));
end component cf_fir_24_8_8_18;
component cf_fir_24_8_8_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
i19 : in  unsigned(15 downto 0);
i20 : in  unsigned(15 downto 0);
i21 : in  unsigned(15 downto 0);
i22 : in  unsigned(15 downto 0);
i23 : in  unsigned(15 downto 0);
i24 : in  unsigned(15 downto 0);
i25 : in  unsigned(15 downto 0);
i26 : in  unsigned(15 downto 0);
i27 : in  unsigned(15 downto 0);
o1 : out unsigned(20 downto 0));
end component cf_fir_24_8_8_3;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n1 <= "00000000";
    elsif i1 = "1" then
      n1 <= i29;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n2 <= "00000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n3 <= "00000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
n4 <= i4 * n1;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0000000000000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
s6 : cf_fir_24_8_8_24 port map (clock_c, i1, i3, n3, s6_1, s6_2, s6_3, s6_4, s6_5, s6_6, s6_7, s6_8, s6_9, s6_10, s6_11, s6_12, s6_13, s6_14, s6_15, s6_16, s6_17, s6_18, s6_19, s6_20, s6_21, s6_22);
s7 : cf_fir_24_8_8_18 port map (clock_c, i1, i2, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, i22, i23, i24, i25, i26, i27, i28, n2, n3, s6_1, s6_2, s6_3, s6_4, s6_5, s6_6, s6_7, s6_8, s6_9, s6_10, s6_11, s6_12, s6_13, s6_14, s6_15, s6_16, s6_17, s6_18, s6_19, s6_20, s6_21, s6_22, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s7_7, s7_8, s7_9, s7_10, s7_11, s7_12, s7_13, s7_14, s7_15, s7_16, s7_17, s7_18, s7_19, s7_20, s7_21, s7_22, s7_23, s7_24);
s8 : cf_fir_24_8_8_3 port map (clock_c, i1, i2, n5, s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s7_7, s7_8, s7_9, s7_10, s7_11, s7_12, s7_13, s7_14, s7_15, s7_16, s7_17, s7_18, s7_19, s7_20, s7_21, s7_22, s7_23, s7_24, s8_1);
o1 <= s8_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(7 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
o1 : out unsigned(20 downto 0));
end entity cf_fir_24_8_8_1;
architecture rtl of cf_fir_24_8_8_1 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal s3_1 : unsigned(20 downto 0);
component cf_fir_24_8_8_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
i28 : in  unsigned(7 downto 0);
i29 : in  unsigned(7 downto 0);
o1 : out unsigned(20 downto 0));
end component cf_fir_24_8_8_2;
begin
n1 <= "1";
n2 <= "0";
s3 : cf_fir_24_8_8_2 port map (clock_c, n1, n2, i1, i2, i3, i4, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15, i16, i17, i18, i19, i20, i21, i22, i23, i24, i25, i26, i27, s3_1);
o1 <= s3_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_24_8_8 is
port(
signal clock_c : in std_logic;
signal reset_i : in unsigned(0 downto 0);
signal data_i : in unsigned(7 downto 0);
signal k0_i : in unsigned(7 downto 0);
signal k1_i : in unsigned(7 downto 0);
signal k2_i : in unsigned(7 downto 0);
signal k3_i : in unsigned(7 downto 0);
signal k4_i : in unsigned(7 downto 0);
signal k5_i : in unsigned(7 downto 0);
signal k6_i : in unsigned(7 downto 0);
signal k7_i : in unsigned(7 downto 0);
signal k8_i : in unsigned(7 downto 0);
signal k9_i : in unsigned(7 downto 0);
signal k10_i : in unsigned(7 downto 0);
signal k11_i : in unsigned(7 downto 0);
signal k12_i : in unsigned(7 downto 0);
signal k13_i : in unsigned(7 downto 0);
signal k14_i : in unsigned(7 downto 0);
signal k15_i : in unsigned(7 downto 0);
signal k16_i : in unsigned(7 downto 0);
signal k17_i : in unsigned(7 downto 0);
signal k18_i : in unsigned(7 downto 0);
signal k19_i : in unsigned(7 downto 0);
signal k20_i : in unsigned(7 downto 0);
signal k21_i : in unsigned(7 downto 0);
signal k22_i : in unsigned(7 downto 0);
signal k23_i : in unsigned(7 downto 0);
signal k24_i : in unsigned(7 downto 0);
signal data_o : out unsigned(20 downto 0));
end entity cf_fir_24_8_8;
architecture rtl of cf_fir_24_8_8 is
component cf_fir_24_8_8_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(7 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
i11 : in  unsigned(7 downto 0);
i12 : in  unsigned(7 downto 0);
i13 : in  unsigned(7 downto 0);
i14 : in  unsigned(7 downto 0);
i15 : in  unsigned(7 downto 0);
i16 : in  unsigned(7 downto 0);
i17 : in  unsigned(7 downto 0);
i18 : in  unsigned(7 downto 0);
i19 : in  unsigned(7 downto 0);
i20 : in  unsigned(7 downto 0);
i21 : in  unsigned(7 downto 0);
i22 : in  unsigned(7 downto 0);
i23 : in  unsigned(7 downto 0);
i24 : in  unsigned(7 downto 0);
i25 : in  unsigned(7 downto 0);
i26 : in  unsigned(7 downto 0);
i27 : in  unsigned(7 downto 0);
o1 : out unsigned(20 downto 0));
end component cf_fir_24_8_8_1;
signal n1 : unsigned(20 downto 0);
begin
s1 : cf_fir_24_8_8_1 port map (clock_c, reset_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, k8_i, k9_i, k10_i, k11_i, k12_i, k13_i, k14_i, k15_i, k16_i, k17_i, k18_i, k19_i, k20_i, k21_i, k22_i, k23_i, k24_i, data_i, n1);
data_o <= n1;
end architecture rtl;


