#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs finite impulse response (FIR) filtering.
#    The filter's sum of products is pipelined with a register after
#    every multiplier and adder.  The adder network is a balanced binary
#    tree to minimize latency.  The sum of products has no numeric loss because the
#    multipliers keep all resulting bits and each adder extends the precision by 1.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
#  
#    Inputs:
#      data_i  : Input data.
#      k0_i    : Coefficient 0 multiplied by in_i(0).
#      k1_i    : Coefficient 1 multiplied by in_i(k-1).
#      k2_i    : Coefficient 2 multiplied by in_i(k-2).
#      ...
#      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
#  
#    Outputs:
#      data_o : Output data.
#  
#  Built In Parameters:
#  
#    Filter Order             = 33
#    Input Precision          = 16
#    Coefficient Precision    = 16
#    Sum of Products Latency  = 7
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:45:58 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fir_33_16_16
#    Clock Domains : clock_c  
#    Vector Input  : reset_i(1)
#    Vector Input  : data_i(16)
#    Vector Input  : k0_i(16)
#    Vector Input  : k1_i(16)
#    Vector Input  : k2_i(16)
#    Vector Input  : k3_i(16)
#    Vector Input  : k4_i(16)
#    Vector Input  : k5_i(16)
#    Vector Input  : k6_i(16)
#    Vector Input  : k7_i(16)
#    Vector Input  : k8_i(16)
#    Vector Input  : k9_i(16)
#    Vector Input  : k10_i(16)
#    Vector Input  : k11_i(16)
#    Vector Input  : k12_i(16)
#    Vector Input  : k13_i(16)
#    Vector Input  : k14_i(16)
#    Vector Input  : k15_i(16)
#    Vector Input  : k16_i(16)
#    Vector Input  : k17_i(16)
#    Vector Input  : k18_i(16)
#    Vector Input  : k19_i(16)
#    Vector Input  : k20_i(16)
#    Vector Input  : k21_i(16)
#    Vector Input  : k22_i(16)
#    Vector Input  : k23_i(16)
#    Vector Input  : k24_i(16)
#    Vector Input  : k25_i(16)
#    Vector Input  : k26_i(16)
#    Vector Input  : k27_i(16)
#    Vector Input  : k28_i(16)
#    Vector Input  : k29_i(16)
#    Vector Input  : k30_i(16)
#    Vector Input  : k31_i(16)
#    Vector Input  : k32_i(16)
#    Vector Input  : k33_i(16)
#    Vector Output : data_o(38)
#  
#  
#  

import sys
import time

class cf_fir_33_16_16:

  def init(self):
    self.n981 = 0L
    self.n971 = 0L
    self.n969 = 0L
    self.n960 = 0L
    self.n950 = 0L
    self.n948 = 0L
    self.n939 = 0L
    self.n929 = 0L
    self.n927 = 0L
    self.n917 = 0L
    self.n915 = 0L
    self.n906 = 0L
    self.n896 = 0L
    self.n894 = 0L
    self.n884 = 0L
    self.n882 = 0L
    self.n872 = 0L
    self.n870 = 0L
    self.n860 = 0L
    self.n858 = 0L
    self.n849 = 0L
    self.n839 = 0L
    self.n837 = 0L
    self.n827 = 0L
    self.n825 = 0L
    self.n815 = 0L
    self.n813 = 0L
    self.n803 = 0L
    self.n801 = 0L
    self.n791 = 0L
    self.n789 = 0L
    self.n779 = 0L
    self.n777 = 0L
    self.n767 = 0L
    self.n765 = 0L
    self.n755 = 0L
    self.n753 = 0L
    self.n743 = 0L
    self.n741 = 0L
    self.n731 = 0L
    self.n729 = 0L
    self.n719 = 0L
    self.n717 = 0L
    self.n707 = 0L
    self.n705 = 0L
    self.n695 = 0L
    self.n693 = 0L
    self.n683 = 0L
    self.n681 = 0L
    self.n671 = 0L
    self.n669 = 0L
    self.n659 = 0L
    self.n657 = 0L
    self.n647 = 0L
    self.n645 = 0L
    self.n635 = 0L
    self.n633 = 0L
    self.n623 = 0L
    self.n621 = 0L
    self.n611 = 0L
    self.n609 = 0L
    self.n599 = 0L
    self.n597 = 0L
    self.n587 = 0L
    self.n585 = 0L
    self.n575 = 0L
    self.n573 = 0L
    self.n563 = 0L
    self.n561 = 0L
    self.n551 = 0L
    self.n549 = 0L
    self.n38 = 0L
    self.n37 = 0L
    self.n36 = 0L
    self.n35 = 0L
    self.n34 = 0L
    self.n33 = 0L
    self.n32 = 0L
    self.n31 = 0L
    self.n30 = 0L
    self.n29 = 0L
    self.n28 = 0L
    self.n27 = 0L
    self.n26 = 0L
    self.n25 = 0L
    self.n24 = 0L
    self.n23 = 0L
    self.n22 = 0L
    self.n21 = 0L
    self.n20 = 0L
    self.n19 = 0L
    self.n18 = 0L
    self.n17 = 0L
    self.n16 = 0L
    self.n15 = 0L
    self.n14 = 0L
    self.n13 = 0L
    self.n12 = 0L
    self.n11 = 0L
    self.n10 = 0L
    self.n9 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n972 = 0L
    self.n970 = 0L
    self.n961 = 0L
    self.n951 = 0L
    self.n949 = 0L
    self.n940 = 0L
    self.n930 = 0L
    self.n928 = 0L
    self.n918 = 0L
    self.n916 = 0L
    self.n907 = 0L
    self.n897 = 0L
    self.n895 = 0L
    self.n885 = 0L
    self.n883 = 0L
    self.n873 = 0L
    self.n871 = 0L
    self.n861 = 0L
    self.n859 = 0L
    self.n850 = 0L
    self.n840 = 0L
    self.n838 = 0L
    self.n828 = 0L
    self.n826 = 0L
    self.n816 = 0L
    self.n814 = 0L
    self.n804 = 0L
    self.n802 = 0L
    self.n792 = 0L
    self.n790 = 0L
    self.n780 = 0L
    self.n778 = 0L
    self.n768 = 0L
    self.n766 = 0L
    self.n756 = 0L
    self.n754 = 0L
    self.n744 = 0L
    self.n742 = 0L
    self.n732 = 0L
    self.n730 = 0L
    self.n720 = 0L
    self.n718 = 0L
    self.n708 = 0L
    self.n706 = 0L
    self.n696 = 0L
    self.n694 = 0L
    self.n684 = 0L
    self.n682 = 0L
    self.n672 = 0L
    self.n670 = 0L
    self.n660 = 0L
    self.n658 = 0L
    self.n648 = 0L
    self.n646 = 0L
    self.n636 = 0L
    self.n634 = 0L
    self.n624 = 0L
    self.n622 = 0L
    self.n612 = 0L
    self.n610 = 0L
    self.n600 = 0L
    self.n598 = 0L
    self.n588 = 0L
    self.n586 = 0L
    self.n576 = 0L
    self.n574 = 0L
    self.n564 = 0L
    self.n562 = 0L
    self.n552 = 0L
    self.n550 = 0L
    self.n541 = 0L
    self.n533 = 0L
    self.n525 = 0L
    self.n517 = 0L
    self.n509 = 0L
    self.n501 = 0L
    self.n493 = 0L
    self.n485 = 0L
    self.n477 = 0L
    self.n469 = 0L
    self.n461 = 0L
    self.n453 = 0L
    self.n445 = 0L
    self.n437 = 0L
    self.n429 = 0L
    self.n421 = 0L
    self.n413 = 0L
    self.n405 = 0L
    self.n397 = 0L
    self.n389 = 0L
    self.n381 = 0L
    self.n373 = 0L
    self.n365 = 0L
    self.n357 = 0L
    self.n349 = 0L
    self.n341 = 0L
    self.n333 = 0L
    self.n325 = 0L
    self.n317 = 0L
    self.n309 = 0L
    self.n301 = 0L
    self.n293 = 0L
    self.n285 = 0L
    self.n277 = 0L
    self.n276 = 0L
    self.n276r = 0L
    self.n276e = 0L
    self.n276d = 0L
    self.n269 = 0L
    self.n269r = 0L
    self.n269e = 0L
    self.n269d = 0L
    self.n262 = 0L
    self.n262r = 0L
    self.n262e = 0L
    self.n262d = 0L
    self.n255 = 0L
    self.n255r = 0L
    self.n255e = 0L
    self.n255d = 0L
    self.n248 = 0L
    self.n248r = 0L
    self.n248e = 0L
    self.n248d = 0L
    self.n241 = 0L
    self.n241r = 0L
    self.n241e = 0L
    self.n241d = 0L
    self.n234 = 0L
    self.n234r = 0L
    self.n234e = 0L
    self.n234d = 0L
    self.n227 = 0L
    self.n227r = 0L
    self.n227e = 0L
    self.n227d = 0L
    self.n220 = 0L
    self.n220r = 0L
    self.n220e = 0L
    self.n220d = 0L
    self.n213 = 0L
    self.n213r = 0L
    self.n213e = 0L
    self.n213d = 0L
    self.n206 = 0L
    self.n206r = 0L
    self.n206e = 0L
    self.n206d = 0L
    self.n199 = 0L
    self.n199r = 0L
    self.n199e = 0L
    self.n199d = 0L
    self.n192 = 0L
    self.n192r = 0L
    self.n192e = 0L
    self.n192d = 0L
    self.n185 = 0L
    self.n185r = 0L
    self.n185e = 0L
    self.n185d = 0L
    self.n178 = 0L
    self.n178r = 0L
    self.n178e = 0L
    self.n178d = 0L
    self.n171 = 0L
    self.n171r = 0L
    self.n171e = 0L
    self.n171d = 0L
    self.n164 = 0L
    self.n164r = 0L
    self.n164e = 0L
    self.n164d = 0L
    self.n157 = 0L
    self.n157r = 0L
    self.n157e = 0L
    self.n157d = 0L
    self.n150 = 0L
    self.n150r = 0L
    self.n150e = 0L
    self.n150d = 0L
    self.n143 = 0L
    self.n143r = 0L
    self.n143e = 0L
    self.n143d = 0L
    self.n136 = 0L
    self.n136r = 0L
    self.n136e = 0L
    self.n136d = 0L
    self.n129 = 0L
    self.n129r = 0L
    self.n129e = 0L
    self.n129d = 0L
    self.n122 = 0L
    self.n122r = 0L
    self.n122e = 0L
    self.n122d = 0L
    self.n115 = 0L
    self.n115r = 0L
    self.n115e = 0L
    self.n115d = 0L
    self.n108 = 0L
    self.n108r = 0L
    self.n108e = 0L
    self.n108d = 0L
    self.n101 = 0L
    self.n101r = 0L
    self.n101e = 0L
    self.n101d = 0L
    self.n94 = 0L
    self.n94r = 0L
    self.n94e = 0L
    self.n94d = 0L
    self.n87 = 0L
    self.n87r = 0L
    self.n87e = 0L
    self.n87d = 0L
    self.n80 = 0L
    self.n80r = 0L
    self.n80e = 0L
    self.n80d = 0L
    self.n73 = 0L
    self.n73r = 0L
    self.n73e = 0L
    self.n73d = 0L
    self.n66 = 0L
    self.n66r = 0L
    self.n66e = 0L
    self.n66d = 0L
    self.n59 = 0L
    self.n59r = 0L
    self.n59e = 0L
    self.n59d = 0L
    self.n52 = 0L
    self.n52r = 0L
    self.n52e = 0L
    self.n52d = 0L
    self.n45 = 0L
    self.n45r = 0L
    self.n45e = 0L
    self.n45d = 0L
    self.n973 = 0L
    self.n968 = 0L
    self.n968r = 0L
    self.n968e = 0L
    self.n968d = 0L
    self.n952 = 0L
    self.n947 = 0L
    self.n947r = 0L
    self.n947e = 0L
    self.n947d = 0L
    self.n931 = 0L
    self.n919 = 0L
    self.n914 = 0L
    self.n914r = 0L
    self.n914e = 0L
    self.n914d = 0L
    self.n898 = 0L
    self.n886 = 0L
    self.n874 = 0L
    self.n862 = 0L
    self.n857 = 0L
    self.n857r = 0L
    self.n857e = 0L
    self.n857d = 0L
    self.n841 = 0L
    self.n829 = 0L
    self.n817 = 0L
    self.n805 = 0L
    self.n793 = 0L
    self.n781 = 0L
    self.n769 = 0L
    self.n757 = 0L
    self.n745 = 0L
    self.n733 = 0L
    self.n721 = 0L
    self.n709 = 0L
    self.n697 = 0L
    self.n685 = 0L
    self.n673 = 0L
    self.n661 = 0L
    self.n649 = 0L
    self.n637 = 0L
    self.n625 = 0L
    self.n613 = 0L
    self.n601 = 0L
    self.n589 = 0L
    self.n577 = 0L
    self.n565 = 0L
    self.n553 = 0L
    self.n548 = 0L
    self.n548r = 0L
    self.n548e = 0L
    self.n548d = 0L
    self.n540 = 0L
    self.n540r = 0L
    self.n540e = 0L
    self.n540d = 0L
    self.n532 = 0L
    self.n532r = 0L
    self.n532e = 0L
    self.n532d = 0L
    self.n524 = 0L
    self.n524r = 0L
    self.n524e = 0L
    self.n524d = 0L
    self.n516 = 0L
    self.n516r = 0L
    self.n516e = 0L
    self.n516d = 0L
    self.n508 = 0L
    self.n508r = 0L
    self.n508e = 0L
    self.n508d = 0L
    self.n500 = 0L
    self.n500r = 0L
    self.n500e = 0L
    self.n500d = 0L
    self.n492 = 0L
    self.n492r = 0L
    self.n492e = 0L
    self.n492d = 0L
    self.n484 = 0L
    self.n484r = 0L
    self.n484e = 0L
    self.n484d = 0L
    self.n476 = 0L
    self.n476r = 0L
    self.n476e = 0L
    self.n476d = 0L
    self.n468 = 0L
    self.n468r = 0L
    self.n468e = 0L
    self.n468d = 0L
    self.n460 = 0L
    self.n460r = 0L
    self.n460e = 0L
    self.n460d = 0L
    self.n452 = 0L
    self.n452r = 0L
    self.n452e = 0L
    self.n452d = 0L
    self.n444 = 0L
    self.n444r = 0L
    self.n444e = 0L
    self.n444d = 0L
    self.n436 = 0L
    self.n436r = 0L
    self.n436e = 0L
    self.n436d = 0L
    self.n428 = 0L
    self.n428r = 0L
    self.n428e = 0L
    self.n428d = 0L
    self.n420 = 0L
    self.n420r = 0L
    self.n420e = 0L
    self.n420d = 0L
    self.n412 = 0L
    self.n412r = 0L
    self.n412e = 0L
    self.n412d = 0L
    self.n404 = 0L
    self.n404r = 0L
    self.n404e = 0L
    self.n404d = 0L
    self.n396 = 0L
    self.n396r = 0L
    self.n396e = 0L
    self.n396d = 0L
    self.n388 = 0L
    self.n388r = 0L
    self.n388e = 0L
    self.n388d = 0L
    self.n380 = 0L
    self.n380r = 0L
    self.n380e = 0L
    self.n380d = 0L
    self.n372 = 0L
    self.n372r = 0L
    self.n372e = 0L
    self.n372d = 0L
    self.n364 = 0L
    self.n364r = 0L
    self.n364e = 0L
    self.n364d = 0L
    self.n356 = 0L
    self.n356r = 0L
    self.n356e = 0L
    self.n356d = 0L
    self.n348 = 0L
    self.n348r = 0L
    self.n348e = 0L
    self.n348d = 0L
    self.n340 = 0L
    self.n340r = 0L
    self.n340e = 0L
    self.n340d = 0L
    self.n332 = 0L
    self.n332r = 0L
    self.n332e = 0L
    self.n332d = 0L
    self.n324 = 0L
    self.n324r = 0L
    self.n324e = 0L
    self.n324d = 0L
    self.n316 = 0L
    self.n316r = 0L
    self.n316e = 0L
    self.n316d = 0L
    self.n308 = 0L
    self.n308r = 0L
    self.n308e = 0L
    self.n308d = 0L
    self.n300 = 0L
    self.n300r = 0L
    self.n300e = 0L
    self.n300d = 0L
    self.n292 = 0L
    self.n292r = 0L
    self.n292e = 0L
    self.n292d = 0L
    self.n284 = 0L
    self.n284r = 0L
    self.n284e = 0L
    self.n284d = 0L
    self.n980 = 0L
    self.n980r = 0L
    self.n980e = 0L
    self.n980d = 0L
    self.n959 = 0L
    self.n959r = 0L
    self.n959e = 0L
    self.n959d = 0L
    self.n938 = 0L
    self.n938r = 0L
    self.n938e = 0L
    self.n938d = 0L
    self.n926 = 0L
    self.n926r = 0L
    self.n926e = 0L
    self.n926d = 0L
    self.n905 = 0L
    self.n905r = 0L
    self.n905e = 0L
    self.n905d = 0L
    self.n893 = 0L
    self.n893r = 0L
    self.n893e = 0L
    self.n893d = 0L
    self.n881 = 0L
    self.n881r = 0L
    self.n881e = 0L
    self.n881d = 0L
    self.n869 = 0L
    self.n869r = 0L
    self.n869e = 0L
    self.n869d = 0L
    self.n848 = 0L
    self.n848r = 0L
    self.n848e = 0L
    self.n848d = 0L
    self.n836 = 0L
    self.n836r = 0L
    self.n836e = 0L
    self.n836d = 0L
    self.n824 = 0L
    self.n824r = 0L
    self.n824e = 0L
    self.n824d = 0L
    self.n812 = 0L
    self.n812r = 0L
    self.n812e = 0L
    self.n812d = 0L
    self.n800 = 0L
    self.n800r = 0L
    self.n800e = 0L
    self.n800d = 0L
    self.n788 = 0L
    self.n788r = 0L
    self.n788e = 0L
    self.n788d = 0L
    self.n776 = 0L
    self.n776r = 0L
    self.n776e = 0L
    self.n776d = 0L
    self.n764 = 0L
    self.n764r = 0L
    self.n764e = 0L
    self.n764d = 0L
    self.n752 = 0L
    self.n752r = 0L
    self.n752e = 0L
    self.n752d = 0L
    self.n740 = 0L
    self.n740r = 0L
    self.n740e = 0L
    self.n740d = 0L
    self.n728 = 0L
    self.n728r = 0L
    self.n728e = 0L
    self.n728d = 0L
    self.n716 = 0L
    self.n716r = 0L
    self.n716e = 0L
    self.n716d = 0L
    self.n704 = 0L
    self.n704r = 0L
    self.n704e = 0L
    self.n704d = 0L
    self.n692 = 0L
    self.n692r = 0L
    self.n692e = 0L
    self.n692d = 0L
    self.n680 = 0L
    self.n680r = 0L
    self.n680e = 0L
    self.n680d = 0L
    self.n668 = 0L
    self.n668r = 0L
    self.n668e = 0L
    self.n668d = 0L
    self.n656 = 0L
    self.n656r = 0L
    self.n656e = 0L
    self.n656d = 0L
    self.n644 = 0L
    self.n644r = 0L
    self.n644e = 0L
    self.n644d = 0L
    self.n632 = 0L
    self.n632r = 0L
    self.n632e = 0L
    self.n632d = 0L
    self.n620 = 0L
    self.n620r = 0L
    self.n620e = 0L
    self.n620d = 0L
    self.n608 = 0L
    self.n608r = 0L
    self.n608e = 0L
    self.n608d = 0L
    self.n596 = 0L
    self.n596r = 0L
    self.n596e = 0L
    self.n596d = 0L
    self.n584 = 0L
    self.n584r = 0L
    self.n584e = 0L
    self.n584d = 0L
    self.n572 = 0L
    self.n572r = 0L
    self.n572e = 0L
    self.n572d = 0L
    self.n560 = 0L
    self.n560r = 0L
    self.n560e = 0L
    self.n560d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_i, data_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, k8_i, k9_i, k10_i, k11_i, k12_i, k13_i, k14_i, k15_i, k16_i, k17_i, k18_i, k19_i, k20_i, k21_i, k22_i, k23_i, k24_i, k25_i, k26_i, k27_i, k28_i, k29_i, k30_i, k31_i, k32_i, k33_i, ):
    data_o = self.n980
    self.n981 = self.n980
    self.n971 = ((self.n968 & 0x1000000000L) >> 36)
    self.n969 = ((self.n959 & 0x1000000000L) >> 36)
    self.n960 = ((self.n947 & 0x800000000L) >> 35)
    self.n950 = ((self.n938 & 0x800000000L) >> 35)
    self.n948 = ((self.n926 & 0x800000000L) >> 35)
    self.n939 = ((self.n914 & 0x400000000L) >> 34)
    self.n929 = ((self.n905 & 0x400000000L) >> 34)
    self.n927 = ((self.n893 & 0x400000000L) >> 34)
    self.n917 = ((self.n881 & 0x400000000L) >> 34)
    self.n915 = ((self.n869 & 0x400000000L) >> 34)
    self.n906 = ((self.n857 & 0x200000000L) >> 33)
    self.n896 = ((self.n848 & 0x200000000L) >> 33)
    self.n894 = ((self.n836 & 0x200000000L) >> 33)
    self.n884 = ((self.n824 & 0x200000000L) >> 33)
    self.n882 = ((self.n812 & 0x200000000L) >> 33)
    self.n872 = ((self.n800 & 0x200000000L) >> 33)
    self.n870 = ((self.n788 & 0x200000000L) >> 33)
    self.n860 = ((self.n776 & 0x200000000L) >> 33)
    self.n858 = ((self.n764 & 0x200000000L) >> 33)
    self.n849 = ((self.n752 & 0x100000000L) >> 32)
    self.n839 = ((self.n740 & 0x100000000L) >> 32)
    self.n837 = ((self.n728 & 0x100000000L) >> 32)
    self.n827 = ((self.n716 & 0x100000000L) >> 32)
    self.n825 = ((self.n704 & 0x100000000L) >> 32)
    self.n815 = ((self.n692 & 0x100000000L) >> 32)
    self.n813 = ((self.n680 & 0x100000000L) >> 32)
    self.n803 = ((self.n668 & 0x100000000L) >> 32)
    self.n801 = ((self.n656 & 0x100000000L) >> 32)
    self.n791 = ((self.n644 & 0x100000000L) >> 32)
    self.n789 = ((self.n632 & 0x100000000L) >> 32)
    self.n779 = ((self.n620 & 0x100000000L) >> 32)
    self.n777 = ((self.n608 & 0x100000000L) >> 32)
    self.n767 = ((self.n596 & 0x100000000L) >> 32)
    self.n765 = ((self.n584 & 0x100000000L) >> 32)
    self.n755 = ((self.n572 & 0x100000000L) >> 32)
    self.n753 = ((self.n560 & 0x100000000L) >> 32)
    self.n743 = ((self.n548 & 0x80000000L) >> 31)
    self.n741 = ((self.n540 & 0x80000000L) >> 31)
    self.n731 = ((self.n532 & 0x80000000L) >> 31)
    self.n729 = ((self.n524 & 0x80000000L) >> 31)
    self.n719 = ((self.n516 & 0x80000000L) >> 31)
    self.n717 = ((self.n508 & 0x80000000L) >> 31)
    self.n707 = ((self.n500 & 0x80000000L) >> 31)
    self.n705 = ((self.n492 & 0x80000000L) >> 31)
    self.n695 = ((self.n484 & 0x80000000L) >> 31)
    self.n693 = ((self.n476 & 0x80000000L) >> 31)
    self.n683 = ((self.n468 & 0x80000000L) >> 31)
    self.n681 = ((self.n460 & 0x80000000L) >> 31)
    self.n671 = ((self.n452 & 0x80000000L) >> 31)
    self.n669 = ((self.n444 & 0x80000000L) >> 31)
    self.n659 = ((self.n436 & 0x80000000L) >> 31)
    self.n657 = ((self.n428 & 0x80000000L) >> 31)
    self.n647 = ((self.n420 & 0x80000000L) >> 31)
    self.n645 = ((self.n412 & 0x80000000L) >> 31)
    self.n635 = ((self.n404 & 0x80000000L) >> 31)
    self.n633 = ((self.n396 & 0x80000000L) >> 31)
    self.n623 = ((self.n388 & 0x80000000L) >> 31)
    self.n621 = ((self.n380 & 0x80000000L) >> 31)
    self.n611 = ((self.n372 & 0x80000000L) >> 31)
    self.n609 = ((self.n364 & 0x80000000L) >> 31)
    self.n599 = ((self.n356 & 0x80000000L) >> 31)
    self.n597 = ((self.n348 & 0x80000000L) >> 31)
    self.n587 = ((self.n340 & 0x80000000L) >> 31)
    self.n585 = ((self.n332 & 0x80000000L) >> 31)
    self.n575 = ((self.n324 & 0x80000000L) >> 31)
    self.n573 = ((self.n316 & 0x80000000L) >> 31)
    self.n563 = ((self.n308 & 0x80000000L) >> 31)
    self.n561 = ((self.n300 & 0x80000000L) >> 31)
    self.n551 = ((self.n292 & 0x80000000L) >> 31)
    self.n549 = ((self.n284 & 0x80000000L) >> 31)
    self.n38 = data_i
    self.n37 = k33_i
    self.n36 = k32_i
    self.n35 = k31_i
    self.n34 = k30_i
    self.n33 = k29_i
    self.n32 = k28_i
    self.n31 = k27_i
    self.n30 = k26_i
    self.n29 = k25_i
    self.n28 = k24_i
    self.n27 = k23_i
    self.n26 = k22_i
    self.n25 = k21_i
    self.n24 = k20_i
    self.n23 = k19_i
    self.n22 = k18_i
    self.n21 = k17_i
    self.n20 = k16_i
    self.n19 = k15_i
    self.n18 = k14_i
    self.n17 = k13_i
    self.n16 = k12_i
    self.n15 = k11_i
    self.n14 = k10_i
    self.n13 = k9_i
    self.n12 = k8_i
    self.n11 = k7_i
    self.n10 = k6_i
    self.n9 = k5_i
    self.n8 = k4_i
    self.n7 = k3_i
    self.n6 = k2_i
    self.n5 = k1_i
    self.n4 = k0_i
    self.n3 = reset_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    self.n972 = self.n971 << 37 | self.n968
    self.n970 = self.n969 << 37 | self.n959
    self.n961 = self.n960 << 36 | self.n947
    self.n951 = self.n950 << 36 | self.n938
    self.n949 = self.n948 << 36 | self.n926
    self.n940 = self.n939 << 35 | self.n914
    self.n930 = self.n929 << 35 | self.n905
    self.n928 = self.n927 << 35 | self.n893
    self.n918 = self.n917 << 35 | self.n881
    self.n916 = self.n915 << 35 | self.n869
    self.n907 = self.n906 << 34 | self.n857
    self.n897 = self.n896 << 34 | self.n848
    self.n895 = self.n894 << 34 | self.n836
    self.n885 = self.n884 << 34 | self.n824
    self.n883 = self.n882 << 34 | self.n812
    self.n873 = self.n872 << 34 | self.n800
    self.n871 = self.n870 << 34 | self.n788
    self.n861 = self.n860 << 34 | self.n776
    self.n859 = self.n858 << 34 | self.n764
    self.n850 = self.n849 << 33 | self.n752
    self.n840 = self.n839 << 33 | self.n740
    self.n838 = self.n837 << 33 | self.n728
    self.n828 = self.n827 << 33 | self.n716
    self.n826 = self.n825 << 33 | self.n704
    self.n816 = self.n815 << 33 | self.n692
    self.n814 = self.n813 << 33 | self.n680
    self.n804 = self.n803 << 33 | self.n668
    self.n802 = self.n801 << 33 | self.n656
    self.n792 = self.n791 << 33 | self.n644
    self.n790 = self.n789 << 33 | self.n632
    self.n780 = self.n779 << 33 | self.n620
    self.n778 = self.n777 << 33 | self.n608
    self.n768 = self.n767 << 33 | self.n596
    self.n766 = self.n765 << 33 | self.n584
    self.n756 = self.n755 << 33 | self.n572
    self.n754 = self.n753 << 33 | self.n560
    self.n744 = self.n743 << 32 | self.n548
    self.n742 = self.n741 << 32 | self.n540
    self.n732 = self.n731 << 32 | self.n532
    self.n730 = self.n729 << 32 | self.n524
    self.n720 = self.n719 << 32 | self.n516
    self.n718 = self.n717 << 32 | self.n508
    self.n708 = self.n707 << 32 | self.n500
    self.n706 = self.n705 << 32 | self.n492
    self.n696 = self.n695 << 32 | self.n484
    self.n694 = self.n693 << 32 | self.n476
    self.n684 = self.n683 << 32 | self.n468
    self.n682 = self.n681 << 32 | self.n460
    self.n672 = self.n671 << 32 | self.n452
    self.n670 = self.n669 << 32 | self.n444
    self.n660 = self.n659 << 32 | self.n436
    self.n658 = self.n657 << 32 | self.n428
    self.n648 = self.n647 << 32 | self.n420
    self.n646 = self.n645 << 32 | self.n412
    self.n636 = self.n635 << 32 | self.n404
    self.n634 = self.n633 << 32 | self.n396
    self.n624 = self.n623 << 32 | self.n388
    self.n622 = self.n621 << 32 | self.n380
    self.n612 = self.n611 << 32 | self.n372
    self.n610 = self.n609 << 32 | self.n364
    self.n600 = self.n599 << 32 | self.n356
    self.n598 = self.n597 << 32 | self.n348
    self.n588 = self.n587 << 32 | self.n340
    self.n586 = self.n585 << 32 | self.n332
    self.n576 = self.n575 << 32 | self.n324
    self.n574 = self.n573 << 32 | self.n316
    self.n564 = self.n563 << 32 | self.n308
    self.n562 = self.n561 << 32 | self.n300
    self.n552 = self.n551 << 32 | self.n292
    self.n550 = self.n549 << 32 | self.n284
    self.n541 = (self.n37 * self.n276) & 0xFFFFFFFFL
    self.n533 = (self.n36 * self.n269) & 0xFFFFFFFFL
    self.n525 = (self.n35 * self.n262) & 0xFFFFFFFFL
    self.n517 = (self.n34 * self.n255) & 0xFFFFFFFFL
    self.n509 = (self.n33 * self.n248) & 0xFFFFFFFFL
    self.n501 = (self.n32 * self.n241) & 0xFFFFFFFFL
    self.n493 = (self.n31 * self.n234) & 0xFFFFFFFFL
    self.n485 = (self.n30 * self.n227) & 0xFFFFFFFFL
    self.n477 = (self.n29 * self.n220) & 0xFFFFFFFFL
    self.n469 = (self.n28 * self.n213) & 0xFFFFFFFFL
    self.n461 = (self.n27 * self.n206) & 0xFFFFFFFFL
    self.n453 = (self.n26 * self.n199) & 0xFFFFFFFFL
    self.n445 = (self.n25 * self.n192) & 0xFFFFFFFFL
    self.n437 = (self.n24 * self.n185) & 0xFFFFFFFFL
    self.n429 = (self.n23 * self.n178) & 0xFFFFFFFFL
    self.n421 = (self.n22 * self.n171) & 0xFFFFFFFFL
    self.n413 = (self.n21 * self.n164) & 0xFFFFFFFFL
    self.n405 = (self.n20 * self.n157) & 0xFFFFFFFFL
    self.n397 = (self.n19 * self.n150) & 0xFFFFFFFFL
    self.n389 = (self.n18 * self.n143) & 0xFFFFFFFFL
    self.n381 = (self.n17 * self.n136) & 0xFFFFFFFFL
    self.n373 = (self.n16 * self.n129) & 0xFFFFFFFFL
    self.n365 = (self.n15 * self.n122) & 0xFFFFFFFFL
    self.n357 = (self.n14 * self.n115) & 0xFFFFFFFFL
    self.n349 = (self.n13 * self.n108) & 0xFFFFFFFFL
    self.n341 = (self.n12 * self.n101) & 0xFFFFFFFFL
    self.n333 = (self.n11 * self.n94) & 0xFFFFFFFFL
    self.n325 = (self.n10 * self.n87) & 0xFFFFFFFFL
    self.n317 = (self.n9 * self.n80) & 0xFFFFFFFFL
    self.n309 = (self.n8 * self.n73) & 0xFFFFFFFFL
    self.n301 = (self.n7 * self.n66) & 0xFFFFFFFFL
    self.n293 = (self.n6 * self.n59) & 0xFFFFFFFFL
    self.n285 = (self.n5 * self.n52) & 0xFFFFFFFFL
    self.n277 = (self.n4 * self.n45) & 0xFFFFFFFFL
    self.n276r = self.n3
    self.n276e = self.n1
    self.n276d = self.n269
    self.n269r = self.n3
    self.n269e = self.n1
    self.n269d = self.n262
    self.n262r = self.n3
    self.n262e = self.n1
    self.n262d = self.n255
    self.n255r = self.n3
    self.n255e = self.n1
    self.n255d = self.n248
    self.n248r = self.n3
    self.n248e = self.n1
    self.n248d = self.n241
    self.n241r = self.n3
    self.n241e = self.n1
    self.n241d = self.n234
    self.n234r = self.n3
    self.n234e = self.n1
    self.n234d = self.n227
    self.n227r = self.n3
    self.n227e = self.n1
    self.n227d = self.n220
    self.n220r = self.n3
    self.n220e = self.n1
    self.n220d = self.n213
    self.n213r = self.n3
    self.n213e = self.n1
    self.n213d = self.n206
    self.n206r = self.n3
    self.n206e = self.n1
    self.n206d = self.n199
    self.n199r = self.n3
    self.n199e = self.n1
    self.n199d = self.n192
    self.n192r = self.n3
    self.n192e = self.n1
    self.n192d = self.n185
    self.n185r = self.n3
    self.n185e = self.n1
    self.n185d = self.n178
    self.n178r = self.n3
    self.n178e = self.n1
    self.n178d = self.n171
    self.n171r = self.n3
    self.n171e = self.n1
    self.n171d = self.n164
    self.n164r = self.n3
    self.n164e = self.n1
    self.n164d = self.n157
    self.n157r = self.n3
    self.n157e = self.n1
    self.n157d = self.n150
    self.n150r = self.n3
    self.n150e = self.n1
    self.n150d = self.n143
    self.n143r = self.n3
    self.n143e = self.n1
    self.n143d = self.n136
    self.n136r = self.n3
    self.n136e = self.n1
    self.n136d = self.n129
    self.n129r = self.n3
    self.n129e = self.n1
    self.n129d = self.n122
    self.n122r = self.n3
    self.n122e = self.n1
    self.n122d = self.n115
    self.n115r = self.n3
    self.n115e = self.n1
    self.n115d = self.n108
    self.n108r = self.n3
    self.n108e = self.n1
    self.n108d = self.n101
    self.n101r = self.n3
    self.n101e = self.n1
    self.n101d = self.n94
    self.n94r = self.n3
    self.n94e = self.n1
    self.n94d = self.n87
    self.n87r = self.n3
    self.n87e = self.n1
    self.n87d = self.n80
    self.n80r = self.n3
    self.n80e = self.n1
    self.n80d = self.n73
    self.n73r = self.n3
    self.n73e = self.n1
    self.n73d = self.n66
    self.n66r = self.n3
    self.n66e = self.n1
    self.n66d = self.n59
    self.n59r = self.n3
    self.n59e = self.n1
    self.n59d = self.n52
    self.n52r = self.n3
    self.n52e = self.n1
    self.n52d = self.n45
    self.n45r = self.n3
    self.n45e = self.n1
    self.n45d = self.n38
    self.n973 = (self.n970 + self.n972) & 0x3FFFFFFFFFL
    self.n968r = self.n2
    self.n968e = self.n1
    self.n968d = self.n961
    self.n952 = (self.n949 + self.n951) & 0x1FFFFFFFFFL
    self.n947r = self.n2
    self.n947e = self.n1
    self.n947d = self.n940
    self.n931 = (self.n928 + self.n930) & 0xFFFFFFFFFL
    self.n919 = (self.n916 + self.n918) & 0xFFFFFFFFFL
    self.n914r = self.n2
    self.n914e = self.n1
    self.n914d = self.n907
    self.n898 = (self.n895 + self.n897) & 0x7FFFFFFFFL
    self.n886 = (self.n883 + self.n885) & 0x7FFFFFFFFL
    self.n874 = (self.n871 + self.n873) & 0x7FFFFFFFFL
    self.n862 = (self.n859 + self.n861) & 0x7FFFFFFFFL
    self.n857r = self.n2
    self.n857e = self.n1
    self.n857d = self.n850
    self.n841 = (self.n838 + self.n840) & 0x3FFFFFFFFL
    self.n829 = (self.n826 + self.n828) & 0x3FFFFFFFFL
    self.n817 = (self.n814 + self.n816) & 0x3FFFFFFFFL
    self.n805 = (self.n802 + self.n804) & 0x3FFFFFFFFL
    self.n793 = (self.n790 + self.n792) & 0x3FFFFFFFFL
    self.n781 = (self.n778 + self.n780) & 0x3FFFFFFFFL
    self.n769 = (self.n766 + self.n768) & 0x3FFFFFFFFL
    self.n757 = (self.n754 + self.n756) & 0x3FFFFFFFFL
    self.n745 = (self.n742 + self.n744) & 0x1FFFFFFFFL
    self.n733 = (self.n730 + self.n732) & 0x1FFFFFFFFL
    self.n721 = (self.n718 + self.n720) & 0x1FFFFFFFFL
    self.n709 = (self.n706 + self.n708) & 0x1FFFFFFFFL
    self.n697 = (self.n694 + self.n696) & 0x1FFFFFFFFL
    self.n685 = (self.n682 + self.n684) & 0x1FFFFFFFFL
    self.n673 = (self.n670 + self.n672) & 0x1FFFFFFFFL
    self.n661 = (self.n658 + self.n660) & 0x1FFFFFFFFL
    self.n649 = (self.n646 + self.n648) & 0x1FFFFFFFFL
    self.n637 = (self.n634 + self.n636) & 0x1FFFFFFFFL
    self.n625 = (self.n622 + self.n624) & 0x1FFFFFFFFL
    self.n613 = (self.n610 + self.n612) & 0x1FFFFFFFFL
    self.n601 = (self.n598 + self.n600) & 0x1FFFFFFFFL
    self.n589 = (self.n586 + self.n588) & 0x1FFFFFFFFL
    self.n577 = (self.n574 + self.n576) & 0x1FFFFFFFFL
    self.n565 = (self.n562 + self.n564) & 0x1FFFFFFFFL
    self.n553 = (self.n550 + self.n552) & 0x1FFFFFFFFL
    self.n548r = self.n2
    self.n548e = self.n1
    self.n548d = self.n541
    self.n540r = self.n2
    self.n540e = self.n1
    self.n540d = self.n533
    self.n532r = self.n2
    self.n532e = self.n1
    self.n532d = self.n525
    self.n524r = self.n2
    self.n524e = self.n1
    self.n524d = self.n517
    self.n516r = self.n2
    self.n516e = self.n1
    self.n516d = self.n509
    self.n508r = self.n2
    self.n508e = self.n1
    self.n508d = self.n501
    self.n500r = self.n2
    self.n500e = self.n1
    self.n500d = self.n493
    self.n492r = self.n2
    self.n492e = self.n1
    self.n492d = self.n485
    self.n484r = self.n2
    self.n484e = self.n1
    self.n484d = self.n477
    self.n476r = self.n2
    self.n476e = self.n1
    self.n476d = self.n469
    self.n468r = self.n2
    self.n468e = self.n1
    self.n468d = self.n461
    self.n460r = self.n2
    self.n460e = self.n1
    self.n460d = self.n453
    self.n452r = self.n2
    self.n452e = self.n1
    self.n452d = self.n445
    self.n444r = self.n2
    self.n444e = self.n1
    self.n444d = self.n437
    self.n436r = self.n2
    self.n436e = self.n1
    self.n436d = self.n429
    self.n428r = self.n2
    self.n428e = self.n1
    self.n428d = self.n421
    self.n420r = self.n2
    self.n420e = self.n1
    self.n420d = self.n413
    self.n412r = self.n2
    self.n412e = self.n1
    self.n412d = self.n405
    self.n404r = self.n2
    self.n404e = self.n1
    self.n404d = self.n397
    self.n396r = self.n2
    self.n396e = self.n1
    self.n396d = self.n389
    self.n388r = self.n2
    self.n388e = self.n1
    self.n388d = self.n381
    self.n380r = self.n2
    self.n380e = self.n1
    self.n380d = self.n373
    self.n372r = self.n2
    self.n372e = self.n1
    self.n372d = self.n365
    self.n364r = self.n2
    self.n364e = self.n1
    self.n364d = self.n357
    self.n356r = self.n2
    self.n356e = self.n1
    self.n356d = self.n349
    self.n348r = self.n2
    self.n348e = self.n1
    self.n348d = self.n341
    self.n340r = self.n2
    self.n340e = self.n1
    self.n340d = self.n333
    self.n332r = self.n2
    self.n332e = self.n1
    self.n332d = self.n325
    self.n324r = self.n2
    self.n324e = self.n1
    self.n324d = self.n317
    self.n316r = self.n2
    self.n316e = self.n1
    self.n316d = self.n309
    self.n308r = self.n2
    self.n308e = self.n1
    self.n308d = self.n301
    self.n300r = self.n2
    self.n300e = self.n1
    self.n300d = self.n293
    self.n292r = self.n2
    self.n292e = self.n1
    self.n292d = self.n285
    self.n284r = self.n2
    self.n284e = self.n1
    self.n284d = self.n277
    self.n980r = self.n2
    self.n980e = self.n1
    self.n980d = self.n973
    self.n959r = self.n2
    self.n959e = self.n1
    self.n959d = self.n952
    self.n938r = self.n2
    self.n938e = self.n1
    self.n938d = self.n931
    self.n926r = self.n2
    self.n926e = self.n1
    self.n926d = self.n919
    self.n905r = self.n2
    self.n905e = self.n1
    self.n905d = self.n898
    self.n893r = self.n2
    self.n893e = self.n1
    self.n893d = self.n886
    self.n881r = self.n2
    self.n881e = self.n1
    self.n881d = self.n874
    self.n869r = self.n2
    self.n869e = self.n1
    self.n869d = self.n862
    self.n848r = self.n2
    self.n848e = self.n1
    self.n848d = self.n841
    self.n836r = self.n2
    self.n836e = self.n1
    self.n836d = self.n829
    self.n824r = self.n2
    self.n824e = self.n1
    self.n824d = self.n817
    self.n812r = self.n2
    self.n812e = self.n1
    self.n812d = self.n805
    self.n800r = self.n2
    self.n800e = self.n1
    self.n800d = self.n793
    self.n788r = self.n2
    self.n788e = self.n1
    self.n788d = self.n781
    self.n776r = self.n2
    self.n776e = self.n1
    self.n776d = self.n769
    self.n764r = self.n2
    self.n764e = self.n1
    self.n764d = self.n757
    self.n752r = self.n2
    self.n752e = self.n1
    self.n752d = self.n745
    self.n740r = self.n2
    self.n740e = self.n1
    self.n740d = self.n733
    self.n728r = self.n2
    self.n728e = self.n1
    self.n728d = self.n721
    self.n716r = self.n2
    self.n716e = self.n1
    self.n716d = self.n709
    self.n704r = self.n2
    self.n704e = self.n1
    self.n704d = self.n697
    self.n692r = self.n2
    self.n692e = self.n1
    self.n692d = self.n685
    self.n680r = self.n2
    self.n680e = self.n1
    self.n680d = self.n673
    self.n668r = self.n2
    self.n668e = self.n1
    self.n668d = self.n661
    self.n656r = self.n2
    self.n656e = self.n1
    self.n656d = self.n649
    self.n644r = self.n2
    self.n644e = self.n1
    self.n644d = self.n637
    self.n632r = self.n2
    self.n632e = self.n1
    self.n632d = self.n625
    self.n620r = self.n2
    self.n620e = self.n1
    self.n620d = self.n613
    self.n608r = self.n2
    self.n608e = self.n1
    self.n608d = self.n601
    self.n596r = self.n2
    self.n596e = self.n1
    self.n596d = self.n589
    self.n584r = self.n2
    self.n584e = self.n1
    self.n584d = self.n577
    self.n572r = self.n2
    self.n572e = self.n1
    self.n572d = self.n565
    self.n560r = self.n2
    self.n560e = self.n1
    self.n560d = self.n553
    return (data_o, )

  def cycle_clock(self):
    if self.n45r:
      self.n45 = 0L
    elif self.n45e:
        self.n45 = self.n45d
    if self.n52r:
      self.n52 = 0L
    elif self.n52e:
        self.n52 = self.n52d
    if self.n59r:
      self.n59 = 0L
    elif self.n59e:
        self.n59 = self.n59d
    if self.n66r:
      self.n66 = 0L
    elif self.n66e:
        self.n66 = self.n66d
    if self.n73r:
      self.n73 = 0L
    elif self.n73e:
        self.n73 = self.n73d
    if self.n80r:
      self.n80 = 0L
    elif self.n80e:
        self.n80 = self.n80d
    if self.n87r:
      self.n87 = 0L
    elif self.n87e:
        self.n87 = self.n87d
    if self.n94r:
      self.n94 = 0L
    elif self.n94e:
        self.n94 = self.n94d
    if self.n101r:
      self.n101 = 0L
    elif self.n101e:
        self.n101 = self.n101d
    if self.n108r:
      self.n108 = 0L
    elif self.n108e:
        self.n108 = self.n108d
    if self.n115r:
      self.n115 = 0L
    elif self.n115e:
        self.n115 = self.n115d
    if self.n122r:
      self.n122 = 0L
    elif self.n122e:
        self.n122 = self.n122d
    if self.n129r:
      self.n129 = 0L
    elif self.n129e:
        self.n129 = self.n129d
    if self.n136r:
      self.n136 = 0L
    elif self.n136e:
        self.n136 = self.n136d
    if self.n143r:
      self.n143 = 0L
    elif self.n143e:
        self.n143 = self.n143d
    if self.n150r:
      self.n150 = 0L
    elif self.n150e:
        self.n150 = self.n150d
    if self.n157r:
      self.n157 = 0L
    elif self.n157e:
        self.n157 = self.n157d
    if self.n164r:
      self.n164 = 0L
    elif self.n164e:
        self.n164 = self.n164d
    if self.n171r:
      self.n171 = 0L
    elif self.n171e:
        self.n171 = self.n171d
    if self.n178r:
      self.n178 = 0L
    elif self.n178e:
        self.n178 = self.n178d
    if self.n185r:
      self.n185 = 0L
    elif self.n185e:
        self.n185 = self.n185d
    if self.n192r:
      self.n192 = 0L
    elif self.n192e:
        self.n192 = self.n192d
    if self.n199r:
      self.n199 = 0L
    elif self.n199e:
        self.n199 = self.n199d
    if self.n206r:
      self.n206 = 0L
    elif self.n206e:
        self.n206 = self.n206d
    if self.n213r:
      self.n213 = 0L
    elif self.n213e:
        self.n213 = self.n213d
    if self.n220r:
      self.n220 = 0L
    elif self.n220e:
        self.n220 = self.n220d
    if self.n227r:
      self.n227 = 0L
    elif self.n227e:
        self.n227 = self.n227d
    if self.n234r:
      self.n234 = 0L
    elif self.n234e:
        self.n234 = self.n234d
    if self.n241r:
      self.n241 = 0L
    elif self.n241e:
        self.n241 = self.n241d
    if self.n248r:
      self.n248 = 0L
    elif self.n248e:
        self.n248 = self.n248d
    if self.n255r:
      self.n255 = 0L
    elif self.n255e:
        self.n255 = self.n255d
    if self.n262r:
      self.n262 = 0L
    elif self.n262e:
        self.n262 = self.n262d
    if self.n269r:
      self.n269 = 0L
    elif self.n269e:
        self.n269 = self.n269d
    if self.n276r:
      self.n276 = 0L
    elif self.n276e:
        self.n276 = self.n276d
    if self.n284r:
      self.n284 = 0L
    elif self.n284e:
        self.n284 = self.n284d
    if self.n292r:
      self.n292 = 0L
    elif self.n292e:
        self.n292 = self.n292d
    if self.n300r:
      self.n300 = 0L
    elif self.n300e:
        self.n300 = self.n300d
    if self.n308r:
      self.n308 = 0L
    elif self.n308e:
        self.n308 = self.n308d
    if self.n316r:
      self.n316 = 0L
    elif self.n316e:
        self.n316 = self.n316d
    if self.n324r:
      self.n324 = 0L
    elif self.n324e:
        self.n324 = self.n324d
    if self.n332r:
      self.n332 = 0L
    elif self.n332e:
        self.n332 = self.n332d
    if self.n340r:
      self.n340 = 0L
    elif self.n340e:
        self.n340 = self.n340d
    if self.n348r:
      self.n348 = 0L
    elif self.n348e:
        self.n348 = self.n348d
    if self.n356r:
      self.n356 = 0L
    elif self.n356e:
        self.n356 = self.n356d
    if self.n364r:
      self.n364 = 0L
    elif self.n364e:
        self.n364 = self.n364d
    if self.n372r:
      self.n372 = 0L
    elif self.n372e:
        self.n372 = self.n372d
    if self.n380r:
      self.n380 = 0L
    elif self.n380e:
        self.n380 = self.n380d
    if self.n388r:
      self.n388 = 0L
    elif self.n388e:
        self.n388 = self.n388d
    if self.n396r:
      self.n396 = 0L
    elif self.n396e:
        self.n396 = self.n396d
    if self.n404r:
      self.n404 = 0L
    elif self.n404e:
        self.n404 = self.n404d
    if self.n412r:
      self.n412 = 0L
    elif self.n412e:
        self.n412 = self.n412d
    if self.n420r:
      self.n420 = 0L
    elif self.n420e:
        self.n420 = self.n420d
    if self.n428r:
      self.n428 = 0L
    elif self.n428e:
        self.n428 = self.n428d
    if self.n436r:
      self.n436 = 0L
    elif self.n436e:
        self.n436 = self.n436d
    if self.n444r:
      self.n444 = 0L
    elif self.n444e:
        self.n444 = self.n444d
    if self.n452r:
      self.n452 = 0L
    elif self.n452e:
        self.n452 = self.n452d
    if self.n460r:
      self.n460 = 0L
    elif self.n460e:
        self.n460 = self.n460d
    if self.n468r:
      self.n468 = 0L
    elif self.n468e:
        self.n468 = self.n468d
    if self.n476r:
      self.n476 = 0L
    elif self.n476e:
        self.n476 = self.n476d
    if self.n484r:
      self.n484 = 0L
    elif self.n484e:
        self.n484 = self.n484d
    if self.n492r:
      self.n492 = 0L
    elif self.n492e:
        self.n492 = self.n492d
    if self.n500r:
      self.n500 = 0L
    elif self.n500e:
        self.n500 = self.n500d
    if self.n508r:
      self.n508 = 0L
    elif self.n508e:
        self.n508 = self.n508d
    if self.n516r:
      self.n516 = 0L
    elif self.n516e:
        self.n516 = self.n516d
    if self.n524r:
      self.n524 = 0L
    elif self.n524e:
        self.n524 = self.n524d
    if self.n532r:
      self.n532 = 0L
    elif self.n532e:
        self.n532 = self.n532d
    if self.n540r:
      self.n540 = 0L
    elif self.n540e:
        self.n540 = self.n540d
    if self.n548r:
      self.n548 = 0L
    elif self.n548e:
        self.n548 = self.n548d
    if self.n560r:
      self.n560 = 0L
    elif self.n560e:
        self.n560 = self.n560d
    if self.n572r:
      self.n572 = 0L
    elif self.n572e:
        self.n572 = self.n572d
    if self.n584r:
      self.n584 = 0L
    elif self.n584e:
        self.n584 = self.n584d
    if self.n596r:
      self.n596 = 0L
    elif self.n596e:
        self.n596 = self.n596d
    if self.n608r:
      self.n608 = 0L
    elif self.n608e:
        self.n608 = self.n608d
    if self.n620r:
      self.n620 = 0L
    elif self.n620e:
        self.n620 = self.n620d
    if self.n632r:
      self.n632 = 0L
    elif self.n632e:
        self.n632 = self.n632d
    if self.n644r:
      self.n644 = 0L
    elif self.n644e:
        self.n644 = self.n644d
    if self.n656r:
      self.n656 = 0L
    elif self.n656e:
        self.n656 = self.n656d
    if self.n668r:
      self.n668 = 0L
    elif self.n668e:
        self.n668 = self.n668d
    if self.n680r:
      self.n680 = 0L
    elif self.n680e:
        self.n680 = self.n680d
    if self.n692r:
      self.n692 = 0L
    elif self.n692e:
        self.n692 = self.n692d
    if self.n704r:
      self.n704 = 0L
    elif self.n704e:
        self.n704 = self.n704d
    if self.n716r:
      self.n716 = 0L
    elif self.n716e:
        self.n716 = self.n716d
    if self.n728r:
      self.n728 = 0L
    elif self.n728e:
        self.n728 = self.n728d
    if self.n740r:
      self.n740 = 0L
    elif self.n740e:
        self.n740 = self.n740d
    if self.n752r:
      self.n752 = 0L
    elif self.n752e:
        self.n752 = self.n752d
    if self.n764r:
      self.n764 = 0L
    elif self.n764e:
        self.n764 = self.n764d
    if self.n776r:
      self.n776 = 0L
    elif self.n776e:
        self.n776 = self.n776d
    if self.n788r:
      self.n788 = 0L
    elif self.n788e:
        self.n788 = self.n788d
    if self.n800r:
      self.n800 = 0L
    elif self.n800e:
        self.n800 = self.n800d
    if self.n812r:
      self.n812 = 0L
    elif self.n812e:
        self.n812 = self.n812d
    if self.n824r:
      self.n824 = 0L
    elif self.n824e:
        self.n824 = self.n824d
    if self.n836r:
      self.n836 = 0L
    elif self.n836e:
        self.n836 = self.n836d
    if self.n848r:
      self.n848 = 0L
    elif self.n848e:
        self.n848 = self.n848d
    if self.n857r:
      self.n857 = 0L
    elif self.n857e:
        self.n857 = self.n857d
    if self.n869r:
      self.n869 = 0L
    elif self.n869e:
        self.n869 = self.n869d
    if self.n881r:
      self.n881 = 0L
    elif self.n881e:
        self.n881 = self.n881d
    if self.n893r:
      self.n893 = 0L
    elif self.n893e:
        self.n893 = self.n893d
    if self.n905r:
      self.n905 = 0L
    elif self.n905e:
        self.n905 = self.n905d
    if self.n914r:
      self.n914 = 0L
    elif self.n914e:
        self.n914 = self.n914d
    if self.n926r:
      self.n926 = 0L
    elif self.n926e:
        self.n926 = self.n926d
    if self.n938r:
      self.n938 = 0L
    elif self.n938e:
        self.n938 = self.n938d
    if self.n947r:
      self.n947 = 0L
    elif self.n947e:
        self.n947 = self.n947d
    if self.n959r:
      self.n959 = 0L
    elif self.n959e:
        self.n959 = self.n959d
    if self.n968r:
      self.n968 = 0L
    elif self.n968e:
        self.n968 = self.n968d
    if self.n980r:
      self.n980 = 0L
    elif self.n980e:
        self.n980 = self.n980d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n38 = self.n38
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n9 = self.n9
    self.sim_n10 = self.n10
    self.sim_n11 = self.n11
    self.sim_n12 = self.n12
    self.sim_n13 = self.n13
    self.sim_n14 = self.n14
    self.sim_n15 = self.n15
    self.sim_n16 = self.n16
    self.sim_n17 = self.n17
    self.sim_n18 = self.n18
    self.sim_n19 = self.n19
    self.sim_n20 = self.n20
    self.sim_n21 = self.n21
    self.sim_n22 = self.n22
    self.sim_n23 = self.n23
    self.sim_n24 = self.n24
    self.sim_n25 = self.n25
    self.sim_n26 = self.n26
    self.sim_n27 = self.n27
    self.sim_n28 = self.n28
    self.sim_n29 = self.n29
    self.sim_n30 = self.n30
    self.sim_n31 = self.n31
    self.sim_n32 = self.n32
    self.sim_n33 = self.n33
    self.sim_n34 = self.n34
    self.sim_n35 = self.n35
    self.sim_n36 = self.n36
    self.sim_n37 = self.n37
    self.sim_n981 = self.n981
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fir_33_16_16 $end\n")
    self.sim_file.write("$var wire 1 ! reset_i $end\n")
    self.sim_file.write("$var wire 16 \" data_i $end\n")
    self.sim_file.write("$var wire 16 # k0_i $end\n")
    self.sim_file.write("$var wire 16 $ k1_i $end\n")
    self.sim_file.write("$var wire 16 % k2_i $end\n")
    self.sim_file.write("$var wire 16 & k3_i $end\n")
    self.sim_file.write("$var wire 16 ' k4_i $end\n")
    self.sim_file.write("$var wire 16 ( k5_i $end\n")
    self.sim_file.write("$var wire 16 ) k6_i $end\n")
    self.sim_file.write("$var wire 16 * k7_i $end\n")
    self.sim_file.write("$var wire 16 + k8_i $end\n")
    self.sim_file.write("$var wire 16 , k9_i $end\n")
    self.sim_file.write("$var wire 16 - k10_i $end\n")
    self.sim_file.write("$var wire 16 . k11_i $end\n")
    self.sim_file.write("$var wire 16 / k12_i $end\n")
    self.sim_file.write("$var wire 16 0 k13_i $end\n")
    self.sim_file.write("$var wire 16 1 k14_i $end\n")
    self.sim_file.write("$var wire 16 2 k15_i $end\n")
    self.sim_file.write("$var wire 16 3 k16_i $end\n")
    self.sim_file.write("$var wire 16 4 k17_i $end\n")
    self.sim_file.write("$var wire 16 5 k18_i $end\n")
    self.sim_file.write("$var wire 16 6 k19_i $end\n")
    self.sim_file.write("$var wire 16 7 k20_i $end\n")
    self.sim_file.write("$var wire 16 8 k21_i $end\n")
    self.sim_file.write("$var wire 16 9 k22_i $end\n")
    self.sim_file.write("$var wire 16 : k23_i $end\n")
    self.sim_file.write("$var wire 16 ; k24_i $end\n")
    self.sim_file.write("$var wire 16 < k25_i $end\n")
    self.sim_file.write("$var wire 16 = k26_i $end\n")
    self.sim_file.write("$var wire 16 > k27_i $end\n")
    self.sim_file.write("$var wire 16 ? k28_i $end\n")
    self.sim_file.write("$var wire 16 @ k29_i $end\n")
    self.sim_file.write("$var wire 16 A k30_i $end\n")
    self.sim_file.write("$var wire 16 B k31_i $end\n")
    self.sim_file.write("$var wire 16 C k32_i $end\n")
    self.sim_file.write("$var wire 16 D k33_i $end\n")
    self.sim_file.write("$var wire 38 E data_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n38 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n38 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" \"\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n9 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n9 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n10 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n10 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n11 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n11 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" *\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n12 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n12 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" +\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n13 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n13 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ,\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n14 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n14 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" -\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n15 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n15 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" .\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n16 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n16 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" /\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n17 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n17 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 0\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n18 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n18 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 1\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n19 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n19 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 2\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n20 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n20 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 3\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n21 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n21 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 4\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n22 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n22 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 5\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n23 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n23 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 6\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n24 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n24 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 7\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n25 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n25 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 8\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n26 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n26 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" 9\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n27 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n27 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" :\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n28 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n28 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ;\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n29 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n29 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" <\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n30 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n30 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" =\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n31 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n31 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" >\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n32 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n32 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" ?\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n33 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n33 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" @\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n34 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n34 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" A\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n35 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n35 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" B\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n36 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n36 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" C\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n37 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n37 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" D\n")
    found = 0
    for bit in range(37, -1, -1):
      if found:
        if self.n981 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n981 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" E\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n38 != self.n38:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n38 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n38 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" \"\n")
      self.sim_n38 = self.n38
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n8 = self.n8
    if self.sim_n9 != self.n9:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n9 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n9 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n9 = self.n9
    if self.sim_n10 != self.n10:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n10 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n10 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n10 = self.n10
    if self.sim_n11 != self.n11:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n11 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n11 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" *\n")
      self.sim_n11 = self.n11
    if self.sim_n12 != self.n12:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n12 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n12 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" +\n")
      self.sim_n12 = self.n12
    if self.sim_n13 != self.n13:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n13 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n13 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ,\n")
      self.sim_n13 = self.n13
    if self.sim_n14 != self.n14:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n14 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n14 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" -\n")
      self.sim_n14 = self.n14
    if self.sim_n15 != self.n15:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n15 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n15 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" .\n")
      self.sim_n15 = self.n15
    if self.sim_n16 != self.n16:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n16 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n16 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" /\n")
      self.sim_n16 = self.n16
    if self.sim_n17 != self.n17:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n17 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n17 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 0\n")
      self.sim_n17 = self.n17
    if self.sim_n18 != self.n18:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n18 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n18 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 1\n")
      self.sim_n18 = self.n18
    if self.sim_n19 != self.n19:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n19 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n19 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 2\n")
      self.sim_n19 = self.n19
    if self.sim_n20 != self.n20:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n20 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n20 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 3\n")
      self.sim_n20 = self.n20
    if self.sim_n21 != self.n21:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n21 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n21 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 4\n")
      self.sim_n21 = self.n21
    if self.sim_n22 != self.n22:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n22 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n22 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 5\n")
      self.sim_n22 = self.n22
    if self.sim_n23 != self.n23:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n23 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n23 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 6\n")
      self.sim_n23 = self.n23
    if self.sim_n24 != self.n24:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n24 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n24 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 7\n")
      self.sim_n24 = self.n24
    if self.sim_n25 != self.n25:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n25 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n25 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 8\n")
      self.sim_n25 = self.n25
    if self.sim_n26 != self.n26:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n26 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n26 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" 9\n")
      self.sim_n26 = self.n26
    if self.sim_n27 != self.n27:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n27 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n27 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" :\n")
      self.sim_n27 = self.n27
    if self.sim_n28 != self.n28:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n28 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n28 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ;\n")
      self.sim_n28 = self.n28
    if self.sim_n29 != self.n29:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n29 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n29 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" <\n")
      self.sim_n29 = self.n29
    if self.sim_n30 != self.n30:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n30 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n30 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" =\n")
      self.sim_n30 = self.n30
    if self.sim_n31 != self.n31:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n31 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n31 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" >\n")
      self.sim_n31 = self.n31
    if self.sim_n32 != self.n32:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n32 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n32 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" ?\n")
      self.sim_n32 = self.n32
    if self.sim_n33 != self.n33:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n33 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n33 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" @\n")
      self.sim_n33 = self.n33
    if self.sim_n34 != self.n34:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n34 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n34 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" A\n")
      self.sim_n34 = self.n34
    if self.sim_n35 != self.n35:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n35 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n35 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" B\n")
      self.sim_n35 = self.n35
    if self.sim_n36 != self.n36:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n36 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n36 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" C\n")
      self.sim_n36 = self.n36
    if self.sim_n37 != self.n37:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n37 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n37 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" D\n")
      self.sim_n37 = self.n37
    if self.sim_n981 != self.n981:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(37, -1, -1):
        if found:
          if self.n981 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n981 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" E\n")
      self.sim_n981 = self.n981
    self.sim_count = self.sim_count + 1

