#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs finite impulse response (FIR) filtering.
#    The filter's sum of products is pipelined with a register after
#    every multiplier and adder.  The adder network is a balanced binary
#    tree to minimize latency.  The sum of products has no numeric loss because the
#    multipliers keep all resulting bits and each adder extends the precision by 1.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
#  
#    Inputs:
#      data_i  : Input data.
#      k0_i    : Coefficient 0 multiplied by in_i(0).
#      k1_i    : Coefficient 1 multiplied by in_i(k-1).
#      k2_i    : Coefficient 2 multiplied by in_i(k-2).
#      ...
#      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
#  
#    Outputs:
#      data_o : Output data.
#  
#  Built In Parameters:
#  
#    Filter Order             = 3
#    Input Precision          = 8
#    Coefficient Precision    = 8
#    Sum of Products Latency  = 3
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:45:46 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fir_3_8_8
#    Clock Domains : clock_c  
#    Vector Input  : reset_i(1)
#    Vector Input  : data_i(8)
#    Vector Input  : k0_i(8)
#    Vector Input  : k1_i(8)
#    Vector Input  : k2_i(8)
#    Vector Input  : k3_i(8)
#    Vector Output : data_o(18)
#  
#  
#  

import sys
import time

class cf_fir_3_8_8:

  def init(self):
    self.n105 = 0L
    self.n95 = 0L
    self.n93 = 0L
    self.n83 = 0L
    self.n81 = 0L
    self.n71 = 0L
    self.n69 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n96 = 0L
    self.n94 = 0L
    self.n84 = 0L
    self.n82 = 0L
    self.n72 = 0L
    self.n70 = 0L
    self.n61 = 0L
    self.n53 = 0L
    self.n45 = 0L
    self.n37 = 0L
    self.n36 = 0L
    self.n36r = 0L
    self.n36e = 0L
    self.n36d = 0L
    self.n29 = 0L
    self.n29r = 0L
    self.n29e = 0L
    self.n29d = 0L
    self.n22 = 0L
    self.n22r = 0L
    self.n22e = 0L
    self.n22d = 0L
    self.n15 = 0L
    self.n15r = 0L
    self.n15e = 0L
    self.n15d = 0L
    self.n97 = 0L
    self.n85 = 0L
    self.n73 = 0L
    self.n68 = 0L
    self.n68r = 0L
    self.n68e = 0L
    self.n68d = 0L
    self.n60 = 0L
    self.n60r = 0L
    self.n60e = 0L
    self.n60d = 0L
    self.n52 = 0L
    self.n52r = 0L
    self.n52e = 0L
    self.n52d = 0L
    self.n44 = 0L
    self.n44r = 0L
    self.n44e = 0L
    self.n44d = 0L
    self.n104 = 0L
    self.n104r = 0L
    self.n104e = 0L
    self.n104d = 0L
    self.n92 = 0L
    self.n92r = 0L
    self.n92e = 0L
    self.n92d = 0L
    self.n80 = 0L
    self.n80r = 0L
    self.n80e = 0L
    self.n80d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_i, data_i, k0_i, k1_i, k2_i, k3_i, ):
    data_o = self.n104
    self.n105 = self.n104
    self.n95 = ((self.n92 & 0x10000L) >> 16)
    self.n93 = ((self.n80 & 0x10000L) >> 16)
    self.n83 = ((self.n68 & 0x8000L) >> 15)
    self.n81 = ((self.n60 & 0x8000L) >> 15)
    self.n71 = ((self.n52 & 0x8000L) >> 15)
    self.n69 = ((self.n44 & 0x8000L) >> 15)
    self.n8 = data_i
    self.n7 = k3_i
    self.n6 = k2_i
    self.n5 = k1_i
    self.n4 = k0_i
    self.n3 = reset_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    self.n96 = self.n95 << 17 | self.n92
    self.n94 = self.n93 << 17 | self.n80
    self.n84 = self.n83 << 16 | self.n68
    self.n82 = self.n81 << 16 | self.n60
    self.n72 = self.n71 << 16 | self.n52
    self.n70 = self.n69 << 16 | self.n44
    self.n61 = (self.n7 * self.n36) & 0xFFFFL
    self.n53 = (self.n6 * self.n29) & 0xFFFFL
    self.n45 = (self.n5 * self.n22) & 0xFFFFL
    self.n37 = (self.n4 * self.n15) & 0xFFFFL
    self.n36r = self.n3
    self.n36e = self.n1
    self.n36d = self.n29
    self.n29r = self.n3
    self.n29e = self.n1
    self.n29d = self.n22
    self.n22r = self.n3
    self.n22e = self.n1
    self.n22d = self.n15
    self.n15r = self.n3
    self.n15e = self.n1
    self.n15d = self.n8
    self.n97 = (self.n94 + self.n96) & 0x3FFFFL
    self.n85 = (self.n82 + self.n84) & 0x1FFFFL
    self.n73 = (self.n70 + self.n72) & 0x1FFFFL
    self.n68r = self.n2
    self.n68e = self.n1
    self.n68d = self.n61
    self.n60r = self.n2
    self.n60e = self.n1
    self.n60d = self.n53
    self.n52r = self.n2
    self.n52e = self.n1
    self.n52d = self.n45
    self.n44r = self.n2
    self.n44e = self.n1
    self.n44d = self.n37
    self.n104r = self.n2
    self.n104e = self.n1
    self.n104d = self.n97
    self.n92r = self.n2
    self.n92e = self.n1
    self.n92d = self.n85
    self.n80r = self.n2
    self.n80e = self.n1
    self.n80d = self.n73
    return (data_o, )

  def cycle_clock(self):
    if self.n15r:
      self.n15 = 0L
    elif self.n15e:
        self.n15 = self.n15d
    if self.n22r:
      self.n22 = 0L
    elif self.n22e:
        self.n22 = self.n22d
    if self.n29r:
      self.n29 = 0L
    elif self.n29e:
        self.n29 = self.n29d
    if self.n36r:
      self.n36 = 0L
    elif self.n36e:
        self.n36 = self.n36d
    if self.n44r:
      self.n44 = 0L
    elif self.n44e:
        self.n44 = self.n44d
    if self.n52r:
      self.n52 = 0L
    elif self.n52e:
        self.n52 = self.n52d
    if self.n60r:
      self.n60 = 0L
    elif self.n60e:
        self.n60 = self.n60d
    if self.n68r:
      self.n68 = 0L
    elif self.n68e:
        self.n68 = self.n68d
    if self.n80r:
      self.n80 = 0L
    elif self.n80e:
        self.n80 = self.n80d
    if self.n92r:
      self.n92 = 0L
    elif self.n92e:
        self.n92 = self.n92d
    if self.n104r:
      self.n104 = 0L
    elif self.n104e:
        self.n104 = self.n104d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n8 = self.n8
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n105 = self.n105
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fir_3_8_8 $end\n")
    self.sim_file.write("$var wire 1 ! reset_i $end\n")
    self.sim_file.write("$var wire 8 \" data_i $end\n")
    self.sim_file.write("$var wire 8 # k0_i $end\n")
    self.sim_file.write("$var wire 8 $ k1_i $end\n")
    self.sim_file.write("$var wire 8 % k2_i $end\n")
    self.sim_file.write("$var wire 8 & k3_i $end\n")
    self.sim_file.write("$var wire 18 ' data_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" \"\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(7, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(17, -1, -1):
      if found:
        if self.n105 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n105 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" \"\n")
      self.sim_n8 = self.n8
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(7, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n7 = self.n7
    if self.sim_n105 != self.n105:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(17, -1, -1):
        if found:
          if self.n105 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n105 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n105 = self.n105
    self.sim_count = self.sim_count + 1

