--
--  Copyright (c) 2003 Launchbird Design Systems, Inc.
--  All rights reserved.
--  
--  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
--    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
--    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
--  
--  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
--  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
--  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
--  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
--  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
--  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--  
--  
--  Overview:
--  
--    Performs finite impulse response (FIR) filtering.
--    The filter's sum of products is pipelined with a register after
--    every multiplier and adder.  The adder network is a balanced binary
--    tree to minimize latency.  The sum of products has no numeric loss because the
--    multipliers keep all resulting bits and each adder extends the precision by 1.
--  
--  Interface:
--  
--    Synchronization:
--      clock_c  : Clock input.
--      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
--  
--    Inputs:
--      data_i  : Input data.
--      k0_i    : Coefficient 0 multiplied by in_i(0).
--      k1_i    : Coefficient 1 multiplied by in_i(k-1).
--      k2_i    : Coefficient 2 multiplied by in_i(k-2).
--      ...
--      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
--  
--    Outputs:
--      data_o : Output data.
--  
--  Built In Parameters:
--  
--    Filter Order             = 3
--    Input Precision          = 8
--    Coefficient Precision    = 8
--    Sum of Products Latency  = 3
--  
--  
--  
--  
--  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
--  
--  Build Date : Fri Aug 22 09:45:46 CDT 2003
--  
--  Interface
--  
--    Build Name    : cf_fir_3_8_8
--    Clock Domains : clock_c  
--    Vector Input  : reset_i(1)
--    Vector Input  : data_i(8)
--    Vector Input  : k0_i(8)
--    Vector Input  : k1_i(8)
--    Vector Input  : k2_i(8)
--    Vector Input  : k3_i(8)
--    Vector Output : data_o(18)
--  
--  
--  

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_3_8_8_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0));
end entity cf_fir_3_8_8_4;
architecture rtl of cf_fir_3_8_8_4 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(16 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(16 downto 0);
signal n5 : unsigned(16 downto 0);
signal n6 : unsigned(16 downto 0) := "00000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(16 downto 0);
signal n11 : unsigned(16 downto 0);
signal n12 : unsigned(16 downto 0) := "00000000000000000";
begin
n1 <= i3(15 downto 15);
n2 <= n1 & i3;
n3 <= i4(15 downto 15);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(15 downto 15);
n8 <= n7 & i5;
n9 <= i6(15 downto 15);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "00000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_3_8_8_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0));
end entity cf_fir_3_8_8_3;
architecture rtl of cf_fir_3_8_8_3 is
signal n1 : unsigned(15 downto 0);
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0);
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0);
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0) := "0000000000000000";
begin
n1 <= i3 * i7;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i8;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i9;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_3_8_8_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
o1 : out unsigned(17 downto 0));
end entity cf_fir_3_8_8_2;
architecture rtl of cf_fir_3_8_8_2 is
signal n1 : unsigned(7 downto 0) := "00000000";
signal n2 : unsigned(7 downto 0) := "00000000";
signal n3 : unsigned(7 downto 0) := "00000000";
signal n4 : unsigned(7 downto 0) := "00000000";
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(17 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(17 downto 0);
signal n9 : unsigned(17 downto 0);
signal n10 : unsigned(17 downto 0) := "000000000000000000";
signal s11_1 : unsigned(16 downto 0);
signal s11_2 : unsigned(16 downto 0);
signal s12_1 : unsigned(15 downto 0);
signal s12_2 : unsigned(15 downto 0);
signal s12_3 : unsigned(15 downto 0);
signal s12_4 : unsigned(15 downto 0);
component cf_fir_3_8_8_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
o1 : out unsigned(16 downto 0);
o2 : out unsigned(16 downto 0));
end component cf_fir_3_8_8_4;
component cf_fir_3_8_8_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
i9 : in  unsigned(7 downto 0);
i10 : in  unsigned(7 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0));
end component cf_fir_3_8_8_3;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n1 <= "00000000";
    elsif i1 = "1" then
      n1 <= i8;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n2 <= "00000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n3 <= "00000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i3 = "1" then
      n4 <= "00000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= s11_1(16 downto 16);
n6 <= n5 & s11_1;
n7 <= s11_2(16 downto 16);
n8 <= n7 & s11_2;
n9 <= n6 + n8;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n10 <= "000000000000000000";
    elsif i1 = "1" then
      n10 <= n9;
    end if;
  end if;
end process;
s11 : cf_fir_3_8_8_4 port map (clock_c, i1, i2, s12_1, s12_2, s12_3, s12_4, s11_1, s11_2);
s12 : cf_fir_3_8_8_3 port map (clock_c, i1, i2, i4, i5, i6, i7, n1, n2, n3, n4, s12_1, s12_2, s12_3, s12_4);
o1 <= n10;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_3_8_8_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(7 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
o1 : out unsigned(17 downto 0));
end entity cf_fir_3_8_8_1;
architecture rtl of cf_fir_3_8_8_1 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal s3_1 : unsigned(17 downto 0);
component cf_fir_3_8_8_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
i7 : in  unsigned(7 downto 0);
i8 : in  unsigned(7 downto 0);
o1 : out unsigned(17 downto 0));
end component cf_fir_3_8_8_2;
begin
n1 <= "1";
n2 <= "0";
s3 : cf_fir_3_8_8_2 port map (clock_c, n1, n2, i1, i2, i3, i4, i5, i6, s3_1);
o1 <= s3_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_3_8_8 is
port(
signal clock_c : in std_logic;
signal reset_i : in unsigned(0 downto 0);
signal data_i : in unsigned(7 downto 0);
signal k0_i : in unsigned(7 downto 0);
signal k1_i : in unsigned(7 downto 0);
signal k2_i : in unsigned(7 downto 0);
signal k3_i : in unsigned(7 downto 0);
signal data_o : out unsigned(17 downto 0));
end entity cf_fir_3_8_8;
architecture rtl of cf_fir_3_8_8 is
component cf_fir_3_8_8_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(7 downto 0);
i3 : in  unsigned(7 downto 0);
i4 : in  unsigned(7 downto 0);
i5 : in  unsigned(7 downto 0);
i6 : in  unsigned(7 downto 0);
o1 : out unsigned(17 downto 0));
end component cf_fir_3_8_8_1;
signal n1 : unsigned(17 downto 0);
begin
s1 : cf_fir_3_8_8_1 port map (clock_c, reset_i, k0_i, k1_i, k2_i, k3_i, data_i, n1);
data_o <= n1;
end architecture rtl;


