//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs finite impulse response (FIR) filtering.
//    The filter's sum of products is pipelined with a register after
//    every multiplier and adder.  The adder network is a balanced binary
//    tree to minimize latency.  The sum of products has no numeric loss because the
//    multipliers keep all resulting bits and each adder extends the precision by 1.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
//  
//    Inputs:
//      data_i  : Input data.
//      k0_i    : Coefficient 0 multiplied by in_i(0).
//      k1_i    : Coefficient 1 multiplied by in_i(k-1).
//      k2_i    : Coefficient 2 multiplied by in_i(k-2).
//      ...
//      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
//  
//    Outputs:
//      data_o : Output data.
//  
//  Built In Parameters:
//  
//    Filter Order             = 7
//    Input Precision          = 16
//    Coefficient Precision    = 16
//    Sum of Products Latency  = 4
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:45:49 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fir_7_16_16
//    Clock Domains : clock_c  
//    Vector Input  : reset_i(1)
//    Vector Input  : data_i(16)
//    Vector Input  : k0_i(16)
//    Vector Input  : k1_i(16)
//    Vector Input  : k2_i(16)
//    Vector Input  : k3_i(16)
//    Vector Input  : k4_i(16)
//    Vector Input  : k5_i(16)
//    Vector Input  : k6_i(16)
//    Vector Input  : k7_i(16)
//    Vector Output : data_o(35)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_fir_7_16_16.h"

static unsigned char *data_o;
static unsigned char n207[1];
static unsigned char n205[1];
static unsigned char n195[1];
static unsigned char n193[1];
static unsigned char n183[1];
static unsigned char n181[1];
static unsigned char n171[1];
static unsigned char n169[1];
static unsigned char n159[1];
static unsigned char n157[1];
static unsigned char n147[1];
static unsigned char n145[1];
static unsigned char n135[1];
static unsigned char n133[1];
static unsigned char *data_i;
static unsigned char *k7_i;
static unsigned char *k6_i;
static unsigned char *k5_i;
static unsigned char *k4_i;
static unsigned char *k3_i;
static unsigned char *k2_i;
static unsigned char *k1_i;
static unsigned char *k0_i;
static unsigned char *reset_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char n208[5];
static unsigned char n206[5];
static unsigned char n196[5];
static unsigned char n194[5];
static unsigned char n184[5];
static unsigned char n182[5];
static unsigned char n172[5];
static unsigned char n170[5];
static unsigned char n160[5];
static unsigned char n158[5];
static unsigned char n148[5];
static unsigned char n146[5];
static unsigned char n136[5];
static unsigned char n134[5];
static unsigned char n125[4];
static unsigned char n117[4];
static unsigned char n109[4];
static unsigned char n101[4];
static unsigned char n93[4];
static unsigned char n85[4];
static unsigned char n77[4];
static unsigned char n69[4];
static unsigned char n68[2];
static unsigned char n68r[1];
static unsigned char n68e[1];
static unsigned char n68d[2];
static unsigned char n61[2];
static unsigned char n61r[1];
static unsigned char n61e[1];
static unsigned char n61d[2];
static unsigned char n54[2];
static unsigned char n54r[1];
static unsigned char n54e[1];
static unsigned char n54d[2];
static unsigned char n47[2];
static unsigned char n47r[1];
static unsigned char n47e[1];
static unsigned char n47d[2];
static unsigned char n40[2];
static unsigned char n40r[1];
static unsigned char n40e[1];
static unsigned char n40d[2];
static unsigned char n33[2];
static unsigned char n33r[1];
static unsigned char n33e[1];
static unsigned char n33d[2];
static unsigned char n26[2];
static unsigned char n26r[1];
static unsigned char n26e[1];
static unsigned char n26d[2];
static unsigned char n19[2];
static unsigned char n19r[1];
static unsigned char n19e[1];
static unsigned char n19d[2];
static unsigned char n209[5];
static unsigned char n197[5];
static unsigned char n185[5];
static unsigned char n173[5];
static unsigned char n161[5];
static unsigned char n149[5];
static unsigned char n137[5];
static unsigned char n132[4];
static unsigned char n132r[1];
static unsigned char n132e[1];
static unsigned char n132d[4];
static unsigned char n124[4];
static unsigned char n124r[1];
static unsigned char n124e[1];
static unsigned char n124d[4];
static unsigned char n116[4];
static unsigned char n116r[1];
static unsigned char n116e[1];
static unsigned char n116d[4];
static unsigned char n108[4];
static unsigned char n108r[1];
static unsigned char n108e[1];
static unsigned char n108d[4];
static unsigned char n100[4];
static unsigned char n100r[1];
static unsigned char n100e[1];
static unsigned char n100d[4];
static unsigned char n92[4];
static unsigned char n92r[1];
static unsigned char n92e[1];
static unsigned char n92d[4];
static unsigned char n84[4];
static unsigned char n84r[1];
static unsigned char n84e[1];
static unsigned char n84d[4];
static unsigned char n76[4];
static unsigned char n76r[1];
static unsigned char n76e[1];
static unsigned char n76d[4];
static unsigned char n216[5];
static unsigned char n216r[1];
static unsigned char n216e[1];
static unsigned char n216d[5];
static unsigned char n204[5];
static unsigned char n204r[1];
static unsigned char n204e[1];
static unsigned char n204d[5];
static unsigned char n192[5];
static unsigned char n192r[1];
static unsigned char n192e[1];
static unsigned char n192d[5];
static unsigned char n180[5];
static unsigned char n180r[1];
static unsigned char n180e[1];
static unsigned char n180d[5];
static unsigned char n168[5];
static unsigned char n168r[1];
static unsigned char n168e[1];
static unsigned char n168d[5];
static unsigned char n156[5];
static unsigned char n156r[1];
static unsigned char n156e[1];
static unsigned char n156d[5];
static unsigned char n144[5];
static unsigned char n144r[1];
static unsigned char n144e[1];
static unsigned char n144d[5];

void cf_fir_7_16_16_ports(unsigned char* port_reset_i, unsigned char* port_data_i, unsigned char* port_k0_i, unsigned char* port_k1_i, unsigned char* port_k2_i, unsigned char* port_k3_i, unsigned char* port_k4_i, unsigned char* port_k5_i, unsigned char* port_k6_i, unsigned char* port_k7_i, unsigned char* port_data_o) {
  reset_i = port_reset_i;
  data_i = port_data_i;
  k0_i = port_k0_i;
  k1_i = port_k1_i;
  k2_i = port_k2_i;
  k3_i = port_k3_i;
  k4_i = port_k4_i;
  k5_i = port_k5_i;
  k6_i = port_k6_i;
  k7_i = port_k7_i;
  data_o = port_data_o;
}

void cf_fir_7_16_16_calc() {
  data_o[0] = n216[0];
  data_o[1] = n216[1];
  data_o[2] = n216[2];
  data_o[3] = n216[3];
  data_o[4] = n216[4];
  n207[0] = (1 & (n204[4] >> 1));
  n205[0] = (1 & (n192[4] >> 1));
  n195[0] = (1 & (n180[4]));
  n193[0] = (1 & (n168[4]));
  n183[0] = (1 & (n156[4]));
  n181[0] = (1 & (n144[4]));
  n171[0] = (1 & (n132[3] >> 7));
  n169[0] = (1 & (n124[3] >> 7));
  n159[0] = (1 & (n116[3] >> 7));
  n157[0] = (1 & (n108[3] >> 7));
  n147[0] = (1 & (n100[3] >> 7));
  n145[0] = (1 & (n92[3] >> 7));
  n135[0] = (1 & (n84[3] >> 7));
  n133[0] = (1 & (n76[3] >> 7));
  n2[0] = 0;
  n1[0] = 1;
  n208[0] = n204[0];
  n208[1] = n204[1];
  n208[2] = n204[2];
  n208[3] = n204[3];
  n208[4] = 255 & (n207[0] << 2 | n204[4]);
  n206[0] = n192[0];
  n206[1] = n192[1];
  n206[2] = n192[2];
  n206[3] = n192[3];
  n206[4] = 255 & (n205[0] << 2 | n192[4]);
  n196[0] = n180[0];
  n196[1] = n180[1];
  n196[2] = n180[2];
  n196[3] = n180[3];
  n196[4] = 255 & (n195[0] << 1 | n180[4]);
  n194[0] = n168[0];
  n194[1] = n168[1];
  n194[2] = n168[2];
  n194[3] = n168[3];
  n194[4] = 255 & (n193[0] << 1 | n168[4]);
  n184[0] = n156[0];
  n184[1] = n156[1];
  n184[2] = n156[2];
  n184[3] = n156[3];
  n184[4] = 255 & (n183[0] << 1 | n156[4]);
  n182[0] = n144[0];
  n182[1] = n144[1];
  n182[2] = n144[2];
  n182[3] = n144[3];
  n182[4] = 255 & (n181[0] << 1 | n144[4]);
  n172[0] = n132[0];
  n172[1] = n132[1];
  n172[2] = n132[2];
  n172[3] = n132[3];
  n172[4] = n171[0];
  n170[0] = n124[0];
  n170[1] = n124[1];
  n170[2] = n124[2];
  n170[3] = n124[3];
  n170[4] = n169[0];
  n160[0] = n116[0];
  n160[1] = n116[1];
  n160[2] = n116[2];
  n160[3] = n116[3];
  n160[4] = n159[0];
  n158[0] = n108[0];
  n158[1] = n108[1];
  n158[2] = n108[2];
  n158[3] = n108[3];
  n158[4] = n157[0];
  n148[0] = n100[0];
  n148[1] = n100[1];
  n148[2] = n100[2];
  n148[3] = n100[3];
  n148[4] = n147[0];
  n146[0] = n92[0];
  n146[1] = n92[1];
  n146[2] = n92[2];
  n146[3] = n92[3];
  n146[4] = n145[0];
  n136[0] = n84[0];
  n136[1] = n84[1];
  n136[2] = n84[2];
  n136[3] = n84[3];
  n136[4] = n135[0];
  n134[0] = n76[0];
  n134[1] = n76[1];
  n134[2] = n76[2];
  n134[3] = n76[3];
  n134[4] = n133[0];
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k7_i[1];
    a[0] = k7_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n68[1];
    b[0] = n68[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n125[0] = 255 & (unsigned char) tmp, tmp >> 8), n125[1] = 255 & (unsigned char) tmp, tmp >> 8), n125[2] = 255 & (unsigned char) tmp, tmp >> 8), n125[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k6_i[1];
    a[0] = k6_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n61[1];
    b[0] = n61[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n117[0] = 255 & (unsigned char) tmp, tmp >> 8), n117[1] = 255 & (unsigned char) tmp, tmp >> 8), n117[2] = 255 & (unsigned char) tmp, tmp >> 8), n117[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k5_i[1];
    a[0] = k5_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n54[1];
    b[0] = n54[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n109[0] = 255 & (unsigned char) tmp, tmp >> 8), n109[1] = 255 & (unsigned char) tmp, tmp >> 8), n109[2] = 255 & (unsigned char) tmp, tmp >> 8), n109[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k4_i[1];
    a[0] = k4_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n47[1];
    b[0] = n47[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n101[0] = 255 & (unsigned char) tmp, tmp >> 8), n101[1] = 255 & (unsigned char) tmp, tmp >> 8), n101[2] = 255 & (unsigned char) tmp, tmp >> 8), n101[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k3_i[1];
    a[0] = k3_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n40[1];
    b[0] = n40[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n93[0] = 255 & (unsigned char) tmp, tmp >> 8), n93[1] = 255 & (unsigned char) tmp, tmp >> 8), n93[2] = 255 & (unsigned char) tmp, tmp >> 8), n93[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k2_i[1];
    a[0] = k2_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n33[1];
    b[0] = n33[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n85[0] = 255 & (unsigned char) tmp, tmp >> 8), n85[1] = 255 & (unsigned char) tmp, tmp >> 8), n85[2] = 255 & (unsigned char) tmp, tmp >> 8), n85[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k1_i[1];
    a[0] = k1_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n26[1];
    b[0] = n26[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n77[0] = 255 & (unsigned char) tmp, tmp >> 8), n77[1] = 255 & (unsigned char) tmp, tmp >> 8), n77[2] = 255 & (unsigned char) tmp, tmp >> 8), n77[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k0_i[1];
    a[0] = k0_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n19[1];
    b[0] = n19[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n69[0] = 255 & (unsigned char) tmp, tmp >> 8), n69[1] = 255 & (unsigned char) tmp, tmp >> 8), n69[2] = 255 & (unsigned char) tmp, tmp >> 8), n69[3] = 255 & (unsigned char) tmp);
  }
  n68r[0] = reset_i[0];
  n68e[0] = n1[0];
  n68d[0] = n61[0];
  n68d[1] = n61[1];
  n61r[0] = reset_i[0];
  n61e[0] = n1[0];
  n61d[0] = n54[0];
  n61d[1] = n54[1];
  n54r[0] = reset_i[0];
  n54e[0] = n1[0];
  n54d[0] = n47[0];
  n54d[1] = n47[1];
  n47r[0] = reset_i[0];
  n47e[0] = n1[0];
  n47d[0] = n40[0];
  n47d[1] = n40[1];
  n40r[0] = reset_i[0];
  n40e[0] = n1[0];
  n40d[0] = n33[0];
  n40d[1] = n33[1];
  n33r[0] = reset_i[0];
  n33e[0] = n1[0];
  n33d[0] = n26[0];
  n33d[1] = n26[1];
  n26r[0] = reset_i[0];
  n26e[0] = n1[0];
  n26d[0] = n19[0];
  n26d[1] = n19[1];
  n19r[0] = reset_i[0];
  n19e[0] = n1[0];
  n19d[0] = data_i[0];
  n19d[1] = data_i[1];
  { unsigned int tmp; (tmp = (unsigned int) n206[4] + (unsigned int) n208[4] + (tmp = (unsigned int) n206[3] + (unsigned int) n208[3] + (tmp = (unsigned int) n206[2] + (unsigned int) n208[2] + (tmp = (unsigned int) n206[1] + (unsigned int) n208[1] + (tmp = (unsigned int) n206[0] + (unsigned int) n208[0], n209[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n209[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n209[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n209[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n209[4] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n194[4] + (unsigned int) n196[4] + (tmp = (unsigned int) n194[3] + (unsigned int) n196[3] + (tmp = (unsigned int) n194[2] + (unsigned int) n196[2] + (tmp = (unsigned int) n194[1] + (unsigned int) n196[1] + (tmp = (unsigned int) n194[0] + (unsigned int) n196[0], n197[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n197[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n197[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n197[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n197[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n182[4] + (unsigned int) n184[4] + (tmp = (unsigned int) n182[3] + (unsigned int) n184[3] + (tmp = (unsigned int) n182[2] + (unsigned int) n184[2] + (tmp = (unsigned int) n182[1] + (unsigned int) n184[1] + (tmp = (unsigned int) n182[0] + (unsigned int) n184[0], n185[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n185[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n185[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n185[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n185[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n170[4] + (unsigned int) n172[4] + (tmp = (unsigned int) n170[3] + (unsigned int) n172[3] + (tmp = (unsigned int) n170[2] + (unsigned int) n172[2] + (tmp = (unsigned int) n170[1] + (unsigned int) n172[1] + (tmp = (unsigned int) n170[0] + (unsigned int) n172[0], n173[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n173[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n173[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n173[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n173[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n158[4] + (unsigned int) n160[4] + (tmp = (unsigned int) n158[3] + (unsigned int) n160[3] + (tmp = (unsigned int) n158[2] + (unsigned int) n160[2] + (tmp = (unsigned int) n158[1] + (unsigned int) n160[1] + (tmp = (unsigned int) n158[0] + (unsigned int) n160[0], n161[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n161[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n161[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n161[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n161[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n146[4] + (unsigned int) n148[4] + (tmp = (unsigned int) n146[3] + (unsigned int) n148[3] + (tmp = (unsigned int) n146[2] + (unsigned int) n148[2] + (tmp = (unsigned int) n146[1] + (unsigned int) n148[1] + (tmp = (unsigned int) n146[0] + (unsigned int) n148[0], n149[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n149[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n149[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n149[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n149[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n134[4] + (unsigned int) n136[4] + (tmp = (unsigned int) n134[3] + (unsigned int) n136[3] + (tmp = (unsigned int) n134[2] + (unsigned int) n136[2] + (tmp = (unsigned int) n134[1] + (unsigned int) n136[1] + (tmp = (unsigned int) n134[0] + (unsigned int) n136[0], n137[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[4] = 1 & (unsigned char) tmp); }
  n132r[0] = n2[0];
  n132e[0] = n1[0];
  n132d[0] = n125[0];
  n132d[1] = n125[1];
  n132d[2] = n125[2];
  n132d[3] = n125[3];
  n124r[0] = n2[0];
  n124e[0] = n1[0];
  n124d[0] = n117[0];
  n124d[1] = n117[1];
  n124d[2] = n117[2];
  n124d[3] = n117[3];
  n116r[0] = n2[0];
  n116e[0] = n1[0];
  n116d[0] = n109[0];
  n116d[1] = n109[1];
  n116d[2] = n109[2];
  n116d[3] = n109[3];
  n108r[0] = n2[0];
  n108e[0] = n1[0];
  n108d[0] = n101[0];
  n108d[1] = n101[1];
  n108d[2] = n101[2];
  n108d[3] = n101[3];
  n100r[0] = n2[0];
  n100e[0] = n1[0];
  n100d[0] = n93[0];
  n100d[1] = n93[1];
  n100d[2] = n93[2];
  n100d[3] = n93[3];
  n92r[0] = n2[0];
  n92e[0] = n1[0];
  n92d[0] = n85[0];
  n92d[1] = n85[1];
  n92d[2] = n85[2];
  n92d[3] = n85[3];
  n84r[0] = n2[0];
  n84e[0] = n1[0];
  n84d[0] = n77[0];
  n84d[1] = n77[1];
  n84d[2] = n77[2];
  n84d[3] = n77[3];
  n76r[0] = n2[0];
  n76e[0] = n1[0];
  n76d[0] = n69[0];
  n76d[1] = n69[1];
  n76d[2] = n69[2];
  n76d[3] = n69[3];
  n216r[0] = n2[0];
  n216e[0] = n1[0];
  n216d[0] = n209[0];
  n216d[1] = n209[1];
  n216d[2] = n209[2];
  n216d[3] = n209[3];
  n216d[4] = n209[4];
  n204r[0] = n2[0];
  n204e[0] = n1[0];
  n204d[0] = n197[0];
  n204d[1] = n197[1];
  n204d[2] = n197[2];
  n204d[3] = n197[3];
  n204d[4] = n197[4];
  n192r[0] = n2[0];
  n192e[0] = n1[0];
  n192d[0] = n185[0];
  n192d[1] = n185[1];
  n192d[2] = n185[2];
  n192d[3] = n185[3];
  n192d[4] = n185[4];
  n180r[0] = n2[0];
  n180e[0] = n1[0];
  n180d[0] = n173[0];
  n180d[1] = n173[1];
  n180d[2] = n173[2];
  n180d[3] = n173[3];
  n180d[4] = n173[4];
  n168r[0] = n2[0];
  n168e[0] = n1[0];
  n168d[0] = n161[0];
  n168d[1] = n161[1];
  n168d[2] = n161[2];
  n168d[3] = n161[3];
  n168d[4] = n161[4];
  n156r[0] = n2[0];
  n156e[0] = n1[0];
  n156d[0] = n149[0];
  n156d[1] = n149[1];
  n156d[2] = n149[2];
  n156d[3] = n149[3];
  n156d[4] = n149[4];
  n144r[0] = n2[0];
  n144e[0] = n1[0];
  n144d[0] = n137[0];
  n144d[1] = n137[1];
  n144d[2] = n137[2];
  n144d[3] = n137[3];
  n144d[4] = n137[4];
}

void cf_fir_7_16_16_init() {
  n207[0] = 0;
  n205[0] = 0;
  n195[0] = 0;
  n193[0] = 0;
  n183[0] = 0;
  n181[0] = 0;
  n171[0] = 0;
  n169[0] = 0;
  n159[0] = 0;
  n157[0] = 0;
  n147[0] = 0;
  n145[0] = 0;
  n135[0] = 0;
  n133[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  { int index; for (index = 5; index > 0;) n208[--index] = 0; }
  { int index; for (index = 5; index > 0;) n206[--index] = 0; }
  { int index; for (index = 5; index > 0;) n196[--index] = 0; }
  { int index; for (index = 5; index > 0;) n194[--index] = 0; }
  { int index; for (index = 5; index > 0;) n184[--index] = 0; }
  { int index; for (index = 5; index > 0;) n182[--index] = 0; }
  { int index; for (index = 5; index > 0;) n172[--index] = 0; }
  { int index; for (index = 5; index > 0;) n170[--index] = 0; }
  { int index; for (index = 5; index > 0;) n160[--index] = 0; }
  { int index; for (index = 5; index > 0;) n158[--index] = 0; }
  { int index; for (index = 5; index > 0;) n148[--index] = 0; }
  { int index; for (index = 5; index > 0;) n146[--index] = 0; }
  { int index; for (index = 5; index > 0;) n136[--index] = 0; }
  { int index; for (index = 5; index > 0;) n134[--index] = 0; }
  { int index; for (index = 4; index > 0;) n125[--index] = 0; }
  { int index; for (index = 4; index > 0;) n117[--index] = 0; }
  { int index; for (index = 4; index > 0;) n109[--index] = 0; }
  { int index; for (index = 4; index > 0;) n101[--index] = 0; }
  { int index; for (index = 4; index > 0;) n93[--index] = 0; }
  { int index; for (index = 4; index > 0;) n85[--index] = 0; }
  { int index; for (index = 4; index > 0;) n77[--index] = 0; }
  { int index; for (index = 4; index > 0;) n69[--index] = 0; }
  { int index; for (index = 2; index > 0;) n68[--index] = 0; }
  n68r[0] = 0;
  n68e[0] = 0;
  { int index; for (index = 2; index > 0;) n68d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n61[--index] = 0; }
  n61r[0] = 0;
  n61e[0] = 0;
  { int index; for (index = 2; index > 0;) n61d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n54[--index] = 0; }
  n54r[0] = 0;
  n54e[0] = 0;
  { int index; for (index = 2; index > 0;) n54d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n47[--index] = 0; }
  n47r[0] = 0;
  n47e[0] = 0;
  { int index; for (index = 2; index > 0;) n47d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n40[--index] = 0; }
  n40r[0] = 0;
  n40e[0] = 0;
  { int index; for (index = 2; index > 0;) n40d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n33[--index] = 0; }
  n33r[0] = 0;
  n33e[0] = 0;
  { int index; for (index = 2; index > 0;) n33d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n26[--index] = 0; }
  n26r[0] = 0;
  n26e[0] = 0;
  { int index; for (index = 2; index > 0;) n26d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n19[--index] = 0; }
  n19r[0] = 0;
  n19e[0] = 0;
  { int index; for (index = 2; index > 0;) n19d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n209[--index] = 0; }
  { int index; for (index = 5; index > 0;) n197[--index] = 0; }
  { int index; for (index = 5; index > 0;) n185[--index] = 0; }
  { int index; for (index = 5; index > 0;) n173[--index] = 0; }
  { int index; for (index = 5; index > 0;) n161[--index] = 0; }
  { int index; for (index = 5; index > 0;) n149[--index] = 0; }
  { int index; for (index = 5; index > 0;) n137[--index] = 0; }
  { int index; for (index = 4; index > 0;) n132[--index] = 0; }
  n132r[0] = 0;
  n132e[0] = 0;
  { int index; for (index = 4; index > 0;) n132d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n124[--index] = 0; }
  n124r[0] = 0;
  n124e[0] = 0;
  { int index; for (index = 4; index > 0;) n124d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n116[--index] = 0; }
  n116r[0] = 0;
  n116e[0] = 0;
  { int index; for (index = 4; index > 0;) n116d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n108[--index] = 0; }
  n108r[0] = 0;
  n108e[0] = 0;
  { int index; for (index = 4; index > 0;) n108d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n100[--index] = 0; }
  n100r[0] = 0;
  n100e[0] = 0;
  { int index; for (index = 4; index > 0;) n100d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n92[--index] = 0; }
  n92r[0] = 0;
  n92e[0] = 0;
  { int index; for (index = 4; index > 0;) n92d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n84[--index] = 0; }
  n84r[0] = 0;
  n84e[0] = 0;
  { int index; for (index = 4; index > 0;) n84d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n76[--index] = 0; }
  n76r[0] = 0;
  n76e[0] = 0;
  { int index; for (index = 4; index > 0;) n76d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n216[--index] = 0; }
  n216r[0] = 0;
  n216e[0] = 0;
  { int index; for (index = 5; index > 0;) n216d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n204[--index] = 0; }
  n204r[0] = 0;
  n204e[0] = 0;
  { int index; for (index = 5; index > 0;) n204d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n192[--index] = 0; }
  n192r[0] = 0;
  n192e[0] = 0;
  { int index; for (index = 5; index > 0;) n192d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n180[--index] = 0; }
  n180r[0] = 0;
  n180e[0] = 0;
  { int index; for (index = 5; index > 0;) n180d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n168[--index] = 0; }
  n168r[0] = 0;
  n168e[0] = 0;
  { int index; for (index = 5; index > 0;) n168d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n156[--index] = 0; }
  n156r[0] = 0;
  n156e[0] = 0;
  { int index; for (index = 5; index > 0;) n156d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n144[--index] = 0; }
  n144r[0] = 0;
  n144e[0] = 0;
  { int index; for (index = 5; index > 0;) n144d[--index] = 0; }
  cf_fir_7_16_16_calc();
}

void cf_fir_7_16_16_cycle_clock()
{
  if (n19r[0]) {
    n19[0] = 0;
    n19[1] = 0;
  }
  else if (n19e[0]) {
    n19[0] = n19d[0];
    n19[1] = n19d[1];
  }
  if (n26r[0]) {
    n26[0] = 0;
    n26[1] = 0;
  }
  else if (n26e[0]) {
    n26[0] = n26d[0];
    n26[1] = n26d[1];
  }
  if (n33r[0]) {
    n33[0] = 0;
    n33[1] = 0;
  }
  else if (n33e[0]) {
    n33[0] = n33d[0];
    n33[1] = n33d[1];
  }
  if (n40r[0]) {
    n40[0] = 0;
    n40[1] = 0;
  }
  else if (n40e[0]) {
    n40[0] = n40d[0];
    n40[1] = n40d[1];
  }
  if (n47r[0]) {
    n47[0] = 0;
    n47[1] = 0;
  }
  else if (n47e[0]) {
    n47[0] = n47d[0];
    n47[1] = n47d[1];
  }
  if (n54r[0]) {
    n54[0] = 0;
    n54[1] = 0;
  }
  else if (n54e[0]) {
    n54[0] = n54d[0];
    n54[1] = n54d[1];
  }
  if (n61r[0]) {
    n61[0] = 0;
    n61[1] = 0;
  }
  else if (n61e[0]) {
    n61[0] = n61d[0];
    n61[1] = n61d[1];
  }
  if (n68r[0]) {
    n68[0] = 0;
    n68[1] = 0;
  }
  else if (n68e[0]) {
    n68[0] = n68d[0];
    n68[1] = n68d[1];
  }
  if (n76r[0]) {
    n76[0] = 0;
    n76[1] = 0;
    n76[2] = 0;
    n76[3] = 0;
  }
  else if (n76e[0]) {
    n76[0] = n76d[0];
    n76[1] = n76d[1];
    n76[2] = n76d[2];
    n76[3] = n76d[3];
  }
  if (n84r[0]) {
    n84[0] = 0;
    n84[1] = 0;
    n84[2] = 0;
    n84[3] = 0;
  }
  else if (n84e[0]) {
    n84[0] = n84d[0];
    n84[1] = n84d[1];
    n84[2] = n84d[2];
    n84[3] = n84d[3];
  }
  if (n92r[0]) {
    n92[0] = 0;
    n92[1] = 0;
    n92[2] = 0;
    n92[3] = 0;
  }
  else if (n92e[0]) {
    n92[0] = n92d[0];
    n92[1] = n92d[1];
    n92[2] = n92d[2];
    n92[3] = n92d[3];
  }
  if (n100r[0]) {
    n100[0] = 0;
    n100[1] = 0;
    n100[2] = 0;
    n100[3] = 0;
  }
  else if (n100e[0]) {
    n100[0] = n100d[0];
    n100[1] = n100d[1];
    n100[2] = n100d[2];
    n100[3] = n100d[3];
  }
  if (n108r[0]) {
    n108[0] = 0;
    n108[1] = 0;
    n108[2] = 0;
    n108[3] = 0;
  }
  else if (n108e[0]) {
    n108[0] = n108d[0];
    n108[1] = n108d[1];
    n108[2] = n108d[2];
    n108[3] = n108d[3];
  }
  if (n116r[0]) {
    n116[0] = 0;
    n116[1] = 0;
    n116[2] = 0;
    n116[3] = 0;
  }
  else if (n116e[0]) {
    n116[0] = n116d[0];
    n116[1] = n116d[1];
    n116[2] = n116d[2];
    n116[3] = n116d[3];
  }
  if (n124r[0]) {
    n124[0] = 0;
    n124[1] = 0;
    n124[2] = 0;
    n124[3] = 0;
  }
  else if (n124e[0]) {
    n124[0] = n124d[0];
    n124[1] = n124d[1];
    n124[2] = n124d[2];
    n124[3] = n124d[3];
  }
  if (n132r[0]) {
    n132[0] = 0;
    n132[1] = 0;
    n132[2] = 0;
    n132[3] = 0;
  }
  else if (n132e[0]) {
    n132[0] = n132d[0];
    n132[1] = n132d[1];
    n132[2] = n132d[2];
    n132[3] = n132d[3];
  }
  if (n144r[0]) {
    n144[0] = 0;
    n144[1] = 0;
    n144[2] = 0;
    n144[3] = 0;
    n144[4] = 0;
  }
  else if (n144e[0]) {
    n144[0] = n144d[0];
    n144[1] = n144d[1];
    n144[2] = n144d[2];
    n144[3] = n144d[3];
    n144[4] = n144d[4];
  }
  if (n156r[0]) {
    n156[0] = 0;
    n156[1] = 0;
    n156[2] = 0;
    n156[3] = 0;
    n156[4] = 0;
  }
  else if (n156e[0]) {
    n156[0] = n156d[0];
    n156[1] = n156d[1];
    n156[2] = n156d[2];
    n156[3] = n156d[3];
    n156[4] = n156d[4];
  }
  if (n168r[0]) {
    n168[0] = 0;
    n168[1] = 0;
    n168[2] = 0;
    n168[3] = 0;
    n168[4] = 0;
  }
  else if (n168e[0]) {
    n168[0] = n168d[0];
    n168[1] = n168d[1];
    n168[2] = n168d[2];
    n168[3] = n168d[3];
    n168[4] = n168d[4];
  }
  if (n180r[0]) {
    n180[0] = 0;
    n180[1] = 0;
    n180[2] = 0;
    n180[3] = 0;
    n180[4] = 0;
  }
  else if (n180e[0]) {
    n180[0] = n180d[0];
    n180[1] = n180d[1];
    n180[2] = n180d[2];
    n180[3] = n180d[3];
    n180[4] = n180d[4];
  }
  if (n192r[0]) {
    n192[0] = 0;
    n192[1] = 0;
    n192[2] = 0;
    n192[3] = 0;
    n192[4] = 0;
  }
  else if (n192e[0]) {
    n192[0] = n192d[0];
    n192[1] = n192d[1];
    n192[2] = n192d[2];
    n192[3] = n192d[3];
    n192[4] = n192d[4];
  }
  if (n204r[0]) {
    n204[0] = 0;
    n204[1] = 0;
    n204[2] = 0;
    n204[3] = 0;
    n204[4] = 0;
  }
  else if (n204e[0]) {
    n204[0] = n204d[0];
    n204[1] = n204d[1];
    n204[2] = n204d[2];
    n204[3] = n204d[3];
    n204[4] = n204d[4];
  }
  if (n216r[0]) {
    n216[0] = 0;
    n216[1] = 0;
    n216[2] = 0;
    n216[3] = 0;
    n216[4] = 0;
  }
  else if (n216e[0]) {
    n216[0] = n216d[0];
    n216[1] = n216d[1];
    n216[2] = n216d[2];
    n216[3] = n216d[3];
    n216[4] = n216d[4];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_i[1];
static unsigned char sim_data_i[2];
static unsigned char sim_k0_i[2];
static unsigned char sim_k1_i[2];
static unsigned char sim_k2_i[2];
static unsigned char sim_k3_i[2];
static unsigned char sim_k4_i[2];
static unsigned char sim_k5_i[2];
static unsigned char sim_k6_i[2];
static unsigned char sim_k7_i[2];
static unsigned char sim_data_o[5];

void cf_fir_7_16_16_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_fir_7_16_16_init();
  sim_reset_i[0] = reset_i[0];
  sim_data_i[0] = data_i[0];
  sim_data_i[1] = data_i[1];
  sim_k0_i[0] = k0_i[0];
  sim_k0_i[1] = k0_i[1];
  sim_k1_i[0] = k1_i[0];
  sim_k1_i[1] = k1_i[1];
  sim_k2_i[0] = k2_i[0];
  sim_k2_i[1] = k2_i[1];
  sim_k3_i[0] = k3_i[0];
  sim_k3_i[1] = k3_i[1];
  sim_k4_i[0] = k4_i[0];
  sim_k4_i[1] = k4_i[1];
  sim_k5_i[0] = k5_i[0];
  sim_k5_i[1] = k5_i[1];
  sim_k6_i[0] = k6_i[0];
  sim_k6_i[1] = k6_i[1];
  sim_k7_i[0] = k7_i[0];
  sim_k7_i[1] = k7_i[1];
  sim_data_o[0] = data_o[0];
  sim_data_o[1] = data_o[1];
  sim_data_o[2] = data_o[2];
  sim_data_o[3] = data_o[3];
  sim_data_o[4] = data_o[4];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_fir_7_16_16 $end\n"
    "$var wire 1 ! reset_i $end\n"
    "$var wire 16 \" data_i $end\n"
    "$var wire 16 # k0_i $end\n"
    "$var wire 16 $ k1_i $end\n"
    "$var wire 16 %% k2_i $end\n"
    "$var wire 16 & k3_i $end\n"
    "$var wire 16 ' k4_i $end\n"
    "$var wire 16 ( k5_i $end\n"
    "$var wire 16 ) k6_i $end\n"
    "$var wire 16 * k7_i $end\n"
    "$var wire 35 + data_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
        else if (bit & data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " \"\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
        else if (bit & k0_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
        else if (bit & k1_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
        else if (bit & k2_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
        else if (bit & k3_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
        else if (bit & k4_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
        else if (bit & k5_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
        else if (bit & k6_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
        else if (bit & k7_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 4; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
        else if (bit & data_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_fir_7_16_16_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_fir_7_16_16_sim_sample() {
  int changed = 0;
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_data_i[1] != data_i[1] || sim_data_i[0] != data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
          else if (bit & data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " \"\n");
    }
    sim_data_i[0] = data_i[0];
    sim_data_i[1] = data_i[1];
  }
  if (sim_k0_i[1] != k0_i[1] || sim_k0_i[0] != k0_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
          else if (bit & k0_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_k0_i[0] = k0_i[0];
    sim_k0_i[1] = k0_i[1];
  }
  if (sim_k1_i[1] != k1_i[1] || sim_k1_i[0] != k1_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
          else if (bit & k1_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_k1_i[0] = k1_i[0];
    sim_k1_i[1] = k1_i[1];
  }
  if (sim_k2_i[1] != k2_i[1] || sim_k2_i[0] != k2_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
          else if (bit & k2_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_k2_i[0] = k2_i[0];
    sim_k2_i[1] = k2_i[1];
  }
  if (sim_k3_i[1] != k3_i[1] || sim_k3_i[0] != k3_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
          else if (bit & k3_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_k3_i[0] = k3_i[0];
    sim_k3_i[1] = k3_i[1];
  }
  if (sim_k4_i[1] != k4_i[1] || sim_k4_i[0] != k4_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
          else if (bit & k4_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_k4_i[0] = k4_i[0];
    sim_k4_i[1] = k4_i[1];
  }
  if (sim_k5_i[1] != k5_i[1] || sim_k5_i[0] != k5_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
          else if (bit & k5_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_k5_i[0] = k5_i[0];
    sim_k5_i[1] = k5_i[1];
  }
  if (sim_k6_i[1] != k6_i[1] || sim_k6_i[0] != k6_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
          else if (bit & k6_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_k6_i[0] = k6_i[0];
    sim_k6_i[1] = k6_i[1];
  }
  if (sim_k7_i[1] != k7_i[1] || sim_k7_i[0] != k7_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
          else if (bit & k7_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_k7_i[0] = k7_i[0];
    sim_k7_i[1] = k7_i[1];
  }
  if (sim_data_o[4] != data_o[4] || sim_data_o[3] != data_o[3] || sim_data_o[2] != data_o[2] || sim_data_o[1] != data_o[1] || sim_data_o[0] != data_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 4; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
          else if (bit & data_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_data_o[0] = data_o[0];
    sim_data_o[1] = data_o[1];
    sim_data_o[2] = data_o[2];
    sim_data_o[3] = data_o[3];
    sim_data_o[4] = data_o[4];
  }
  sim_count++;
}

