#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs finite impulse response (FIR) filtering.
#    The filter's sum of products is pipelined with a register after
#    every multiplier and adder.  The adder network is a balanced binary
#    tree to minimize latency.  The sum of products has no numeric loss because the
#    multipliers keep all resulting bits and each adder extends the precision by 1.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
#  
#    Inputs:
#      data_i  : Input data.
#      k0_i    : Coefficient 0 multiplied by in_i(0).
#      k1_i    : Coefficient 1 multiplied by in_i(k-1).
#      k2_i    : Coefficient 2 multiplied by in_i(k-2).
#      ...
#      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
#  
#    Outputs:
#      data_o : Output data.
#  
#  Built In Parameters:
#  
#    Filter Order             = 7
#    Input Precision          = 16
#    Coefficient Precision    = 16
#    Sum of Products Latency  = 4
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:45:49 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fir_7_16_16
#    Clock Domains : clock_c  
#    Vector Input  : reset_i(1)
#    Vector Input  : data_i(16)
#    Vector Input  : k0_i(16)
#    Vector Input  : k1_i(16)
#    Vector Input  : k2_i(16)
#    Vector Input  : k3_i(16)
#    Vector Input  : k4_i(16)
#    Vector Input  : k5_i(16)
#    Vector Input  : k6_i(16)
#    Vector Input  : k7_i(16)
#    Vector Output : data_o(35)
#  
#  
#  

import sys
import time

class cf_fir_7_16_16:

  def init(self):
    self.n217 = 0L
    self.n207 = 0L
    self.n205 = 0L
    self.n195 = 0L
    self.n193 = 0L
    self.n183 = 0L
    self.n181 = 0L
    self.n171 = 0L
    self.n169 = 0L
    self.n159 = 0L
    self.n157 = 0L
    self.n147 = 0L
    self.n145 = 0L
    self.n135 = 0L
    self.n133 = 0L
    self.n12 = 0L
    self.n11 = 0L
    self.n10 = 0L
    self.n9 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n2 = 0L
    self.n1 = 0L
    self.n208 = 0L
    self.n206 = 0L
    self.n196 = 0L
    self.n194 = 0L
    self.n184 = 0L
    self.n182 = 0L
    self.n172 = 0L
    self.n170 = 0L
    self.n160 = 0L
    self.n158 = 0L
    self.n148 = 0L
    self.n146 = 0L
    self.n136 = 0L
    self.n134 = 0L
    self.n125 = 0L
    self.n117 = 0L
    self.n109 = 0L
    self.n101 = 0L
    self.n93 = 0L
    self.n85 = 0L
    self.n77 = 0L
    self.n69 = 0L
    self.n68 = 0L
    self.n68r = 0L
    self.n68e = 0L
    self.n68d = 0L
    self.n61 = 0L
    self.n61r = 0L
    self.n61e = 0L
    self.n61d = 0L
    self.n54 = 0L
    self.n54r = 0L
    self.n54e = 0L
    self.n54d = 0L
    self.n47 = 0L
    self.n47r = 0L
    self.n47e = 0L
    self.n47d = 0L
    self.n40 = 0L
    self.n40r = 0L
    self.n40e = 0L
    self.n40d = 0L
    self.n33 = 0L
    self.n33r = 0L
    self.n33e = 0L
    self.n33d = 0L
    self.n26 = 0L
    self.n26r = 0L
    self.n26e = 0L
    self.n26d = 0L
    self.n19 = 0L
    self.n19r = 0L
    self.n19e = 0L
    self.n19d = 0L
    self.n209 = 0L
    self.n197 = 0L
    self.n185 = 0L
    self.n173 = 0L
    self.n161 = 0L
    self.n149 = 0L
    self.n137 = 0L
    self.n132 = 0L
    self.n132r = 0L
    self.n132e = 0L
    self.n132d = 0L
    self.n124 = 0L
    self.n124r = 0L
    self.n124e = 0L
    self.n124d = 0L
    self.n116 = 0L
    self.n116r = 0L
    self.n116e = 0L
    self.n116d = 0L
    self.n108 = 0L
    self.n108r = 0L
    self.n108e = 0L
    self.n108d = 0L
    self.n100 = 0L
    self.n100r = 0L
    self.n100e = 0L
    self.n100d = 0L
    self.n92 = 0L
    self.n92r = 0L
    self.n92e = 0L
    self.n92d = 0L
    self.n84 = 0L
    self.n84r = 0L
    self.n84e = 0L
    self.n84d = 0L
    self.n76 = 0L
    self.n76r = 0L
    self.n76e = 0L
    self.n76d = 0L
    self.n216 = 0L
    self.n216r = 0L
    self.n216e = 0L
    self.n216d = 0L
    self.n204 = 0L
    self.n204r = 0L
    self.n204e = 0L
    self.n204d = 0L
    self.n192 = 0L
    self.n192r = 0L
    self.n192e = 0L
    self.n192d = 0L
    self.n180 = 0L
    self.n180r = 0L
    self.n180e = 0L
    self.n180d = 0L
    self.n168 = 0L
    self.n168r = 0L
    self.n168e = 0L
    self.n168d = 0L
    self.n156 = 0L
    self.n156r = 0L
    self.n156e = 0L
    self.n156d = 0L
    self.n144 = 0L
    self.n144r = 0L
    self.n144e = 0L
    self.n144d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, reset_i, data_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, ):
    data_o = self.n216
    self.n217 = self.n216
    self.n207 = ((self.n204 & 0x200000000L) >> 33)
    self.n205 = ((self.n192 & 0x200000000L) >> 33)
    self.n195 = ((self.n180 & 0x100000000L) >> 32)
    self.n193 = ((self.n168 & 0x100000000L) >> 32)
    self.n183 = ((self.n156 & 0x100000000L) >> 32)
    self.n181 = ((self.n144 & 0x100000000L) >> 32)
    self.n171 = ((self.n132 & 0x80000000L) >> 31)
    self.n169 = ((self.n124 & 0x80000000L) >> 31)
    self.n159 = ((self.n116 & 0x80000000L) >> 31)
    self.n157 = ((self.n108 & 0x80000000L) >> 31)
    self.n147 = ((self.n100 & 0x80000000L) >> 31)
    self.n145 = ((self.n92 & 0x80000000L) >> 31)
    self.n135 = ((self.n84 & 0x80000000L) >> 31)
    self.n133 = ((self.n76 & 0x80000000L) >> 31)
    self.n12 = data_i
    self.n11 = k7_i
    self.n10 = k6_i
    self.n9 = k5_i
    self.n8 = k4_i
    self.n7 = k3_i
    self.n6 = k2_i
    self.n5 = k1_i
    self.n4 = k0_i
    self.n3 = reset_i
    self.n2 = 0x0L
    self.n1 = 0x1L
    self.n208 = self.n207 << 34 | self.n204
    self.n206 = self.n205 << 34 | self.n192
    self.n196 = self.n195 << 33 | self.n180
    self.n194 = self.n193 << 33 | self.n168
    self.n184 = self.n183 << 33 | self.n156
    self.n182 = self.n181 << 33 | self.n144
    self.n172 = self.n171 << 32 | self.n132
    self.n170 = self.n169 << 32 | self.n124
    self.n160 = self.n159 << 32 | self.n116
    self.n158 = self.n157 << 32 | self.n108
    self.n148 = self.n147 << 32 | self.n100
    self.n146 = self.n145 << 32 | self.n92
    self.n136 = self.n135 << 32 | self.n84
    self.n134 = self.n133 << 32 | self.n76
    self.n125 = (self.n11 * self.n68) & 0xFFFFFFFFL
    self.n117 = (self.n10 * self.n61) & 0xFFFFFFFFL
    self.n109 = (self.n9 * self.n54) & 0xFFFFFFFFL
    self.n101 = (self.n8 * self.n47) & 0xFFFFFFFFL
    self.n93 = (self.n7 * self.n40) & 0xFFFFFFFFL
    self.n85 = (self.n6 * self.n33) & 0xFFFFFFFFL
    self.n77 = (self.n5 * self.n26) & 0xFFFFFFFFL
    self.n69 = (self.n4 * self.n19) & 0xFFFFFFFFL
    self.n68r = self.n3
    self.n68e = self.n1
    self.n68d = self.n61
    self.n61r = self.n3
    self.n61e = self.n1
    self.n61d = self.n54
    self.n54r = self.n3
    self.n54e = self.n1
    self.n54d = self.n47
    self.n47r = self.n3
    self.n47e = self.n1
    self.n47d = self.n40
    self.n40r = self.n3
    self.n40e = self.n1
    self.n40d = self.n33
    self.n33r = self.n3
    self.n33e = self.n1
    self.n33d = self.n26
    self.n26r = self.n3
    self.n26e = self.n1
    self.n26d = self.n19
    self.n19r = self.n3
    self.n19e = self.n1
    self.n19d = self.n12
    self.n209 = (self.n206 + self.n208) & 0x7FFFFFFFFL
    self.n197 = (self.n194 + self.n196) & 0x3FFFFFFFFL
    self.n185 = (self.n182 + self.n184) & 0x3FFFFFFFFL
    self.n173 = (self.n170 + self.n172) & 0x1FFFFFFFFL
    self.n161 = (self.n158 + self.n160) & 0x1FFFFFFFFL
    self.n149 = (self.n146 + self.n148) & 0x1FFFFFFFFL
    self.n137 = (self.n134 + self.n136) & 0x1FFFFFFFFL
    self.n132r = self.n2
    self.n132e = self.n1
    self.n132d = self.n125
    self.n124r = self.n2
    self.n124e = self.n1
    self.n124d = self.n117
    self.n116r = self.n2
    self.n116e = self.n1
    self.n116d = self.n109
    self.n108r = self.n2
    self.n108e = self.n1
    self.n108d = self.n101
    self.n100r = self.n2
    self.n100e = self.n1
    self.n100d = self.n93
    self.n92r = self.n2
    self.n92e = self.n1
    self.n92d = self.n85
    self.n84r = self.n2
    self.n84e = self.n1
    self.n84d = self.n77
    self.n76r = self.n2
    self.n76e = self.n1
    self.n76d = self.n69
    self.n216r = self.n2
    self.n216e = self.n1
    self.n216d = self.n209
    self.n204r = self.n2
    self.n204e = self.n1
    self.n204d = self.n197
    self.n192r = self.n2
    self.n192e = self.n1
    self.n192d = self.n185
    self.n180r = self.n2
    self.n180e = self.n1
    self.n180d = self.n173
    self.n168r = self.n2
    self.n168e = self.n1
    self.n168d = self.n161
    self.n156r = self.n2
    self.n156e = self.n1
    self.n156d = self.n149
    self.n144r = self.n2
    self.n144e = self.n1
    self.n144d = self.n137
    return (data_o, )

  def cycle_clock(self):
    if self.n19r:
      self.n19 = 0L
    elif self.n19e:
        self.n19 = self.n19d
    if self.n26r:
      self.n26 = 0L
    elif self.n26e:
        self.n26 = self.n26d
    if self.n33r:
      self.n33 = 0L
    elif self.n33e:
        self.n33 = self.n33d
    if self.n40r:
      self.n40 = 0L
    elif self.n40e:
        self.n40 = self.n40d
    if self.n47r:
      self.n47 = 0L
    elif self.n47e:
        self.n47 = self.n47d
    if self.n54r:
      self.n54 = 0L
    elif self.n54e:
        self.n54 = self.n54d
    if self.n61r:
      self.n61 = 0L
    elif self.n61e:
        self.n61 = self.n61d
    if self.n68r:
      self.n68 = 0L
    elif self.n68e:
        self.n68 = self.n68d
    if self.n76r:
      self.n76 = 0L
    elif self.n76e:
        self.n76 = self.n76d
    if self.n84r:
      self.n84 = 0L
    elif self.n84e:
        self.n84 = self.n84d
    if self.n92r:
      self.n92 = 0L
    elif self.n92e:
        self.n92 = self.n92d
    if self.n100r:
      self.n100 = 0L
    elif self.n100e:
        self.n100 = self.n100d
    if self.n108r:
      self.n108 = 0L
    elif self.n108e:
        self.n108 = self.n108d
    if self.n116r:
      self.n116 = 0L
    elif self.n116e:
        self.n116 = self.n116d
    if self.n124r:
      self.n124 = 0L
    elif self.n124e:
        self.n124 = self.n124d
    if self.n132r:
      self.n132 = 0L
    elif self.n132e:
        self.n132 = self.n132d
    if self.n144r:
      self.n144 = 0L
    elif self.n144e:
        self.n144 = self.n144d
    if self.n156r:
      self.n156 = 0L
    elif self.n156e:
        self.n156 = self.n156d
    if self.n168r:
      self.n168 = 0L
    elif self.n168e:
        self.n168 = self.n168d
    if self.n180r:
      self.n180 = 0L
    elif self.n180e:
        self.n180 = self.n180d
    if self.n192r:
      self.n192 = 0L
    elif self.n192e:
        self.n192 = self.n192d
    if self.n204r:
      self.n204 = 0L
    elif self.n204e:
        self.n204 = self.n204d
    if self.n216r:
      self.n216 = 0L
    elif self.n216e:
        self.n216 = self.n216d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n12 = self.n12
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n9 = self.n9
    self.sim_n10 = self.n10
    self.sim_n11 = self.n11
    self.sim_n217 = self.n217
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fir_7_16_16 $end\n")
    self.sim_file.write("$var wire 1 ! reset_i $end\n")
    self.sim_file.write("$var wire 16 \" data_i $end\n")
    self.sim_file.write("$var wire 16 # k0_i $end\n")
    self.sim_file.write("$var wire 16 $ k1_i $end\n")
    self.sim_file.write("$var wire 16 % k2_i $end\n")
    self.sim_file.write("$var wire 16 & k3_i $end\n")
    self.sim_file.write("$var wire 16 ' k4_i $end\n")
    self.sim_file.write("$var wire 16 ( k5_i $end\n")
    self.sim_file.write("$var wire 16 ) k6_i $end\n")
    self.sim_file.write("$var wire 16 * k7_i $end\n")
    self.sim_file.write("$var wire 35 + data_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n12 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n12 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" \"\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n9 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n9 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n10 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n10 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n11 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n11 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" *\n")
    found = 0
    for bit in range(34, -1, -1):
      if found:
        if self.n217 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n217 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" +\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n12 != self.n12:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n12 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n12 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" \"\n")
      self.sim_n12 = self.n12
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n8 = self.n8
    if self.sim_n9 != self.n9:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n9 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n9 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n9 = self.n9
    if self.sim_n10 != self.n10:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n10 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n10 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n10 = self.n10
    if self.sim_n11 != self.n11:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n11 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n11 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" *\n")
      self.sim_n11 = self.n11
    if self.sim_n217 != self.n217:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(34, -1, -1):
        if found:
          if self.n217 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n217 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" +\n")
      self.sim_n217 = self.n217
    self.sim_count = self.sim_count + 1

