--
--  Copyright (c) 2003 Launchbird Design Systems, Inc.
--  All rights reserved.
--  
--  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
--    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
--    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
--  
--  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
--  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
--  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
--  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
--  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
--  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--  
--  
--  Overview:
--  
--    Performs finite impulse response (FIR) filtering.
--    The filter's sum of products is pipelined with a register after
--    every multiplier and adder.  The adder network is a balanced binary
--    tree to minimize latency.  The sum of products has no numeric loss because the
--    multipliers keep all resulting bits and each adder extends the precision by 1.
--  
--  Interface:
--  
--    Synchronization:
--      clock_c  : Clock input.
--      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
--  
--    Inputs:
--      data_i  : Input data.
--      k0_i    : Coefficient 0 multiplied by in_i(0).
--      k1_i    : Coefficient 1 multiplied by in_i(k-1).
--      k2_i    : Coefficient 2 multiplied by in_i(k-2).
--      ...
--      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
--  
--    Outputs:
--      data_o : Output data.
--  
--  Built In Parameters:
--  
--    Filter Order             = 7
--    Input Precision          = 16
--    Coefficient Precision    = 16
--    Sum of Products Latency  = 4
--  
--  
--  
--  
--  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
--  
--  Build Date : Fri Aug 22 09:45:49 CDT 2003
--  
--  Interface
--  
--    Build Name    : cf_fir_7_16_16
--    Clock Domains : clock_c  
--    Vector Input  : reset_i(1)
--    Vector Input  : data_i(16)
--    Vector Input  : k0_i(16)
--    Vector Input  : k1_i(16)
--    Vector Input  : k2_i(16)
--    Vector Input  : k3_i(16)
--    Vector Input  : k4_i(16)
--    Vector Input  : k5_i(16)
--    Vector Input  : k6_i(16)
--    Vector Input  : k7_i(16)
--    Vector Output : data_o(35)
--  
--  
--  

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(32 downto 0);
i4 : in  unsigned(32 downto 0);
i5 : in  unsigned(32 downto 0);
i6 : in  unsigned(32 downto 0);
o1 : out unsigned(33 downto 0);
o2 : out unsigned(33 downto 0));
end entity cf_fir_7_16_16_8;
architecture rtl of cf_fir_7_16_16_8 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(33 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(33 downto 0);
signal n5 : unsigned(33 downto 0);
signal n6 : unsigned(33 downto 0) := "0000000000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(33 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(33 downto 0);
signal n11 : unsigned(33 downto 0);
signal n12 : unsigned(33 downto 0) := "0000000000000000000000000000000000";
begin
n1 <= i3(32 downto 32);
n2 <= n1 & i3;
n3 <= i4(32 downto 32);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(32 downto 32);
n8 <= n7 & i5;
n9 <= i6(32 downto 32);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "0000000000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(31 downto 0);
i4 : in  unsigned(31 downto 0);
i5 : in  unsigned(31 downto 0);
i6 : in  unsigned(31 downto 0);
o1 : out unsigned(32 downto 0);
o2 : out unsigned(32 downto 0));
end entity cf_fir_7_16_16_7;
architecture rtl of cf_fir_7_16_16_7 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(32 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(32 downto 0);
signal n5 : unsigned(32 downto 0);
signal n6 : unsigned(32 downto 0) := "000000000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(32 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(32 downto 0);
signal n11 : unsigned(32 downto 0);
signal n12 : unsigned(32 downto 0) := "000000000000000000000000000000000";
begin
n1 <= i3(31 downto 31);
n2 <= n1 & i3;
n3 <= i4(31 downto 31);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(31 downto 31);
n8 <= n7 & i5;
n9 <= i6(31 downto 31);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "000000000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(31 downto 0);
i4 : in  unsigned(31 downto 0);
i5 : in  unsigned(31 downto 0);
i6 : in  unsigned(31 downto 0);
i7 : in  unsigned(31 downto 0);
i8 : in  unsigned(31 downto 0);
i9 : in  unsigned(31 downto 0);
i10 : in  unsigned(31 downto 0);
o1 : out unsigned(32 downto 0);
o2 : out unsigned(32 downto 0);
o3 : out unsigned(32 downto 0);
o4 : out unsigned(32 downto 0));
end entity cf_fir_7_16_16_6;
architecture rtl of cf_fir_7_16_16_6 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(32 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(32 downto 0);
signal n5 : unsigned(32 downto 0);
signal n6 : unsigned(32 downto 0) := "000000000000000000000000000000000";
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(32 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(32 downto 0);
signal n11 : unsigned(32 downto 0);
signal n12 : unsigned(32 downto 0) := "000000000000000000000000000000000";
signal s13_1 : unsigned(32 downto 0);
signal s13_2 : unsigned(32 downto 0);
component cf_fir_7_16_16_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(31 downto 0);
i4 : in  unsigned(31 downto 0);
i5 : in  unsigned(31 downto 0);
i6 : in  unsigned(31 downto 0);
o1 : out unsigned(32 downto 0);
o2 : out unsigned(32 downto 0));
end component cf_fir_7_16_16_7;
begin
n1 <= i3(31 downto 31);
n2 <= n1 & i3;
n3 <= i4(31 downto 31);
n4 <= n3 & i4;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i5(31 downto 31);
n8 <= n7 & i5;
n9 <= i6(31 downto 31);
n10 <= n9 & i6;
n11 <= n8 + n10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n12 <= "000000000000000000000000000000000";
    elsif i1 = "1" then
      n12 <= n11;
    end if;
  end if;
end process;
s13 : cf_fir_7_16_16_7 port map (clock_c, i1, i2, i7, i8, i9, i10, s13_1, s13_2);
o4 <= s13_2;
o3 <= s13_1;
o2 <= n12;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(31 downto 0);
i4 : in  unsigned(31 downto 0);
i5 : in  unsigned(31 downto 0);
i6 : in  unsigned(31 downto 0);
i7 : in  unsigned(31 downto 0);
i8 : in  unsigned(31 downto 0);
i9 : in  unsigned(31 downto 0);
i10 : in  unsigned(31 downto 0);
o1 : out unsigned(34 downto 0));
end entity cf_fir_7_16_16_5;
architecture rtl of cf_fir_7_16_16_5 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(34 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(34 downto 0);
signal n5 : unsigned(34 downto 0);
signal n6 : unsigned(34 downto 0) := "00000000000000000000000000000000000";
signal s7_1 : unsigned(33 downto 0);
signal s7_2 : unsigned(33 downto 0);
signal s8_1 : unsigned(32 downto 0);
signal s8_2 : unsigned(32 downto 0);
signal s8_3 : unsigned(32 downto 0);
signal s8_4 : unsigned(32 downto 0);
component cf_fir_7_16_16_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(32 downto 0);
i4 : in  unsigned(32 downto 0);
i5 : in  unsigned(32 downto 0);
i6 : in  unsigned(32 downto 0);
o1 : out unsigned(33 downto 0);
o2 : out unsigned(33 downto 0));
end component cf_fir_7_16_16_8;
component cf_fir_7_16_16_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(31 downto 0);
i4 : in  unsigned(31 downto 0);
i5 : in  unsigned(31 downto 0);
i6 : in  unsigned(31 downto 0);
i7 : in  unsigned(31 downto 0);
i8 : in  unsigned(31 downto 0);
i9 : in  unsigned(31 downto 0);
i10 : in  unsigned(31 downto 0);
o1 : out unsigned(32 downto 0);
o2 : out unsigned(32 downto 0);
o3 : out unsigned(32 downto 0);
o4 : out unsigned(32 downto 0));
end component cf_fir_7_16_16_6;
begin
n1 <= s7_1(33 downto 33);
n2 <= n1 & s7_1;
n3 <= s7_2(33 downto 33);
n4 <= n3 & s7_2;
n5 <= n2 + n4;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
s7 : cf_fir_7_16_16_8 port map (clock_c, i1, i2, s8_1, s8_2, s8_3, s8_4, s7_1, s7_2);
s8 : cf_fir_7_16_16_6 port map (clock_c, i1, i2, i3, i4, i5, i6, i7, i8, i9, i10, s8_1, s8_2, s8_3, s8_4);
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
o1 : out unsigned(31 downto 0);
o2 : out unsigned(31 downto 0);
o3 : out unsigned(31 downto 0);
o4 : out unsigned(31 downto 0));
end entity cf_fir_7_16_16_4;
architecture rtl of cf_fir_7_16_16_4 is
signal n1 : unsigned(31 downto 0);
signal n2 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal n3 : unsigned(31 downto 0);
signal n4 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal n5 : unsigned(31 downto 0);
signal n6 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal n7 : unsigned(31 downto 0);
signal n8 : unsigned(31 downto 0) := "00000000000000000000000000000000";
begin
n1 <= i3 * i7;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i8;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i9;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i10;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
o1 : out unsigned(31 downto 0);
o2 : out unsigned(31 downto 0);
o3 : out unsigned(31 downto 0);
o4 : out unsigned(31 downto 0);
o5 : out unsigned(31 downto 0);
o6 : out unsigned(31 downto 0);
o7 : out unsigned(31 downto 0);
o8 : out unsigned(31 downto 0));
end entity cf_fir_7_16_16_3;
architecture rtl of cf_fir_7_16_16_3 is
signal n1 : unsigned(31 downto 0);
signal n2 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal n3 : unsigned(31 downto 0);
signal n4 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal n5 : unsigned(31 downto 0);
signal n6 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal n7 : unsigned(31 downto 0);
signal n8 : unsigned(31 downto 0) := "00000000000000000000000000000000";
signal s9_1 : unsigned(31 downto 0);
signal s9_2 : unsigned(31 downto 0);
signal s9_3 : unsigned(31 downto 0);
signal s9_4 : unsigned(31 downto 0);
component cf_fir_7_16_16_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
o1 : out unsigned(31 downto 0);
o2 : out unsigned(31 downto 0);
o3 : out unsigned(31 downto 0);
o4 : out unsigned(31 downto 0));
end component cf_fir_7_16_16_4;
begin
n1 <= i3 * i11;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
n3 <= i4 * i12;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
n5 <= i5 * i13;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
n7 <= i6 * i14;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "00000000000000000000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
s9 : cf_fir_7_16_16_4 port map (clock_c, i1, i2, i7, i8, i9, i10, i15, i16, i17, i18, s9_1, s9_2, s9_3, s9_4);
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n8;
o3 <= n6;
o2 <= n4;
o1 <= n2;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0));
end entity cf_fir_7_16_16_2;
architecture rtl of cf_fir_7_16_16_2 is
signal n1 : unsigned(15 downto 0) := "0000000000000000";
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(15 downto 0) := "0000000000000000";
signal n4 : unsigned(15 downto 0) := "0000000000000000";
signal n5 : unsigned(15 downto 0) := "0000000000000000";
signal n6 : unsigned(15 downto 0) := "0000000000000000";
signal n7 : unsigned(15 downto 0) := "0000000000000000";
signal n8 : unsigned(15 downto 0) := "0000000000000000";
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0000000000000000";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= n1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0000000000000000";
    elsif i1 = "1" then
      n3 <= n2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0000000000000000";
    elsif i1 = "1" then
      n4 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0000000000000000";
    elsif i1 = "1" then
      n5 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0000000000000000";
    elsif i1 = "1" then
      n6 <= n5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "0000000000000000";
    elsif i1 = "1" then
      n7 <= n6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "0000000000000000";
    elsif i1 = "1" then
      n8 <= n7;
    end if;
  end if;
end process;
o8 <= n8;
o7 <= n7;
o6 <= n6;
o5 <= n5;
o4 <= n4;
o3 <= n3;
o2 <= n2;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(15 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
o1 : out unsigned(34 downto 0));
end entity cf_fir_7_16_16_1;
architecture rtl of cf_fir_7_16_16_1 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal s3_1 : unsigned(34 downto 0);
signal s4_1 : unsigned(31 downto 0);
signal s4_2 : unsigned(31 downto 0);
signal s4_3 : unsigned(31 downto 0);
signal s4_4 : unsigned(31 downto 0);
signal s4_5 : unsigned(31 downto 0);
signal s4_6 : unsigned(31 downto 0);
signal s4_7 : unsigned(31 downto 0);
signal s4_8 : unsigned(31 downto 0);
signal s5_1 : unsigned(15 downto 0);
signal s5_2 : unsigned(15 downto 0);
signal s5_3 : unsigned(15 downto 0);
signal s5_4 : unsigned(15 downto 0);
signal s5_5 : unsigned(15 downto 0);
signal s5_6 : unsigned(15 downto 0);
signal s5_7 : unsigned(15 downto 0);
signal s5_8 : unsigned(15 downto 0);
component cf_fir_7_16_16_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(31 downto 0);
i4 : in  unsigned(31 downto 0);
i5 : in  unsigned(31 downto 0);
i6 : in  unsigned(31 downto 0);
i7 : in  unsigned(31 downto 0);
i8 : in  unsigned(31 downto 0);
i9 : in  unsigned(31 downto 0);
i10 : in  unsigned(31 downto 0);
o1 : out unsigned(34 downto 0));
end component cf_fir_7_16_16_5;
component cf_fir_7_16_16_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
i11 : in  unsigned(15 downto 0);
i12 : in  unsigned(15 downto 0);
i13 : in  unsigned(15 downto 0);
i14 : in  unsigned(15 downto 0);
i15 : in  unsigned(15 downto 0);
i16 : in  unsigned(15 downto 0);
i17 : in  unsigned(15 downto 0);
i18 : in  unsigned(15 downto 0);
o1 : out unsigned(31 downto 0);
o2 : out unsigned(31 downto 0);
o3 : out unsigned(31 downto 0);
o4 : out unsigned(31 downto 0);
o5 : out unsigned(31 downto 0);
o6 : out unsigned(31 downto 0);
o7 : out unsigned(31 downto 0);
o8 : out unsigned(31 downto 0));
end component cf_fir_7_16_16_3;
component cf_fir_7_16_16_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0);
o2 : out unsigned(15 downto 0);
o3 : out unsigned(15 downto 0);
o4 : out unsigned(15 downto 0);
o5 : out unsigned(15 downto 0);
o6 : out unsigned(15 downto 0);
o7 : out unsigned(15 downto 0);
o8 : out unsigned(15 downto 0));
end component cf_fir_7_16_16_2;
begin
n1 <= "1";
n2 <= "0";
s3 : cf_fir_7_16_16_5 port map (clock_c, n1, n2, s4_1, s4_2, s4_3, s4_4, s4_5, s4_6, s4_7, s4_8, s3_1);
s4 : cf_fir_7_16_16_3 port map (clock_c, n1, n2, i2, i3, i4, i5, i6, i7, i8, i9, s5_1, s5_2, s5_3, s5_4, s5_5, s5_6, s5_7, s5_8, s4_1, s4_2, s4_3, s4_4, s4_5, s4_6, s4_7, s4_8);
s5 : cf_fir_7_16_16_2 port map (clock_c, n1, i1, i10, s5_1, s5_2, s5_3, s5_4, s5_5, s5_6, s5_7, s5_8);
o1 <= s3_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fir_7_16_16 is
port(
signal clock_c : in std_logic;
signal reset_i : in unsigned(0 downto 0);
signal data_i : in unsigned(15 downto 0);
signal k0_i : in unsigned(15 downto 0);
signal k1_i : in unsigned(15 downto 0);
signal k2_i : in unsigned(15 downto 0);
signal k3_i : in unsigned(15 downto 0);
signal k4_i : in unsigned(15 downto 0);
signal k5_i : in unsigned(15 downto 0);
signal k6_i : in unsigned(15 downto 0);
signal k7_i : in unsigned(15 downto 0);
signal data_o : out unsigned(34 downto 0));
end entity cf_fir_7_16_16;
architecture rtl of cf_fir_7_16_16 is
component cf_fir_7_16_16_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(15 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
i5 : in  unsigned(15 downto 0);
i6 : in  unsigned(15 downto 0);
i7 : in  unsigned(15 downto 0);
i8 : in  unsigned(15 downto 0);
i9 : in  unsigned(15 downto 0);
i10 : in  unsigned(15 downto 0);
o1 : out unsigned(34 downto 0));
end component cf_fir_7_16_16_1;
signal n1 : unsigned(34 downto 0);
begin
s1 : cf_fir_7_16_16_1 port map (clock_c, reset_i, k0_i, k1_i, k2_i, k3_i, k4_i, k5_i, k6_i, k7_i, data_i, n1);
data_o <= n1;
end architecture rtl;


