//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs finite impulse response (FIR) filtering.
//    The filter's sum of products is pipelined with a register after
//    every multiplier and adder.  The adder network is a balanced binary
//    tree to minimize latency.  The sum of products has no numeric loss because the
//    multipliers keep all resulting bits and each adder extends the precision by 1.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      reset_i  : Filter delay bank synchronous reset.  Does not reset sum of products pipeline registers.
//  
//    Inputs:
//      data_i  : Input data.
//      k0_i    : Coefficient 0 multiplied by in_i(0).
//      k1_i    : Coefficient 1 multiplied by in_i(k-1).
//      k2_i    : Coefficient 2 multiplied by in_i(k-2).
//      ...
//      k<order>_i : Coefficient <order> multiplied by in_i(k-<order>).
//  
//    Outputs:
//      data_o : Output data.
//  
//  Built In Parameters:
//  
//    Filter Order             = 33
//    Input Precision          = 16
//    Coefficient Precision    = 16
//    Sum of Products Latency  = 7
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:45:58 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fir_33_16_16
//    Clock Domains : clock_c  
//    Vector Input  : reset_i(1)
//    Vector Input  : data_i(16)
//    Vector Input  : k0_i(16)
//    Vector Input  : k1_i(16)
//    Vector Input  : k2_i(16)
//    Vector Input  : k3_i(16)
//    Vector Input  : k4_i(16)
//    Vector Input  : k5_i(16)
//    Vector Input  : k6_i(16)
//    Vector Input  : k7_i(16)
//    Vector Input  : k8_i(16)
//    Vector Input  : k9_i(16)
//    Vector Input  : k10_i(16)
//    Vector Input  : k11_i(16)
//    Vector Input  : k12_i(16)
//    Vector Input  : k13_i(16)
//    Vector Input  : k14_i(16)
//    Vector Input  : k15_i(16)
//    Vector Input  : k16_i(16)
//    Vector Input  : k17_i(16)
//    Vector Input  : k18_i(16)
//    Vector Input  : k19_i(16)
//    Vector Input  : k20_i(16)
//    Vector Input  : k21_i(16)
//    Vector Input  : k22_i(16)
//    Vector Input  : k23_i(16)
//    Vector Input  : k24_i(16)
//    Vector Input  : k25_i(16)
//    Vector Input  : k26_i(16)
//    Vector Input  : k27_i(16)
//    Vector Input  : k28_i(16)
//    Vector Input  : k29_i(16)
//    Vector Input  : k30_i(16)
//    Vector Input  : k31_i(16)
//    Vector Input  : k32_i(16)
//    Vector Input  : k33_i(16)
//    Vector Output : data_o(38)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_fir_33_16_16.h"

static unsigned char *data_o;
static unsigned char n971[1];
static unsigned char n969[1];
static unsigned char n960[1];
static unsigned char n950[1];
static unsigned char n948[1];
static unsigned char n939[1];
static unsigned char n929[1];
static unsigned char n927[1];
static unsigned char n917[1];
static unsigned char n915[1];
static unsigned char n906[1];
static unsigned char n896[1];
static unsigned char n894[1];
static unsigned char n884[1];
static unsigned char n882[1];
static unsigned char n872[1];
static unsigned char n870[1];
static unsigned char n860[1];
static unsigned char n858[1];
static unsigned char n849[1];
static unsigned char n839[1];
static unsigned char n837[1];
static unsigned char n827[1];
static unsigned char n825[1];
static unsigned char n815[1];
static unsigned char n813[1];
static unsigned char n803[1];
static unsigned char n801[1];
static unsigned char n791[1];
static unsigned char n789[1];
static unsigned char n779[1];
static unsigned char n777[1];
static unsigned char n767[1];
static unsigned char n765[1];
static unsigned char n755[1];
static unsigned char n753[1];
static unsigned char n743[1];
static unsigned char n741[1];
static unsigned char n731[1];
static unsigned char n729[1];
static unsigned char n719[1];
static unsigned char n717[1];
static unsigned char n707[1];
static unsigned char n705[1];
static unsigned char n695[1];
static unsigned char n693[1];
static unsigned char n683[1];
static unsigned char n681[1];
static unsigned char n671[1];
static unsigned char n669[1];
static unsigned char n659[1];
static unsigned char n657[1];
static unsigned char n647[1];
static unsigned char n645[1];
static unsigned char n635[1];
static unsigned char n633[1];
static unsigned char n623[1];
static unsigned char n621[1];
static unsigned char n611[1];
static unsigned char n609[1];
static unsigned char n599[1];
static unsigned char n597[1];
static unsigned char n587[1];
static unsigned char n585[1];
static unsigned char n575[1];
static unsigned char n573[1];
static unsigned char n563[1];
static unsigned char n561[1];
static unsigned char n551[1];
static unsigned char n549[1];
static unsigned char *data_i;
static unsigned char *k33_i;
static unsigned char *k32_i;
static unsigned char *k31_i;
static unsigned char *k30_i;
static unsigned char *k29_i;
static unsigned char *k28_i;
static unsigned char *k27_i;
static unsigned char *k26_i;
static unsigned char *k25_i;
static unsigned char *k24_i;
static unsigned char *k23_i;
static unsigned char *k22_i;
static unsigned char *k21_i;
static unsigned char *k20_i;
static unsigned char *k19_i;
static unsigned char *k18_i;
static unsigned char *k17_i;
static unsigned char *k16_i;
static unsigned char *k15_i;
static unsigned char *k14_i;
static unsigned char *k13_i;
static unsigned char *k12_i;
static unsigned char *k11_i;
static unsigned char *k10_i;
static unsigned char *k9_i;
static unsigned char *k8_i;
static unsigned char *k7_i;
static unsigned char *k6_i;
static unsigned char *k5_i;
static unsigned char *k4_i;
static unsigned char *k3_i;
static unsigned char *k2_i;
static unsigned char *k1_i;
static unsigned char *k0_i;
static unsigned char *reset_i;
static unsigned char n2[1];
static unsigned char n1[1];
static unsigned char n972[5];
static unsigned char n970[5];
static unsigned char n961[5];
static unsigned char n951[5];
static unsigned char n949[5];
static unsigned char n940[5];
static unsigned char n930[5];
static unsigned char n928[5];
static unsigned char n918[5];
static unsigned char n916[5];
static unsigned char n907[5];
static unsigned char n897[5];
static unsigned char n895[5];
static unsigned char n885[5];
static unsigned char n883[5];
static unsigned char n873[5];
static unsigned char n871[5];
static unsigned char n861[5];
static unsigned char n859[5];
static unsigned char n850[5];
static unsigned char n840[5];
static unsigned char n838[5];
static unsigned char n828[5];
static unsigned char n826[5];
static unsigned char n816[5];
static unsigned char n814[5];
static unsigned char n804[5];
static unsigned char n802[5];
static unsigned char n792[5];
static unsigned char n790[5];
static unsigned char n780[5];
static unsigned char n778[5];
static unsigned char n768[5];
static unsigned char n766[5];
static unsigned char n756[5];
static unsigned char n754[5];
static unsigned char n744[5];
static unsigned char n742[5];
static unsigned char n732[5];
static unsigned char n730[5];
static unsigned char n720[5];
static unsigned char n718[5];
static unsigned char n708[5];
static unsigned char n706[5];
static unsigned char n696[5];
static unsigned char n694[5];
static unsigned char n684[5];
static unsigned char n682[5];
static unsigned char n672[5];
static unsigned char n670[5];
static unsigned char n660[5];
static unsigned char n658[5];
static unsigned char n648[5];
static unsigned char n646[5];
static unsigned char n636[5];
static unsigned char n634[5];
static unsigned char n624[5];
static unsigned char n622[5];
static unsigned char n612[5];
static unsigned char n610[5];
static unsigned char n600[5];
static unsigned char n598[5];
static unsigned char n588[5];
static unsigned char n586[5];
static unsigned char n576[5];
static unsigned char n574[5];
static unsigned char n564[5];
static unsigned char n562[5];
static unsigned char n552[5];
static unsigned char n550[5];
static unsigned char n541[4];
static unsigned char n533[4];
static unsigned char n525[4];
static unsigned char n517[4];
static unsigned char n509[4];
static unsigned char n501[4];
static unsigned char n493[4];
static unsigned char n485[4];
static unsigned char n477[4];
static unsigned char n469[4];
static unsigned char n461[4];
static unsigned char n453[4];
static unsigned char n445[4];
static unsigned char n437[4];
static unsigned char n429[4];
static unsigned char n421[4];
static unsigned char n413[4];
static unsigned char n405[4];
static unsigned char n397[4];
static unsigned char n389[4];
static unsigned char n381[4];
static unsigned char n373[4];
static unsigned char n365[4];
static unsigned char n357[4];
static unsigned char n349[4];
static unsigned char n341[4];
static unsigned char n333[4];
static unsigned char n325[4];
static unsigned char n317[4];
static unsigned char n309[4];
static unsigned char n301[4];
static unsigned char n293[4];
static unsigned char n285[4];
static unsigned char n277[4];
static unsigned char n276[2];
static unsigned char n276r[1];
static unsigned char n276e[1];
static unsigned char n276d[2];
static unsigned char n269[2];
static unsigned char n269r[1];
static unsigned char n269e[1];
static unsigned char n269d[2];
static unsigned char n262[2];
static unsigned char n262r[1];
static unsigned char n262e[1];
static unsigned char n262d[2];
static unsigned char n255[2];
static unsigned char n255r[1];
static unsigned char n255e[1];
static unsigned char n255d[2];
static unsigned char n248[2];
static unsigned char n248r[1];
static unsigned char n248e[1];
static unsigned char n248d[2];
static unsigned char n241[2];
static unsigned char n241r[1];
static unsigned char n241e[1];
static unsigned char n241d[2];
static unsigned char n234[2];
static unsigned char n234r[1];
static unsigned char n234e[1];
static unsigned char n234d[2];
static unsigned char n227[2];
static unsigned char n227r[1];
static unsigned char n227e[1];
static unsigned char n227d[2];
static unsigned char n220[2];
static unsigned char n220r[1];
static unsigned char n220e[1];
static unsigned char n220d[2];
static unsigned char n213[2];
static unsigned char n213r[1];
static unsigned char n213e[1];
static unsigned char n213d[2];
static unsigned char n206[2];
static unsigned char n206r[1];
static unsigned char n206e[1];
static unsigned char n206d[2];
static unsigned char n199[2];
static unsigned char n199r[1];
static unsigned char n199e[1];
static unsigned char n199d[2];
static unsigned char n192[2];
static unsigned char n192r[1];
static unsigned char n192e[1];
static unsigned char n192d[2];
static unsigned char n185[2];
static unsigned char n185r[1];
static unsigned char n185e[1];
static unsigned char n185d[2];
static unsigned char n178[2];
static unsigned char n178r[1];
static unsigned char n178e[1];
static unsigned char n178d[2];
static unsigned char n171[2];
static unsigned char n171r[1];
static unsigned char n171e[1];
static unsigned char n171d[2];
static unsigned char n164[2];
static unsigned char n164r[1];
static unsigned char n164e[1];
static unsigned char n164d[2];
static unsigned char n157[2];
static unsigned char n157r[1];
static unsigned char n157e[1];
static unsigned char n157d[2];
static unsigned char n150[2];
static unsigned char n150r[1];
static unsigned char n150e[1];
static unsigned char n150d[2];
static unsigned char n143[2];
static unsigned char n143r[1];
static unsigned char n143e[1];
static unsigned char n143d[2];
static unsigned char n136[2];
static unsigned char n136r[1];
static unsigned char n136e[1];
static unsigned char n136d[2];
static unsigned char n129[2];
static unsigned char n129r[1];
static unsigned char n129e[1];
static unsigned char n129d[2];
static unsigned char n122[2];
static unsigned char n122r[1];
static unsigned char n122e[1];
static unsigned char n122d[2];
static unsigned char n115[2];
static unsigned char n115r[1];
static unsigned char n115e[1];
static unsigned char n115d[2];
static unsigned char n108[2];
static unsigned char n108r[1];
static unsigned char n108e[1];
static unsigned char n108d[2];
static unsigned char n101[2];
static unsigned char n101r[1];
static unsigned char n101e[1];
static unsigned char n101d[2];
static unsigned char n94[2];
static unsigned char n94r[1];
static unsigned char n94e[1];
static unsigned char n94d[2];
static unsigned char n87[2];
static unsigned char n87r[1];
static unsigned char n87e[1];
static unsigned char n87d[2];
static unsigned char n80[2];
static unsigned char n80r[1];
static unsigned char n80e[1];
static unsigned char n80d[2];
static unsigned char n73[2];
static unsigned char n73r[1];
static unsigned char n73e[1];
static unsigned char n73d[2];
static unsigned char n66[2];
static unsigned char n66r[1];
static unsigned char n66e[1];
static unsigned char n66d[2];
static unsigned char n59[2];
static unsigned char n59r[1];
static unsigned char n59e[1];
static unsigned char n59d[2];
static unsigned char n52[2];
static unsigned char n52r[1];
static unsigned char n52e[1];
static unsigned char n52d[2];
static unsigned char n45[2];
static unsigned char n45r[1];
static unsigned char n45e[1];
static unsigned char n45d[2];
static unsigned char n973[5];
static unsigned char n968[5];
static unsigned char n968r[1];
static unsigned char n968e[1];
static unsigned char n968d[5];
static unsigned char n952[5];
static unsigned char n947[5];
static unsigned char n947r[1];
static unsigned char n947e[1];
static unsigned char n947d[5];
static unsigned char n931[5];
static unsigned char n919[5];
static unsigned char n914[5];
static unsigned char n914r[1];
static unsigned char n914e[1];
static unsigned char n914d[5];
static unsigned char n898[5];
static unsigned char n886[5];
static unsigned char n874[5];
static unsigned char n862[5];
static unsigned char n857[5];
static unsigned char n857r[1];
static unsigned char n857e[1];
static unsigned char n857d[5];
static unsigned char n841[5];
static unsigned char n829[5];
static unsigned char n817[5];
static unsigned char n805[5];
static unsigned char n793[5];
static unsigned char n781[5];
static unsigned char n769[5];
static unsigned char n757[5];
static unsigned char n745[5];
static unsigned char n733[5];
static unsigned char n721[5];
static unsigned char n709[5];
static unsigned char n697[5];
static unsigned char n685[5];
static unsigned char n673[5];
static unsigned char n661[5];
static unsigned char n649[5];
static unsigned char n637[5];
static unsigned char n625[5];
static unsigned char n613[5];
static unsigned char n601[5];
static unsigned char n589[5];
static unsigned char n577[5];
static unsigned char n565[5];
static unsigned char n553[5];
static unsigned char n548[4];
static unsigned char n548r[1];
static unsigned char n548e[1];
static unsigned char n548d[4];
static unsigned char n540[4];
static unsigned char n540r[1];
static unsigned char n540e[1];
static unsigned char n540d[4];
static unsigned char n532[4];
static unsigned char n532r[1];
static unsigned char n532e[1];
static unsigned char n532d[4];
static unsigned char n524[4];
static unsigned char n524r[1];
static unsigned char n524e[1];
static unsigned char n524d[4];
static unsigned char n516[4];
static unsigned char n516r[1];
static unsigned char n516e[1];
static unsigned char n516d[4];
static unsigned char n508[4];
static unsigned char n508r[1];
static unsigned char n508e[1];
static unsigned char n508d[4];
static unsigned char n500[4];
static unsigned char n500r[1];
static unsigned char n500e[1];
static unsigned char n500d[4];
static unsigned char n492[4];
static unsigned char n492r[1];
static unsigned char n492e[1];
static unsigned char n492d[4];
static unsigned char n484[4];
static unsigned char n484r[1];
static unsigned char n484e[1];
static unsigned char n484d[4];
static unsigned char n476[4];
static unsigned char n476r[1];
static unsigned char n476e[1];
static unsigned char n476d[4];
static unsigned char n468[4];
static unsigned char n468r[1];
static unsigned char n468e[1];
static unsigned char n468d[4];
static unsigned char n460[4];
static unsigned char n460r[1];
static unsigned char n460e[1];
static unsigned char n460d[4];
static unsigned char n452[4];
static unsigned char n452r[1];
static unsigned char n452e[1];
static unsigned char n452d[4];
static unsigned char n444[4];
static unsigned char n444r[1];
static unsigned char n444e[1];
static unsigned char n444d[4];
static unsigned char n436[4];
static unsigned char n436r[1];
static unsigned char n436e[1];
static unsigned char n436d[4];
static unsigned char n428[4];
static unsigned char n428r[1];
static unsigned char n428e[1];
static unsigned char n428d[4];
static unsigned char n420[4];
static unsigned char n420r[1];
static unsigned char n420e[1];
static unsigned char n420d[4];
static unsigned char n412[4];
static unsigned char n412r[1];
static unsigned char n412e[1];
static unsigned char n412d[4];
static unsigned char n404[4];
static unsigned char n404r[1];
static unsigned char n404e[1];
static unsigned char n404d[4];
static unsigned char n396[4];
static unsigned char n396r[1];
static unsigned char n396e[1];
static unsigned char n396d[4];
static unsigned char n388[4];
static unsigned char n388r[1];
static unsigned char n388e[1];
static unsigned char n388d[4];
static unsigned char n380[4];
static unsigned char n380r[1];
static unsigned char n380e[1];
static unsigned char n380d[4];
static unsigned char n372[4];
static unsigned char n372r[1];
static unsigned char n372e[1];
static unsigned char n372d[4];
static unsigned char n364[4];
static unsigned char n364r[1];
static unsigned char n364e[1];
static unsigned char n364d[4];
static unsigned char n356[4];
static unsigned char n356r[1];
static unsigned char n356e[1];
static unsigned char n356d[4];
static unsigned char n348[4];
static unsigned char n348r[1];
static unsigned char n348e[1];
static unsigned char n348d[4];
static unsigned char n340[4];
static unsigned char n340r[1];
static unsigned char n340e[1];
static unsigned char n340d[4];
static unsigned char n332[4];
static unsigned char n332r[1];
static unsigned char n332e[1];
static unsigned char n332d[4];
static unsigned char n324[4];
static unsigned char n324r[1];
static unsigned char n324e[1];
static unsigned char n324d[4];
static unsigned char n316[4];
static unsigned char n316r[1];
static unsigned char n316e[1];
static unsigned char n316d[4];
static unsigned char n308[4];
static unsigned char n308r[1];
static unsigned char n308e[1];
static unsigned char n308d[4];
static unsigned char n300[4];
static unsigned char n300r[1];
static unsigned char n300e[1];
static unsigned char n300d[4];
static unsigned char n292[4];
static unsigned char n292r[1];
static unsigned char n292e[1];
static unsigned char n292d[4];
static unsigned char n284[4];
static unsigned char n284r[1];
static unsigned char n284e[1];
static unsigned char n284d[4];
static unsigned char n980[5];
static unsigned char n980r[1];
static unsigned char n980e[1];
static unsigned char n980d[5];
static unsigned char n959[5];
static unsigned char n959r[1];
static unsigned char n959e[1];
static unsigned char n959d[5];
static unsigned char n938[5];
static unsigned char n938r[1];
static unsigned char n938e[1];
static unsigned char n938d[5];
static unsigned char n926[5];
static unsigned char n926r[1];
static unsigned char n926e[1];
static unsigned char n926d[5];
static unsigned char n905[5];
static unsigned char n905r[1];
static unsigned char n905e[1];
static unsigned char n905d[5];
static unsigned char n893[5];
static unsigned char n893r[1];
static unsigned char n893e[1];
static unsigned char n893d[5];
static unsigned char n881[5];
static unsigned char n881r[1];
static unsigned char n881e[1];
static unsigned char n881d[5];
static unsigned char n869[5];
static unsigned char n869r[1];
static unsigned char n869e[1];
static unsigned char n869d[5];
static unsigned char n848[5];
static unsigned char n848r[1];
static unsigned char n848e[1];
static unsigned char n848d[5];
static unsigned char n836[5];
static unsigned char n836r[1];
static unsigned char n836e[1];
static unsigned char n836d[5];
static unsigned char n824[5];
static unsigned char n824r[1];
static unsigned char n824e[1];
static unsigned char n824d[5];
static unsigned char n812[5];
static unsigned char n812r[1];
static unsigned char n812e[1];
static unsigned char n812d[5];
static unsigned char n800[5];
static unsigned char n800r[1];
static unsigned char n800e[1];
static unsigned char n800d[5];
static unsigned char n788[5];
static unsigned char n788r[1];
static unsigned char n788e[1];
static unsigned char n788d[5];
static unsigned char n776[5];
static unsigned char n776r[1];
static unsigned char n776e[1];
static unsigned char n776d[5];
static unsigned char n764[5];
static unsigned char n764r[1];
static unsigned char n764e[1];
static unsigned char n764d[5];
static unsigned char n752[5];
static unsigned char n752r[1];
static unsigned char n752e[1];
static unsigned char n752d[5];
static unsigned char n740[5];
static unsigned char n740r[1];
static unsigned char n740e[1];
static unsigned char n740d[5];
static unsigned char n728[5];
static unsigned char n728r[1];
static unsigned char n728e[1];
static unsigned char n728d[5];
static unsigned char n716[5];
static unsigned char n716r[1];
static unsigned char n716e[1];
static unsigned char n716d[5];
static unsigned char n704[5];
static unsigned char n704r[1];
static unsigned char n704e[1];
static unsigned char n704d[5];
static unsigned char n692[5];
static unsigned char n692r[1];
static unsigned char n692e[1];
static unsigned char n692d[5];
static unsigned char n680[5];
static unsigned char n680r[1];
static unsigned char n680e[1];
static unsigned char n680d[5];
static unsigned char n668[5];
static unsigned char n668r[1];
static unsigned char n668e[1];
static unsigned char n668d[5];
static unsigned char n656[5];
static unsigned char n656r[1];
static unsigned char n656e[1];
static unsigned char n656d[5];
static unsigned char n644[5];
static unsigned char n644r[1];
static unsigned char n644e[1];
static unsigned char n644d[5];
static unsigned char n632[5];
static unsigned char n632r[1];
static unsigned char n632e[1];
static unsigned char n632d[5];
static unsigned char n620[5];
static unsigned char n620r[1];
static unsigned char n620e[1];
static unsigned char n620d[5];
static unsigned char n608[5];
static unsigned char n608r[1];
static unsigned char n608e[1];
static unsigned char n608d[5];
static unsigned char n596[5];
static unsigned char n596r[1];
static unsigned char n596e[1];
static unsigned char n596d[5];
static unsigned char n584[5];
static unsigned char n584r[1];
static unsigned char n584e[1];
static unsigned char n584d[5];
static unsigned char n572[5];
static unsigned char n572r[1];
static unsigned char n572e[1];
static unsigned char n572d[5];
static unsigned char n560[5];
static unsigned char n560r[1];
static unsigned char n560e[1];
static unsigned char n560d[5];

void cf_fir_33_16_16_ports(unsigned char* port_reset_i, unsigned char* port_data_i, unsigned char* port_k0_i, unsigned char* port_k1_i, unsigned char* port_k2_i, unsigned char* port_k3_i, unsigned char* port_k4_i, unsigned char* port_k5_i, unsigned char* port_k6_i, unsigned char* port_k7_i, unsigned char* port_k8_i, unsigned char* port_k9_i, unsigned char* port_k10_i, unsigned char* port_k11_i, unsigned char* port_k12_i, unsigned char* port_k13_i, unsigned char* port_k14_i, unsigned char* port_k15_i, unsigned char* port_k16_i, unsigned char* port_k17_i, unsigned char* port_k18_i, unsigned char* port_k19_i, unsigned char* port_k20_i, unsigned char* port_k21_i, unsigned char* port_k22_i, unsigned char* port_k23_i, unsigned char* port_k24_i, unsigned char* port_k25_i, unsigned char* port_k26_i, unsigned char* port_k27_i, unsigned char* port_k28_i, unsigned char* port_k29_i, unsigned char* port_k30_i, unsigned char* port_k31_i, unsigned char* port_k32_i, unsigned char* port_k33_i, unsigned char* port_data_o) {
  reset_i = port_reset_i;
  data_i = port_data_i;
  k0_i = port_k0_i;
  k1_i = port_k1_i;
  k2_i = port_k2_i;
  k3_i = port_k3_i;
  k4_i = port_k4_i;
  k5_i = port_k5_i;
  k6_i = port_k6_i;
  k7_i = port_k7_i;
  k8_i = port_k8_i;
  k9_i = port_k9_i;
  k10_i = port_k10_i;
  k11_i = port_k11_i;
  k12_i = port_k12_i;
  k13_i = port_k13_i;
  k14_i = port_k14_i;
  k15_i = port_k15_i;
  k16_i = port_k16_i;
  k17_i = port_k17_i;
  k18_i = port_k18_i;
  k19_i = port_k19_i;
  k20_i = port_k20_i;
  k21_i = port_k21_i;
  k22_i = port_k22_i;
  k23_i = port_k23_i;
  k24_i = port_k24_i;
  k25_i = port_k25_i;
  k26_i = port_k26_i;
  k27_i = port_k27_i;
  k28_i = port_k28_i;
  k29_i = port_k29_i;
  k30_i = port_k30_i;
  k31_i = port_k31_i;
  k32_i = port_k32_i;
  k33_i = port_k33_i;
  data_o = port_data_o;
}

void cf_fir_33_16_16_calc() {
  data_o[0] = n980[0];
  data_o[1] = n980[1];
  data_o[2] = n980[2];
  data_o[3] = n980[3];
  data_o[4] = n980[4];
  n971[0] = (1 & (n968[4] >> 4));
  n969[0] = (1 & (n959[4] >> 4));
  n960[0] = (1 & (n947[4] >> 3));
  n950[0] = (1 & (n938[4] >> 3));
  n948[0] = (1 & (n926[4] >> 3));
  n939[0] = (1 & (n914[4] >> 2));
  n929[0] = (1 & (n905[4] >> 2));
  n927[0] = (1 & (n893[4] >> 2));
  n917[0] = (1 & (n881[4] >> 2));
  n915[0] = (1 & (n869[4] >> 2));
  n906[0] = (1 & (n857[4] >> 1));
  n896[0] = (1 & (n848[4] >> 1));
  n894[0] = (1 & (n836[4] >> 1));
  n884[0] = (1 & (n824[4] >> 1));
  n882[0] = (1 & (n812[4] >> 1));
  n872[0] = (1 & (n800[4] >> 1));
  n870[0] = (1 & (n788[4] >> 1));
  n860[0] = (1 & (n776[4] >> 1));
  n858[0] = (1 & (n764[4] >> 1));
  n849[0] = (1 & (n752[4]));
  n839[0] = (1 & (n740[4]));
  n837[0] = (1 & (n728[4]));
  n827[0] = (1 & (n716[4]));
  n825[0] = (1 & (n704[4]));
  n815[0] = (1 & (n692[4]));
  n813[0] = (1 & (n680[4]));
  n803[0] = (1 & (n668[4]));
  n801[0] = (1 & (n656[4]));
  n791[0] = (1 & (n644[4]));
  n789[0] = (1 & (n632[4]));
  n779[0] = (1 & (n620[4]));
  n777[0] = (1 & (n608[4]));
  n767[0] = (1 & (n596[4]));
  n765[0] = (1 & (n584[4]));
  n755[0] = (1 & (n572[4]));
  n753[0] = (1 & (n560[4]));
  n743[0] = (1 & (n548[3] >> 7));
  n741[0] = (1 & (n540[3] >> 7));
  n731[0] = (1 & (n532[3] >> 7));
  n729[0] = (1 & (n524[3] >> 7));
  n719[0] = (1 & (n516[3] >> 7));
  n717[0] = (1 & (n508[3] >> 7));
  n707[0] = (1 & (n500[3] >> 7));
  n705[0] = (1 & (n492[3] >> 7));
  n695[0] = (1 & (n484[3] >> 7));
  n693[0] = (1 & (n476[3] >> 7));
  n683[0] = (1 & (n468[3] >> 7));
  n681[0] = (1 & (n460[3] >> 7));
  n671[0] = (1 & (n452[3] >> 7));
  n669[0] = (1 & (n444[3] >> 7));
  n659[0] = (1 & (n436[3] >> 7));
  n657[0] = (1 & (n428[3] >> 7));
  n647[0] = (1 & (n420[3] >> 7));
  n645[0] = (1 & (n412[3] >> 7));
  n635[0] = (1 & (n404[3] >> 7));
  n633[0] = (1 & (n396[3] >> 7));
  n623[0] = (1 & (n388[3] >> 7));
  n621[0] = (1 & (n380[3] >> 7));
  n611[0] = (1 & (n372[3] >> 7));
  n609[0] = (1 & (n364[3] >> 7));
  n599[0] = (1 & (n356[3] >> 7));
  n597[0] = (1 & (n348[3] >> 7));
  n587[0] = (1 & (n340[3] >> 7));
  n585[0] = (1 & (n332[3] >> 7));
  n575[0] = (1 & (n324[3] >> 7));
  n573[0] = (1 & (n316[3] >> 7));
  n563[0] = (1 & (n308[3] >> 7));
  n561[0] = (1 & (n300[3] >> 7));
  n551[0] = (1 & (n292[3] >> 7));
  n549[0] = (1 & (n284[3] >> 7));
  n2[0] = 0;
  n1[0] = 1;
  n972[0] = n968[0];
  n972[1] = n968[1];
  n972[2] = n968[2];
  n972[3] = n968[3];
  n972[4] = 255 & (n971[0] << 5 | n968[4]);
  n970[0] = n959[0];
  n970[1] = n959[1];
  n970[2] = n959[2];
  n970[3] = n959[3];
  n970[4] = 255 & (n969[0] << 5 | n959[4]);
  n961[0] = n947[0];
  n961[1] = n947[1];
  n961[2] = n947[2];
  n961[3] = n947[3];
  n961[4] = 255 & (n960[0] << 4 | n947[4]);
  n951[0] = n938[0];
  n951[1] = n938[1];
  n951[2] = n938[2];
  n951[3] = n938[3];
  n951[4] = 255 & (n950[0] << 4 | n938[4]);
  n949[0] = n926[0];
  n949[1] = n926[1];
  n949[2] = n926[2];
  n949[3] = n926[3];
  n949[4] = 255 & (n948[0] << 4 | n926[4]);
  n940[0] = n914[0];
  n940[1] = n914[1];
  n940[2] = n914[2];
  n940[3] = n914[3];
  n940[4] = 255 & (n939[0] << 3 | n914[4]);
  n930[0] = n905[0];
  n930[1] = n905[1];
  n930[2] = n905[2];
  n930[3] = n905[3];
  n930[4] = 255 & (n929[0] << 3 | n905[4]);
  n928[0] = n893[0];
  n928[1] = n893[1];
  n928[2] = n893[2];
  n928[3] = n893[3];
  n928[4] = 255 & (n927[0] << 3 | n893[4]);
  n918[0] = n881[0];
  n918[1] = n881[1];
  n918[2] = n881[2];
  n918[3] = n881[3];
  n918[4] = 255 & (n917[0] << 3 | n881[4]);
  n916[0] = n869[0];
  n916[1] = n869[1];
  n916[2] = n869[2];
  n916[3] = n869[3];
  n916[4] = 255 & (n915[0] << 3 | n869[4]);
  n907[0] = n857[0];
  n907[1] = n857[1];
  n907[2] = n857[2];
  n907[3] = n857[3];
  n907[4] = 255 & (n906[0] << 2 | n857[4]);
  n897[0] = n848[0];
  n897[1] = n848[1];
  n897[2] = n848[2];
  n897[3] = n848[3];
  n897[4] = 255 & (n896[0] << 2 | n848[4]);
  n895[0] = n836[0];
  n895[1] = n836[1];
  n895[2] = n836[2];
  n895[3] = n836[3];
  n895[4] = 255 & (n894[0] << 2 | n836[4]);
  n885[0] = n824[0];
  n885[1] = n824[1];
  n885[2] = n824[2];
  n885[3] = n824[3];
  n885[4] = 255 & (n884[0] << 2 | n824[4]);
  n883[0] = n812[0];
  n883[1] = n812[1];
  n883[2] = n812[2];
  n883[3] = n812[3];
  n883[4] = 255 & (n882[0] << 2 | n812[4]);
  n873[0] = n800[0];
  n873[1] = n800[1];
  n873[2] = n800[2];
  n873[3] = n800[3];
  n873[4] = 255 & (n872[0] << 2 | n800[4]);
  n871[0] = n788[0];
  n871[1] = n788[1];
  n871[2] = n788[2];
  n871[3] = n788[3];
  n871[4] = 255 & (n870[0] << 2 | n788[4]);
  n861[0] = n776[0];
  n861[1] = n776[1];
  n861[2] = n776[2];
  n861[3] = n776[3];
  n861[4] = 255 & (n860[0] << 2 | n776[4]);
  n859[0] = n764[0];
  n859[1] = n764[1];
  n859[2] = n764[2];
  n859[3] = n764[3];
  n859[4] = 255 & (n858[0] << 2 | n764[4]);
  n850[0] = n752[0];
  n850[1] = n752[1];
  n850[2] = n752[2];
  n850[3] = n752[3];
  n850[4] = 255 & (n849[0] << 1 | n752[4]);
  n840[0] = n740[0];
  n840[1] = n740[1];
  n840[2] = n740[2];
  n840[3] = n740[3];
  n840[4] = 255 & (n839[0] << 1 | n740[4]);
  n838[0] = n728[0];
  n838[1] = n728[1];
  n838[2] = n728[2];
  n838[3] = n728[3];
  n838[4] = 255 & (n837[0] << 1 | n728[4]);
  n828[0] = n716[0];
  n828[1] = n716[1];
  n828[2] = n716[2];
  n828[3] = n716[3];
  n828[4] = 255 & (n827[0] << 1 | n716[4]);
  n826[0] = n704[0];
  n826[1] = n704[1];
  n826[2] = n704[2];
  n826[3] = n704[3];
  n826[4] = 255 & (n825[0] << 1 | n704[4]);
  n816[0] = n692[0];
  n816[1] = n692[1];
  n816[2] = n692[2];
  n816[3] = n692[3];
  n816[4] = 255 & (n815[0] << 1 | n692[4]);
  n814[0] = n680[0];
  n814[1] = n680[1];
  n814[2] = n680[2];
  n814[3] = n680[3];
  n814[4] = 255 & (n813[0] << 1 | n680[4]);
  n804[0] = n668[0];
  n804[1] = n668[1];
  n804[2] = n668[2];
  n804[3] = n668[3];
  n804[4] = 255 & (n803[0] << 1 | n668[4]);
  n802[0] = n656[0];
  n802[1] = n656[1];
  n802[2] = n656[2];
  n802[3] = n656[3];
  n802[4] = 255 & (n801[0] << 1 | n656[4]);
  n792[0] = n644[0];
  n792[1] = n644[1];
  n792[2] = n644[2];
  n792[3] = n644[3];
  n792[4] = 255 & (n791[0] << 1 | n644[4]);
  n790[0] = n632[0];
  n790[1] = n632[1];
  n790[2] = n632[2];
  n790[3] = n632[3];
  n790[4] = 255 & (n789[0] << 1 | n632[4]);
  n780[0] = n620[0];
  n780[1] = n620[1];
  n780[2] = n620[2];
  n780[3] = n620[3];
  n780[4] = 255 & (n779[0] << 1 | n620[4]);
  n778[0] = n608[0];
  n778[1] = n608[1];
  n778[2] = n608[2];
  n778[3] = n608[3];
  n778[4] = 255 & (n777[0] << 1 | n608[4]);
  n768[0] = n596[0];
  n768[1] = n596[1];
  n768[2] = n596[2];
  n768[3] = n596[3];
  n768[4] = 255 & (n767[0] << 1 | n596[4]);
  n766[0] = n584[0];
  n766[1] = n584[1];
  n766[2] = n584[2];
  n766[3] = n584[3];
  n766[4] = 255 & (n765[0] << 1 | n584[4]);
  n756[0] = n572[0];
  n756[1] = n572[1];
  n756[2] = n572[2];
  n756[3] = n572[3];
  n756[4] = 255 & (n755[0] << 1 | n572[4]);
  n754[0] = n560[0];
  n754[1] = n560[1];
  n754[2] = n560[2];
  n754[3] = n560[3];
  n754[4] = 255 & (n753[0] << 1 | n560[4]);
  n744[0] = n548[0];
  n744[1] = n548[1];
  n744[2] = n548[2];
  n744[3] = n548[3];
  n744[4] = n743[0];
  n742[0] = n540[0];
  n742[1] = n540[1];
  n742[2] = n540[2];
  n742[3] = n540[3];
  n742[4] = n741[0];
  n732[0] = n532[0];
  n732[1] = n532[1];
  n732[2] = n532[2];
  n732[3] = n532[3];
  n732[4] = n731[0];
  n730[0] = n524[0];
  n730[1] = n524[1];
  n730[2] = n524[2];
  n730[3] = n524[3];
  n730[4] = n729[0];
  n720[0] = n516[0];
  n720[1] = n516[1];
  n720[2] = n516[2];
  n720[3] = n516[3];
  n720[4] = n719[0];
  n718[0] = n508[0];
  n718[1] = n508[1];
  n718[2] = n508[2];
  n718[3] = n508[3];
  n718[4] = n717[0];
  n708[0] = n500[0];
  n708[1] = n500[1];
  n708[2] = n500[2];
  n708[3] = n500[3];
  n708[4] = n707[0];
  n706[0] = n492[0];
  n706[1] = n492[1];
  n706[2] = n492[2];
  n706[3] = n492[3];
  n706[4] = n705[0];
  n696[0] = n484[0];
  n696[1] = n484[1];
  n696[2] = n484[2];
  n696[3] = n484[3];
  n696[4] = n695[0];
  n694[0] = n476[0];
  n694[1] = n476[1];
  n694[2] = n476[2];
  n694[3] = n476[3];
  n694[4] = n693[0];
  n684[0] = n468[0];
  n684[1] = n468[1];
  n684[2] = n468[2];
  n684[3] = n468[3];
  n684[4] = n683[0];
  n682[0] = n460[0];
  n682[1] = n460[1];
  n682[2] = n460[2];
  n682[3] = n460[3];
  n682[4] = n681[0];
  n672[0] = n452[0];
  n672[1] = n452[1];
  n672[2] = n452[2];
  n672[3] = n452[3];
  n672[4] = n671[0];
  n670[0] = n444[0];
  n670[1] = n444[1];
  n670[2] = n444[2];
  n670[3] = n444[3];
  n670[4] = n669[0];
  n660[0] = n436[0];
  n660[1] = n436[1];
  n660[2] = n436[2];
  n660[3] = n436[3];
  n660[4] = n659[0];
  n658[0] = n428[0];
  n658[1] = n428[1];
  n658[2] = n428[2];
  n658[3] = n428[3];
  n658[4] = n657[0];
  n648[0] = n420[0];
  n648[1] = n420[1];
  n648[2] = n420[2];
  n648[3] = n420[3];
  n648[4] = n647[0];
  n646[0] = n412[0];
  n646[1] = n412[1];
  n646[2] = n412[2];
  n646[3] = n412[3];
  n646[4] = n645[0];
  n636[0] = n404[0];
  n636[1] = n404[1];
  n636[2] = n404[2];
  n636[3] = n404[3];
  n636[4] = n635[0];
  n634[0] = n396[0];
  n634[1] = n396[1];
  n634[2] = n396[2];
  n634[3] = n396[3];
  n634[4] = n633[0];
  n624[0] = n388[0];
  n624[1] = n388[1];
  n624[2] = n388[2];
  n624[3] = n388[3];
  n624[4] = n623[0];
  n622[0] = n380[0];
  n622[1] = n380[1];
  n622[2] = n380[2];
  n622[3] = n380[3];
  n622[4] = n621[0];
  n612[0] = n372[0];
  n612[1] = n372[1];
  n612[2] = n372[2];
  n612[3] = n372[3];
  n612[4] = n611[0];
  n610[0] = n364[0];
  n610[1] = n364[1];
  n610[2] = n364[2];
  n610[3] = n364[3];
  n610[4] = n609[0];
  n600[0] = n356[0];
  n600[1] = n356[1];
  n600[2] = n356[2];
  n600[3] = n356[3];
  n600[4] = n599[0];
  n598[0] = n348[0];
  n598[1] = n348[1];
  n598[2] = n348[2];
  n598[3] = n348[3];
  n598[4] = n597[0];
  n588[0] = n340[0];
  n588[1] = n340[1];
  n588[2] = n340[2];
  n588[3] = n340[3];
  n588[4] = n587[0];
  n586[0] = n332[0];
  n586[1] = n332[1];
  n586[2] = n332[2];
  n586[3] = n332[3];
  n586[4] = n585[0];
  n576[0] = n324[0];
  n576[1] = n324[1];
  n576[2] = n324[2];
  n576[3] = n324[3];
  n576[4] = n575[0];
  n574[0] = n316[0];
  n574[1] = n316[1];
  n574[2] = n316[2];
  n574[3] = n316[3];
  n574[4] = n573[0];
  n564[0] = n308[0];
  n564[1] = n308[1];
  n564[2] = n308[2];
  n564[3] = n308[3];
  n564[4] = n563[0];
  n562[0] = n300[0];
  n562[1] = n300[1];
  n562[2] = n300[2];
  n562[3] = n300[3];
  n562[4] = n561[0];
  n552[0] = n292[0];
  n552[1] = n292[1];
  n552[2] = n292[2];
  n552[3] = n292[3];
  n552[4] = n551[0];
  n550[0] = n284[0];
  n550[1] = n284[1];
  n550[2] = n284[2];
  n550[3] = n284[3];
  n550[4] = n549[0];
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k33_i[1];
    a[0] = k33_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n276[1];
    b[0] = n276[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n541[0] = 255 & (unsigned char) tmp, tmp >> 8), n541[1] = 255 & (unsigned char) tmp, tmp >> 8), n541[2] = 255 & (unsigned char) tmp, tmp >> 8), n541[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k32_i[1];
    a[0] = k32_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n269[1];
    b[0] = n269[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n533[0] = 255 & (unsigned char) tmp, tmp >> 8), n533[1] = 255 & (unsigned char) tmp, tmp >> 8), n533[2] = 255 & (unsigned char) tmp, tmp >> 8), n533[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k31_i[1];
    a[0] = k31_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n262[1];
    b[0] = n262[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n525[0] = 255 & (unsigned char) tmp, tmp >> 8), n525[1] = 255 & (unsigned char) tmp, tmp >> 8), n525[2] = 255 & (unsigned char) tmp, tmp >> 8), n525[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k30_i[1];
    a[0] = k30_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n255[1];
    b[0] = n255[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n517[0] = 255 & (unsigned char) tmp, tmp >> 8), n517[1] = 255 & (unsigned char) tmp, tmp >> 8), n517[2] = 255 & (unsigned char) tmp, tmp >> 8), n517[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k29_i[1];
    a[0] = k29_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n248[1];
    b[0] = n248[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n509[0] = 255 & (unsigned char) tmp, tmp >> 8), n509[1] = 255 & (unsigned char) tmp, tmp >> 8), n509[2] = 255 & (unsigned char) tmp, tmp >> 8), n509[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k28_i[1];
    a[0] = k28_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n241[1];
    b[0] = n241[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n501[0] = 255 & (unsigned char) tmp, tmp >> 8), n501[1] = 255 & (unsigned char) tmp, tmp >> 8), n501[2] = 255 & (unsigned char) tmp, tmp >> 8), n501[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k27_i[1];
    a[0] = k27_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n234[1];
    b[0] = n234[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n493[0] = 255 & (unsigned char) tmp, tmp >> 8), n493[1] = 255 & (unsigned char) tmp, tmp >> 8), n493[2] = 255 & (unsigned char) tmp, tmp >> 8), n493[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k26_i[1];
    a[0] = k26_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n227[1];
    b[0] = n227[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n485[0] = 255 & (unsigned char) tmp, tmp >> 8), n485[1] = 255 & (unsigned char) tmp, tmp >> 8), n485[2] = 255 & (unsigned char) tmp, tmp >> 8), n485[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k25_i[1];
    a[0] = k25_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n220[1];
    b[0] = n220[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n477[0] = 255 & (unsigned char) tmp, tmp >> 8), n477[1] = 255 & (unsigned char) tmp, tmp >> 8), n477[2] = 255 & (unsigned char) tmp, tmp >> 8), n477[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k24_i[1];
    a[0] = k24_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n213[1];
    b[0] = n213[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n469[0] = 255 & (unsigned char) tmp, tmp >> 8), n469[1] = 255 & (unsigned char) tmp, tmp >> 8), n469[2] = 255 & (unsigned char) tmp, tmp >> 8), n469[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k23_i[1];
    a[0] = k23_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n206[1];
    b[0] = n206[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n461[0] = 255 & (unsigned char) tmp, tmp >> 8), n461[1] = 255 & (unsigned char) tmp, tmp >> 8), n461[2] = 255 & (unsigned char) tmp, tmp >> 8), n461[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k22_i[1];
    a[0] = k22_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n199[1];
    b[0] = n199[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n453[0] = 255 & (unsigned char) tmp, tmp >> 8), n453[1] = 255 & (unsigned char) tmp, tmp >> 8), n453[2] = 255 & (unsigned char) tmp, tmp >> 8), n453[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k21_i[1];
    a[0] = k21_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n192[1];
    b[0] = n192[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n445[0] = 255 & (unsigned char) tmp, tmp >> 8), n445[1] = 255 & (unsigned char) tmp, tmp >> 8), n445[2] = 255 & (unsigned char) tmp, tmp >> 8), n445[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k20_i[1];
    a[0] = k20_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n185[1];
    b[0] = n185[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n437[0] = 255 & (unsigned char) tmp, tmp >> 8), n437[1] = 255 & (unsigned char) tmp, tmp >> 8), n437[2] = 255 & (unsigned char) tmp, tmp >> 8), n437[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k19_i[1];
    a[0] = k19_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n178[1];
    b[0] = n178[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n429[0] = 255 & (unsigned char) tmp, tmp >> 8), n429[1] = 255 & (unsigned char) tmp, tmp >> 8), n429[2] = 255 & (unsigned char) tmp, tmp >> 8), n429[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k18_i[1];
    a[0] = k18_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n171[1];
    b[0] = n171[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n421[0] = 255 & (unsigned char) tmp, tmp >> 8), n421[1] = 255 & (unsigned char) tmp, tmp >> 8), n421[2] = 255 & (unsigned char) tmp, tmp >> 8), n421[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k17_i[1];
    a[0] = k17_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n164[1];
    b[0] = n164[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n413[0] = 255 & (unsigned char) tmp, tmp >> 8), n413[1] = 255 & (unsigned char) tmp, tmp >> 8), n413[2] = 255 & (unsigned char) tmp, tmp >> 8), n413[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k16_i[1];
    a[0] = k16_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n157[1];
    b[0] = n157[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n405[0] = 255 & (unsigned char) tmp, tmp >> 8), n405[1] = 255 & (unsigned char) tmp, tmp >> 8), n405[2] = 255 & (unsigned char) tmp, tmp >> 8), n405[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k15_i[1];
    a[0] = k15_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n150[1];
    b[0] = n150[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n397[0] = 255 & (unsigned char) tmp, tmp >> 8), n397[1] = 255 & (unsigned char) tmp, tmp >> 8), n397[2] = 255 & (unsigned char) tmp, tmp >> 8), n397[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k14_i[1];
    a[0] = k14_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n143[1];
    b[0] = n143[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n389[0] = 255 & (unsigned char) tmp, tmp >> 8), n389[1] = 255 & (unsigned char) tmp, tmp >> 8), n389[2] = 255 & (unsigned char) tmp, tmp >> 8), n389[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k13_i[1];
    a[0] = k13_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n136[1];
    b[0] = n136[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n381[0] = 255 & (unsigned char) tmp, tmp >> 8), n381[1] = 255 & (unsigned char) tmp, tmp >> 8), n381[2] = 255 & (unsigned char) tmp, tmp >> 8), n381[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k12_i[1];
    a[0] = k12_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n129[1];
    b[0] = n129[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n373[0] = 255 & (unsigned char) tmp, tmp >> 8), n373[1] = 255 & (unsigned char) tmp, tmp >> 8), n373[2] = 255 & (unsigned char) tmp, tmp >> 8), n373[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k11_i[1];
    a[0] = k11_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n122[1];
    b[0] = n122[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n365[0] = 255 & (unsigned char) tmp, tmp >> 8), n365[1] = 255 & (unsigned char) tmp, tmp >> 8), n365[2] = 255 & (unsigned char) tmp, tmp >> 8), n365[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k10_i[1];
    a[0] = k10_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n115[1];
    b[0] = n115[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n357[0] = 255 & (unsigned char) tmp, tmp >> 8), n357[1] = 255 & (unsigned char) tmp, tmp >> 8), n357[2] = 255 & (unsigned char) tmp, tmp >> 8), n357[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k9_i[1];
    a[0] = k9_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n108[1];
    b[0] = n108[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n349[0] = 255 & (unsigned char) tmp, tmp >> 8), n349[1] = 255 & (unsigned char) tmp, tmp >> 8), n349[2] = 255 & (unsigned char) tmp, tmp >> 8), n349[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k8_i[1];
    a[0] = k8_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n101[1];
    b[0] = n101[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n341[0] = 255 & (unsigned char) tmp, tmp >> 8), n341[1] = 255 & (unsigned char) tmp, tmp >> 8), n341[2] = 255 & (unsigned char) tmp, tmp >> 8), n341[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k7_i[1];
    a[0] = k7_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n94[1];
    b[0] = n94[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n333[0] = 255 & (unsigned char) tmp, tmp >> 8), n333[1] = 255 & (unsigned char) tmp, tmp >> 8), n333[2] = 255 & (unsigned char) tmp, tmp >> 8), n333[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k6_i[1];
    a[0] = k6_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n87[1];
    b[0] = n87[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n325[0] = 255 & (unsigned char) tmp, tmp >> 8), n325[1] = 255 & (unsigned char) tmp, tmp >> 8), n325[2] = 255 & (unsigned char) tmp, tmp >> 8), n325[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k5_i[1];
    a[0] = k5_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n80[1];
    b[0] = n80[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n317[0] = 255 & (unsigned char) tmp, tmp >> 8), n317[1] = 255 & (unsigned char) tmp, tmp >> 8), n317[2] = 255 & (unsigned char) tmp, tmp >> 8), n317[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k4_i[1];
    a[0] = k4_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n73[1];
    b[0] = n73[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n309[0] = 255 & (unsigned char) tmp, tmp >> 8), n309[1] = 255 & (unsigned char) tmp, tmp >> 8), n309[2] = 255 & (unsigned char) tmp, tmp >> 8), n309[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k3_i[1];
    a[0] = k3_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n66[1];
    b[0] = n66[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n301[0] = 255 & (unsigned char) tmp, tmp >> 8), n301[1] = 255 & (unsigned char) tmp, tmp >> 8), n301[2] = 255 & (unsigned char) tmp, tmp >> 8), n301[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k2_i[1];
    a[0] = k2_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n59[1];
    b[0] = n59[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n293[0] = 255 & (unsigned char) tmp, tmp >> 8), n293[1] = 255 & (unsigned char) tmp, tmp >> 8), n293[2] = 255 & (unsigned char) tmp, tmp >> 8), n293[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k1_i[1];
    a[0] = k1_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n52[1];
    b[0] = n52[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n285[0] = 255 & (unsigned char) tmp, tmp >> 8), n285[1] = 255 & (unsigned char) tmp, tmp >> 8), n285[2] = 255 & (unsigned char) tmp, tmp >> 8), n285[3] = 255 & (unsigned char) tmp);
  }
  {
    unsigned int tmp;
    unsigned char a[4];
    unsigned char b[4];
    a[3] = 0;
    a[2] = 0;
    a[1] = k0_i[1];
    a[0] = k0_i[0];
    b[3] = 0;
    b[2] = 0;
    b[1] = n45[1];
    b[0] = n45[0];
    (tmp = ((unsigned int) a[3] * (unsigned int) b[0]) + ((unsigned int) a[2] * (unsigned int) b[1]) + ((unsigned int) a[1] * (unsigned int) b[2]) + ((unsigned int) a[0] * (unsigned int) b[3]) + (tmp = ((unsigned int) a[2] * (unsigned int) b[0]) + ((unsigned int) a[1] * (unsigned int) b[1]) + ((unsigned int) a[0] * (unsigned int) b[2]) + (tmp = ((unsigned int) a[1] * (unsigned int) b[0]) + ((unsigned int) a[0] * (unsigned int) b[1]) + (tmp = ((unsigned int) a[0] * (unsigned int) b[0]), n277[0] = 255 & (unsigned char) tmp, tmp >> 8), n277[1] = 255 & (unsigned char) tmp, tmp >> 8), n277[2] = 255 & (unsigned char) tmp, tmp >> 8), n277[3] = 255 & (unsigned char) tmp);
  }
  n276r[0] = reset_i[0];
  n276e[0] = n1[0];
  n276d[0] = n269[0];
  n276d[1] = n269[1];
  n269r[0] = reset_i[0];
  n269e[0] = n1[0];
  n269d[0] = n262[0];
  n269d[1] = n262[1];
  n262r[0] = reset_i[0];
  n262e[0] = n1[0];
  n262d[0] = n255[0];
  n262d[1] = n255[1];
  n255r[0] = reset_i[0];
  n255e[0] = n1[0];
  n255d[0] = n248[0];
  n255d[1] = n248[1];
  n248r[0] = reset_i[0];
  n248e[0] = n1[0];
  n248d[0] = n241[0];
  n248d[1] = n241[1];
  n241r[0] = reset_i[0];
  n241e[0] = n1[0];
  n241d[0] = n234[0];
  n241d[1] = n234[1];
  n234r[0] = reset_i[0];
  n234e[0] = n1[0];
  n234d[0] = n227[0];
  n234d[1] = n227[1];
  n227r[0] = reset_i[0];
  n227e[0] = n1[0];
  n227d[0] = n220[0];
  n227d[1] = n220[1];
  n220r[0] = reset_i[0];
  n220e[0] = n1[0];
  n220d[0] = n213[0];
  n220d[1] = n213[1];
  n213r[0] = reset_i[0];
  n213e[0] = n1[0];
  n213d[0] = n206[0];
  n213d[1] = n206[1];
  n206r[0] = reset_i[0];
  n206e[0] = n1[0];
  n206d[0] = n199[0];
  n206d[1] = n199[1];
  n199r[0] = reset_i[0];
  n199e[0] = n1[0];
  n199d[0] = n192[0];
  n199d[1] = n192[1];
  n192r[0] = reset_i[0];
  n192e[0] = n1[0];
  n192d[0] = n185[0];
  n192d[1] = n185[1];
  n185r[0] = reset_i[0];
  n185e[0] = n1[0];
  n185d[0] = n178[0];
  n185d[1] = n178[1];
  n178r[0] = reset_i[0];
  n178e[0] = n1[0];
  n178d[0] = n171[0];
  n178d[1] = n171[1];
  n171r[0] = reset_i[0];
  n171e[0] = n1[0];
  n171d[0] = n164[0];
  n171d[1] = n164[1];
  n164r[0] = reset_i[0];
  n164e[0] = n1[0];
  n164d[0] = n157[0];
  n164d[1] = n157[1];
  n157r[0] = reset_i[0];
  n157e[0] = n1[0];
  n157d[0] = n150[0];
  n157d[1] = n150[1];
  n150r[0] = reset_i[0];
  n150e[0] = n1[0];
  n150d[0] = n143[0];
  n150d[1] = n143[1];
  n143r[0] = reset_i[0];
  n143e[0] = n1[0];
  n143d[0] = n136[0];
  n143d[1] = n136[1];
  n136r[0] = reset_i[0];
  n136e[0] = n1[0];
  n136d[0] = n129[0];
  n136d[1] = n129[1];
  n129r[0] = reset_i[0];
  n129e[0] = n1[0];
  n129d[0] = n122[0];
  n129d[1] = n122[1];
  n122r[0] = reset_i[0];
  n122e[0] = n1[0];
  n122d[0] = n115[0];
  n122d[1] = n115[1];
  n115r[0] = reset_i[0];
  n115e[0] = n1[0];
  n115d[0] = n108[0];
  n115d[1] = n108[1];
  n108r[0] = reset_i[0];
  n108e[0] = n1[0];
  n108d[0] = n101[0];
  n108d[1] = n101[1];
  n101r[0] = reset_i[0];
  n101e[0] = n1[0];
  n101d[0] = n94[0];
  n101d[1] = n94[1];
  n94r[0] = reset_i[0];
  n94e[0] = n1[0];
  n94d[0] = n87[0];
  n94d[1] = n87[1];
  n87r[0] = reset_i[0];
  n87e[0] = n1[0];
  n87d[0] = n80[0];
  n87d[1] = n80[1];
  n80r[0] = reset_i[0];
  n80e[0] = n1[0];
  n80d[0] = n73[0];
  n80d[1] = n73[1];
  n73r[0] = reset_i[0];
  n73e[0] = n1[0];
  n73d[0] = n66[0];
  n73d[1] = n66[1];
  n66r[0] = reset_i[0];
  n66e[0] = n1[0];
  n66d[0] = n59[0];
  n66d[1] = n59[1];
  n59r[0] = reset_i[0];
  n59e[0] = n1[0];
  n59d[0] = n52[0];
  n59d[1] = n52[1];
  n52r[0] = reset_i[0];
  n52e[0] = n1[0];
  n52d[0] = n45[0];
  n52d[1] = n45[1];
  n45r[0] = reset_i[0];
  n45e[0] = n1[0];
  n45d[0] = data_i[0];
  n45d[1] = data_i[1];
  { unsigned int tmp; (tmp = (unsigned int) n970[4] + (unsigned int) n972[4] + (tmp = (unsigned int) n970[3] + (unsigned int) n972[3] + (tmp = (unsigned int) n970[2] + (unsigned int) n972[2] + (tmp = (unsigned int) n970[1] + (unsigned int) n972[1] + (tmp = (unsigned int) n970[0] + (unsigned int) n972[0], n973[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n973[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n973[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n973[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n973[4] = 63 & (unsigned char) tmp); }
  n968r[0] = n2[0];
  n968e[0] = n1[0];
  n968d[0] = n961[0];
  n968d[1] = n961[1];
  n968d[2] = n961[2];
  n968d[3] = n961[3];
  n968d[4] = n961[4];
  { unsigned int tmp; (tmp = (unsigned int) n949[4] + (unsigned int) n951[4] + (tmp = (unsigned int) n949[3] + (unsigned int) n951[3] + (tmp = (unsigned int) n949[2] + (unsigned int) n951[2] + (tmp = (unsigned int) n949[1] + (unsigned int) n951[1] + (tmp = (unsigned int) n949[0] + (unsigned int) n951[0], n952[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n952[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n952[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n952[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n952[4] = 31 & (unsigned char) tmp); }
  n947r[0] = n2[0];
  n947e[0] = n1[0];
  n947d[0] = n940[0];
  n947d[1] = n940[1];
  n947d[2] = n940[2];
  n947d[3] = n940[3];
  n947d[4] = n940[4];
  { unsigned int tmp; (tmp = (unsigned int) n928[4] + (unsigned int) n930[4] + (tmp = (unsigned int) n928[3] + (unsigned int) n930[3] + (tmp = (unsigned int) n928[2] + (unsigned int) n930[2] + (tmp = (unsigned int) n928[1] + (unsigned int) n930[1] + (tmp = (unsigned int) n928[0] + (unsigned int) n930[0], n931[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n931[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n931[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n931[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n931[4] = 15 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n916[4] + (unsigned int) n918[4] + (tmp = (unsigned int) n916[3] + (unsigned int) n918[3] + (tmp = (unsigned int) n916[2] + (unsigned int) n918[2] + (tmp = (unsigned int) n916[1] + (unsigned int) n918[1] + (tmp = (unsigned int) n916[0] + (unsigned int) n918[0], n919[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n919[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n919[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n919[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n919[4] = 15 & (unsigned char) tmp); }
  n914r[0] = n2[0];
  n914e[0] = n1[0];
  n914d[0] = n907[0];
  n914d[1] = n907[1];
  n914d[2] = n907[2];
  n914d[3] = n907[3];
  n914d[4] = n907[4];
  { unsigned int tmp; (tmp = (unsigned int) n895[4] + (unsigned int) n897[4] + (tmp = (unsigned int) n895[3] + (unsigned int) n897[3] + (tmp = (unsigned int) n895[2] + (unsigned int) n897[2] + (tmp = (unsigned int) n895[1] + (unsigned int) n897[1] + (tmp = (unsigned int) n895[0] + (unsigned int) n897[0], n898[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n898[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n898[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n898[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n898[4] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n883[4] + (unsigned int) n885[4] + (tmp = (unsigned int) n883[3] + (unsigned int) n885[3] + (tmp = (unsigned int) n883[2] + (unsigned int) n885[2] + (tmp = (unsigned int) n883[1] + (unsigned int) n885[1] + (tmp = (unsigned int) n883[0] + (unsigned int) n885[0], n886[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n886[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n886[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n886[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n886[4] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n871[4] + (unsigned int) n873[4] + (tmp = (unsigned int) n871[3] + (unsigned int) n873[3] + (tmp = (unsigned int) n871[2] + (unsigned int) n873[2] + (tmp = (unsigned int) n871[1] + (unsigned int) n873[1] + (tmp = (unsigned int) n871[0] + (unsigned int) n873[0], n874[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n874[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n874[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n874[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n874[4] = 7 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n859[4] + (unsigned int) n861[4] + (tmp = (unsigned int) n859[3] + (unsigned int) n861[3] + (tmp = (unsigned int) n859[2] + (unsigned int) n861[2] + (tmp = (unsigned int) n859[1] + (unsigned int) n861[1] + (tmp = (unsigned int) n859[0] + (unsigned int) n861[0], n862[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n862[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n862[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n862[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n862[4] = 7 & (unsigned char) tmp); }
  n857r[0] = n2[0];
  n857e[0] = n1[0];
  n857d[0] = n850[0];
  n857d[1] = n850[1];
  n857d[2] = n850[2];
  n857d[3] = n850[3];
  n857d[4] = n850[4];
  { unsigned int tmp; (tmp = (unsigned int) n838[4] + (unsigned int) n840[4] + (tmp = (unsigned int) n838[3] + (unsigned int) n840[3] + (tmp = (unsigned int) n838[2] + (unsigned int) n840[2] + (tmp = (unsigned int) n838[1] + (unsigned int) n840[1] + (tmp = (unsigned int) n838[0] + (unsigned int) n840[0], n841[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n841[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n841[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n841[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n841[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n826[4] + (unsigned int) n828[4] + (tmp = (unsigned int) n826[3] + (unsigned int) n828[3] + (tmp = (unsigned int) n826[2] + (unsigned int) n828[2] + (tmp = (unsigned int) n826[1] + (unsigned int) n828[1] + (tmp = (unsigned int) n826[0] + (unsigned int) n828[0], n829[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n829[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n829[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n829[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n829[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n814[4] + (unsigned int) n816[4] + (tmp = (unsigned int) n814[3] + (unsigned int) n816[3] + (tmp = (unsigned int) n814[2] + (unsigned int) n816[2] + (tmp = (unsigned int) n814[1] + (unsigned int) n816[1] + (tmp = (unsigned int) n814[0] + (unsigned int) n816[0], n817[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n817[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n817[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n817[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n817[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n802[4] + (unsigned int) n804[4] + (tmp = (unsigned int) n802[3] + (unsigned int) n804[3] + (tmp = (unsigned int) n802[2] + (unsigned int) n804[2] + (tmp = (unsigned int) n802[1] + (unsigned int) n804[1] + (tmp = (unsigned int) n802[0] + (unsigned int) n804[0], n805[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n805[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n805[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n805[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n805[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n790[4] + (unsigned int) n792[4] + (tmp = (unsigned int) n790[3] + (unsigned int) n792[3] + (tmp = (unsigned int) n790[2] + (unsigned int) n792[2] + (tmp = (unsigned int) n790[1] + (unsigned int) n792[1] + (tmp = (unsigned int) n790[0] + (unsigned int) n792[0], n793[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n793[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n793[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n793[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n793[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n778[4] + (unsigned int) n780[4] + (tmp = (unsigned int) n778[3] + (unsigned int) n780[3] + (tmp = (unsigned int) n778[2] + (unsigned int) n780[2] + (tmp = (unsigned int) n778[1] + (unsigned int) n780[1] + (tmp = (unsigned int) n778[0] + (unsigned int) n780[0], n781[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n781[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n781[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n781[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n781[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n766[4] + (unsigned int) n768[4] + (tmp = (unsigned int) n766[3] + (unsigned int) n768[3] + (tmp = (unsigned int) n766[2] + (unsigned int) n768[2] + (tmp = (unsigned int) n766[1] + (unsigned int) n768[1] + (tmp = (unsigned int) n766[0] + (unsigned int) n768[0], n769[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n769[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n769[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n769[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n769[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n754[4] + (unsigned int) n756[4] + (tmp = (unsigned int) n754[3] + (unsigned int) n756[3] + (tmp = (unsigned int) n754[2] + (unsigned int) n756[2] + (tmp = (unsigned int) n754[1] + (unsigned int) n756[1] + (tmp = (unsigned int) n754[0] + (unsigned int) n756[0], n757[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n757[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n757[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n757[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n757[4] = 3 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n742[4] + (unsigned int) n744[4] + (tmp = (unsigned int) n742[3] + (unsigned int) n744[3] + (tmp = (unsigned int) n742[2] + (unsigned int) n744[2] + (tmp = (unsigned int) n742[1] + (unsigned int) n744[1] + (tmp = (unsigned int) n742[0] + (unsigned int) n744[0], n745[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n745[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n745[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n745[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n745[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n730[4] + (unsigned int) n732[4] + (tmp = (unsigned int) n730[3] + (unsigned int) n732[3] + (tmp = (unsigned int) n730[2] + (unsigned int) n732[2] + (tmp = (unsigned int) n730[1] + (unsigned int) n732[1] + (tmp = (unsigned int) n730[0] + (unsigned int) n732[0], n733[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n733[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n733[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n733[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n733[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n718[4] + (unsigned int) n720[4] + (tmp = (unsigned int) n718[3] + (unsigned int) n720[3] + (tmp = (unsigned int) n718[2] + (unsigned int) n720[2] + (tmp = (unsigned int) n718[1] + (unsigned int) n720[1] + (tmp = (unsigned int) n718[0] + (unsigned int) n720[0], n721[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n721[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n721[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n721[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n721[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n706[4] + (unsigned int) n708[4] + (tmp = (unsigned int) n706[3] + (unsigned int) n708[3] + (tmp = (unsigned int) n706[2] + (unsigned int) n708[2] + (tmp = (unsigned int) n706[1] + (unsigned int) n708[1] + (tmp = (unsigned int) n706[0] + (unsigned int) n708[0], n709[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n709[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n709[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n709[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n709[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n694[4] + (unsigned int) n696[4] + (tmp = (unsigned int) n694[3] + (unsigned int) n696[3] + (tmp = (unsigned int) n694[2] + (unsigned int) n696[2] + (tmp = (unsigned int) n694[1] + (unsigned int) n696[1] + (tmp = (unsigned int) n694[0] + (unsigned int) n696[0], n697[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n697[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n697[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n697[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n697[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n682[4] + (unsigned int) n684[4] + (tmp = (unsigned int) n682[3] + (unsigned int) n684[3] + (tmp = (unsigned int) n682[2] + (unsigned int) n684[2] + (tmp = (unsigned int) n682[1] + (unsigned int) n684[1] + (tmp = (unsigned int) n682[0] + (unsigned int) n684[0], n685[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n685[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n685[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n685[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n685[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n670[4] + (unsigned int) n672[4] + (tmp = (unsigned int) n670[3] + (unsigned int) n672[3] + (tmp = (unsigned int) n670[2] + (unsigned int) n672[2] + (tmp = (unsigned int) n670[1] + (unsigned int) n672[1] + (tmp = (unsigned int) n670[0] + (unsigned int) n672[0], n673[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n673[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n673[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n673[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n673[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n658[4] + (unsigned int) n660[4] + (tmp = (unsigned int) n658[3] + (unsigned int) n660[3] + (tmp = (unsigned int) n658[2] + (unsigned int) n660[2] + (tmp = (unsigned int) n658[1] + (unsigned int) n660[1] + (tmp = (unsigned int) n658[0] + (unsigned int) n660[0], n661[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n661[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n661[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n661[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n661[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n646[4] + (unsigned int) n648[4] + (tmp = (unsigned int) n646[3] + (unsigned int) n648[3] + (tmp = (unsigned int) n646[2] + (unsigned int) n648[2] + (tmp = (unsigned int) n646[1] + (unsigned int) n648[1] + (tmp = (unsigned int) n646[0] + (unsigned int) n648[0], n649[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n649[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n649[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n649[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n649[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n634[4] + (unsigned int) n636[4] + (tmp = (unsigned int) n634[3] + (unsigned int) n636[3] + (tmp = (unsigned int) n634[2] + (unsigned int) n636[2] + (tmp = (unsigned int) n634[1] + (unsigned int) n636[1] + (tmp = (unsigned int) n634[0] + (unsigned int) n636[0], n637[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n637[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n637[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n637[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n637[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n622[4] + (unsigned int) n624[4] + (tmp = (unsigned int) n622[3] + (unsigned int) n624[3] + (tmp = (unsigned int) n622[2] + (unsigned int) n624[2] + (tmp = (unsigned int) n622[1] + (unsigned int) n624[1] + (tmp = (unsigned int) n622[0] + (unsigned int) n624[0], n625[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n625[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n625[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n625[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n625[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n610[4] + (unsigned int) n612[4] + (tmp = (unsigned int) n610[3] + (unsigned int) n612[3] + (tmp = (unsigned int) n610[2] + (unsigned int) n612[2] + (tmp = (unsigned int) n610[1] + (unsigned int) n612[1] + (tmp = (unsigned int) n610[0] + (unsigned int) n612[0], n613[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n613[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n613[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n613[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n613[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n598[4] + (unsigned int) n600[4] + (tmp = (unsigned int) n598[3] + (unsigned int) n600[3] + (tmp = (unsigned int) n598[2] + (unsigned int) n600[2] + (tmp = (unsigned int) n598[1] + (unsigned int) n600[1] + (tmp = (unsigned int) n598[0] + (unsigned int) n600[0], n601[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n601[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n601[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n601[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n601[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n586[4] + (unsigned int) n588[4] + (tmp = (unsigned int) n586[3] + (unsigned int) n588[3] + (tmp = (unsigned int) n586[2] + (unsigned int) n588[2] + (tmp = (unsigned int) n586[1] + (unsigned int) n588[1] + (tmp = (unsigned int) n586[0] + (unsigned int) n588[0], n589[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n589[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n589[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n589[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n589[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n574[4] + (unsigned int) n576[4] + (tmp = (unsigned int) n574[3] + (unsigned int) n576[3] + (tmp = (unsigned int) n574[2] + (unsigned int) n576[2] + (tmp = (unsigned int) n574[1] + (unsigned int) n576[1] + (tmp = (unsigned int) n574[0] + (unsigned int) n576[0], n577[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n577[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n577[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n577[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n577[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n562[4] + (unsigned int) n564[4] + (tmp = (unsigned int) n562[3] + (unsigned int) n564[3] + (tmp = (unsigned int) n562[2] + (unsigned int) n564[2] + (tmp = (unsigned int) n562[1] + (unsigned int) n564[1] + (tmp = (unsigned int) n562[0] + (unsigned int) n564[0], n565[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n565[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n565[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n565[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n565[4] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n550[4] + (unsigned int) n552[4] + (tmp = (unsigned int) n550[3] + (unsigned int) n552[3] + (tmp = (unsigned int) n550[2] + (unsigned int) n552[2] + (tmp = (unsigned int) n550[1] + (unsigned int) n552[1] + (tmp = (unsigned int) n550[0] + (unsigned int) n552[0], n553[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n553[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n553[2] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n553[3] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n553[4] = 1 & (unsigned char) tmp); }
  n548r[0] = n2[0];
  n548e[0] = n1[0];
  n548d[0] = n541[0];
  n548d[1] = n541[1];
  n548d[2] = n541[2];
  n548d[3] = n541[3];
  n540r[0] = n2[0];
  n540e[0] = n1[0];
  n540d[0] = n533[0];
  n540d[1] = n533[1];
  n540d[2] = n533[2];
  n540d[3] = n533[3];
  n532r[0] = n2[0];
  n532e[0] = n1[0];
  n532d[0] = n525[0];
  n532d[1] = n525[1];
  n532d[2] = n525[2];
  n532d[3] = n525[3];
  n524r[0] = n2[0];
  n524e[0] = n1[0];
  n524d[0] = n517[0];
  n524d[1] = n517[1];
  n524d[2] = n517[2];
  n524d[3] = n517[3];
  n516r[0] = n2[0];
  n516e[0] = n1[0];
  n516d[0] = n509[0];
  n516d[1] = n509[1];
  n516d[2] = n509[2];
  n516d[3] = n509[3];
  n508r[0] = n2[0];
  n508e[0] = n1[0];
  n508d[0] = n501[0];
  n508d[1] = n501[1];
  n508d[2] = n501[2];
  n508d[3] = n501[3];
  n500r[0] = n2[0];
  n500e[0] = n1[0];
  n500d[0] = n493[0];
  n500d[1] = n493[1];
  n500d[2] = n493[2];
  n500d[3] = n493[3];
  n492r[0] = n2[0];
  n492e[0] = n1[0];
  n492d[0] = n485[0];
  n492d[1] = n485[1];
  n492d[2] = n485[2];
  n492d[3] = n485[3];
  n484r[0] = n2[0];
  n484e[0] = n1[0];
  n484d[0] = n477[0];
  n484d[1] = n477[1];
  n484d[2] = n477[2];
  n484d[3] = n477[3];
  n476r[0] = n2[0];
  n476e[0] = n1[0];
  n476d[0] = n469[0];
  n476d[1] = n469[1];
  n476d[2] = n469[2];
  n476d[3] = n469[3];
  n468r[0] = n2[0];
  n468e[0] = n1[0];
  n468d[0] = n461[0];
  n468d[1] = n461[1];
  n468d[2] = n461[2];
  n468d[3] = n461[3];
  n460r[0] = n2[0];
  n460e[0] = n1[0];
  n460d[0] = n453[0];
  n460d[1] = n453[1];
  n460d[2] = n453[2];
  n460d[3] = n453[3];
  n452r[0] = n2[0];
  n452e[0] = n1[0];
  n452d[0] = n445[0];
  n452d[1] = n445[1];
  n452d[2] = n445[2];
  n452d[3] = n445[3];
  n444r[0] = n2[0];
  n444e[0] = n1[0];
  n444d[0] = n437[0];
  n444d[1] = n437[1];
  n444d[2] = n437[2];
  n444d[3] = n437[3];
  n436r[0] = n2[0];
  n436e[0] = n1[0];
  n436d[0] = n429[0];
  n436d[1] = n429[1];
  n436d[2] = n429[2];
  n436d[3] = n429[3];
  n428r[0] = n2[0];
  n428e[0] = n1[0];
  n428d[0] = n421[0];
  n428d[1] = n421[1];
  n428d[2] = n421[2];
  n428d[3] = n421[3];
  n420r[0] = n2[0];
  n420e[0] = n1[0];
  n420d[0] = n413[0];
  n420d[1] = n413[1];
  n420d[2] = n413[2];
  n420d[3] = n413[3];
  n412r[0] = n2[0];
  n412e[0] = n1[0];
  n412d[0] = n405[0];
  n412d[1] = n405[1];
  n412d[2] = n405[2];
  n412d[3] = n405[3];
  n404r[0] = n2[0];
  n404e[0] = n1[0];
  n404d[0] = n397[0];
  n404d[1] = n397[1];
  n404d[2] = n397[2];
  n404d[3] = n397[3];
  n396r[0] = n2[0];
  n396e[0] = n1[0];
  n396d[0] = n389[0];
  n396d[1] = n389[1];
  n396d[2] = n389[2];
  n396d[3] = n389[3];
  n388r[0] = n2[0];
  n388e[0] = n1[0];
  n388d[0] = n381[0];
  n388d[1] = n381[1];
  n388d[2] = n381[2];
  n388d[3] = n381[3];
  n380r[0] = n2[0];
  n380e[0] = n1[0];
  n380d[0] = n373[0];
  n380d[1] = n373[1];
  n380d[2] = n373[2];
  n380d[3] = n373[3];
  n372r[0] = n2[0];
  n372e[0] = n1[0];
  n372d[0] = n365[0];
  n372d[1] = n365[1];
  n372d[2] = n365[2];
  n372d[3] = n365[3];
  n364r[0] = n2[0];
  n364e[0] = n1[0];
  n364d[0] = n357[0];
  n364d[1] = n357[1];
  n364d[2] = n357[2];
  n364d[3] = n357[3];
  n356r[0] = n2[0];
  n356e[0] = n1[0];
  n356d[0] = n349[0];
  n356d[1] = n349[1];
  n356d[2] = n349[2];
  n356d[3] = n349[3];
  n348r[0] = n2[0];
  n348e[0] = n1[0];
  n348d[0] = n341[0];
  n348d[1] = n341[1];
  n348d[2] = n341[2];
  n348d[3] = n341[3];
  n340r[0] = n2[0];
  n340e[0] = n1[0];
  n340d[0] = n333[0];
  n340d[1] = n333[1];
  n340d[2] = n333[2];
  n340d[3] = n333[3];
  n332r[0] = n2[0];
  n332e[0] = n1[0];
  n332d[0] = n325[0];
  n332d[1] = n325[1];
  n332d[2] = n325[2];
  n332d[3] = n325[3];
  n324r[0] = n2[0];
  n324e[0] = n1[0];
  n324d[0] = n317[0];
  n324d[1] = n317[1];
  n324d[2] = n317[2];
  n324d[3] = n317[3];
  n316r[0] = n2[0];
  n316e[0] = n1[0];
  n316d[0] = n309[0];
  n316d[1] = n309[1];
  n316d[2] = n309[2];
  n316d[3] = n309[3];
  n308r[0] = n2[0];
  n308e[0] = n1[0];
  n308d[0] = n301[0];
  n308d[1] = n301[1];
  n308d[2] = n301[2];
  n308d[3] = n301[3];
  n300r[0] = n2[0];
  n300e[0] = n1[0];
  n300d[0] = n293[0];
  n300d[1] = n293[1];
  n300d[2] = n293[2];
  n300d[3] = n293[3];
  n292r[0] = n2[0];
  n292e[0] = n1[0];
  n292d[0] = n285[0];
  n292d[1] = n285[1];
  n292d[2] = n285[2];
  n292d[3] = n285[3];
  n284r[0] = n2[0];
  n284e[0] = n1[0];
  n284d[0] = n277[0];
  n284d[1] = n277[1];
  n284d[2] = n277[2];
  n284d[3] = n277[3];
  n980r[0] = n2[0];
  n980e[0] = n1[0];
  n980d[0] = n973[0];
  n980d[1] = n973[1];
  n980d[2] = n973[2];
  n980d[3] = n973[3];
  n980d[4] = n973[4];
  n959r[0] = n2[0];
  n959e[0] = n1[0];
  n959d[0] = n952[0];
  n959d[1] = n952[1];
  n959d[2] = n952[2];
  n959d[3] = n952[3];
  n959d[4] = n952[4];
  n938r[0] = n2[0];
  n938e[0] = n1[0];
  n938d[0] = n931[0];
  n938d[1] = n931[1];
  n938d[2] = n931[2];
  n938d[3] = n931[3];
  n938d[4] = n931[4];
  n926r[0] = n2[0];
  n926e[0] = n1[0];
  n926d[0] = n919[0];
  n926d[1] = n919[1];
  n926d[2] = n919[2];
  n926d[3] = n919[3];
  n926d[4] = n919[4];
  n905r[0] = n2[0];
  n905e[0] = n1[0];
  n905d[0] = n898[0];
  n905d[1] = n898[1];
  n905d[2] = n898[2];
  n905d[3] = n898[3];
  n905d[4] = n898[4];
  n893r[0] = n2[0];
  n893e[0] = n1[0];
  n893d[0] = n886[0];
  n893d[1] = n886[1];
  n893d[2] = n886[2];
  n893d[3] = n886[3];
  n893d[4] = n886[4];
  n881r[0] = n2[0];
  n881e[0] = n1[0];
  n881d[0] = n874[0];
  n881d[1] = n874[1];
  n881d[2] = n874[2];
  n881d[3] = n874[3];
  n881d[4] = n874[4];
  n869r[0] = n2[0];
  n869e[0] = n1[0];
  n869d[0] = n862[0];
  n869d[1] = n862[1];
  n869d[2] = n862[2];
  n869d[3] = n862[3];
  n869d[4] = n862[4];
  n848r[0] = n2[0];
  n848e[0] = n1[0];
  n848d[0] = n841[0];
  n848d[1] = n841[1];
  n848d[2] = n841[2];
  n848d[3] = n841[3];
  n848d[4] = n841[4];
  n836r[0] = n2[0];
  n836e[0] = n1[0];
  n836d[0] = n829[0];
  n836d[1] = n829[1];
  n836d[2] = n829[2];
  n836d[3] = n829[3];
  n836d[4] = n829[4];
  n824r[0] = n2[0];
  n824e[0] = n1[0];
  n824d[0] = n817[0];
  n824d[1] = n817[1];
  n824d[2] = n817[2];
  n824d[3] = n817[3];
  n824d[4] = n817[4];
  n812r[0] = n2[0];
  n812e[0] = n1[0];
  n812d[0] = n805[0];
  n812d[1] = n805[1];
  n812d[2] = n805[2];
  n812d[3] = n805[3];
  n812d[4] = n805[4];
  n800r[0] = n2[0];
  n800e[0] = n1[0];
  n800d[0] = n793[0];
  n800d[1] = n793[1];
  n800d[2] = n793[2];
  n800d[3] = n793[3];
  n800d[4] = n793[4];
  n788r[0] = n2[0];
  n788e[0] = n1[0];
  n788d[0] = n781[0];
  n788d[1] = n781[1];
  n788d[2] = n781[2];
  n788d[3] = n781[3];
  n788d[4] = n781[4];
  n776r[0] = n2[0];
  n776e[0] = n1[0];
  n776d[0] = n769[0];
  n776d[1] = n769[1];
  n776d[2] = n769[2];
  n776d[3] = n769[3];
  n776d[4] = n769[4];
  n764r[0] = n2[0];
  n764e[0] = n1[0];
  n764d[0] = n757[0];
  n764d[1] = n757[1];
  n764d[2] = n757[2];
  n764d[3] = n757[3];
  n764d[4] = n757[4];
  n752r[0] = n2[0];
  n752e[0] = n1[0];
  n752d[0] = n745[0];
  n752d[1] = n745[1];
  n752d[2] = n745[2];
  n752d[3] = n745[3];
  n752d[4] = n745[4];
  n740r[0] = n2[0];
  n740e[0] = n1[0];
  n740d[0] = n733[0];
  n740d[1] = n733[1];
  n740d[2] = n733[2];
  n740d[3] = n733[3];
  n740d[4] = n733[4];
  n728r[0] = n2[0];
  n728e[0] = n1[0];
  n728d[0] = n721[0];
  n728d[1] = n721[1];
  n728d[2] = n721[2];
  n728d[3] = n721[3];
  n728d[4] = n721[4];
  n716r[0] = n2[0];
  n716e[0] = n1[0];
  n716d[0] = n709[0];
  n716d[1] = n709[1];
  n716d[2] = n709[2];
  n716d[3] = n709[3];
  n716d[4] = n709[4];
  n704r[0] = n2[0];
  n704e[0] = n1[0];
  n704d[0] = n697[0];
  n704d[1] = n697[1];
  n704d[2] = n697[2];
  n704d[3] = n697[3];
  n704d[4] = n697[4];
  n692r[0] = n2[0];
  n692e[0] = n1[0];
  n692d[0] = n685[0];
  n692d[1] = n685[1];
  n692d[2] = n685[2];
  n692d[3] = n685[3];
  n692d[4] = n685[4];
  n680r[0] = n2[0];
  n680e[0] = n1[0];
  n680d[0] = n673[0];
  n680d[1] = n673[1];
  n680d[2] = n673[2];
  n680d[3] = n673[3];
  n680d[4] = n673[4];
  n668r[0] = n2[0];
  n668e[0] = n1[0];
  n668d[0] = n661[0];
  n668d[1] = n661[1];
  n668d[2] = n661[2];
  n668d[3] = n661[3];
  n668d[4] = n661[4];
  n656r[0] = n2[0];
  n656e[0] = n1[0];
  n656d[0] = n649[0];
  n656d[1] = n649[1];
  n656d[2] = n649[2];
  n656d[3] = n649[3];
  n656d[4] = n649[4];
  n644r[0] = n2[0];
  n644e[0] = n1[0];
  n644d[0] = n637[0];
  n644d[1] = n637[1];
  n644d[2] = n637[2];
  n644d[3] = n637[3];
  n644d[4] = n637[4];
  n632r[0] = n2[0];
  n632e[0] = n1[0];
  n632d[0] = n625[0];
  n632d[1] = n625[1];
  n632d[2] = n625[2];
  n632d[3] = n625[3];
  n632d[4] = n625[4];
  n620r[0] = n2[0];
  n620e[0] = n1[0];
  n620d[0] = n613[0];
  n620d[1] = n613[1];
  n620d[2] = n613[2];
  n620d[3] = n613[3];
  n620d[4] = n613[4];
  n608r[0] = n2[0];
  n608e[0] = n1[0];
  n608d[0] = n601[0];
  n608d[1] = n601[1];
  n608d[2] = n601[2];
  n608d[3] = n601[3];
  n608d[4] = n601[4];
  n596r[0] = n2[0];
  n596e[0] = n1[0];
  n596d[0] = n589[0];
  n596d[1] = n589[1];
  n596d[2] = n589[2];
  n596d[3] = n589[3];
  n596d[4] = n589[4];
  n584r[0] = n2[0];
  n584e[0] = n1[0];
  n584d[0] = n577[0];
  n584d[1] = n577[1];
  n584d[2] = n577[2];
  n584d[3] = n577[3];
  n584d[4] = n577[4];
  n572r[0] = n2[0];
  n572e[0] = n1[0];
  n572d[0] = n565[0];
  n572d[1] = n565[1];
  n572d[2] = n565[2];
  n572d[3] = n565[3];
  n572d[4] = n565[4];
  n560r[0] = n2[0];
  n560e[0] = n1[0];
  n560d[0] = n553[0];
  n560d[1] = n553[1];
  n560d[2] = n553[2];
  n560d[3] = n553[3];
  n560d[4] = n553[4];
}

void cf_fir_33_16_16_init() {
  n971[0] = 0;
  n969[0] = 0;
  n960[0] = 0;
  n950[0] = 0;
  n948[0] = 0;
  n939[0] = 0;
  n929[0] = 0;
  n927[0] = 0;
  n917[0] = 0;
  n915[0] = 0;
  n906[0] = 0;
  n896[0] = 0;
  n894[0] = 0;
  n884[0] = 0;
  n882[0] = 0;
  n872[0] = 0;
  n870[0] = 0;
  n860[0] = 0;
  n858[0] = 0;
  n849[0] = 0;
  n839[0] = 0;
  n837[0] = 0;
  n827[0] = 0;
  n825[0] = 0;
  n815[0] = 0;
  n813[0] = 0;
  n803[0] = 0;
  n801[0] = 0;
  n791[0] = 0;
  n789[0] = 0;
  n779[0] = 0;
  n777[0] = 0;
  n767[0] = 0;
  n765[0] = 0;
  n755[0] = 0;
  n753[0] = 0;
  n743[0] = 0;
  n741[0] = 0;
  n731[0] = 0;
  n729[0] = 0;
  n719[0] = 0;
  n717[0] = 0;
  n707[0] = 0;
  n705[0] = 0;
  n695[0] = 0;
  n693[0] = 0;
  n683[0] = 0;
  n681[0] = 0;
  n671[0] = 0;
  n669[0] = 0;
  n659[0] = 0;
  n657[0] = 0;
  n647[0] = 0;
  n645[0] = 0;
  n635[0] = 0;
  n633[0] = 0;
  n623[0] = 0;
  n621[0] = 0;
  n611[0] = 0;
  n609[0] = 0;
  n599[0] = 0;
  n597[0] = 0;
  n587[0] = 0;
  n585[0] = 0;
  n575[0] = 0;
  n573[0] = 0;
  n563[0] = 0;
  n561[0] = 0;
  n551[0] = 0;
  n549[0] = 0;
  n2[0] = 0;
  n1[0] = 0;
  { int index; for (index = 5; index > 0;) n972[--index] = 0; }
  { int index; for (index = 5; index > 0;) n970[--index] = 0; }
  { int index; for (index = 5; index > 0;) n961[--index] = 0; }
  { int index; for (index = 5; index > 0;) n951[--index] = 0; }
  { int index; for (index = 5; index > 0;) n949[--index] = 0; }
  { int index; for (index = 5; index > 0;) n940[--index] = 0; }
  { int index; for (index = 5; index > 0;) n930[--index] = 0; }
  { int index; for (index = 5; index > 0;) n928[--index] = 0; }
  { int index; for (index = 5; index > 0;) n918[--index] = 0; }
  { int index; for (index = 5; index > 0;) n916[--index] = 0; }
  { int index; for (index = 5; index > 0;) n907[--index] = 0; }
  { int index; for (index = 5; index > 0;) n897[--index] = 0; }
  { int index; for (index = 5; index > 0;) n895[--index] = 0; }
  { int index; for (index = 5; index > 0;) n885[--index] = 0; }
  { int index; for (index = 5; index > 0;) n883[--index] = 0; }
  { int index; for (index = 5; index > 0;) n873[--index] = 0; }
  { int index; for (index = 5; index > 0;) n871[--index] = 0; }
  { int index; for (index = 5; index > 0;) n861[--index] = 0; }
  { int index; for (index = 5; index > 0;) n859[--index] = 0; }
  { int index; for (index = 5; index > 0;) n850[--index] = 0; }
  { int index; for (index = 5; index > 0;) n840[--index] = 0; }
  { int index; for (index = 5; index > 0;) n838[--index] = 0; }
  { int index; for (index = 5; index > 0;) n828[--index] = 0; }
  { int index; for (index = 5; index > 0;) n826[--index] = 0; }
  { int index; for (index = 5; index > 0;) n816[--index] = 0; }
  { int index; for (index = 5; index > 0;) n814[--index] = 0; }
  { int index; for (index = 5; index > 0;) n804[--index] = 0; }
  { int index; for (index = 5; index > 0;) n802[--index] = 0; }
  { int index; for (index = 5; index > 0;) n792[--index] = 0; }
  { int index; for (index = 5; index > 0;) n790[--index] = 0; }
  { int index; for (index = 5; index > 0;) n780[--index] = 0; }
  { int index; for (index = 5; index > 0;) n778[--index] = 0; }
  { int index; for (index = 5; index > 0;) n768[--index] = 0; }
  { int index; for (index = 5; index > 0;) n766[--index] = 0; }
  { int index; for (index = 5; index > 0;) n756[--index] = 0; }
  { int index; for (index = 5; index > 0;) n754[--index] = 0; }
  { int index; for (index = 5; index > 0;) n744[--index] = 0; }
  { int index; for (index = 5; index > 0;) n742[--index] = 0; }
  { int index; for (index = 5; index > 0;) n732[--index] = 0; }
  { int index; for (index = 5; index > 0;) n730[--index] = 0; }
  { int index; for (index = 5; index > 0;) n720[--index] = 0; }
  { int index; for (index = 5; index > 0;) n718[--index] = 0; }
  { int index; for (index = 5; index > 0;) n708[--index] = 0; }
  { int index; for (index = 5; index > 0;) n706[--index] = 0; }
  { int index; for (index = 5; index > 0;) n696[--index] = 0; }
  { int index; for (index = 5; index > 0;) n694[--index] = 0; }
  { int index; for (index = 5; index > 0;) n684[--index] = 0; }
  { int index; for (index = 5; index > 0;) n682[--index] = 0; }
  { int index; for (index = 5; index > 0;) n672[--index] = 0; }
  { int index; for (index = 5; index > 0;) n670[--index] = 0; }
  { int index; for (index = 5; index > 0;) n660[--index] = 0; }
  { int index; for (index = 5; index > 0;) n658[--index] = 0; }
  { int index; for (index = 5; index > 0;) n648[--index] = 0; }
  { int index; for (index = 5; index > 0;) n646[--index] = 0; }
  { int index; for (index = 5; index > 0;) n636[--index] = 0; }
  { int index; for (index = 5; index > 0;) n634[--index] = 0; }
  { int index; for (index = 5; index > 0;) n624[--index] = 0; }
  { int index; for (index = 5; index > 0;) n622[--index] = 0; }
  { int index; for (index = 5; index > 0;) n612[--index] = 0; }
  { int index; for (index = 5; index > 0;) n610[--index] = 0; }
  { int index; for (index = 5; index > 0;) n600[--index] = 0; }
  { int index; for (index = 5; index > 0;) n598[--index] = 0; }
  { int index; for (index = 5; index > 0;) n588[--index] = 0; }
  { int index; for (index = 5; index > 0;) n586[--index] = 0; }
  { int index; for (index = 5; index > 0;) n576[--index] = 0; }
  { int index; for (index = 5; index > 0;) n574[--index] = 0; }
  { int index; for (index = 5; index > 0;) n564[--index] = 0; }
  { int index; for (index = 5; index > 0;) n562[--index] = 0; }
  { int index; for (index = 5; index > 0;) n552[--index] = 0; }
  { int index; for (index = 5; index > 0;) n550[--index] = 0; }
  { int index; for (index = 4; index > 0;) n541[--index] = 0; }
  { int index; for (index = 4; index > 0;) n533[--index] = 0; }
  { int index; for (index = 4; index > 0;) n525[--index] = 0; }
  { int index; for (index = 4; index > 0;) n517[--index] = 0; }
  { int index; for (index = 4; index > 0;) n509[--index] = 0; }
  { int index; for (index = 4; index > 0;) n501[--index] = 0; }
  { int index; for (index = 4; index > 0;) n493[--index] = 0; }
  { int index; for (index = 4; index > 0;) n485[--index] = 0; }
  { int index; for (index = 4; index > 0;) n477[--index] = 0; }
  { int index; for (index = 4; index > 0;) n469[--index] = 0; }
  { int index; for (index = 4; index > 0;) n461[--index] = 0; }
  { int index; for (index = 4; index > 0;) n453[--index] = 0; }
  { int index; for (index = 4; index > 0;) n445[--index] = 0; }
  { int index; for (index = 4; index > 0;) n437[--index] = 0; }
  { int index; for (index = 4; index > 0;) n429[--index] = 0; }
  { int index; for (index = 4; index > 0;) n421[--index] = 0; }
  { int index; for (index = 4; index > 0;) n413[--index] = 0; }
  { int index; for (index = 4; index > 0;) n405[--index] = 0; }
  { int index; for (index = 4; index > 0;) n397[--index] = 0; }
  { int index; for (index = 4; index > 0;) n389[--index] = 0; }
  { int index; for (index = 4; index > 0;) n381[--index] = 0; }
  { int index; for (index = 4; index > 0;) n373[--index] = 0; }
  { int index; for (index = 4; index > 0;) n365[--index] = 0; }
  { int index; for (index = 4; index > 0;) n357[--index] = 0; }
  { int index; for (index = 4; index > 0;) n349[--index] = 0; }
  { int index; for (index = 4; index > 0;) n341[--index] = 0; }
  { int index; for (index = 4; index > 0;) n333[--index] = 0; }
  { int index; for (index = 4; index > 0;) n325[--index] = 0; }
  { int index; for (index = 4; index > 0;) n317[--index] = 0; }
  { int index; for (index = 4; index > 0;) n309[--index] = 0; }
  { int index; for (index = 4; index > 0;) n301[--index] = 0; }
  { int index; for (index = 4; index > 0;) n293[--index] = 0; }
  { int index; for (index = 4; index > 0;) n285[--index] = 0; }
  { int index; for (index = 4; index > 0;) n277[--index] = 0; }
  { int index; for (index = 2; index > 0;) n276[--index] = 0; }
  n276r[0] = 0;
  n276e[0] = 0;
  { int index; for (index = 2; index > 0;) n276d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n269[--index] = 0; }
  n269r[0] = 0;
  n269e[0] = 0;
  { int index; for (index = 2; index > 0;) n269d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n262[--index] = 0; }
  n262r[0] = 0;
  n262e[0] = 0;
  { int index; for (index = 2; index > 0;) n262d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n255[--index] = 0; }
  n255r[0] = 0;
  n255e[0] = 0;
  { int index; for (index = 2; index > 0;) n255d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n248[--index] = 0; }
  n248r[0] = 0;
  n248e[0] = 0;
  { int index; for (index = 2; index > 0;) n248d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n241[--index] = 0; }
  n241r[0] = 0;
  n241e[0] = 0;
  { int index; for (index = 2; index > 0;) n241d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n234[--index] = 0; }
  n234r[0] = 0;
  n234e[0] = 0;
  { int index; for (index = 2; index > 0;) n234d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n227[--index] = 0; }
  n227r[0] = 0;
  n227e[0] = 0;
  { int index; for (index = 2; index > 0;) n227d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n220[--index] = 0; }
  n220r[0] = 0;
  n220e[0] = 0;
  { int index; for (index = 2; index > 0;) n220d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n213[--index] = 0; }
  n213r[0] = 0;
  n213e[0] = 0;
  { int index; for (index = 2; index > 0;) n213d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n206[--index] = 0; }
  n206r[0] = 0;
  n206e[0] = 0;
  { int index; for (index = 2; index > 0;) n206d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n199[--index] = 0; }
  n199r[0] = 0;
  n199e[0] = 0;
  { int index; for (index = 2; index > 0;) n199d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n192[--index] = 0; }
  n192r[0] = 0;
  n192e[0] = 0;
  { int index; for (index = 2; index > 0;) n192d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n185[--index] = 0; }
  n185r[0] = 0;
  n185e[0] = 0;
  { int index; for (index = 2; index > 0;) n185d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n178[--index] = 0; }
  n178r[0] = 0;
  n178e[0] = 0;
  { int index; for (index = 2; index > 0;) n178d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n171[--index] = 0; }
  n171r[0] = 0;
  n171e[0] = 0;
  { int index; for (index = 2; index > 0;) n171d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n164[--index] = 0; }
  n164r[0] = 0;
  n164e[0] = 0;
  { int index; for (index = 2; index > 0;) n164d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n157[--index] = 0; }
  n157r[0] = 0;
  n157e[0] = 0;
  { int index; for (index = 2; index > 0;) n157d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n150[--index] = 0; }
  n150r[0] = 0;
  n150e[0] = 0;
  { int index; for (index = 2; index > 0;) n150d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n143[--index] = 0; }
  n143r[0] = 0;
  n143e[0] = 0;
  { int index; for (index = 2; index > 0;) n143d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n136[--index] = 0; }
  n136r[0] = 0;
  n136e[0] = 0;
  { int index; for (index = 2; index > 0;) n136d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n129[--index] = 0; }
  n129r[0] = 0;
  n129e[0] = 0;
  { int index; for (index = 2; index > 0;) n129d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n122[--index] = 0; }
  n122r[0] = 0;
  n122e[0] = 0;
  { int index; for (index = 2; index > 0;) n122d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n115[--index] = 0; }
  n115r[0] = 0;
  n115e[0] = 0;
  { int index; for (index = 2; index > 0;) n115d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n108[--index] = 0; }
  n108r[0] = 0;
  n108e[0] = 0;
  { int index; for (index = 2; index > 0;) n108d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n101[--index] = 0; }
  n101r[0] = 0;
  n101e[0] = 0;
  { int index; for (index = 2; index > 0;) n101d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n94[--index] = 0; }
  n94r[0] = 0;
  n94e[0] = 0;
  { int index; for (index = 2; index > 0;) n94d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n87[--index] = 0; }
  n87r[0] = 0;
  n87e[0] = 0;
  { int index; for (index = 2; index > 0;) n87d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n80[--index] = 0; }
  n80r[0] = 0;
  n80e[0] = 0;
  { int index; for (index = 2; index > 0;) n80d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n73[--index] = 0; }
  n73r[0] = 0;
  n73e[0] = 0;
  { int index; for (index = 2; index > 0;) n73d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n66[--index] = 0; }
  n66r[0] = 0;
  n66e[0] = 0;
  { int index; for (index = 2; index > 0;) n66d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n59[--index] = 0; }
  n59r[0] = 0;
  n59e[0] = 0;
  { int index; for (index = 2; index > 0;) n59d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n52[--index] = 0; }
  n52r[0] = 0;
  n52e[0] = 0;
  { int index; for (index = 2; index > 0;) n52d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n45[--index] = 0; }
  n45r[0] = 0;
  n45e[0] = 0;
  { int index; for (index = 2; index > 0;) n45d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n973[--index] = 0; }
  { int index; for (index = 5; index > 0;) n968[--index] = 0; }
  n968r[0] = 0;
  n968e[0] = 0;
  { int index; for (index = 5; index > 0;) n968d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n952[--index] = 0; }
  { int index; for (index = 5; index > 0;) n947[--index] = 0; }
  n947r[0] = 0;
  n947e[0] = 0;
  { int index; for (index = 5; index > 0;) n947d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n931[--index] = 0; }
  { int index; for (index = 5; index > 0;) n919[--index] = 0; }
  { int index; for (index = 5; index > 0;) n914[--index] = 0; }
  n914r[0] = 0;
  n914e[0] = 0;
  { int index; for (index = 5; index > 0;) n914d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n898[--index] = 0; }
  { int index; for (index = 5; index > 0;) n886[--index] = 0; }
  { int index; for (index = 5; index > 0;) n874[--index] = 0; }
  { int index; for (index = 5; index > 0;) n862[--index] = 0; }
  { int index; for (index = 5; index > 0;) n857[--index] = 0; }
  n857r[0] = 0;
  n857e[0] = 0;
  { int index; for (index = 5; index > 0;) n857d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n841[--index] = 0; }
  { int index; for (index = 5; index > 0;) n829[--index] = 0; }
  { int index; for (index = 5; index > 0;) n817[--index] = 0; }
  { int index; for (index = 5; index > 0;) n805[--index] = 0; }
  { int index; for (index = 5; index > 0;) n793[--index] = 0; }
  { int index; for (index = 5; index > 0;) n781[--index] = 0; }
  { int index; for (index = 5; index > 0;) n769[--index] = 0; }
  { int index; for (index = 5; index > 0;) n757[--index] = 0; }
  { int index; for (index = 5; index > 0;) n745[--index] = 0; }
  { int index; for (index = 5; index > 0;) n733[--index] = 0; }
  { int index; for (index = 5; index > 0;) n721[--index] = 0; }
  { int index; for (index = 5; index > 0;) n709[--index] = 0; }
  { int index; for (index = 5; index > 0;) n697[--index] = 0; }
  { int index; for (index = 5; index > 0;) n685[--index] = 0; }
  { int index; for (index = 5; index > 0;) n673[--index] = 0; }
  { int index; for (index = 5; index > 0;) n661[--index] = 0; }
  { int index; for (index = 5; index > 0;) n649[--index] = 0; }
  { int index; for (index = 5; index > 0;) n637[--index] = 0; }
  { int index; for (index = 5; index > 0;) n625[--index] = 0; }
  { int index; for (index = 5; index > 0;) n613[--index] = 0; }
  { int index; for (index = 5; index > 0;) n601[--index] = 0; }
  { int index; for (index = 5; index > 0;) n589[--index] = 0; }
  { int index; for (index = 5; index > 0;) n577[--index] = 0; }
  { int index; for (index = 5; index > 0;) n565[--index] = 0; }
  { int index; for (index = 5; index > 0;) n553[--index] = 0; }
  { int index; for (index = 4; index > 0;) n548[--index] = 0; }
  n548r[0] = 0;
  n548e[0] = 0;
  { int index; for (index = 4; index > 0;) n548d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n540[--index] = 0; }
  n540r[0] = 0;
  n540e[0] = 0;
  { int index; for (index = 4; index > 0;) n540d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n532[--index] = 0; }
  n532r[0] = 0;
  n532e[0] = 0;
  { int index; for (index = 4; index > 0;) n532d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n524[--index] = 0; }
  n524r[0] = 0;
  n524e[0] = 0;
  { int index; for (index = 4; index > 0;) n524d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n516[--index] = 0; }
  n516r[0] = 0;
  n516e[0] = 0;
  { int index; for (index = 4; index > 0;) n516d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n508[--index] = 0; }
  n508r[0] = 0;
  n508e[0] = 0;
  { int index; for (index = 4; index > 0;) n508d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n500[--index] = 0; }
  n500r[0] = 0;
  n500e[0] = 0;
  { int index; for (index = 4; index > 0;) n500d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n492[--index] = 0; }
  n492r[0] = 0;
  n492e[0] = 0;
  { int index; for (index = 4; index > 0;) n492d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n484[--index] = 0; }
  n484r[0] = 0;
  n484e[0] = 0;
  { int index; for (index = 4; index > 0;) n484d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n476[--index] = 0; }
  n476r[0] = 0;
  n476e[0] = 0;
  { int index; for (index = 4; index > 0;) n476d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n468[--index] = 0; }
  n468r[0] = 0;
  n468e[0] = 0;
  { int index; for (index = 4; index > 0;) n468d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n460[--index] = 0; }
  n460r[0] = 0;
  n460e[0] = 0;
  { int index; for (index = 4; index > 0;) n460d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n452[--index] = 0; }
  n452r[0] = 0;
  n452e[0] = 0;
  { int index; for (index = 4; index > 0;) n452d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n444[--index] = 0; }
  n444r[0] = 0;
  n444e[0] = 0;
  { int index; for (index = 4; index > 0;) n444d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n436[--index] = 0; }
  n436r[0] = 0;
  n436e[0] = 0;
  { int index; for (index = 4; index > 0;) n436d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n428[--index] = 0; }
  n428r[0] = 0;
  n428e[0] = 0;
  { int index; for (index = 4; index > 0;) n428d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n420[--index] = 0; }
  n420r[0] = 0;
  n420e[0] = 0;
  { int index; for (index = 4; index > 0;) n420d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n412[--index] = 0; }
  n412r[0] = 0;
  n412e[0] = 0;
  { int index; for (index = 4; index > 0;) n412d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n404[--index] = 0; }
  n404r[0] = 0;
  n404e[0] = 0;
  { int index; for (index = 4; index > 0;) n404d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n396[--index] = 0; }
  n396r[0] = 0;
  n396e[0] = 0;
  { int index; for (index = 4; index > 0;) n396d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n388[--index] = 0; }
  n388r[0] = 0;
  n388e[0] = 0;
  { int index; for (index = 4; index > 0;) n388d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n380[--index] = 0; }
  n380r[0] = 0;
  n380e[0] = 0;
  { int index; for (index = 4; index > 0;) n380d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n372[--index] = 0; }
  n372r[0] = 0;
  n372e[0] = 0;
  { int index; for (index = 4; index > 0;) n372d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n364[--index] = 0; }
  n364r[0] = 0;
  n364e[0] = 0;
  { int index; for (index = 4; index > 0;) n364d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n356[--index] = 0; }
  n356r[0] = 0;
  n356e[0] = 0;
  { int index; for (index = 4; index > 0;) n356d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n348[--index] = 0; }
  n348r[0] = 0;
  n348e[0] = 0;
  { int index; for (index = 4; index > 0;) n348d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n340[--index] = 0; }
  n340r[0] = 0;
  n340e[0] = 0;
  { int index; for (index = 4; index > 0;) n340d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n332[--index] = 0; }
  n332r[0] = 0;
  n332e[0] = 0;
  { int index; for (index = 4; index > 0;) n332d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n324[--index] = 0; }
  n324r[0] = 0;
  n324e[0] = 0;
  { int index; for (index = 4; index > 0;) n324d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n316[--index] = 0; }
  n316r[0] = 0;
  n316e[0] = 0;
  { int index; for (index = 4; index > 0;) n316d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n308[--index] = 0; }
  n308r[0] = 0;
  n308e[0] = 0;
  { int index; for (index = 4; index > 0;) n308d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n300[--index] = 0; }
  n300r[0] = 0;
  n300e[0] = 0;
  { int index; for (index = 4; index > 0;) n300d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n292[--index] = 0; }
  n292r[0] = 0;
  n292e[0] = 0;
  { int index; for (index = 4; index > 0;) n292d[--index] = 0; }
  { int index; for (index = 4; index > 0;) n284[--index] = 0; }
  n284r[0] = 0;
  n284e[0] = 0;
  { int index; for (index = 4; index > 0;) n284d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n980[--index] = 0; }
  n980r[0] = 0;
  n980e[0] = 0;
  { int index; for (index = 5; index > 0;) n980d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n959[--index] = 0; }
  n959r[0] = 0;
  n959e[0] = 0;
  { int index; for (index = 5; index > 0;) n959d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n938[--index] = 0; }
  n938r[0] = 0;
  n938e[0] = 0;
  { int index; for (index = 5; index > 0;) n938d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n926[--index] = 0; }
  n926r[0] = 0;
  n926e[0] = 0;
  { int index; for (index = 5; index > 0;) n926d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n905[--index] = 0; }
  n905r[0] = 0;
  n905e[0] = 0;
  { int index; for (index = 5; index > 0;) n905d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n893[--index] = 0; }
  n893r[0] = 0;
  n893e[0] = 0;
  { int index; for (index = 5; index > 0;) n893d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n881[--index] = 0; }
  n881r[0] = 0;
  n881e[0] = 0;
  { int index; for (index = 5; index > 0;) n881d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n869[--index] = 0; }
  n869r[0] = 0;
  n869e[0] = 0;
  { int index; for (index = 5; index > 0;) n869d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n848[--index] = 0; }
  n848r[0] = 0;
  n848e[0] = 0;
  { int index; for (index = 5; index > 0;) n848d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n836[--index] = 0; }
  n836r[0] = 0;
  n836e[0] = 0;
  { int index; for (index = 5; index > 0;) n836d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n824[--index] = 0; }
  n824r[0] = 0;
  n824e[0] = 0;
  { int index; for (index = 5; index > 0;) n824d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n812[--index] = 0; }
  n812r[0] = 0;
  n812e[0] = 0;
  { int index; for (index = 5; index > 0;) n812d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n800[--index] = 0; }
  n800r[0] = 0;
  n800e[0] = 0;
  { int index; for (index = 5; index > 0;) n800d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n788[--index] = 0; }
  n788r[0] = 0;
  n788e[0] = 0;
  { int index; for (index = 5; index > 0;) n788d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n776[--index] = 0; }
  n776r[0] = 0;
  n776e[0] = 0;
  { int index; for (index = 5; index > 0;) n776d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n764[--index] = 0; }
  n764r[0] = 0;
  n764e[0] = 0;
  { int index; for (index = 5; index > 0;) n764d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n752[--index] = 0; }
  n752r[0] = 0;
  n752e[0] = 0;
  { int index; for (index = 5; index > 0;) n752d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n740[--index] = 0; }
  n740r[0] = 0;
  n740e[0] = 0;
  { int index; for (index = 5; index > 0;) n740d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n728[--index] = 0; }
  n728r[0] = 0;
  n728e[0] = 0;
  { int index; for (index = 5; index > 0;) n728d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n716[--index] = 0; }
  n716r[0] = 0;
  n716e[0] = 0;
  { int index; for (index = 5; index > 0;) n716d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n704[--index] = 0; }
  n704r[0] = 0;
  n704e[0] = 0;
  { int index; for (index = 5; index > 0;) n704d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n692[--index] = 0; }
  n692r[0] = 0;
  n692e[0] = 0;
  { int index; for (index = 5; index > 0;) n692d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n680[--index] = 0; }
  n680r[0] = 0;
  n680e[0] = 0;
  { int index; for (index = 5; index > 0;) n680d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n668[--index] = 0; }
  n668r[0] = 0;
  n668e[0] = 0;
  { int index; for (index = 5; index > 0;) n668d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n656[--index] = 0; }
  n656r[0] = 0;
  n656e[0] = 0;
  { int index; for (index = 5; index > 0;) n656d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n644[--index] = 0; }
  n644r[0] = 0;
  n644e[0] = 0;
  { int index; for (index = 5; index > 0;) n644d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n632[--index] = 0; }
  n632r[0] = 0;
  n632e[0] = 0;
  { int index; for (index = 5; index > 0;) n632d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n620[--index] = 0; }
  n620r[0] = 0;
  n620e[0] = 0;
  { int index; for (index = 5; index > 0;) n620d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n608[--index] = 0; }
  n608r[0] = 0;
  n608e[0] = 0;
  { int index; for (index = 5; index > 0;) n608d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n596[--index] = 0; }
  n596r[0] = 0;
  n596e[0] = 0;
  { int index; for (index = 5; index > 0;) n596d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n584[--index] = 0; }
  n584r[0] = 0;
  n584e[0] = 0;
  { int index; for (index = 5; index > 0;) n584d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n572[--index] = 0; }
  n572r[0] = 0;
  n572e[0] = 0;
  { int index; for (index = 5; index > 0;) n572d[--index] = 0; }
  { int index; for (index = 5; index > 0;) n560[--index] = 0; }
  n560r[0] = 0;
  n560e[0] = 0;
  { int index; for (index = 5; index > 0;) n560d[--index] = 0; }
  cf_fir_33_16_16_calc();
}

void cf_fir_33_16_16_cycle_clock()
{
  if (n45r[0]) {
    n45[0] = 0;
    n45[1] = 0;
  }
  else if (n45e[0]) {
    n45[0] = n45d[0];
    n45[1] = n45d[1];
  }
  if (n52r[0]) {
    n52[0] = 0;
    n52[1] = 0;
  }
  else if (n52e[0]) {
    n52[0] = n52d[0];
    n52[1] = n52d[1];
  }
  if (n59r[0]) {
    n59[0] = 0;
    n59[1] = 0;
  }
  else if (n59e[0]) {
    n59[0] = n59d[0];
    n59[1] = n59d[1];
  }
  if (n66r[0]) {
    n66[0] = 0;
    n66[1] = 0;
  }
  else if (n66e[0]) {
    n66[0] = n66d[0];
    n66[1] = n66d[1];
  }
  if (n73r[0]) {
    n73[0] = 0;
    n73[1] = 0;
  }
  else if (n73e[0]) {
    n73[0] = n73d[0];
    n73[1] = n73d[1];
  }
  if (n80r[0]) {
    n80[0] = 0;
    n80[1] = 0;
  }
  else if (n80e[0]) {
    n80[0] = n80d[0];
    n80[1] = n80d[1];
  }
  if (n87r[0]) {
    n87[0] = 0;
    n87[1] = 0;
  }
  else if (n87e[0]) {
    n87[0] = n87d[0];
    n87[1] = n87d[1];
  }
  if (n94r[0]) {
    n94[0] = 0;
    n94[1] = 0;
  }
  else if (n94e[0]) {
    n94[0] = n94d[0];
    n94[1] = n94d[1];
  }
  if (n101r[0]) {
    n101[0] = 0;
    n101[1] = 0;
  }
  else if (n101e[0]) {
    n101[0] = n101d[0];
    n101[1] = n101d[1];
  }
  if (n108r[0]) {
    n108[0] = 0;
    n108[1] = 0;
  }
  else if (n108e[0]) {
    n108[0] = n108d[0];
    n108[1] = n108d[1];
  }
  if (n115r[0]) {
    n115[0] = 0;
    n115[1] = 0;
  }
  else if (n115e[0]) {
    n115[0] = n115d[0];
    n115[1] = n115d[1];
  }
  if (n122r[0]) {
    n122[0] = 0;
    n122[1] = 0;
  }
  else if (n122e[0]) {
    n122[0] = n122d[0];
    n122[1] = n122d[1];
  }
  if (n129r[0]) {
    n129[0] = 0;
    n129[1] = 0;
  }
  else if (n129e[0]) {
    n129[0] = n129d[0];
    n129[1] = n129d[1];
  }
  if (n136r[0]) {
    n136[0] = 0;
    n136[1] = 0;
  }
  else if (n136e[0]) {
    n136[0] = n136d[0];
    n136[1] = n136d[1];
  }
  if (n143r[0]) {
    n143[0] = 0;
    n143[1] = 0;
  }
  else if (n143e[0]) {
    n143[0] = n143d[0];
    n143[1] = n143d[1];
  }
  if (n150r[0]) {
    n150[0] = 0;
    n150[1] = 0;
  }
  else if (n150e[0]) {
    n150[0] = n150d[0];
    n150[1] = n150d[1];
  }
  if (n157r[0]) {
    n157[0] = 0;
    n157[1] = 0;
  }
  else if (n157e[0]) {
    n157[0] = n157d[0];
    n157[1] = n157d[1];
  }
  if (n164r[0]) {
    n164[0] = 0;
    n164[1] = 0;
  }
  else if (n164e[0]) {
    n164[0] = n164d[0];
    n164[1] = n164d[1];
  }
  if (n171r[0]) {
    n171[0] = 0;
    n171[1] = 0;
  }
  else if (n171e[0]) {
    n171[0] = n171d[0];
    n171[1] = n171d[1];
  }
  if (n178r[0]) {
    n178[0] = 0;
    n178[1] = 0;
  }
  else if (n178e[0]) {
    n178[0] = n178d[0];
    n178[1] = n178d[1];
  }
  if (n185r[0]) {
    n185[0] = 0;
    n185[1] = 0;
  }
  else if (n185e[0]) {
    n185[0] = n185d[0];
    n185[1] = n185d[1];
  }
  if (n192r[0]) {
    n192[0] = 0;
    n192[1] = 0;
  }
  else if (n192e[0]) {
    n192[0] = n192d[0];
    n192[1] = n192d[1];
  }
  if (n199r[0]) {
    n199[0] = 0;
    n199[1] = 0;
  }
  else if (n199e[0]) {
    n199[0] = n199d[0];
    n199[1] = n199d[1];
  }
  if (n206r[0]) {
    n206[0] = 0;
    n206[1] = 0;
  }
  else if (n206e[0]) {
    n206[0] = n206d[0];
    n206[1] = n206d[1];
  }
  if (n213r[0]) {
    n213[0] = 0;
    n213[1] = 0;
  }
  else if (n213e[0]) {
    n213[0] = n213d[0];
    n213[1] = n213d[1];
  }
  if (n220r[0]) {
    n220[0] = 0;
    n220[1] = 0;
  }
  else if (n220e[0]) {
    n220[0] = n220d[0];
    n220[1] = n220d[1];
  }
  if (n227r[0]) {
    n227[0] = 0;
    n227[1] = 0;
  }
  else if (n227e[0]) {
    n227[0] = n227d[0];
    n227[1] = n227d[1];
  }
  if (n234r[0]) {
    n234[0] = 0;
    n234[1] = 0;
  }
  else if (n234e[0]) {
    n234[0] = n234d[0];
    n234[1] = n234d[1];
  }
  if (n241r[0]) {
    n241[0] = 0;
    n241[1] = 0;
  }
  else if (n241e[0]) {
    n241[0] = n241d[0];
    n241[1] = n241d[1];
  }
  if (n248r[0]) {
    n248[0] = 0;
    n248[1] = 0;
  }
  else if (n248e[0]) {
    n248[0] = n248d[0];
    n248[1] = n248d[1];
  }
  if (n255r[0]) {
    n255[0] = 0;
    n255[1] = 0;
  }
  else if (n255e[0]) {
    n255[0] = n255d[0];
    n255[1] = n255d[1];
  }
  if (n262r[0]) {
    n262[0] = 0;
    n262[1] = 0;
  }
  else if (n262e[0]) {
    n262[0] = n262d[0];
    n262[1] = n262d[1];
  }
  if (n269r[0]) {
    n269[0] = 0;
    n269[1] = 0;
  }
  else if (n269e[0]) {
    n269[0] = n269d[0];
    n269[1] = n269d[1];
  }
  if (n276r[0]) {
    n276[0] = 0;
    n276[1] = 0;
  }
  else if (n276e[0]) {
    n276[0] = n276d[0];
    n276[1] = n276d[1];
  }
  if (n284r[0]) {
    n284[0] = 0;
    n284[1] = 0;
    n284[2] = 0;
    n284[3] = 0;
  }
  else if (n284e[0]) {
    n284[0] = n284d[0];
    n284[1] = n284d[1];
    n284[2] = n284d[2];
    n284[3] = n284d[3];
  }
  if (n292r[0]) {
    n292[0] = 0;
    n292[1] = 0;
    n292[2] = 0;
    n292[3] = 0;
  }
  else if (n292e[0]) {
    n292[0] = n292d[0];
    n292[1] = n292d[1];
    n292[2] = n292d[2];
    n292[3] = n292d[3];
  }
  if (n300r[0]) {
    n300[0] = 0;
    n300[1] = 0;
    n300[2] = 0;
    n300[3] = 0;
  }
  else if (n300e[0]) {
    n300[0] = n300d[0];
    n300[1] = n300d[1];
    n300[2] = n300d[2];
    n300[3] = n300d[3];
  }
  if (n308r[0]) {
    n308[0] = 0;
    n308[1] = 0;
    n308[2] = 0;
    n308[3] = 0;
  }
  else if (n308e[0]) {
    n308[0] = n308d[0];
    n308[1] = n308d[1];
    n308[2] = n308d[2];
    n308[3] = n308d[3];
  }
  if (n316r[0]) {
    n316[0] = 0;
    n316[1] = 0;
    n316[2] = 0;
    n316[3] = 0;
  }
  else if (n316e[0]) {
    n316[0] = n316d[0];
    n316[1] = n316d[1];
    n316[2] = n316d[2];
    n316[3] = n316d[3];
  }
  if (n324r[0]) {
    n324[0] = 0;
    n324[1] = 0;
    n324[2] = 0;
    n324[3] = 0;
  }
  else if (n324e[0]) {
    n324[0] = n324d[0];
    n324[1] = n324d[1];
    n324[2] = n324d[2];
    n324[3] = n324d[3];
  }
  if (n332r[0]) {
    n332[0] = 0;
    n332[1] = 0;
    n332[2] = 0;
    n332[3] = 0;
  }
  else if (n332e[0]) {
    n332[0] = n332d[0];
    n332[1] = n332d[1];
    n332[2] = n332d[2];
    n332[3] = n332d[3];
  }
  if (n340r[0]) {
    n340[0] = 0;
    n340[1] = 0;
    n340[2] = 0;
    n340[3] = 0;
  }
  else if (n340e[0]) {
    n340[0] = n340d[0];
    n340[1] = n340d[1];
    n340[2] = n340d[2];
    n340[3] = n340d[3];
  }
  if (n348r[0]) {
    n348[0] = 0;
    n348[1] = 0;
    n348[2] = 0;
    n348[3] = 0;
  }
  else if (n348e[0]) {
    n348[0] = n348d[0];
    n348[1] = n348d[1];
    n348[2] = n348d[2];
    n348[3] = n348d[3];
  }
  if (n356r[0]) {
    n356[0] = 0;
    n356[1] = 0;
    n356[2] = 0;
    n356[3] = 0;
  }
  else if (n356e[0]) {
    n356[0] = n356d[0];
    n356[1] = n356d[1];
    n356[2] = n356d[2];
    n356[3] = n356d[3];
  }
  if (n364r[0]) {
    n364[0] = 0;
    n364[1] = 0;
    n364[2] = 0;
    n364[3] = 0;
  }
  else if (n364e[0]) {
    n364[0] = n364d[0];
    n364[1] = n364d[1];
    n364[2] = n364d[2];
    n364[3] = n364d[3];
  }
  if (n372r[0]) {
    n372[0] = 0;
    n372[1] = 0;
    n372[2] = 0;
    n372[3] = 0;
  }
  else if (n372e[0]) {
    n372[0] = n372d[0];
    n372[1] = n372d[1];
    n372[2] = n372d[2];
    n372[3] = n372d[3];
  }
  if (n380r[0]) {
    n380[0] = 0;
    n380[1] = 0;
    n380[2] = 0;
    n380[3] = 0;
  }
  else if (n380e[0]) {
    n380[0] = n380d[0];
    n380[1] = n380d[1];
    n380[2] = n380d[2];
    n380[3] = n380d[3];
  }
  if (n388r[0]) {
    n388[0] = 0;
    n388[1] = 0;
    n388[2] = 0;
    n388[3] = 0;
  }
  else if (n388e[0]) {
    n388[0] = n388d[0];
    n388[1] = n388d[1];
    n388[2] = n388d[2];
    n388[3] = n388d[3];
  }
  if (n396r[0]) {
    n396[0] = 0;
    n396[1] = 0;
    n396[2] = 0;
    n396[3] = 0;
  }
  else if (n396e[0]) {
    n396[0] = n396d[0];
    n396[1] = n396d[1];
    n396[2] = n396d[2];
    n396[3] = n396d[3];
  }
  if (n404r[0]) {
    n404[0] = 0;
    n404[1] = 0;
    n404[2] = 0;
    n404[3] = 0;
  }
  else if (n404e[0]) {
    n404[0] = n404d[0];
    n404[1] = n404d[1];
    n404[2] = n404d[2];
    n404[3] = n404d[3];
  }
  if (n412r[0]) {
    n412[0] = 0;
    n412[1] = 0;
    n412[2] = 0;
    n412[3] = 0;
  }
  else if (n412e[0]) {
    n412[0] = n412d[0];
    n412[1] = n412d[1];
    n412[2] = n412d[2];
    n412[3] = n412d[3];
  }
  if (n420r[0]) {
    n420[0] = 0;
    n420[1] = 0;
    n420[2] = 0;
    n420[3] = 0;
  }
  else if (n420e[0]) {
    n420[0] = n420d[0];
    n420[1] = n420d[1];
    n420[2] = n420d[2];
    n420[3] = n420d[3];
  }
  if (n428r[0]) {
    n428[0] = 0;
    n428[1] = 0;
    n428[2] = 0;
    n428[3] = 0;
  }
  else if (n428e[0]) {
    n428[0] = n428d[0];
    n428[1] = n428d[1];
    n428[2] = n428d[2];
    n428[3] = n428d[3];
  }
  if (n436r[0]) {
    n436[0] = 0;
    n436[1] = 0;
    n436[2] = 0;
    n436[3] = 0;
  }
  else if (n436e[0]) {
    n436[0] = n436d[0];
    n436[1] = n436d[1];
    n436[2] = n436d[2];
    n436[3] = n436d[3];
  }
  if (n444r[0]) {
    n444[0] = 0;
    n444[1] = 0;
    n444[2] = 0;
    n444[3] = 0;
  }
  else if (n444e[0]) {
    n444[0] = n444d[0];
    n444[1] = n444d[1];
    n444[2] = n444d[2];
    n444[3] = n444d[3];
  }
  if (n452r[0]) {
    n452[0] = 0;
    n452[1] = 0;
    n452[2] = 0;
    n452[3] = 0;
  }
  else if (n452e[0]) {
    n452[0] = n452d[0];
    n452[1] = n452d[1];
    n452[2] = n452d[2];
    n452[3] = n452d[3];
  }
  if (n460r[0]) {
    n460[0] = 0;
    n460[1] = 0;
    n460[2] = 0;
    n460[3] = 0;
  }
  else if (n460e[0]) {
    n460[0] = n460d[0];
    n460[1] = n460d[1];
    n460[2] = n460d[2];
    n460[3] = n460d[3];
  }
  if (n468r[0]) {
    n468[0] = 0;
    n468[1] = 0;
    n468[2] = 0;
    n468[3] = 0;
  }
  else if (n468e[0]) {
    n468[0] = n468d[0];
    n468[1] = n468d[1];
    n468[2] = n468d[2];
    n468[3] = n468d[3];
  }
  if (n476r[0]) {
    n476[0] = 0;
    n476[1] = 0;
    n476[2] = 0;
    n476[3] = 0;
  }
  else if (n476e[0]) {
    n476[0] = n476d[0];
    n476[1] = n476d[1];
    n476[2] = n476d[2];
    n476[3] = n476d[3];
  }
  if (n484r[0]) {
    n484[0] = 0;
    n484[1] = 0;
    n484[2] = 0;
    n484[3] = 0;
  }
  else if (n484e[0]) {
    n484[0] = n484d[0];
    n484[1] = n484d[1];
    n484[2] = n484d[2];
    n484[3] = n484d[3];
  }
  if (n492r[0]) {
    n492[0] = 0;
    n492[1] = 0;
    n492[2] = 0;
    n492[3] = 0;
  }
  else if (n492e[0]) {
    n492[0] = n492d[0];
    n492[1] = n492d[1];
    n492[2] = n492d[2];
    n492[3] = n492d[3];
  }
  if (n500r[0]) {
    n500[0] = 0;
    n500[1] = 0;
    n500[2] = 0;
    n500[3] = 0;
  }
  else if (n500e[0]) {
    n500[0] = n500d[0];
    n500[1] = n500d[1];
    n500[2] = n500d[2];
    n500[3] = n500d[3];
  }
  if (n508r[0]) {
    n508[0] = 0;
    n508[1] = 0;
    n508[2] = 0;
    n508[3] = 0;
  }
  else if (n508e[0]) {
    n508[0] = n508d[0];
    n508[1] = n508d[1];
    n508[2] = n508d[2];
    n508[3] = n508d[3];
  }
  if (n516r[0]) {
    n516[0] = 0;
    n516[1] = 0;
    n516[2] = 0;
    n516[3] = 0;
  }
  else if (n516e[0]) {
    n516[0] = n516d[0];
    n516[1] = n516d[1];
    n516[2] = n516d[2];
    n516[3] = n516d[3];
  }
  if (n524r[0]) {
    n524[0] = 0;
    n524[1] = 0;
    n524[2] = 0;
    n524[3] = 0;
  }
  else if (n524e[0]) {
    n524[0] = n524d[0];
    n524[1] = n524d[1];
    n524[2] = n524d[2];
    n524[3] = n524d[3];
  }
  if (n532r[0]) {
    n532[0] = 0;
    n532[1] = 0;
    n532[2] = 0;
    n532[3] = 0;
  }
  else if (n532e[0]) {
    n532[0] = n532d[0];
    n532[1] = n532d[1];
    n532[2] = n532d[2];
    n532[3] = n532d[3];
  }
  if (n540r[0]) {
    n540[0] = 0;
    n540[1] = 0;
    n540[2] = 0;
    n540[3] = 0;
  }
  else if (n540e[0]) {
    n540[0] = n540d[0];
    n540[1] = n540d[1];
    n540[2] = n540d[2];
    n540[3] = n540d[3];
  }
  if (n548r[0]) {
    n548[0] = 0;
    n548[1] = 0;
    n548[2] = 0;
    n548[3] = 0;
  }
  else if (n548e[0]) {
    n548[0] = n548d[0];
    n548[1] = n548d[1];
    n548[2] = n548d[2];
    n548[3] = n548d[3];
  }
  if (n560r[0]) {
    n560[0] = 0;
    n560[1] = 0;
    n560[2] = 0;
    n560[3] = 0;
    n560[4] = 0;
  }
  else if (n560e[0]) {
    n560[0] = n560d[0];
    n560[1] = n560d[1];
    n560[2] = n560d[2];
    n560[3] = n560d[3];
    n560[4] = n560d[4];
  }
  if (n572r[0]) {
    n572[0] = 0;
    n572[1] = 0;
    n572[2] = 0;
    n572[3] = 0;
    n572[4] = 0;
  }
  else if (n572e[0]) {
    n572[0] = n572d[0];
    n572[1] = n572d[1];
    n572[2] = n572d[2];
    n572[3] = n572d[3];
    n572[4] = n572d[4];
  }
  if (n584r[0]) {
    n584[0] = 0;
    n584[1] = 0;
    n584[2] = 0;
    n584[3] = 0;
    n584[4] = 0;
  }
  else if (n584e[0]) {
    n584[0] = n584d[0];
    n584[1] = n584d[1];
    n584[2] = n584d[2];
    n584[3] = n584d[3];
    n584[4] = n584d[4];
  }
  if (n596r[0]) {
    n596[0] = 0;
    n596[1] = 0;
    n596[2] = 0;
    n596[3] = 0;
    n596[4] = 0;
  }
  else if (n596e[0]) {
    n596[0] = n596d[0];
    n596[1] = n596d[1];
    n596[2] = n596d[2];
    n596[3] = n596d[3];
    n596[4] = n596d[4];
  }
  if (n608r[0]) {
    n608[0] = 0;
    n608[1] = 0;
    n608[2] = 0;
    n608[3] = 0;
    n608[4] = 0;
  }
  else if (n608e[0]) {
    n608[0] = n608d[0];
    n608[1] = n608d[1];
    n608[2] = n608d[2];
    n608[3] = n608d[3];
    n608[4] = n608d[4];
  }
  if (n620r[0]) {
    n620[0] = 0;
    n620[1] = 0;
    n620[2] = 0;
    n620[3] = 0;
    n620[4] = 0;
  }
  else if (n620e[0]) {
    n620[0] = n620d[0];
    n620[1] = n620d[1];
    n620[2] = n620d[2];
    n620[3] = n620d[3];
    n620[4] = n620d[4];
  }
  if (n632r[0]) {
    n632[0] = 0;
    n632[1] = 0;
    n632[2] = 0;
    n632[3] = 0;
    n632[4] = 0;
  }
  else if (n632e[0]) {
    n632[0] = n632d[0];
    n632[1] = n632d[1];
    n632[2] = n632d[2];
    n632[3] = n632d[3];
    n632[4] = n632d[4];
  }
  if (n644r[0]) {
    n644[0] = 0;
    n644[1] = 0;
    n644[2] = 0;
    n644[3] = 0;
    n644[4] = 0;
  }
  else if (n644e[0]) {
    n644[0] = n644d[0];
    n644[1] = n644d[1];
    n644[2] = n644d[2];
    n644[3] = n644d[3];
    n644[4] = n644d[4];
  }
  if (n656r[0]) {
    n656[0] = 0;
    n656[1] = 0;
    n656[2] = 0;
    n656[3] = 0;
    n656[4] = 0;
  }
  else if (n656e[0]) {
    n656[0] = n656d[0];
    n656[1] = n656d[1];
    n656[2] = n656d[2];
    n656[3] = n656d[3];
    n656[4] = n656d[4];
  }
  if (n668r[0]) {
    n668[0] = 0;
    n668[1] = 0;
    n668[2] = 0;
    n668[3] = 0;
    n668[4] = 0;
  }
  else if (n668e[0]) {
    n668[0] = n668d[0];
    n668[1] = n668d[1];
    n668[2] = n668d[2];
    n668[3] = n668d[3];
    n668[4] = n668d[4];
  }
  if (n680r[0]) {
    n680[0] = 0;
    n680[1] = 0;
    n680[2] = 0;
    n680[3] = 0;
    n680[4] = 0;
  }
  else if (n680e[0]) {
    n680[0] = n680d[0];
    n680[1] = n680d[1];
    n680[2] = n680d[2];
    n680[3] = n680d[3];
    n680[4] = n680d[4];
  }
  if (n692r[0]) {
    n692[0] = 0;
    n692[1] = 0;
    n692[2] = 0;
    n692[3] = 0;
    n692[4] = 0;
  }
  else if (n692e[0]) {
    n692[0] = n692d[0];
    n692[1] = n692d[1];
    n692[2] = n692d[2];
    n692[3] = n692d[3];
    n692[4] = n692d[4];
  }
  if (n704r[0]) {
    n704[0] = 0;
    n704[1] = 0;
    n704[2] = 0;
    n704[3] = 0;
    n704[4] = 0;
  }
  else if (n704e[0]) {
    n704[0] = n704d[0];
    n704[1] = n704d[1];
    n704[2] = n704d[2];
    n704[3] = n704d[3];
    n704[4] = n704d[4];
  }
  if (n716r[0]) {
    n716[0] = 0;
    n716[1] = 0;
    n716[2] = 0;
    n716[3] = 0;
    n716[4] = 0;
  }
  else if (n716e[0]) {
    n716[0] = n716d[0];
    n716[1] = n716d[1];
    n716[2] = n716d[2];
    n716[3] = n716d[3];
    n716[4] = n716d[4];
  }
  if (n728r[0]) {
    n728[0] = 0;
    n728[1] = 0;
    n728[2] = 0;
    n728[3] = 0;
    n728[4] = 0;
  }
  else if (n728e[0]) {
    n728[0] = n728d[0];
    n728[1] = n728d[1];
    n728[2] = n728d[2];
    n728[3] = n728d[3];
    n728[4] = n728d[4];
  }
  if (n740r[0]) {
    n740[0] = 0;
    n740[1] = 0;
    n740[2] = 0;
    n740[3] = 0;
    n740[4] = 0;
  }
  else if (n740e[0]) {
    n740[0] = n740d[0];
    n740[1] = n740d[1];
    n740[2] = n740d[2];
    n740[3] = n740d[3];
    n740[4] = n740d[4];
  }
  if (n752r[0]) {
    n752[0] = 0;
    n752[1] = 0;
    n752[2] = 0;
    n752[3] = 0;
    n752[4] = 0;
  }
  else if (n752e[0]) {
    n752[0] = n752d[0];
    n752[1] = n752d[1];
    n752[2] = n752d[2];
    n752[3] = n752d[3];
    n752[4] = n752d[4];
  }
  if (n764r[0]) {
    n764[0] = 0;
    n764[1] = 0;
    n764[2] = 0;
    n764[3] = 0;
    n764[4] = 0;
  }
  else if (n764e[0]) {
    n764[0] = n764d[0];
    n764[1] = n764d[1];
    n764[2] = n764d[2];
    n764[3] = n764d[3];
    n764[4] = n764d[4];
  }
  if (n776r[0]) {
    n776[0] = 0;
    n776[1] = 0;
    n776[2] = 0;
    n776[3] = 0;
    n776[4] = 0;
  }
  else if (n776e[0]) {
    n776[0] = n776d[0];
    n776[1] = n776d[1];
    n776[2] = n776d[2];
    n776[3] = n776d[3];
    n776[4] = n776d[4];
  }
  if (n788r[0]) {
    n788[0] = 0;
    n788[1] = 0;
    n788[2] = 0;
    n788[3] = 0;
    n788[4] = 0;
  }
  else if (n788e[0]) {
    n788[0] = n788d[0];
    n788[1] = n788d[1];
    n788[2] = n788d[2];
    n788[3] = n788d[3];
    n788[4] = n788d[4];
  }
  if (n800r[0]) {
    n800[0] = 0;
    n800[1] = 0;
    n800[2] = 0;
    n800[3] = 0;
    n800[4] = 0;
  }
  else if (n800e[0]) {
    n800[0] = n800d[0];
    n800[1] = n800d[1];
    n800[2] = n800d[2];
    n800[3] = n800d[3];
    n800[4] = n800d[4];
  }
  if (n812r[0]) {
    n812[0] = 0;
    n812[1] = 0;
    n812[2] = 0;
    n812[3] = 0;
    n812[4] = 0;
  }
  else if (n812e[0]) {
    n812[0] = n812d[0];
    n812[1] = n812d[1];
    n812[2] = n812d[2];
    n812[3] = n812d[3];
    n812[4] = n812d[4];
  }
  if (n824r[0]) {
    n824[0] = 0;
    n824[1] = 0;
    n824[2] = 0;
    n824[3] = 0;
    n824[4] = 0;
  }
  else if (n824e[0]) {
    n824[0] = n824d[0];
    n824[1] = n824d[1];
    n824[2] = n824d[2];
    n824[3] = n824d[3];
    n824[4] = n824d[4];
  }
  if (n836r[0]) {
    n836[0] = 0;
    n836[1] = 0;
    n836[2] = 0;
    n836[3] = 0;
    n836[4] = 0;
  }
  else if (n836e[0]) {
    n836[0] = n836d[0];
    n836[1] = n836d[1];
    n836[2] = n836d[2];
    n836[3] = n836d[3];
    n836[4] = n836d[4];
  }
  if (n848r[0]) {
    n848[0] = 0;
    n848[1] = 0;
    n848[2] = 0;
    n848[3] = 0;
    n848[4] = 0;
  }
  else if (n848e[0]) {
    n848[0] = n848d[0];
    n848[1] = n848d[1];
    n848[2] = n848d[2];
    n848[3] = n848d[3];
    n848[4] = n848d[4];
  }
  if (n857r[0]) {
    n857[0] = 0;
    n857[1] = 0;
    n857[2] = 0;
    n857[3] = 0;
    n857[4] = 0;
  }
  else if (n857e[0]) {
    n857[0] = n857d[0];
    n857[1] = n857d[1];
    n857[2] = n857d[2];
    n857[3] = n857d[3];
    n857[4] = n857d[4];
  }
  if (n869r[0]) {
    n869[0] = 0;
    n869[1] = 0;
    n869[2] = 0;
    n869[3] = 0;
    n869[4] = 0;
  }
  else if (n869e[0]) {
    n869[0] = n869d[0];
    n869[1] = n869d[1];
    n869[2] = n869d[2];
    n869[3] = n869d[3];
    n869[4] = n869d[4];
  }
  if (n881r[0]) {
    n881[0] = 0;
    n881[1] = 0;
    n881[2] = 0;
    n881[3] = 0;
    n881[4] = 0;
  }
  else if (n881e[0]) {
    n881[0] = n881d[0];
    n881[1] = n881d[1];
    n881[2] = n881d[2];
    n881[3] = n881d[3];
    n881[4] = n881d[4];
  }
  if (n893r[0]) {
    n893[0] = 0;
    n893[1] = 0;
    n893[2] = 0;
    n893[3] = 0;
    n893[4] = 0;
  }
  else if (n893e[0]) {
    n893[0] = n893d[0];
    n893[1] = n893d[1];
    n893[2] = n893d[2];
    n893[3] = n893d[3];
    n893[4] = n893d[4];
  }
  if (n905r[0]) {
    n905[0] = 0;
    n905[1] = 0;
    n905[2] = 0;
    n905[3] = 0;
    n905[4] = 0;
  }
  else if (n905e[0]) {
    n905[0] = n905d[0];
    n905[1] = n905d[1];
    n905[2] = n905d[2];
    n905[3] = n905d[3];
    n905[4] = n905d[4];
  }
  if (n914r[0]) {
    n914[0] = 0;
    n914[1] = 0;
    n914[2] = 0;
    n914[3] = 0;
    n914[4] = 0;
  }
  else if (n914e[0]) {
    n914[0] = n914d[0];
    n914[1] = n914d[1];
    n914[2] = n914d[2];
    n914[3] = n914d[3];
    n914[4] = n914d[4];
  }
  if (n926r[0]) {
    n926[0] = 0;
    n926[1] = 0;
    n926[2] = 0;
    n926[3] = 0;
    n926[4] = 0;
  }
  else if (n926e[0]) {
    n926[0] = n926d[0];
    n926[1] = n926d[1];
    n926[2] = n926d[2];
    n926[3] = n926d[3];
    n926[4] = n926d[4];
  }
  if (n938r[0]) {
    n938[0] = 0;
    n938[1] = 0;
    n938[2] = 0;
    n938[3] = 0;
    n938[4] = 0;
  }
  else if (n938e[0]) {
    n938[0] = n938d[0];
    n938[1] = n938d[1];
    n938[2] = n938d[2];
    n938[3] = n938d[3];
    n938[4] = n938d[4];
  }
  if (n947r[0]) {
    n947[0] = 0;
    n947[1] = 0;
    n947[2] = 0;
    n947[3] = 0;
    n947[4] = 0;
  }
  else if (n947e[0]) {
    n947[0] = n947d[0];
    n947[1] = n947d[1];
    n947[2] = n947d[2];
    n947[3] = n947d[3];
    n947[4] = n947d[4];
  }
  if (n959r[0]) {
    n959[0] = 0;
    n959[1] = 0;
    n959[2] = 0;
    n959[3] = 0;
    n959[4] = 0;
  }
  else if (n959e[0]) {
    n959[0] = n959d[0];
    n959[1] = n959d[1];
    n959[2] = n959d[2];
    n959[3] = n959d[3];
    n959[4] = n959d[4];
  }
  if (n968r[0]) {
    n968[0] = 0;
    n968[1] = 0;
    n968[2] = 0;
    n968[3] = 0;
    n968[4] = 0;
  }
  else if (n968e[0]) {
    n968[0] = n968d[0];
    n968[1] = n968d[1];
    n968[2] = n968d[2];
    n968[3] = n968d[3];
    n968[4] = n968d[4];
  }
  if (n980r[0]) {
    n980[0] = 0;
    n980[1] = 0;
    n980[2] = 0;
    n980[3] = 0;
    n980[4] = 0;
  }
  else if (n980e[0]) {
    n980[0] = n980d[0];
    n980[1] = n980d[1];
    n980[2] = n980d[2];
    n980[3] = n980d[3];
    n980[4] = n980d[4];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_reset_i[1];
static unsigned char sim_data_i[2];
static unsigned char sim_k0_i[2];
static unsigned char sim_k1_i[2];
static unsigned char sim_k2_i[2];
static unsigned char sim_k3_i[2];
static unsigned char sim_k4_i[2];
static unsigned char sim_k5_i[2];
static unsigned char sim_k6_i[2];
static unsigned char sim_k7_i[2];
static unsigned char sim_k8_i[2];
static unsigned char sim_k9_i[2];
static unsigned char sim_k10_i[2];
static unsigned char sim_k11_i[2];
static unsigned char sim_k12_i[2];
static unsigned char sim_k13_i[2];
static unsigned char sim_k14_i[2];
static unsigned char sim_k15_i[2];
static unsigned char sim_k16_i[2];
static unsigned char sim_k17_i[2];
static unsigned char sim_k18_i[2];
static unsigned char sim_k19_i[2];
static unsigned char sim_k20_i[2];
static unsigned char sim_k21_i[2];
static unsigned char sim_k22_i[2];
static unsigned char sim_k23_i[2];
static unsigned char sim_k24_i[2];
static unsigned char sim_k25_i[2];
static unsigned char sim_k26_i[2];
static unsigned char sim_k27_i[2];
static unsigned char sim_k28_i[2];
static unsigned char sim_k29_i[2];
static unsigned char sim_k30_i[2];
static unsigned char sim_k31_i[2];
static unsigned char sim_k32_i[2];
static unsigned char sim_k33_i[2];
static unsigned char sim_data_o[5];

void cf_fir_33_16_16_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_fir_33_16_16_init();
  sim_reset_i[0] = reset_i[0];
  sim_data_i[0] = data_i[0];
  sim_data_i[1] = data_i[1];
  sim_k0_i[0] = k0_i[0];
  sim_k0_i[1] = k0_i[1];
  sim_k1_i[0] = k1_i[0];
  sim_k1_i[1] = k1_i[1];
  sim_k2_i[0] = k2_i[0];
  sim_k2_i[1] = k2_i[1];
  sim_k3_i[0] = k3_i[0];
  sim_k3_i[1] = k3_i[1];
  sim_k4_i[0] = k4_i[0];
  sim_k4_i[1] = k4_i[1];
  sim_k5_i[0] = k5_i[0];
  sim_k5_i[1] = k5_i[1];
  sim_k6_i[0] = k6_i[0];
  sim_k6_i[1] = k6_i[1];
  sim_k7_i[0] = k7_i[0];
  sim_k7_i[1] = k7_i[1];
  sim_k8_i[0] = k8_i[0];
  sim_k8_i[1] = k8_i[1];
  sim_k9_i[0] = k9_i[0];
  sim_k9_i[1] = k9_i[1];
  sim_k10_i[0] = k10_i[0];
  sim_k10_i[1] = k10_i[1];
  sim_k11_i[0] = k11_i[0];
  sim_k11_i[1] = k11_i[1];
  sim_k12_i[0] = k12_i[0];
  sim_k12_i[1] = k12_i[1];
  sim_k13_i[0] = k13_i[0];
  sim_k13_i[1] = k13_i[1];
  sim_k14_i[0] = k14_i[0];
  sim_k14_i[1] = k14_i[1];
  sim_k15_i[0] = k15_i[0];
  sim_k15_i[1] = k15_i[1];
  sim_k16_i[0] = k16_i[0];
  sim_k16_i[1] = k16_i[1];
  sim_k17_i[0] = k17_i[0];
  sim_k17_i[1] = k17_i[1];
  sim_k18_i[0] = k18_i[0];
  sim_k18_i[1] = k18_i[1];
  sim_k19_i[0] = k19_i[0];
  sim_k19_i[1] = k19_i[1];
  sim_k20_i[0] = k20_i[0];
  sim_k20_i[1] = k20_i[1];
  sim_k21_i[0] = k21_i[0];
  sim_k21_i[1] = k21_i[1];
  sim_k22_i[0] = k22_i[0];
  sim_k22_i[1] = k22_i[1];
  sim_k23_i[0] = k23_i[0];
  sim_k23_i[1] = k23_i[1];
  sim_k24_i[0] = k24_i[0];
  sim_k24_i[1] = k24_i[1];
  sim_k25_i[0] = k25_i[0];
  sim_k25_i[1] = k25_i[1];
  sim_k26_i[0] = k26_i[0];
  sim_k26_i[1] = k26_i[1];
  sim_k27_i[0] = k27_i[0];
  sim_k27_i[1] = k27_i[1];
  sim_k28_i[0] = k28_i[0];
  sim_k28_i[1] = k28_i[1];
  sim_k29_i[0] = k29_i[0];
  sim_k29_i[1] = k29_i[1];
  sim_k30_i[0] = k30_i[0];
  sim_k30_i[1] = k30_i[1];
  sim_k31_i[0] = k31_i[0];
  sim_k31_i[1] = k31_i[1];
  sim_k32_i[0] = k32_i[0];
  sim_k32_i[1] = k32_i[1];
  sim_k33_i[0] = k33_i[0];
  sim_k33_i[1] = k33_i[1];
  sim_data_o[0] = data_o[0];
  sim_data_o[1] = data_o[1];
  sim_data_o[2] = data_o[2];
  sim_data_o[3] = data_o[3];
  sim_data_o[4] = data_o[4];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_fir_33_16_16 $end\n"
    "$var wire 1 ! reset_i $end\n"
    "$var wire 16 \" data_i $end\n"
    "$var wire 16 # k0_i $end\n"
    "$var wire 16 $ k1_i $end\n"
    "$var wire 16 %% k2_i $end\n"
    "$var wire 16 & k3_i $end\n"
    "$var wire 16 ' k4_i $end\n"
    "$var wire 16 ( k5_i $end\n"
    "$var wire 16 ) k6_i $end\n"
    "$var wire 16 * k7_i $end\n"
    "$var wire 16 + k8_i $end\n"
    "$var wire 16 , k9_i $end\n"
    "$var wire 16 - k10_i $end\n"
    "$var wire 16 . k11_i $end\n"
    "$var wire 16 / k12_i $end\n"
    "$var wire 16 0 k13_i $end\n"
    "$var wire 16 1 k14_i $end\n"
    "$var wire 16 2 k15_i $end\n"
    "$var wire 16 3 k16_i $end\n"
    "$var wire 16 4 k17_i $end\n"
    "$var wire 16 5 k18_i $end\n"
    "$var wire 16 6 k19_i $end\n"
    "$var wire 16 7 k20_i $end\n"
    "$var wire 16 8 k21_i $end\n"
    "$var wire 16 9 k22_i $end\n"
    "$var wire 16 : k23_i $end\n"
    "$var wire 16 ; k24_i $end\n"
    "$var wire 16 < k25_i $end\n"
    "$var wire 16 = k26_i $end\n"
    "$var wire 16 > k27_i $end\n"
    "$var wire 16 ? k28_i $end\n"
    "$var wire 16 @ k29_i $end\n"
    "$var wire 16 A k30_i $end\n"
    "$var wire 16 B k31_i $end\n"
    "$var wire 16 C k32_i $end\n"
    "$var wire 16 D k33_i $end\n"
    "$var wire 38 E data_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
        else if (bit & data_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " \"\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
        else if (bit & k0_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
        else if (bit & k1_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
        else if (bit & k2_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
        else if (bit & k3_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
        else if (bit & k4_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
        else if (bit & k5_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
        else if (bit & k6_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
        else if (bit & k7_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " *\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
        else if (bit & k8_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " +\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
        else if (bit & k9_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ,\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
        else if (bit & k10_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " -\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
        else if (bit & k11_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " .\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
        else if (bit & k12_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " /\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k13_i[byte]) ? "1" : "0");
        else if (bit & k13_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 0\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k14_i[byte]) ? "1" : "0");
        else if (bit & k14_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 1\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k15_i[byte]) ? "1" : "0");
        else if (bit & k15_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 2\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k16_i[byte]) ? "1" : "0");
        else if (bit & k16_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 3\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k17_i[byte]) ? "1" : "0");
        else if (bit & k17_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 4\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k18_i[byte]) ? "1" : "0");
        else if (bit & k18_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 5\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k19_i[byte]) ? "1" : "0");
        else if (bit & k19_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 6\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k20_i[byte]) ? "1" : "0");
        else if (bit & k20_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 7\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k21_i[byte]) ? "1" : "0");
        else if (bit & k21_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 8\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k22_i[byte]) ? "1" : "0");
        else if (bit & k22_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " 9\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k23_i[byte]) ? "1" : "0");
        else if (bit & k23_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " :\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k24_i[byte]) ? "1" : "0");
        else if (bit & k24_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ;\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k25_i[byte]) ? "1" : "0");
        else if (bit & k25_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " <\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k26_i[byte]) ? "1" : "0");
        else if (bit & k26_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " =\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k27_i[byte]) ? "1" : "0");
        else if (bit & k27_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " >\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k28_i[byte]) ? "1" : "0");
        else if (bit & k28_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " ?\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k29_i[byte]) ? "1" : "0");
        else if (bit & k29_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " @\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k30_i[byte]) ? "1" : "0");
        else if (bit & k30_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " A\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k31_i[byte]) ? "1" : "0");
        else if (bit & k31_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " B\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k32_i[byte]) ? "1" : "0");
        else if (bit & k32_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " C\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & k33_i[byte]) ? "1" : "0");
        else if (bit & k33_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " D\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 4; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
        else if (bit & data_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " E\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_fir_33_16_16_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_fir_33_16_16_sim_sample() {
  int changed = 0;
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1!\n" : "0!\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_data_i[1] != data_i[1] || sim_data_i[0] != data_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_i[byte]) ? "1" : "0");
          else if (bit & data_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " \"\n");
    }
    sim_data_i[0] = data_i[0];
    sim_data_i[1] = data_i[1];
  }
  if (sim_k0_i[1] != k0_i[1] || sim_k0_i[0] != k0_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k0_i[byte]) ? "1" : "0");
          else if (bit & k0_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_k0_i[0] = k0_i[0];
    sim_k0_i[1] = k0_i[1];
  }
  if (sim_k1_i[1] != k1_i[1] || sim_k1_i[0] != k1_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k1_i[byte]) ? "1" : "0");
          else if (bit & k1_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_k1_i[0] = k1_i[0];
    sim_k1_i[1] = k1_i[1];
  }
  if (sim_k2_i[1] != k2_i[1] || sim_k2_i[0] != k2_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k2_i[byte]) ? "1" : "0");
          else if (bit & k2_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_k2_i[0] = k2_i[0];
    sim_k2_i[1] = k2_i[1];
  }
  if (sim_k3_i[1] != k3_i[1] || sim_k3_i[0] != k3_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k3_i[byte]) ? "1" : "0");
          else if (bit & k3_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_k3_i[0] = k3_i[0];
    sim_k3_i[1] = k3_i[1];
  }
  if (sim_k4_i[1] != k4_i[1] || sim_k4_i[0] != k4_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k4_i[byte]) ? "1" : "0");
          else if (bit & k4_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_k4_i[0] = k4_i[0];
    sim_k4_i[1] = k4_i[1];
  }
  if (sim_k5_i[1] != k5_i[1] || sim_k5_i[0] != k5_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k5_i[byte]) ? "1" : "0");
          else if (bit & k5_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_k5_i[0] = k5_i[0];
    sim_k5_i[1] = k5_i[1];
  }
  if (sim_k6_i[1] != k6_i[1] || sim_k6_i[0] != k6_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k6_i[byte]) ? "1" : "0");
          else if (bit & k6_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_k6_i[0] = k6_i[0];
    sim_k6_i[1] = k6_i[1];
  }
  if (sim_k7_i[1] != k7_i[1] || sim_k7_i[0] != k7_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k7_i[byte]) ? "1" : "0");
          else if (bit & k7_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " *\n");
    }
    sim_k7_i[0] = k7_i[0];
    sim_k7_i[1] = k7_i[1];
  }
  if (sim_k8_i[1] != k8_i[1] || sim_k8_i[0] != k8_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k8_i[byte]) ? "1" : "0");
          else if (bit & k8_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " +\n");
    }
    sim_k8_i[0] = k8_i[0];
    sim_k8_i[1] = k8_i[1];
  }
  if (sim_k9_i[1] != k9_i[1] || sim_k9_i[0] != k9_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k9_i[byte]) ? "1" : "0");
          else if (bit & k9_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ,\n");
    }
    sim_k9_i[0] = k9_i[0];
    sim_k9_i[1] = k9_i[1];
  }
  if (sim_k10_i[1] != k10_i[1] || sim_k10_i[0] != k10_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k10_i[byte]) ? "1" : "0");
          else if (bit & k10_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " -\n");
    }
    sim_k10_i[0] = k10_i[0];
    sim_k10_i[1] = k10_i[1];
  }
  if (sim_k11_i[1] != k11_i[1] || sim_k11_i[0] != k11_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k11_i[byte]) ? "1" : "0");
          else if (bit & k11_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " .\n");
    }
    sim_k11_i[0] = k11_i[0];
    sim_k11_i[1] = k11_i[1];
  }
  if (sim_k12_i[1] != k12_i[1] || sim_k12_i[0] != k12_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k12_i[byte]) ? "1" : "0");
          else if (bit & k12_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " /\n");
    }
    sim_k12_i[0] = k12_i[0];
    sim_k12_i[1] = k12_i[1];
  }
  if (sim_k13_i[1] != k13_i[1] || sim_k13_i[0] != k13_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k13_i[byte]) ? "1" : "0");
          else if (bit & k13_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 0\n");
    }
    sim_k13_i[0] = k13_i[0];
    sim_k13_i[1] = k13_i[1];
  }
  if (sim_k14_i[1] != k14_i[1] || sim_k14_i[0] != k14_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k14_i[byte]) ? "1" : "0");
          else if (bit & k14_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 1\n");
    }
    sim_k14_i[0] = k14_i[0];
    sim_k14_i[1] = k14_i[1];
  }
  if (sim_k15_i[1] != k15_i[1] || sim_k15_i[0] != k15_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k15_i[byte]) ? "1" : "0");
          else if (bit & k15_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 2\n");
    }
    sim_k15_i[0] = k15_i[0];
    sim_k15_i[1] = k15_i[1];
  }
  if (sim_k16_i[1] != k16_i[1] || sim_k16_i[0] != k16_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k16_i[byte]) ? "1" : "0");
          else if (bit & k16_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 3\n");
    }
    sim_k16_i[0] = k16_i[0];
    sim_k16_i[1] = k16_i[1];
  }
  if (sim_k17_i[1] != k17_i[1] || sim_k17_i[0] != k17_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k17_i[byte]) ? "1" : "0");
          else if (bit & k17_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 4\n");
    }
    sim_k17_i[0] = k17_i[0];
    sim_k17_i[1] = k17_i[1];
  }
  if (sim_k18_i[1] != k18_i[1] || sim_k18_i[0] != k18_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k18_i[byte]) ? "1" : "0");
          else if (bit & k18_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 5\n");
    }
    sim_k18_i[0] = k18_i[0];
    sim_k18_i[1] = k18_i[1];
  }
  if (sim_k19_i[1] != k19_i[1] || sim_k19_i[0] != k19_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k19_i[byte]) ? "1" : "0");
          else if (bit & k19_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 6\n");
    }
    sim_k19_i[0] = k19_i[0];
    sim_k19_i[1] = k19_i[1];
  }
  if (sim_k20_i[1] != k20_i[1] || sim_k20_i[0] != k20_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k20_i[byte]) ? "1" : "0");
          else if (bit & k20_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 7\n");
    }
    sim_k20_i[0] = k20_i[0];
    sim_k20_i[1] = k20_i[1];
  }
  if (sim_k21_i[1] != k21_i[1] || sim_k21_i[0] != k21_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k21_i[byte]) ? "1" : "0");
          else if (bit & k21_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 8\n");
    }
    sim_k21_i[0] = k21_i[0];
    sim_k21_i[1] = k21_i[1];
  }
  if (sim_k22_i[1] != k22_i[1] || sim_k22_i[0] != k22_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k22_i[byte]) ? "1" : "0");
          else if (bit & k22_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " 9\n");
    }
    sim_k22_i[0] = k22_i[0];
    sim_k22_i[1] = k22_i[1];
  }
  if (sim_k23_i[1] != k23_i[1] || sim_k23_i[0] != k23_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k23_i[byte]) ? "1" : "0");
          else if (bit & k23_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " :\n");
    }
    sim_k23_i[0] = k23_i[0];
    sim_k23_i[1] = k23_i[1];
  }
  if (sim_k24_i[1] != k24_i[1] || sim_k24_i[0] != k24_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k24_i[byte]) ? "1" : "0");
          else if (bit & k24_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ;\n");
    }
    sim_k24_i[0] = k24_i[0];
    sim_k24_i[1] = k24_i[1];
  }
  if (sim_k25_i[1] != k25_i[1] || sim_k25_i[0] != k25_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k25_i[byte]) ? "1" : "0");
          else if (bit & k25_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " <\n");
    }
    sim_k25_i[0] = k25_i[0];
    sim_k25_i[1] = k25_i[1];
  }
  if (sim_k26_i[1] != k26_i[1] || sim_k26_i[0] != k26_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k26_i[byte]) ? "1" : "0");
          else if (bit & k26_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " =\n");
    }
    sim_k26_i[0] = k26_i[0];
    sim_k26_i[1] = k26_i[1];
  }
  if (sim_k27_i[1] != k27_i[1] || sim_k27_i[0] != k27_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k27_i[byte]) ? "1" : "0");
          else if (bit & k27_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " >\n");
    }
    sim_k27_i[0] = k27_i[0];
    sim_k27_i[1] = k27_i[1];
  }
  if (sim_k28_i[1] != k28_i[1] || sim_k28_i[0] != k28_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k28_i[byte]) ? "1" : "0");
          else if (bit & k28_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " ?\n");
    }
    sim_k28_i[0] = k28_i[0];
    sim_k28_i[1] = k28_i[1];
  }
  if (sim_k29_i[1] != k29_i[1] || sim_k29_i[0] != k29_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k29_i[byte]) ? "1" : "0");
          else if (bit & k29_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " @\n");
    }
    sim_k29_i[0] = k29_i[0];
    sim_k29_i[1] = k29_i[1];
  }
  if (sim_k30_i[1] != k30_i[1] || sim_k30_i[0] != k30_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k30_i[byte]) ? "1" : "0");
          else if (bit & k30_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " A\n");
    }
    sim_k30_i[0] = k30_i[0];
    sim_k30_i[1] = k30_i[1];
  }
  if (sim_k31_i[1] != k31_i[1] || sim_k31_i[0] != k31_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k31_i[byte]) ? "1" : "0");
          else if (bit & k31_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " B\n");
    }
    sim_k31_i[0] = k31_i[0];
    sim_k31_i[1] = k31_i[1];
  }
  if (sim_k32_i[1] != k32_i[1] || sim_k32_i[0] != k32_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k32_i[byte]) ? "1" : "0");
          else if (bit & k32_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " C\n");
    }
    sim_k32_i[0] = k32_i[0];
    sim_k32_i[1] = k32_i[1];
  }
  if (sim_k33_i[1] != k33_i[1] || sim_k33_i[0] != k33_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & k33_i[byte]) ? "1" : "0");
          else if (bit & k33_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " D\n");
    }
    sim_k33_i[0] = k33_i[0];
    sim_k33_i[1] = k33_i[1];
  }
  if (sim_data_o[4] != data_o[4] || sim_data_o[3] != data_o[3] || sim_data_o[2] != data_o[2] || sim_data_o[1] != data_o[1] || sim_data_o[0] != data_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 4; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & data_o[byte]) ? "1" : "0");
          else if (bit & data_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " E\n");
    }
    sim_data_o[0] = data_o[0];
    sim_data_o[1] = data_o[1];
    sim_data_o[2] = data_o[2];
    sim_data_o[3] = data_o[3];
    sim_data_o[4] = data_o[4];
  }
  sim_count++;
}

